.result {
  output: 1dpi;
  output: 4.2;
  output: 4.2dpi;
  output: 2.54dpi;
  output: 1.65354;
  output: 4.2dpcm;
  output: 96dpi;
  output: 0.04375;
  output: 4.2dppx;
  output: 0.3937dpcm;
  output: 10.668;
  output: 4.2dpi;
  output: 1dpcm;
  output: 4.2;
  output: 4.2dpcm;
  output: 37.79528dpcm;
  output: 0.11113;
  output: 4.2dppx;
  output: 0.01042dppx;
  output: 403.2;
  output: 4.2dpi;
  output: 0.02646dppx;
  output: 158.74016;
  output: 4.2dpcm;
  output: 1dppx;
  output: 4.2;
  output: 4.2dppx;
}
