body {
  a: selector-append(".foo", ".bar", ".baz");
  b: selector-append(".a .foo", ".b .bar");
  c: selector-append(".foo", "-suffix");
  d: selector-append('.foo', '.bar, -suffix');
  e: selector-append('.foo', '--suffix');
  f: selector-append('.foo', '.bar, --suffix');
}