// @charset "UTF-8";

@mixin background-image-retina($file, $type, $width, $height) {
  background-image: unquote(image-url("#{$file}.#{$type}", true));
  hey: length(a b c d);
  ho: unquote("hello");
  hee: unquote(unit(10fudge));

  @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
    & {
      background-image: image-url("#{$file}@2x.#{$type}");
      -webkit-background-size: $width $height;
    }
  }
}

$x: foo;
$y: bar;

div {
  @include background-image-retina(test, png, 100px, 300px);
  fudge: walnut;
}

span {
  blah: "#{$x} #{$y}";
  bleh: image-url("#{$x} #{$y}");
}


@mixin foo($x, $y) {
  foo-x: $x;
  foo-y: $y;
}

div {
  @include foo(1, 2);
  @include foo($y: 2, $x: 1);
}

@mixin bar($x, $y: default) {
  bar-x: $x;
  bar-y: $y;
}

div {
  @include bar(1, 2);
  @include bar(1);
  @include bar($x: n1, $y: n2);
  @include bar($x: n1);
  blah: unquote("hello");
}