.color-functions {
    $color: red;
    hue: hue($color);
    hue-type: type-of(hue($color));
    hue-unit: unit(hue($color));
    hue-comparable: comparable(hue($color), hue($color));
	test-1: comparable(lightness(red), 1%);
	test-2: comparable(saturation(red), 1%);
}