foo {
  // c-256: adjust-color(black,$red:-256);
  c-255: adjust-color(black,$red:-255);
  c-254: adjust-color(black,$red:-254);
  c-253: adjust-color(black,$red:-253);
  c-252: adjust-color(black,$red:-252);
  c-251: adjust-color(black,$red:-251);
  c-250: adjust-color(black,$red:-250);
  c-249: adjust-color(black,$red:-249);
  c-248: adjust-color(black,$red:-248);
  c-247: adjust-color(black,$red:-247);
  c-246: adjust-color(black,$red:-246);
  c-245: adjust-color(black,$red:-245);
  c-244: adjust-color(black,$red:-244);
  c-243: adjust-color(black,$red:-243);
  c-242: adjust-color(black,$red:-242);
  c-241: adjust-color(black,$red:-241);
  c-240: adjust-color(black,$red:-240);
  c-239: adjust-color(black,$red:-239);
  c-238: adjust-color(black,$red:-238);
  c-237: adjust-color(black,$red:-237);
  c-236: adjust-color(black,$red:-236);
  c-235: adjust-color(black,$red:-235);
  c-234: adjust-color(black,$red:-234);
  c-233: adjust-color(black,$red:-233);
  c-232: adjust-color(black,$red:-232);
  c-231: adjust-color(black,$red:-231);
  c-230: adjust-color(black,$red:-230);
  c-229: adjust-color(black,$red:-229);
  c-228: adjust-color(black,$red:-228);
  c-227: adjust-color(black,$red:-227);
  c-226: adjust-color(black,$red:-226);
  c-225: adjust-color(black,$red:-225);
  c-224: adjust-color(black,$red:-224);
  c-223: adjust-color(black,$red:-223);
  c-222: adjust-color(black,$red:-222);
  c-221: adjust-color(black,$red:-221);
  c-220: adjust-color(black,$red:-220);
  c-219: adjust-color(black,$red:-219);
  c-218: adjust-color(black,$red:-218);
  c-217: adjust-color(black,$red:-217);
  c-216: adjust-color(black,$red:-216);
  c-215: adjust-color(black,$red:-215);
  c-214: adjust-color(black,$red:-214);
  c-213: adjust-color(black,$red:-213);
  c-212: adjust-color(black,$red:-212);
  c-211: adjust-color(black,$red:-211);
  c-210: adjust-color(black,$red:-210);
  c-209: adjust-color(black,$red:-209);
  c-208: adjust-color(black,$red:-208);
  c-207: adjust-color(black,$red:-207);
  c-206: adjust-color(black,$red:-206);
  c-205: adjust-color(black,$red:-205);
  c-204: adjust-color(black,$red:-204);
  c-203: adjust-color(black,$red:-203);
  c-202: adjust-color(black,$red:-202);
  c-201: adjust-color(black,$red:-201);
  c-200: adjust-color(black,$red:-200);
  c-199: adjust-color(black,$red:-199);
  c-198: adjust-color(black,$red:-198);
  c-197: adjust-color(black,$red:-197);
  c-196: adjust-color(black,$red:-196);
  c-195: adjust-color(black,$red:-195);
  c-194: adjust-color(black,$red:-194);
  c-193: adjust-color(black,$red:-193);
  c-192: adjust-color(black,$red:-192);
  c-191: adjust-color(black,$red:-191);
  c-190: adjust-color(black,$red:-190);
  c-189: adjust-color(black,$red:-189);
  c-188: adjust-color(black,$red:-188);
  c-187: adjust-color(black,$red:-187);
  c-186: adjust-color(black,$red:-186);
  c-185: adjust-color(black,$red:-185);
  c-184: adjust-color(black,$red:-184);
  c-183: adjust-color(black,$red:-183);
  c-182: adjust-color(black,$red:-182);
  c-181: adjust-color(black,$red:-181);
  c-180: adjust-color(black,$red:-180);
  c-179: adjust-color(black,$red:-179);
  c-178: adjust-color(black,$red:-178);
  c-177: adjust-color(black,$red:-177);
  c-176: adjust-color(black,$red:-176);
  c-175: adjust-color(black,$red:-175);
  c-174: adjust-color(black,$red:-174);
  c-173: adjust-color(black,$red:-173);
  c-172: adjust-color(black,$red:-172);
  c-171: adjust-color(black,$red:-171);
  c-170: adjust-color(black,$red:-170);
  c-169: adjust-color(black,$red:-169);
  c-168: adjust-color(black,$red:-168);
  c-167: adjust-color(black,$red:-167);
  c-166: adjust-color(black,$red:-166);
  c-165: adjust-color(black,$red:-165);
  c-164: adjust-color(black,$red:-164);
  c-163: adjust-color(black,$red:-163);
  c-162: adjust-color(black,$red:-162);
  c-161: adjust-color(black,$red:-161);
  c-160: adjust-color(black,$red:-160);
  c-159: adjust-color(black,$red:-159);
  c-158: adjust-color(black,$red:-158);
  c-157: adjust-color(black,$red:-157);
  c-156: adjust-color(black,$red:-156);
  c-155: adjust-color(black,$red:-155);
  c-154: adjust-color(black,$red:-154);
  c-153: adjust-color(black,$red:-153);
  c-152: adjust-color(black,$red:-152);
  c-151: adjust-color(black,$red:-151);
  c-150: adjust-color(black,$red:-150);
  c-149: adjust-color(black,$red:-149);
  c-148: adjust-color(black,$red:-148);
  c-147: adjust-color(black,$red:-147);
  c-146: adjust-color(black,$red:-146);
  c-145: adjust-color(black,$red:-145);
  c-144: adjust-color(black,$red:-144);
  c-143: adjust-color(black,$red:-143);
  c-142: adjust-color(black,$red:-142);
  c-141: adjust-color(black,$red:-141);
  c-140: adjust-color(black,$red:-140);
  c-139: adjust-color(black,$red:-139);
  c-138: adjust-color(black,$red:-138);
  c-137: adjust-color(black,$red:-137);
  c-136: adjust-color(black,$red:-136);
  c-135: adjust-color(black,$red:-135);
  c-134: adjust-color(black,$red:-134);
  c-133: adjust-color(black,$red:-133);
  c-132: adjust-color(black,$red:-132);
  c-131: adjust-color(black,$red:-131);
  c-130: adjust-color(black,$red:-130);
  c-129: adjust-color(black,$red:-129);
  c-128: adjust-color(black,$red:-128);
  c-127: adjust-color(black,$red:-127);
  c-126: adjust-color(black,$red:-126);
  c-125: adjust-color(black,$red:-125);
  c-124: adjust-color(black,$red:-124);
  c-123: adjust-color(black,$red:-123);
  c-122: adjust-color(black,$red:-122);
  c-121: adjust-color(black,$red:-121);
  c-120: adjust-color(black,$red:-120);
  c-119: adjust-color(black,$red:-119);
  c-118: adjust-color(black,$red:-118);
  c-117: adjust-color(black,$red:-117);
  c-116: adjust-color(black,$red:-116);
  c-115: adjust-color(black,$red:-115);
  c-114: adjust-color(black,$red:-114);
  c-113: adjust-color(black,$red:-113);
  c-112: adjust-color(black,$red:-112);
  c-111: adjust-color(black,$red:-111);
  c-110: adjust-color(black,$red:-110);
  c-109: adjust-color(black,$red:-109);
  c-108: adjust-color(black,$red:-108);
  c-107: adjust-color(black,$red:-107);
  c-106: adjust-color(black,$red:-106);
  c-105: adjust-color(black,$red:-105);
  c-104: adjust-color(black,$red:-104);
  c-103: adjust-color(black,$red:-103);
  c-102: adjust-color(black,$red:-102);
  c-101: adjust-color(black,$red:-101);
  c-100: adjust-color(black,$red:-100);
  c-99: adjust-color(black,$red:-99);
  c-98: adjust-color(black,$red:-98);
  c-97: adjust-color(black,$red:-97);
  c-96: adjust-color(black,$red:-96);
  c-95: adjust-color(black,$red:-95);
  c-94: adjust-color(black,$red:-94);
  c-93: adjust-color(black,$red:-93);
  c-92: adjust-color(black,$red:-92);
  c-91: adjust-color(black,$red:-91);
  c-90: adjust-color(black,$red:-90);
  c-89: adjust-color(black,$red:-89);
  c-88: adjust-color(black,$red:-88);
  c-87: adjust-color(black,$red:-87);
  c-86: adjust-color(black,$red:-86);
  c-85: adjust-color(black,$red:-85);
  c-84: adjust-color(black,$red:-84);
  c-83: adjust-color(black,$red:-83);
  c-82: adjust-color(black,$red:-82);
  c-81: adjust-color(black,$red:-81);
  c-80: adjust-color(black,$red:-80);
  c-79: adjust-color(black,$red:-79);
  c-78: adjust-color(black,$red:-78);
  c-77: adjust-color(black,$red:-77);
  c-76: adjust-color(black,$red:-76);
  c-75: adjust-color(black,$red:-75);
  c-74: adjust-color(black,$red:-74);
  c-73: adjust-color(black,$red:-73);
  c-72: adjust-color(black,$red:-72);
  c-71: adjust-color(black,$red:-71);
  c-70: adjust-color(black,$red:-70);
  c-69: adjust-color(black,$red:-69);
  c-68: adjust-color(black,$red:-68);
  c-67: adjust-color(black,$red:-67);
  c-66: adjust-color(black,$red:-66);
  c-65: adjust-color(black,$red:-65);
  c-64: adjust-color(black,$red:-64);
  c-63: adjust-color(black,$red:-63);
  c-62: adjust-color(black,$red:-62);
  c-61: adjust-color(black,$red:-61);
  c-60: adjust-color(black,$red:-60);
  c-59: adjust-color(black,$red:-59);
  c-58: adjust-color(black,$red:-58);
  c-57: adjust-color(black,$red:-57);
  c-56: adjust-color(black,$red:-56);
  c-55: adjust-color(black,$red:-55);
  c-54: adjust-color(black,$red:-54);
  c-53: adjust-color(black,$red:-53);
  c-52: adjust-color(black,$red:-52);
  c-51: adjust-color(black,$red:-51);
  c-50: adjust-color(black,$red:-50);
  c-49: adjust-color(black,$red:-49);
  c-48: adjust-color(black,$red:-48);
  c-47: adjust-color(black,$red:-47);
  c-46: adjust-color(black,$red:-46);
  c-45: adjust-color(black,$red:-45);
  c-44: adjust-color(black,$red:-44);
  c-43: adjust-color(black,$red:-43);
  c-42: adjust-color(black,$red:-42);
  c-41: adjust-color(black,$red:-41);
  c-40: adjust-color(black,$red:-40);
  c-39: adjust-color(black,$red:-39);
  c-38: adjust-color(black,$red:-38);
  c-37: adjust-color(black,$red:-37);
  c-36: adjust-color(black,$red:-36);
  c-35: adjust-color(black,$red:-35);
  c-34: adjust-color(black,$red:-34);
  c-33: adjust-color(black,$red:-33);
  c-32: adjust-color(black,$red:-32);
  c-31: adjust-color(black,$red:-31);
  c-30: adjust-color(black,$red:-30);
  c-29: adjust-color(black,$red:-29);
  c-28: adjust-color(black,$red:-28);
  c-27: adjust-color(black,$red:-27);
  c-26: adjust-color(black,$red:-26);
  c-25: adjust-color(black,$red:-25);
  c-24: adjust-color(black,$red:-24);
  c-23: adjust-color(black,$red:-23);
  c-22: adjust-color(black,$red:-22);
  c-21: adjust-color(black,$red:-21);
  c-20: adjust-color(black,$red:-20);
  c-19: adjust-color(black,$red:-19);
  c-18: adjust-color(black,$red:-18);
  c-17: adjust-color(black,$red:-17);
  c-16: adjust-color(black,$red:-16);
  c-15: adjust-color(black,$red:-15);
  c-14: adjust-color(black,$red:-14);
  c-13: adjust-color(black,$red:-13);
  c-12: adjust-color(black,$red:-12);
  c-11: adjust-color(black,$red:-11);
  c-10: adjust-color(black,$red:-10);
  c-9: adjust-color(black,$red:-9);
  c-8: adjust-color(black,$red:-8);
  c-7: adjust-color(black,$red:-7);
  c-6: adjust-color(black,$red:-6);
  c-5: adjust-color(black,$red:-5);
  c-4: adjust-color(black,$red:-4);
  c-3: adjust-color(black,$red:-3);
  c-2: adjust-color(black,$red:-2);
  c-1: adjust-color(black,$red:-1);
  c0: adjust-color(black,$red:0);
  c1: adjust-color(black,$red:1);
  c2: adjust-color(black,$red:2);
  c3: adjust-color(black,$red:3);
  c4: adjust-color(black,$red:4);
  c5: adjust-color(black,$red:5);
  c6: adjust-color(black,$red:6);
  c7: adjust-color(black,$red:7);
  c8: adjust-color(black,$red:8);
  c9: adjust-color(black,$red:9);
  c10: adjust-color(black,$red:10);
  c11: adjust-color(black,$red:11);
  c12: adjust-color(black,$red:12);
  c13: adjust-color(black,$red:13);
  c14: adjust-color(black,$red:14);
  c15: adjust-color(black,$red:15);
  c16: adjust-color(black,$red:16);
  c17: adjust-color(black,$red:17);
  c18: adjust-color(black,$red:18);
  c19: adjust-color(black,$red:19);
  c20: adjust-color(black,$red:20);
  c21: adjust-color(black,$red:21);
  c22: adjust-color(black,$red:22);
  c23: adjust-color(black,$red:23);
  c24: adjust-color(black,$red:24);
  c25: adjust-color(black,$red:25);
  c26: adjust-color(black,$red:26);
  c27: adjust-color(black,$red:27);
  c28: adjust-color(black,$red:28);
  c29: adjust-color(black,$red:29);
  c30: adjust-color(black,$red:30);
  c31: adjust-color(black,$red:31);
  c32: adjust-color(black,$red:32);
  c33: adjust-color(black,$red:33);
  c34: adjust-color(black,$red:34);
  c35: adjust-color(black,$red:35);
  c36: adjust-color(black,$red:36);
  c37: adjust-color(black,$red:37);
  c38: adjust-color(black,$red:38);
  c39: adjust-color(black,$red:39);
  c40: adjust-color(black,$red:40);
  c41: adjust-color(black,$red:41);
  c42: adjust-color(black,$red:42);
  c43: adjust-color(black,$red:43);
  c44: adjust-color(black,$red:44);
  c45: adjust-color(black,$red:45);
  c46: adjust-color(black,$red:46);
  c47: adjust-color(black,$red:47);
  c48: adjust-color(black,$red:48);
  c49: adjust-color(black,$red:49);
  c50: adjust-color(black,$red:50);
  c51: adjust-color(black,$red:51);
  c52: adjust-color(black,$red:52);
  c53: adjust-color(black,$red:53);
  c54: adjust-color(black,$red:54);
  c55: adjust-color(black,$red:55);
  c56: adjust-color(black,$red:56);
  c57: adjust-color(black,$red:57);
  c58: adjust-color(black,$red:58);
  c59: adjust-color(black,$red:59);
  c60: adjust-color(black,$red:60);
  c61: adjust-color(black,$red:61);
  c62: adjust-color(black,$red:62);
  c63: adjust-color(black,$red:63);
  c64: adjust-color(black,$red:64);
  c65: adjust-color(black,$red:65);
  c66: adjust-color(black,$red:66);
  c67: adjust-color(black,$red:67);
  c68: adjust-color(black,$red:68);
  c69: adjust-color(black,$red:69);
  c70: adjust-color(black,$red:70);
  c71: adjust-color(black,$red:71);
  c72: adjust-color(black,$red:72);
  c73: adjust-color(black,$red:73);
  c74: adjust-color(black,$red:74);
  c75: adjust-color(black,$red:75);
  c76: adjust-color(black,$red:76);
  c77: adjust-color(black,$red:77);
  c78: adjust-color(black,$red:78);
  c79: adjust-color(black,$red:79);
  c80: adjust-color(black,$red:80);
  c81: adjust-color(black,$red:81);
  c82: adjust-color(black,$red:82);
  c83: adjust-color(black,$red:83);
  c84: adjust-color(black,$red:84);
  c85: adjust-color(black,$red:85);
  c86: adjust-color(black,$red:86);
  c87: adjust-color(black,$red:87);
  c88: adjust-color(black,$red:88);
  c89: adjust-color(black,$red:89);
  c90: adjust-color(black,$red:90);
  c91: adjust-color(black,$red:91);
  c92: adjust-color(black,$red:92);
  c93: adjust-color(black,$red:93);
  c94: adjust-color(black,$red:94);
  c95: adjust-color(black,$red:95);
  c96: adjust-color(black,$red:96);
  c97: adjust-color(black,$red:97);
  c98: adjust-color(black,$red:98);
  c99: adjust-color(black,$red:99);
  c100: adjust-color(black,$red:100);
  c101: adjust-color(black,$red:101);
  c102: adjust-color(black,$red:102);
  c103: adjust-color(black,$red:103);
  c104: adjust-color(black,$red:104);
  c105: adjust-color(black,$red:105);
  c106: adjust-color(black,$red:106);
  c107: adjust-color(black,$red:107);
  c108: adjust-color(black,$red:108);
  c109: adjust-color(black,$red:109);
  c110: adjust-color(black,$red:110);
  c111: adjust-color(black,$red:111);
  c112: adjust-color(black,$red:112);
  c113: adjust-color(black,$red:113);
  c114: adjust-color(black,$red:114);
  c115: adjust-color(black,$red:115);
  c116: adjust-color(black,$red:116);
  c117: adjust-color(black,$red:117);
  c118: adjust-color(black,$red:118);
  c119: adjust-color(black,$red:119);
  c120: adjust-color(black,$red:120);
  c121: adjust-color(black,$red:121);
  c122: adjust-color(black,$red:122);
  c123: adjust-color(black,$red:123);
  c124: adjust-color(black,$red:124);
  c125: adjust-color(black,$red:125);
  c126: adjust-color(black,$red:126);
  c127: adjust-color(black,$red:127);
  c128: adjust-color(black,$red:128);
  c129: adjust-color(black,$red:129);
  c130: adjust-color(black,$red:130);
  c131: adjust-color(black,$red:131);
  c132: adjust-color(black,$red:132);
  c133: adjust-color(black,$red:133);
  c134: adjust-color(black,$red:134);
  c135: adjust-color(black,$red:135);
  c136: adjust-color(black,$red:136);
  c137: adjust-color(black,$red:137);
  c138: adjust-color(black,$red:138);
  c139: adjust-color(black,$red:139);
  c140: adjust-color(black,$red:140);
  c141: adjust-color(black,$red:141);
  c142: adjust-color(black,$red:142);
  c143: adjust-color(black,$red:143);
  c144: adjust-color(black,$red:144);
  c145: adjust-color(black,$red:145);
  c146: adjust-color(black,$red:146);
  c147: adjust-color(black,$red:147);
  c148: adjust-color(black,$red:148);
  c149: adjust-color(black,$red:149);
  c150: adjust-color(black,$red:150);
  c151: adjust-color(black,$red:151);
  c152: adjust-color(black,$red:152);
  c153: adjust-color(black,$red:153);
  c154: adjust-color(black,$red:154);
  c155: adjust-color(black,$red:155);
  c156: adjust-color(black,$red:156);
  c157: adjust-color(black,$red:157);
  c158: adjust-color(black,$red:158);
  c159: adjust-color(black,$red:159);
  c160: adjust-color(black,$red:160);
  c161: adjust-color(black,$red:161);
  c162: adjust-color(black,$red:162);
  c163: adjust-color(black,$red:163);
  c164: adjust-color(black,$red:164);
  c165: adjust-color(black,$red:165);
  c166: adjust-color(black,$red:166);
  c167: adjust-color(black,$red:167);
  c168: adjust-color(black,$red:168);
  c169: adjust-color(black,$red:169);
  c170: adjust-color(black,$red:170);
  c171: adjust-color(black,$red:171);
  c172: adjust-color(black,$red:172);
  c173: adjust-color(black,$red:173);
  c174: adjust-color(black,$red:174);
  c175: adjust-color(black,$red:175);
  c176: adjust-color(black,$red:176);
  c177: adjust-color(black,$red:177);
  c178: adjust-color(black,$red:178);
  c179: adjust-color(black,$red:179);
  c180: adjust-color(black,$red:180);
  c181: adjust-color(black,$red:181);
  c182: adjust-color(black,$red:182);
  c183: adjust-color(black,$red:183);
  c184: adjust-color(black,$red:184);
  c185: adjust-color(black,$red:185);
  c186: adjust-color(black,$red:186);
  c187: adjust-color(black,$red:187);
  c188: adjust-color(black,$red:188);
  c189: adjust-color(black,$red:189);
  c190: adjust-color(black,$red:190);
  c191: adjust-color(black,$red:191);
  c192: adjust-color(black,$red:192);
  c193: adjust-color(black,$red:193);
  c194: adjust-color(black,$red:194);
  c195: adjust-color(black,$red:195);
  c196: adjust-color(black,$red:196);
  c197: adjust-color(black,$red:197);
  c198: adjust-color(black,$red:198);
  c199: adjust-color(black,$red:199);
  c200: adjust-color(black,$red:200);
  c201: adjust-color(black,$red:201);
  c202: adjust-color(black,$red:202);
  c203: adjust-color(black,$red:203);
  c204: adjust-color(black,$red:204);
  c205: adjust-color(black,$red:205);
  c206: adjust-color(black,$red:206);
  c207: adjust-color(black,$red:207);
  c208: adjust-color(black,$red:208);
  c209: adjust-color(black,$red:209);
  c210: adjust-color(black,$red:210);
  c211: adjust-color(black,$red:211);
  c212: adjust-color(black,$red:212);
  c213: adjust-color(black,$red:213);
  c214: adjust-color(black,$red:214);
  c215: adjust-color(black,$red:215);
  c216: adjust-color(black,$red:216);
  c217: adjust-color(black,$red:217);
  c218: adjust-color(black,$red:218);
  c219: adjust-color(black,$red:219);
  c220: adjust-color(black,$red:220);
  c221: adjust-color(black,$red:221);
  c222: adjust-color(black,$red:222);
  c223: adjust-color(black,$red:223);
  c224: adjust-color(black,$red:224);
  c225: adjust-color(black,$red:225);
  c226: adjust-color(black,$red:226);
  c227: adjust-color(black,$red:227);
  c228: adjust-color(black,$red:228);
  c229: adjust-color(black,$red:229);
  c230: adjust-color(black,$red:230);
  c231: adjust-color(black,$red:231);
  c232: adjust-color(black,$red:232);
  c233: adjust-color(black,$red:233);
  c234: adjust-color(black,$red:234);
  c235: adjust-color(black,$red:235);
  c236: adjust-color(black,$red:236);
  c237: adjust-color(black,$red:237);
  c238: adjust-color(black,$red:238);
  c239: adjust-color(black,$red:239);
  c240: adjust-color(black,$red:240);
  c241: adjust-color(black,$red:241);
  c242: adjust-color(black,$red:242);
  c243: adjust-color(black,$red:243);
  c244: adjust-color(black,$red:244);
  c245: adjust-color(black,$red:245);
  c246: adjust-color(black,$red:246);
  c247: adjust-color(black,$red:247);
  c248: adjust-color(black,$red:248);
  c249: adjust-color(black,$red:249);
  c250: adjust-color(black,$red:250);
  c251: adjust-color(black,$red:251);
  c252: adjust-color(black,$red:252);
  c253: adjust-color(black,$red:253);
  c254: adjust-color(black,$red:254);
  c255: adjust-color(black,$red:255);
  // c256: adjust-color(black,$red:256);
}
