.result { dquoted: "gamma, ' delta '"; dquoted: "[gamma, ' delta ']"; dquoted: "gamma, ' delta '"; dquoted: "gamma, ' delta '"; dquoted: "['gamma, ' delta '']"; squoted: "gamma, ' delta '"; squoted: "[gamma, ' delta ']"; squoted: "gamma, ' delta '"; squoted: "gamma, ' delta '"; squoted: "['gamma, ' delta '']"; }
