.simple { a: .foo; b: .foo.bar; c: .foo.bar.baz; d: .a .b .foo.bar, .b .a .foo.bar; e: .a .foo.bar; i: .foo.baz, .foo.bang, .bar.baz, .bar.bang; }

.foo, .bar { content: .foo.baz, .foo.bang, .bar.baz, .bar.bang; }
