.result { output: 1px; output: 4.2; output: 4.2px; output: 1.33333px; output: 3.15; output: 4.2pt; output: 16px; output: 0.2625; output: 4.2pc; output: 3.77953px; output: 1.11125; output: 4.2mm; output: 37.79528px; output: 0.11113; output: 4.2cm; output: 96px; output: 0.04375; output: 4.2in; output: 0.75pt; output: 5.6; output: 4.2px; output: 1pt; output: 4.2; output: 4.2pt; output: 12pt; output: 0.35; output: 4.2pc; output: 2.83465pt; output: 1.48167; output: 4.2mm; output: 28.34646pt; output: 0.14817; output: 4.2cm; output: 72pt; output: 0.05833; output: 4.2in; output: 0.0625pc; output: 67.2; output: 4.2px; output: 0.08333pc; output: 50.4; output: 4.2pt; output: 1pc; output: 4.2; output: 4.2pc; output: 0.23622pc; output: 17.78; output: 4.2mm; output: 2.3622pc; output: 1.778; output: 4.2cm; output: 6pc; output: 0.7; output: 4.2in; output: 0.26458mm; output: 15.87402; output: 4.2px; output: 0.35278mm; output: 11.90551; output: 4.2pt; output: 4.23333mm; output: 0.99213; output: 4.2pc; output: 1mm; output: 4.2; output: 4.2mm; output: 10mm; output: 0.42; output: 4.2cm; output: 25.4mm; output: 0.16535; output: 4.2in; output: 0.02646cm; output: 158.74016; output: 4.2px; output: 0.03528cm; output: 119.05512; output: 4.2pt; output: 0.42333cm; output: 9.92126; output: 4.2pc; output: 0.1cm; output: 42; output: 4.2mm; output: 1cm; output: 4.2; output: 4.2cm; output: 2.54cm; output: 1.65354; output: 4.2in; output: 0.01042in; output: 403.2; output: 4.2px; output: 0.01389in; output: 302.4; output: 4.2pt; output: 0.16667in; output: 25.2; output: 4.2pc; output: 0.03937in; output: 106.68; output: 4.2mm; output: 0.3937in; output: 10.668; output: 4.2cm; output: 1in; output: 4.2; output: 4.2in; }
