$i: 9;
$z: 3 !default;
div {
  asd: $i;
  $i: 99 !global;
  $n: 42 !global;
  qwe: $i;
  zapf: $z;
  $z: 84;
  ding: $z;
}
div {
  foo: $n;
  foo: $i;
  $i: 999;
  $n: 999;
  foo: $n;
  foo: $i;
  div {
    $i: 9999;
    $n: 9999 !default;
    bar: $i;
    bar: $n;
  }
  baz: $i;
}
div {
  asd: $i;
  qwe: $n;
  zap: $z;
}