.result{dquoted:"l\\\\ite\\ral";dquoted:"[l\\\\ite\\ral]";dquoted:"l\\\\ite\\ral";dquoted:"l\\\\ite\\ral";dquoted:"['l\\\\ite\\ral']";squoted:"l\\\\ite\\ral";squoted:"[l\\\\ite\\ral]";squoted:"l\\\\ite\\ral";squoted:"l\\\\ite\\ral";squoted:"['l\\\\ite\\ral']"}
