$constraint: "(max-width: 300px)";
$fragment: "nd #{$constraint}";
$comma: "een, pri";
@media screen and #{$constraint} {a: b}
@media screen {
  @media #{$constraint} {a: b}
}
@media screen a#{$fragment} {a: b}
@media scr#{$comma}nt {
  @media #{$constraint} {a: b}
}
