.result {
  output: gamma, "'"delta"'";
  output: #{gamma, "'"delta"'"};
  output: "[#{gamma, "'"delta"'"}]";
  output: "#{gamma, "'"delta"'"}";
  output: '#{gamma, "'"delta"'"}';
  output: "['#{gamma, "'"delta"'"}']";
}
