%-a *.foo1 {a: b}
a {@extend .foo1}
-a {@extend %-a}

%-b *|*.foo2 {b: b}
b {@extend .foo2}
-b {@extend %-b}

%-c |*.foo3 {c: b}
c {@extend .foo3}
-c {@extend %-c}

%-d ns|*.foo4 {d: b}
d {@extend .foo4}
-d {@extend %-d}
