.result {
  output: 1deg;
  output: 4.2;
  output: 4.2deg;
  output: 0.9deg;
  output: 4.6666666667;
  output: 4.2grad;
  output: 57.2957795131deg;
  output: 0.0733038286;
  output: 4.2rad;
  output: 360deg;
  output: 0.0116666667;
  output: 4.2turn;
  output: 1.1111111111grad;
  output: 3.78;
  output: 4.2deg;
  output: 1grad;
  output: 4.2;
  output: 4.2grad;
  output: 63.6619772368grad;
  output: 0.0659734457;
  output: 4.2rad;
  output: 400grad;
  output: 0.0105;
  output: 4.2turn;
  output: 0.0174532925rad;
  output: 240.6422739549;
  output: 4.2deg;
  output: 0.0157079633rad;
  output: 267.3803043944;
  output: 4.2grad;
  output: 1rad;
  output: 4.2;
  output: 4.2rad;
  output: 6.2831853072rad;
  output: 0.668450761;
  output: 4.2turn;
  output: 0.0027777778turn;
  output: 1512;
  output: 4.2deg;
  output: 0.0025turn;
  output: 1680;
  output: 4.2grad;
  output: 0.1591549431turn;
  output: 26.3893782902;
  output: 4.2rad;
  output: 1turn;
  output: 4.2;
  output: 4.2turn;
}
