div{margin:1 2;margin:1 3;margin:1 2 zee;margin:1 kwd-y kwd-z}div blip{hey:now}div blip{hey:now}div{color:global-y;margin:called-from-hux global-y}div blip{hey:now}div{color:calling-hux-again;margin:called-from-hux calling-hux-again}div blip{hey:now}div{blah:original-bung}div{blah:redefined-bung}div{blah:redefined-bung}div{margin:kwdarg1 kwdarg2}div blip{hey:now}hoo{color:boo}div{blah:boogoo some other default}div{value:original}div{value:no longer original}div{arg:changed local x;blarg:changed global y;a:global-x;b:changed global y}
