test {
  test-01: true;
  test-01: true;
  test-01: true;
  test-01: true;
  test-01: false;
  test-01: false;
}

parentless {
  test: parent;
}

.js:root .bou {
  content: 'bar';
}

.js:root .bou .bar {
  content: 'baz';
}
