@import "mystyle.css" supports((display: flex));
@import "mystyle.css" supports((display: flex) and (all: initial));
@import "morestyles.css" supports((all: initial));
@import "morestyles.css" supports((all: initial));
