.test-1 {
  content: null;
  content: inspect(null);
  content: inspect(false);
  content: inspect(true);
  content: inspect(42);
  content: inspect(42.3);
  content: inspect(42px);
  content: inspect("string");
  $list: 1, 2, 3;
  content: inspect($list);
  $map: ( a: 1, b: 2, c: 3 );
  content: inspect($map);
}
