@mixin breakpoint() {
  @media (min-width: 200px) {
    @content;
  }
}

@mixin foo() {
  @include breakpoint {
    @extend %reveal-centered;
  }
}


foo {
  @include breakpoint {
    %reveal-centered {
      left: auto;
      right: auto;
      margin: 0 auto;
    }
  }

  @include foo;
}
