.parent .brother, .parent .sister, .parent .cousin {
  color: green;
  sel: .parent .brother, .parent .sister, .parent .cousin;
  x: .parent .brother + .brother;
  x: .parent .brother + .brother, .parent .sister + .sister;
  x: .parent .brother + .brother, .parent .sister + .sister, .parent .cousin + .cousin; }
  .parent .brother + .brother, .parent .sister + .sister, .parent .cousin + .cousin {
    debug: foo; }
