footer {
    color: red;
}

// Ampersand in SassScript:
/*.button {
    &-primary {
        background: orange;
    }

    &-secondary {
        background: blue;
    }
}*/

// Output:
.button-primary {
    background: orange;
}

.button-secondary {
    background: blue;
}