div { content: false; content: true; content: var 1/2 3 4; content: lit 1/2 3 4; content: true; a: 3, 3; b: 0.5, 0.5; content: true; /***/ content: 3; content: number; content: 0.5; content: 0.5; content: true; content: 1 2 3; color: true; color: true; color: true; }
