div {
  color: color;
  color: string;
  color: color;
  color: number;
  color: number;
  color: number;
  color: list;
  color: string;
  color: string;
  color: string;
  color: bool;
  color: bool;
  color: number;
  color: string;
  color: type-of(red);
  color: "length(a b c d)";
  color: aqua;
  color: aqua;
  color: cyan;
  color: aqua;
  width: 33;
  thing: url(number); }
