$list:   '(-webkit-min-device-pixel-ratio: 2)', '(min-resolution: 192dpi)';
$string: '(-webkit-min-device-pixel-ratio: 2),   (min-resolution: 192dpi)';

.foo {
  // I should not unquote a list, I know. But still.
  content: unquote($list);
  content: unquote($string);
}