.result {
  dquoted: "alpha beta";
  dquoted: "[alpha beta]";
  dquoted: "alpha beta";
  dquoted: "alpha beta";
  dquoted: "['alpha beta']";
  squoted: "alpha beta";
  squoted: "[alpha beta]";
  squoted: "alpha beta";
  squoted: "alpha beta";
  squoted: "['alpha beta']"; }
