@function identity($arg) {@return $arg}

.function-name {
  start: #{1 + 1}foo(arg);
  mid: foo#{1 + 1}bar(arg);
  end: foo#{1 + 1}(arg);
  full: #{foo}(arg);

  evaluates-args: foo#{1 + 1}bar(2 + 2);
  $list: 1, 2, 3, 4, 5;
  supports-splats: foo#{1 + 1}bar($list...);

  not-built-in-function: qu#{o}te(arg);
  not-user-defined-function: id#{enti}ty(arg);

  // In 3.5, this would interpret "red()" as a live function call.
  followed-by-function: b#{o}red(arg);
}