foo { test-1: false; test-2: false; test-3: false; test-4: false; test-5: false; test-6: false; test-7: false; test-8: false; test-9: 10!=10px; test-10: 10 !=10px; test-11: 10!= 10px; test-12: 10 != 10px; test-13: true0px; test-14: true0px; test-15: true0px; test-16: true0px; test-17: falsepx; test-18: falsepx; test-19: falsepx; test-20: falsepx; test-21: falsepx; test-22: falsepx; test-23: falsepx; test-24: falsepx; test-25: false; test-26: false; test-27: false; test-28: false; test-29: 10px!=10px; test-30: 10px !=10px; test-31: 10px!= 10px; test-32: 10px != 10px; test-33: true0px; test-34: true0px; test-35: true0px; test-36: true0px; test-37: falsepx; test-38: falsepx; test-39: falsepx; test-40: falsepx; test-41: falsepx; test-42: falsepx; test-43: falsepx; test-44: falsepx; test-45: 10px!=10px; test-46: 10px !=10px; test-47: 10px!= 10px; test-48: 10px != 10px; test-49: 10true0px; test-50: 10true0px; test-51: 10true0px; test-52: 10true0px; test-53: 10truepx; test-54: 10truepx; test-55: 10truepx; test-56: 10truepx; test-57: 10truepx; test-58: 10truepx; test-59: 10truepx; test-60: 10truepx; test-61: 10true0px; test-62: 10true0px; test-63: 10true0px; test-64: 10true0px; test-65: 10truepx; test-66: 10truepx; test-67: 10truepx; test-68: 10truepx; test-69: 10truepx; test-70: 10truepx; test-71: 10truepx; test-72: 10truepx; test-73: 10px!=10px; test-74: 10px !=10px; test-75: 10px!= 10px; test-76: 10px != 10px; test-77: 10px!=10px; test-78: 10px !=10px; test-79: 10px!= 10px; test-80: 10px != 10px; test-81: 10ptruepx; test-82: 10ptruepx; test-83: 10ptruepx; test-84: 10ptruepx; }
