a b c {
  blee: blee;
  d e f {
    blah: blah;
    bloo: bloo;
  }
  g h, i j {
    @media print and (foo: 1 2 3), (bar: 3px hux(muz)), not screen {
      hey: ho;
      k l m {
        hee: fee;
      }
    }
  }
  blah: blah;
}


