@media only screen { .foo { content: bar; content: foo; } }
@media only screen and (min-width: 1337px) { .foo { content: baz; } }

@media (min-width: 0) and (max-width: 599px) and (min-width: 0) and (max-width: 599px), (min-width: 600px) and (max-width: 899px) and (min-width: 0) and (max-width: 599px) { .foo { content: bar; } }
