$base-text-color: #666;

@function calcNavbarTextColor ($base-text-color) {
        @return $base-text-color;
}

$header-text-color: calcNavbarTextColor($base-text-color);

.test_class {
        color: lighten($header-text-color, 20%);
}