.result {
  output: (0deg + 1deg);
  output: (4.2deg / 1deg);
  output: (4.2deg * 1deg / 1deg);
  output: (0deg + 1grad);
  output: (4.2deg / 1grad);
  output: (4.2deg * 1grad / 1deg);
  output: (0deg + 1rad);
  output: (4.2deg / 1rad);
  output: (4.2deg * 1rad / 1deg);
  output: (0deg + 1turn);
  output: (4.2deg / 1turn);
  output: (4.2deg * 1turn / 1deg);
  output: (0grad + 1deg);
  output: (4.2grad / 1deg);
  output: (4.2grad * 1deg / 1grad);
  output: (0grad + 1grad);
  output: (4.2grad / 1grad);
  output: (4.2grad * 1grad / 1grad);
  output: (0grad + 1rad);
  output: (4.2grad / 1rad);
  output: (4.2grad * 1rad / 1grad);
  output: (0grad + 1turn);
  output: (4.2grad / 1turn);
  output: (4.2grad * 1turn / 1grad);
  output: (0rad + 1deg);
  output: (4.2rad / 1deg);
  output: (4.2rad * 1deg / 1rad);
  output: (0rad + 1grad);
  output: (4.2rad / 1grad);
  output: (4.2rad * 1grad / 1rad);
  output: (0rad + 1rad);
  output: (4.2rad / 1rad);
  output: (4.2rad * 1rad / 1rad);
  output: (0rad + 1turn);
  output: (4.2rad / 1turn);
  output: (4.2rad * 1turn / 1rad);
  output: (0turn + 1deg);
  output: (4.2turn / 1deg);
  output: (4.2turn * 1deg / 1turn);
  output: (0turn + 1grad);
  output: (4.2turn / 1grad);
  output: (4.2turn * 1grad / 1turn);
  output: (0turn + 1rad);
  output: (4.2turn / 1rad);
  output: (4.2turn * 1rad / 1turn);
  output: (0turn + 1turn);
  output: (4.2turn / 1turn);
  output: (4.2turn * 1turn / 1turn);
}
