@import "../assert_helpers";

test {
  a: assert_strict_superselector('.foo .bar', '.foo > .bar.baz');
  b: assert_strict_superselector('.foo .bar', '.foo.baz > .bar');
  c: assert_strict_superselector('.foo .baz', '.foo > .bar > .baz');
}