foo { a: a; b: b; c: c; d: d; }

foo { a: a; b: b; c: c; d: d; }

foo { a: a; b: b; c: c; d: d; }

foo { a: a; b: b; c: c; d: d; }

foo { a: a; b: b; c: c; d: d; }

foo { a: a; b: b; c: c; d: d; }

foo { a: a; b: b; c: c; d: d; }

foo { a: a; b: b; c: c; d: d; }

foo { a: a; b: b; c: c; d: d; }
