.foo, input[type="text"], input[type="search"], input[type="url"], input[type="email"], input[type="password"], input[type="number"], input[type="tel"], input[type="date"], input[type="range"], textarea { bar: baz; }
