body {
  width: calc($x + 2 - 3em / hoolabaloo);
  width: -moz-calc($x + 2 - 3em / hoolabaloo);
  width: -webkit-calc($x + 2 - 3em / hoolabaloo);
  width: -ms-calc($x + 2 - 3em / hoolabaloo);
  height: foo(4);
}
