a { background: url("img.png") no-repeat 6px 0/5px; background: url("img.png") no-repeat 6px 1/5px; background: url("img.png") no-repeat 6px 1px/5px; background: url("img.png") no-repeat 6px 5px/0; background: url("img.png") no-repeat 6px 5px/1; background: url("img.png") no-repeat 6px 5px/1px; }
