.result { output: "[" ",foo   ,   " "]" "bar"; output: [ ,foo   ,    ] bar; output: "[[ ,foo   ,    ] bar]"; output: "[ ,foo   ,    ] bar"; output: "[ ,foo   ,    ] bar"; output: "['[ ,foo   ,    ] bar']"; }
