$map1: (aaa: 100, bbb: 200, ccc: 300);
$map2: (ddd: 400, eee: 500, fff: 600);

a {
  $new-list: append($map1, $map2);
  b: length($new-list);
  b: type-of($new-list);
  b: nth($new-list, 1);
  b: nth($new-list, 2);
  b: nth($new-list, 3);
  b: nth(nth($new-list, 4), 1);
  b: nth(nth($new-list, 4), 2);
  b: nth(nth($new-list, 4), 3);


  $new-list: append($map2, $map1);
  c: length($new-list);
  c: type-of($new-list);
  c: nth($new-list, 1);
  c: nth($new-list, 2);
  c: nth($new-list, 3);
  c: nth(nth($new-list, 4), 1);
  c: nth(nth($new-list, 4), 2);
  c: nth(nth($new-list, 4), 3);
}
