.test .nest {
  length: length(&);
  @for $i from 1 through length(&) {
    $list: nth(&, $i);
    list: $list;
    length: length($list);
  }
}

.test, .other {
  length: length(&);
  @for $i from 1 through length(&) {
    $list: nth(&, $i);
    list: $list;
    length: length($list);
  }
}
