universal-selector { test-01: *; test-02: |*; test-03: *; test-04: |*; test-05: |*; test-06: |*; test-07: *; test-08: |*; test-09: *|*; }

tag-selector { test-1: tag; test-2: |tag; test-3: tag; test-4: tag; test-5: |tag; test-6: tag; }

class-selector { test-1: .class; test-2: |*.class; test-3: .class; test-4: *.class; test-5: |*.class; test-6: *|*.class; }

id-selector { test-1: #id; test-2: |*#id; test-3: #id; test-4: *#id; test-5: |*#id; test-6: *|*#id; }
