foo {
    & bar baz {
        bam: true;
    }
    bar baz & {
        bam: true;
    }
}

foo {
    & bar + baz {
        bam: true;
    }
    bar + baz & {
        bam: true;
    }
}

foo {
    & bar > baz {
        bam: true;
    }
    bar > baz & {
        bam: true;
    }
}

foo {
    & bar ~ baz {
        bam: true;
    }
    bar ~ baz & {
        bam: true;
    }
}
