@function returns-string() {
  @return "selector";
}

#{"selector"} {
  color: red;
}

#{returns-string()} {
  color: red;
}

#{"selector"} selector2 {
  color: red;
}

#{returns-string()} selector2 {
  color: red;
}