foo{test-1:true;test-2:true;test-3:true;test-4:true;test-5:true;test-6:true;test-7:true;test-8:true;test-9:true;test-10:true;test-11:true;test-12:true;test-13:false;test-14:false;test-15:false;test-16:false;test-17:10==itpl;test-18:10 ==itpl;test-19:10== itpl;test-20:10 == itpl;test-21:true;test-22:true;test-23:true;test-24:true;test-25:false;test-26:false;test-27:false;test-28:false;test-29:false;test-30:false;test-31:false;test-32:false;test-33:10%==itpl;test-34:10% ==itpl;test-35:10%== itpl;test-36:10% == itpl;test-37:true;test-38:true;test-39:true;test-40:true;test-41:false;test-42:false;test-43:false;test-44:false;test-45:10px==itpl;test-46:10px ==itpl;test-47:10px== itpl;test-48:10px == itpl;test-49:true;test-50:true;test-51:true;test-52:true;test-53:#AAA==itpl;test-54:#AAA ==itpl;test-55:#AAA== itpl;test-56:#AAA == itpl;test-57:itpl==itpl;test-58:itpl ==itpl;test-59:itpl== itpl;test-60:itpl == itpl}
