foo { test-1: false; test-2: false; test-3: false; test-4: false; test-5: false; test-6: false; test-7: false; test-8: false; test-9: false; test-10: false; test-11: false; test-12: false; test-13: true; test-14: true; test-15: true; test-16: true; test-17: 10!=itpl; test-18: 10 !=itpl; test-19: 10!= itpl; test-20: 10 != itpl; test-21: false; test-22: false; test-23: false; test-24: false; test-25: true; test-26: true; test-27: true; test-28: true; test-29: true; test-30: true; test-31: true; test-32: true; test-33: 10%!=itpl; test-34: 10% !=itpl; test-35: 10%!= itpl; test-36: 10% != itpl; test-37: false; test-38: false; test-39: false; test-40: false; test-41: true; test-42: true; test-43: true; test-44: true; test-45: 10px!=itpl; test-46: 10px !=itpl; test-47: 10px!= itpl; test-48: 10px != itpl; test-49: false; test-50: false; test-51: false; test-52: false; test-53: #AAA!=itpl; test-54: #AAA !=itpl; test-55: #AAA!= itpl; test-56: #AAA != itpl; test-57: itpl!=itpl; test-58: itpl !=itpl; test-59: itpl!= itpl; test-60: itpl != itpl; }
