div {
  less: true;
  less: 0.75;
  less: true;
  eq: true;
  eq: true;
  eq: true;
  eq: false;
  eq: false;
  eq: false;
  eq: false;
  eq: true;
  x: 1in, 1in;
  y: 0.3937007874in;
  eq: true;
  blah: 0.3937007874;
  in: 2.54cm;
  lt: false;
  lt: false;
  lt: false;
}
