main content a box {
  border: solid;
}

supplemtal text b sidebar {
  @extend box;
  background: gray;
}

/********/

mammal {
  blood: warm;
}

mammal.furry.quadruped {
  fur: lots;
  legs: 4;
}

human {
  @extend mammal;
  says: "hello";
}

dog {
  says: "woof";
  @extend mammal.quadruped;
}

/********/

region.country {
  inhabitant.mouse {
    eats: cheddar;
  }
}

region.city {
  inhabitant.mouse {
    eats: camembert;
  }
}

region.country citizen {
  @extend inhabitant;
  ssn: 123 45 6789;
}

region tax-payer {
  @extend inhabitant;
  rate: 17%;
}

/********/

foo {
  color: red;
}

.a.bar {
  @extend fo#{o};
  background: gray;
}

/********/

foo {
  color: red;
}

hux, .bar.a {
  @extend foo;
  background: blue;
}