.result{output:literal literal;output:literalliteral;output:literalliteral;output:literalliteral;output:literal literal;output:literal literal;output:literal literal;output:literal literal;output:literalliteral;output:literal literal;output:literalliteral;output:literalliteral;output:literalliteral;output:literalliteral;output:literal literal;output:literalliteral;output:literalliteral;output:literalliteral;output:literalliteral;output:literal literal;output:literalliteral;output:literalliteral;output:literalliteral;output:"literalliteral";output:"literalliteral";output:"literalliteral";output:"literalliteral";output:"literalliteral";output:"literalliteral";output:"literalliteral";output:"literalliteral";output:"literalliteral";output:"literalliteral";output:"literalliteral";output:"literalliteral";output:"literalliteral";output:"literalliteral";output:"literalliteral"}
