$map: (aaa: 100, bbb: 200, ccc: 300);

a {
  b: nth($map, 1);
  b: length(nth($map, 1));
  b: type-of(nth($map, 1));
  b: nth(nth($map, 1), 1);
  b: nth(nth($map, 1), 2);

  c: nth($map, 2);
  c: length(nth($map, 2));
  c: type-of(nth($map, 2));
  c: nth(nth($map, 2), 1);
  c: nth(nth($map, 2), 2);

  d: nth($map, 3);
  d: length(nth($map, 3));
  d: type-of(nth($map, 3));
  d: nth(nth($map, 3), 1);
  d: nth(nth($map, 3), 2);
}
