div{bar:"b→cde→";bar:"bcd";bar:"ef";bar:"bc";bar:"";bar:"";bar:"abcd";bar:"abcd";bar:"áé";bar:"áéíóúüñ¿";bar:"áéíóúüñ¿éàŤǅǂɊɱʭʬѪ҈ݓ";bar:"Ѫ҈";bar:"áéíóúüñ¿éàŤǅǂɊɱʭʬѪ҈";bar:"";bar:"";bar:"øáéíóúüñ¿éàŤǅǂɊɱʭʬѪ҈ݓ";bar:"øáéíó";bar:""}
