$var: 1;

@mixin test {
  $var: 2;
}

@function test() {
  $var: 3;
  @return "dummy";
}

.selector {
  $var: 4;
  @include test;
  $dummy: test();
  content: $var;
}

.other-selector {
    content: $var;
}
