p {
  color: fade-out(#f00, 0.3);
  color: fade-out(#900, 0.8);
  color: fade-out(#000, .6);
  color: fade-out(#fff, .2);
  color: fade-out(#999, .4);
  color: fade-out(#000, .5);
  color: fade-out(#333, +.99);
  // test old function name
  color: transparentize(#f00, 0.3);
  color: transparentize(#900, 0.8);
  color: transparentize(#000, .6);
  color: transparentize(#fff, .2);
  color: transparentize(#999, .4);
  color: transparentize(#000, .5);
  color: transparentize(#333, +.99);
}