earth mammal,earth dog,earth cat,earth horse,earth naysayer,earth bird{blood:warm}earth mammal,earth dog,earth cat,earth horse,earth naysayer{produces-milk:true}dog{says:"Woof!"}cat{says:"Meow."}horse,naysayer{says:"Nay."}[hey],ho{a:b}ho{c:d}fancy outer space vehicle,fancy outer space new american mars rover,new american mars fancy outer space rover{insides:advanced}new american mars rover{wheels:big}foo,a b c{something:whatever}a b c{blah:blah}d e f,d e g{blah:blah}g{bloo:bloo}
