a b {
  color: red;
  :first-child, :nth-of-type(  -2n+1 ) {
    .foo#bar:nth-child(even) {
      hoo: goo;
    }
    blah: bloo;
    ::after {
      content: "glux";
      color: green;
    }
    :not(.foo) {
      hoo: boo;
    }
    a { b: c; }
  }
}