.simple { a: .a .b, .a .foo .bar, .foo .a .bar; b: .foo .x, .foo .a .bar, .a .foo .bar; c: .foo .x, .foo .bang, .x.bar, .bar.bang; d: .y .x, .foo .x, .y .foo, .foo .foo; e: .foo .x, .foo .bar, .foo .bang; f: .foo.x, .foo; }
