.foo { mixin-sees: .foo; function-sees: .foo; }

.bar a { mixin-sees: .bar a; function-sees: .bar a; }

.bar, .baz { mixin-sees: .bar, .baz; function-sees: .bar, .baz; }

.where .qux.waldo .final { mixin-sees: .where .qux.waldo .final; function-sees: .where .qux.waldo .final; }
