.result {
  output: (0dpi + 1dpi);
  output: (4.2dpi / 1dpi);
  output: (4.2dpi * 1dpi / 1dpi);
  output: (0dpi + 1dpcm);
  output: (4.2dpi / 1dpcm);
  output: (4.2dpi * 1dpcm / 1dpi);
  output: (0dpi + 1dppx);
  output: (4.2dpi / 1dppx);
  output: (4.2dpi * 1dppx / 1dpi);
  output: (0dpcm + 1dpi);
  output: (4.2dpcm / 1dpi);
  output: (4.2dpcm * 1dpi / 1dpcm);
  output: (0dpcm + 1dpcm);
  output: (4.2dpcm / 1dpcm);
  output: (4.2dpcm * 1dpcm / 1dpcm);
  output: (0dpcm + 1dppx);
  output: (4.2dpcm / 1dppx);
  output: (4.2dpcm * 1dppx / 1dpcm);
  output: (0dppx + 1dpi);
  output: (4.2dppx / 1dpi);
  output: (4.2dppx * 1dpi / 1dppx);
  output: (0dppx + 1dpcm);
  output: (4.2dppx / 1dpcm);
  output: (4.2dppx * 1dpcm / 1dppx);
  output: (0dppx + 1dppx);
  output: (4.2dppx / 1dppx);
  output: (4.2dppx * 1dppx / 1dppx);
}
