div {

  bar: to-upper-case("blah");
  bar: to-upper-case("BLAH");
  bar: to-upper-case("bLaH");
  bar: to-upper-case("1232178942");
  bar: to-upper-case(blah);
  bar: to-upper-case(BLAH);
  bar: to-upper-case(bLaH);
  bar: to-upper-case("");

  bar: to-lower-case("blah");
  bar: to-lower-case("BLAH");
  bar: to-lower-case("bLaH");
  bar: to-lower-case("1232178942");
  bar: to-lower-case(blah);
  bar: to-lower-case(BLAH);
  bar: to-lower-case(bLaH);
  bar: to-lower-case("");

}
