.result { dquoted: "squoted"; dquoted: "[squoted]"; dquoted: "squoted"; dquoted: "squoted"; dquoted: "['squoted']"; squoted: "squoted"; squoted: "[squoted]"; squoted: "squoted"; squoted: "squoted"; squoted: "['squoted']"; }
