// $a: 12px / 1em;
// $b: 6px / 1em;
// $c: 10em;
// $x: -9999em;
// $aa: 1px * 1px;

a {
  $foo: 2em;
  $bar: 2em;

  foo: $foo;          // 2em  ✔
  bar: $bar;          // 2em  ✔
  // a: $foo * $bar;     // 4em*em isn't a valid CSS value.  ✔
  a: $foo / $bar;     // 1  ✔
  a: $foo + $bar;     // 4em  ✔
  a: $foo - $bar;     // 0em  ✔


  $foo: 2px;
  $bar: 2em;

  foo: $foo;          // 2px  ✔
  bar: $bar;          // 2em  ✔
  // a: $foo * $bar;     // 4em*px isn't a valid CSS value.  ✔
  // a: $foo / $bar;     // 1px/em isn't a valid CSS value.  ✔
  // a: $foo + $bar;     // Incompatible units: 'em' and 'px'.  ✔
  // a: $foo - $bar;     // Incompatible units: 'em' and 'px'.  ✔


  $foo: 2em;
  $bar: 2px;

  foo: $foo;          // 2em  ✔
  bar: $bar;          // 2px  ✔
  // a: $foo * $bar;     // 4em*px isn't a valid CSS value.  ✔
  // a: $foo / $bar;     // 1em/px isn't a valid CSS value.  ✔
  // a: $foo + $bar;     // Incompatible units: 'px' and 'em'.  ✔
  // a: $foo - $bar;     // Incompatible units: 'px' and 'em'.  ✔


  $foo: 2px / 2em;
  $bar: 2px;

  // foo: $foo;          // 1px/em isn't a valid CSS value.  ✔
  bar: $bar;          // 2px  ✔
  // a: $foo * $bar;     // 2px*px/em isn't a valid CSS value.  ✔
  // a: $foo / $bar;     // 0.5/em isn't a valid CSS value.  ✔
  // a: $foo + $bar;     // Incompatible units: '' and 'em'.
  // a: $foo - $bar;     // Incompatible units: '' and 'em'.


  $foo: 2em / 2px;
  $bar: 2px;

  // foo: $foo;          // 1em/px isn't a valid CSS value.  ✔
  bar: $bar;          // 2px  ✔
  a: $foo * $bar;     // 2em  ✔
  // a: $foo / $bar;     // 0.5em/px*px isn't a valid CSS value.  ✔
  // a: $foo + $bar;     // Incompatible units: 'px' and 'em'.
  // a: $foo - $bar;     // Incompatible units: 'px' and 'em'.


  $foo: 2em / 2px;
  $bar: 2em / 2px;

  // foo: $foo;          // 1em/px isn't a valid CSS value.  ✔
  // bar: $bar;          // 1em/px isn't a valid CSS value.  ✔
  // a: $foo * $bar;     // 1em*em/px*px isn't a valid CSS value.  ✔
  a: $foo / $bar;     // 1  ✔
  // a: $foo + $bar;     // 2em/px isn't a valid CSS value.  ✔
  // a: $foo - $bar;     // 0em/px isn't a valid CSS value.  ✔


  $foo: 2px / 2em;
  $bar: 2em / 2px;

  // foo: $foo;          // 1px/em isn't a valid CSS value.  ✔
  // bar: $bar;          // 1em/px isn't a valid CSS value.  ✔
  a: $foo * $bar;     // 1  ✔
  // a: $foo / $bar;     // 1px*px/em*em isn't a valid CSS value.  ✔
  // a: $foo + $bar;     // Incompatible units: 'em' and 'px'.
  // a: $foo - $bar;     // Incompatible units: 'em' and 'px'.


  $foo: 2px;
  $bar: 2px / 2em;

  foo: $foo;          // 2px  ✔
  // bar: $bar;          // 1px/em isn't a valid CSS value.  ✔
  // a: $foo * $bar;     // 2px*px/em isn't a valid CSS value.  ✔
  a: $foo / $bar;     // 2em  ✔
  // a: $foo + $bar;     // Incompatible units: 'em' and ''.
  // a: $foo - $bar;     // Incompatible units: 'em' and ''.


  $foo: 2px;
  $bar: 2em / 2px;

  foo: $foo;          // 2px  ✔
  // bar: $bar;          // 1em/px isn't a valid CSS value.  ✔
  a: $foo * $bar;     // 2em  ✔
  // a: $foo / $bar;     // 2px*px/em isn't a valid CSS value.  ✔
  // a: $foo + $bar;     // Incompatible units: 'em' and 'px'.
  // a: $foo - $bar;     // Incompatible units: 'em' and 'px'.
}
