.result { dquoted: "
GHIJKLMNOPQRSTUVWXYZ"; dquoted: "[
GHIJKLMNOPQRSTUVWXYZ]"; dquoted: "
GHIJKLMNOPQRSTUVWXYZ"; dquoted: "
GHIJKLMNOPQRSTUVWXYZ"; dquoted: "['
GHIJKLMNOPQRSTUVWXYZ']"; squoted: "
GHIJKLMNOPQRSTUVWXYZ"; squoted: "[
GHIJKLMNOPQRSTUVWXYZ]"; squoted: "
GHIJKLMNOPQRSTUVWXYZ"; squoted: "
GHIJKLMNOPQRSTUVWXYZ"; squoted: "['
GHIJKLMNOPQRSTUVWXYZ']"; }
