foo {
  foo: string;
  foo: string;
  bar: string::string;
  bar: string::string;
  foo: string;
  foo: string;
  bar: string::string;
  bar: string::string; }

bar {
  foo: arglist;
  foo: arglist;
  bar: string::arglist;
  bar: string::arglist;
  foo: arglist;
  foo: arglist;
  bar: string::arglist;
  bar: string::arglist; }
