$name: all;
$value: initial;
@import "mystyle.css" supports(display: flex);
@import "mystyle.css" supports((display: flex) and ($name: $value));
@import "morestyles.css" supports($name: $value);
@import "morestyles.css" supports(($name: $value));
