@function foobar() {
  @return foobar;
}

@function fudge($str) {
  @return "assets/fudge/" + $str;
}


body {
  display: call(foobar); 
  display: call(min, 1,3,5,7);
  display: call(min, 5);
  display: call(max, 10,3,5,7);
  color: fudge("blah");
}