@fudge hux bloo;

div {
	color: red;
	@fudge {
		span {
			width: 10px;
			a {
				font: whatever;
			}
		}
	}
	height: 20px;
	@-webkit-keyframes SOMETHING {
		0%   { opacity: 0; }
		50%  { opacity: 0.5; }
		100% { opacity: 1.0; }
	}
	@-webkit-keyframes BOUNCE {
		from {
			left: 0px;
		}
		to {
			left: 200px;
		}
	}
}

div {
	span {
		font: whatever;
	}
	border: {
		upper: {
			left: 10px;
			right: 9px;
		}
		lower: {
			left: 8px;
			right: 7px;
		}
	}
	background: gray;
}

@fudge HEY, HOO, HA:first-child {
	color: blue;
}

@mudge div span, a:visited;

@fu#{dge} foo {
	color: red;
}
