[data-icon='test-1']:before{content:'\\'}[data-icon='test-2']:before{content:'\''}[data-icon='test-3']:before{content:"\""}[data-icon='test-4']:before{content:'\\'}[data-icon='test-5']:before{content:'\''}[data-icon='test-6']:before{content:"\""}.\E9motion{blah:hi}.\E9 dition{blah:hi}.\0000E9dition{blah:hi}
