@function foo($a, $should-be-empty...) {
  @return length($should-be-empty);
}

@function bar($args...) {
  @return call(foo, $args...);
}

@function args($args...) {
  @return $args;
}

$a: args(1, 2, 3);

test {
  test: bar($a);
}
