foo {
  @at-root {
    & {
      color: blue;
    }

    &--modifier {
      color: red;
    }
  }
}

foo {
  color: blue;

  @at-root {
    & bar {
      color: red;
    }
  }
}

foo {
  color: blue;

  @at-root {
    bar & {
      color: red;
    }
  }
}

foo {
  color: blue;

  @at-root {
    bar {
        & baz {
            color: red;
        }
    }
  }
}

foo {
    @at-root bar & {
        color: red;

        & baz {
            color: blue;
        }
    }
}
