.csv{output:"alpha","beta","gamma","delta";output:alpha,beta,gamma,delta;output:"[alpha,beta,gamma,delta]";output:"alpha,beta,gamma,delta";output:"["alpha,beta,gamma,delta"]";output:"alpha,beta,gamma,delta";output:"['alpha,beta,gamma,delta']"}.ssv{output:"alpha" "beta" "gamma" "delta";output:alpha beta gamma delta;output:"[alpha beta gamma delta]";output:"alpha beta gamma delta";output:"["alpha beta gamma delta"]";output:"alpha beta gamma delta";output:"['alpha beta gamma delta']"}
