a, b {
  color: red;
  background: blue;
}

c, d {
  color: gray;
  e, f {
    background: blue;
    padding: 10px 5px;
  }
  g, h {
    blah: blah;
    bloo: bloo;
  }
  i, j {
    foo: goo;
    k, l {
      m, n, o {
        wow: we are far inside;
        but: it still works;
      }
      hoo: boo;
    }
  }
}