foo {
  c-1: change-color(red,$hue:-1);
  c0: change-color(red,$hue:0);
  c1: change-color(red,$hue:1);
  c2: change-color(red,$hue:2);
  c3: change-color(red,$hue:3);
  c4: change-color(red,$hue:4);
  c5: change-color(red,$hue:5);
  c6: change-color(red,$hue:6);
  c7: change-color(red,$hue:7);
  c8: change-color(red,$hue:8);
  c9: change-color(red,$hue:9);
  c10: change-color(red,$hue:10);
  c11: change-color(red,$hue:11);
  c12: change-color(red,$hue:12);
  c13: change-color(red,$hue:13);
  c14: change-color(red,$hue:14);
  c15: change-color(red,$hue:15);
  c16: change-color(red,$hue:16);
  c17: change-color(red,$hue:17);
  c18: change-color(red,$hue:18);
  c19: change-color(red,$hue:19);
  c20: change-color(red,$hue:20);
  c21: change-color(red,$hue:21);
  c22: change-color(red,$hue:22);
  c23: change-color(red,$hue:23);
  c24: change-color(red,$hue:24);
  c25: change-color(red,$hue:25);
  c26: change-color(red,$hue:26);
  c27: change-color(red,$hue:27);
  c28: change-color(red,$hue:28);
  c29: change-color(red,$hue:29);
  c30: change-color(red,$hue:30);
  c31: change-color(red,$hue:31);
  c32: change-color(red,$hue:32);
  c33: change-color(red,$hue:33);
  c34: change-color(red,$hue:34);
  c35: change-color(red,$hue:35);
  c36: change-color(red,$hue:36);
  c37: change-color(red,$hue:37);
  c38: change-color(red,$hue:38);
  c39: change-color(red,$hue:39);
  c40: change-color(red,$hue:40);
  c41: change-color(red,$hue:41);
  c42: change-color(red,$hue:42);
  c43: change-color(red,$hue:43);
  c44: change-color(red,$hue:44);
  c45: change-color(red,$hue:45);
  c46: change-color(red,$hue:46);
  c47: change-color(red,$hue:47);
  c48: change-color(red,$hue:48);
  c49: change-color(red,$hue:49);
  c50: change-color(red,$hue:50);
  c51: change-color(red,$hue:51);
  c52: change-color(red,$hue:52);
  c53: change-color(red,$hue:53);
  c54: change-color(red,$hue:54);
  c55: change-color(red,$hue:55);
  c56: change-color(red,$hue:56);
  c57: change-color(red,$hue:57);
  c58: change-color(red,$hue:58);
  c59: change-color(red,$hue:59);
  c60: change-color(red,$hue:60);
  c61: change-color(red,$hue:61);
  c62: change-color(red,$hue:62);
  c63: change-color(red,$hue:63);
  c64: change-color(red,$hue:64);
  c65: change-color(red,$hue:65);
  c66: change-color(red,$hue:66);
  c67: change-color(red,$hue:67);
  c68: change-color(red,$hue:68);
  c69: change-color(red,$hue:69);
  c70: change-color(red,$hue:70);
  c71: change-color(red,$hue:71);
  c72: change-color(red,$hue:72);
  c73: change-color(red,$hue:73);
  c74: change-color(red,$hue:74);
  c75: change-color(red,$hue:75);
  c76: change-color(red,$hue:76);
  c77: change-color(red,$hue:77);
  c78: change-color(red,$hue:78);
  c79: change-color(red,$hue:79);
  c80: change-color(red,$hue:80);
  c81: change-color(red,$hue:81);
  c82: change-color(red,$hue:82);
  c83: change-color(red,$hue:83);
  c84: change-color(red,$hue:84);
  c85: change-color(red,$hue:85);
  c86: change-color(red,$hue:86);
  c87: change-color(red,$hue:87);
  c88: change-color(red,$hue:88);
  c89: change-color(red,$hue:89);
  c90: change-color(red,$hue:90);
  c91: change-color(red,$hue:91);
  c92: change-color(red,$hue:92);
  c93: change-color(red,$hue:93);
  c94: change-color(red,$hue:94);
  c95: change-color(red,$hue:95);
  c96: change-color(red,$hue:96);
  c97: change-color(red,$hue:97);
  c98: change-color(red,$hue:98);
  c99: change-color(red,$hue:99);
  c100: change-color(red,$hue:100);
  c101: change-color(red,$hue:101);
  c102: change-color(red,$hue:102);
  c103: change-color(red,$hue:103);
  c104: change-color(red,$hue:104);
  c105: change-color(red,$hue:105);
  c106: change-color(red,$hue:106);
  c107: change-color(red,$hue:107);
  c108: change-color(red,$hue:108);
  c109: change-color(red,$hue:109);
  c110: change-color(red,$hue:110);
  c111: change-color(red,$hue:111);
  c112: change-color(red,$hue:112);
  c113: change-color(red,$hue:113);
  c114: change-color(red,$hue:114);
  c115: change-color(red,$hue:115);
  c116: change-color(red,$hue:116);
  c117: change-color(red,$hue:117);
  c118: change-color(red,$hue:118);
  c119: change-color(red,$hue:119);
  c120: change-color(red,$hue:120);
  c121: change-color(red,$hue:121);
  c122: change-color(red,$hue:122);
  c123: change-color(red,$hue:123);
  c124: change-color(red,$hue:124);
  c125: change-color(red,$hue:125);
  c126: change-color(red,$hue:126);
  c127: change-color(red,$hue:127);
  c128: change-color(red,$hue:128);
  c129: change-color(red,$hue:129);
  c130: change-color(red,$hue:130);
  c131: change-color(red,$hue:131);
  c132: change-color(red,$hue:132);
  c133: change-color(red,$hue:133);
  c134: change-color(red,$hue:134);
  c135: change-color(red,$hue:135);
  c136: change-color(red,$hue:136);
  c137: change-color(red,$hue:137);
  c138: change-color(red,$hue:138);
  c139: change-color(red,$hue:139);
  c140: change-color(red,$hue:140);
  c141: change-color(red,$hue:141);
  c142: change-color(red,$hue:142);
  c143: change-color(red,$hue:143);
  c144: change-color(red,$hue:144);
  c145: change-color(red,$hue:145);
  c146: change-color(red,$hue:146);
  c147: change-color(red,$hue:147);
  c148: change-color(red,$hue:148);
  c149: change-color(red,$hue:149);
  c150: change-color(red,$hue:150);
  c151: change-color(red,$hue:151);
  c152: change-color(red,$hue:152);
  c153: change-color(red,$hue:153);
  c154: change-color(red,$hue:154);
  c155: change-color(red,$hue:155);
  c156: change-color(red,$hue:156);
  c157: change-color(red,$hue:157);
  c158: change-color(red,$hue:158);
  c159: change-color(red,$hue:159);
  c160: change-color(red,$hue:160);
  c161: change-color(red,$hue:161);
  c162: change-color(red,$hue:162);
  c163: change-color(red,$hue:163);
  c164: change-color(red,$hue:164);
  c165: change-color(red,$hue:165);
  c166: change-color(red,$hue:166);
  c167: change-color(red,$hue:167);
  c168: change-color(red,$hue:168);
  c169: change-color(red,$hue:169);
  c170: change-color(red,$hue:170);
  c171: change-color(red,$hue:171);
  c172: change-color(red,$hue:172);
  c173: change-color(red,$hue:173);
  c174: change-color(red,$hue:174);
  c175: change-color(red,$hue:175);
  c176: change-color(red,$hue:176);
  c177: change-color(red,$hue:177);
  c178: change-color(red,$hue:178);
  c179: change-color(red,$hue:179);
  c180: change-color(red,$hue:180);
  c181: change-color(red,$hue:181);
  c182: change-color(red,$hue:182);
  c183: change-color(red,$hue:183);
  c184: change-color(red,$hue:184);
  c185: change-color(red,$hue:185);
  c186: change-color(red,$hue:186);
  c187: change-color(red,$hue:187);
  c188: change-color(red,$hue:188);
  c189: change-color(red,$hue:189);
  c190: change-color(red,$hue:190);
  c191: change-color(red,$hue:191);
  c192: change-color(red,$hue:192);
  c193: change-color(red,$hue:193);
  c194: change-color(red,$hue:194);
  c195: change-color(red,$hue:195);
  c196: change-color(red,$hue:196);
  c197: change-color(red,$hue:197);
  c198: change-color(red,$hue:198);
  c199: change-color(red,$hue:199);
  c200: change-color(red,$hue:200);
  c201: change-color(red,$hue:201);
  c202: change-color(red,$hue:202);
  c203: change-color(red,$hue:203);
  c204: change-color(red,$hue:204);
  c205: change-color(red,$hue:205);
  c206: change-color(red,$hue:206);
  c207: change-color(red,$hue:207);
  c208: change-color(red,$hue:208);
  c209: change-color(red,$hue:209);
  c210: change-color(red,$hue:210);
  c211: change-color(red,$hue:211);
  c212: change-color(red,$hue:212);
  c213: change-color(red,$hue:213);
  c214: change-color(red,$hue:214);
  c215: change-color(red,$hue:215);
  c216: change-color(red,$hue:216);
  c217: change-color(red,$hue:217);
  c218: change-color(red,$hue:218);
  c219: change-color(red,$hue:219);
  c220: change-color(red,$hue:220);
  c221: change-color(red,$hue:221);
  c222: change-color(red,$hue:222);
  c223: change-color(red,$hue:223);
  c224: change-color(red,$hue:224);
  c225: change-color(red,$hue:225);
  c226: change-color(red,$hue:226);
  c227: change-color(red,$hue:227);
  c228: change-color(red,$hue:228);
  c229: change-color(red,$hue:229);
  c230: change-color(red,$hue:230);
  c231: change-color(red,$hue:231);
  c232: change-color(red,$hue:232);
  c233: change-color(red,$hue:233);
  c234: change-color(red,$hue:234);
  c235: change-color(red,$hue:235);
  c236: change-color(red,$hue:236);
  c237: change-color(red,$hue:237);
  c238: change-color(red,$hue:238);
  c239: change-color(red,$hue:239);
  c240: change-color(red,$hue:240);
  c241: change-color(red,$hue:241);
  c242: change-color(red,$hue:242);
  c243: change-color(red,$hue:243);
  c244: change-color(red,$hue:244);
  c245: change-color(red,$hue:245);
  c246: change-color(red,$hue:246);
  c247: change-color(red,$hue:247);
  c248: change-color(red,$hue:248);
  c249: change-color(red,$hue:249);
  c250: change-color(red,$hue:250);
  c251: change-color(red,$hue:251);
  c252: change-color(red,$hue:252);
  c253: change-color(red,$hue:253);
  c254: change-color(red,$hue:254);
  c255: change-color(red,$hue:255);
  c256: change-color(red,$hue:256);
  c257: change-color(red,$hue:257);
  c258: change-color(red,$hue:258);
  c259: change-color(red,$hue:259);
  c260: change-color(red,$hue:260);
  c261: change-color(red,$hue:261);
  c262: change-color(red,$hue:262);
  c263: change-color(red,$hue:263);
  c264: change-color(red,$hue:264);
  c265: change-color(red,$hue:265);
  c266: change-color(red,$hue:266);
  c267: change-color(red,$hue:267);
  c268: change-color(red,$hue:268);
  c269: change-color(red,$hue:269);
  c270: change-color(red,$hue:270);
  c271: change-color(red,$hue:271);
  c272: change-color(red,$hue:272);
  c273: change-color(red,$hue:273);
  c274: change-color(red,$hue:274);
  c275: change-color(red,$hue:275);
  c276: change-color(red,$hue:276);
  c277: change-color(red,$hue:277);
  c278: change-color(red,$hue:278);
  c279: change-color(red,$hue:279);
  c280: change-color(red,$hue:280);
  c281: change-color(red,$hue:281);
  c282: change-color(red,$hue:282);
  c283: change-color(red,$hue:283);
  c284: change-color(red,$hue:284);
  c285: change-color(red,$hue:285);
  c286: change-color(red,$hue:286);
  c287: change-color(red,$hue:287);
  c288: change-color(red,$hue:288);
  c289: change-color(red,$hue:289);
  c290: change-color(red,$hue:290);
  c291: change-color(red,$hue:291);
  c292: change-color(red,$hue:292);
  c293: change-color(red,$hue:293);
  c294: change-color(red,$hue:294);
  c295: change-color(red,$hue:295);
  c296: change-color(red,$hue:296);
  c297: change-color(red,$hue:297);
  c298: change-color(red,$hue:298);
  c299: change-color(red,$hue:299);
  c300: change-color(red,$hue:300);
  c301: change-color(red,$hue:301);
  c302: change-color(red,$hue:302);
  c303: change-color(red,$hue:303);
  c304: change-color(red,$hue:304);
  c305: change-color(red,$hue:305);
  c306: change-color(red,$hue:306);
  c307: change-color(red,$hue:307);
  c308: change-color(red,$hue:308);
  c309: change-color(red,$hue:309);
  c310: change-color(red,$hue:310);
  c311: change-color(red,$hue:311);
  c312: change-color(red,$hue:312);
  c313: change-color(red,$hue:313);
  c314: change-color(red,$hue:314);
  c315: change-color(red,$hue:315);
  c316: change-color(red,$hue:316);
  c317: change-color(red,$hue:317);
  c318: change-color(red,$hue:318);
  c319: change-color(red,$hue:319);
  c320: change-color(red,$hue:320);
  c321: change-color(red,$hue:321);
  c322: change-color(red,$hue:322);
  c323: change-color(red,$hue:323);
  c324: change-color(red,$hue:324);
  c325: change-color(red,$hue:325);
  c326: change-color(red,$hue:326);
  c327: change-color(red,$hue:327);
  c328: change-color(red,$hue:328);
  c329: change-color(red,$hue:329);
  c330: change-color(red,$hue:330);
  c331: change-color(red,$hue:331);
  c332: change-color(red,$hue:332);
  c333: change-color(red,$hue:333);
  c334: change-color(red,$hue:334);
  c335: change-color(red,$hue:335);
  c336: change-color(red,$hue:336);
  c337: change-color(red,$hue:337);
  c338: change-color(red,$hue:338);
  c339: change-color(red,$hue:339);
  c340: change-color(red,$hue:340);
  c341: change-color(red,$hue:341);
  c342: change-color(red,$hue:342);
  c343: change-color(red,$hue:343);
  c344: change-color(red,$hue:344);
  c345: change-color(red,$hue:345);
  c346: change-color(red,$hue:346);
  c347: change-color(red,$hue:347);
  c348: change-color(red,$hue:348);
  c349: change-color(red,$hue:349);
  c350: change-color(red,$hue:350);
  c351: change-color(red,$hue:351);
  c352: change-color(red,$hue:352);
  c353: change-color(red,$hue:353);
  c354: change-color(red,$hue:354);
  c355: change-color(red,$hue:355);
  c356: change-color(red,$hue:356);
  c357: change-color(red,$hue:357);
  c358: change-color(red,$hue:358);
  c359: change-color(red,$hue:359);
  c360: change-color(red,$hue:360);
}
