.testOneLevelPassthrough {
  width: 1px;
  height: 2px;
  opacity: 0.3; }

.testOneLevelNoArgs {
  width: 0;
  height: 0;
  opacity: 0; }

.testOneLevelSingleArg {
  width: 1px;
  height: 0;
  opacity: 0; }

.testOneLevelNamedSingleArg {
  width: 0;
  height: 0;
  opacity: 0.1; }

.testOneLevelNamedArgs {
  width: 1px;
  height: 2px;
  opacity: 0.3; }

.testTwoLevelPassthrough {
  width: 1px;
  height: 2px;
  opacity: 0.3; }

.testTwoLevelNoArgs {
  width: 0;
  height: 0;
  opacity: 0; }

.testTwoLevelSingleArg {
  width: 1px;
  height: 0;
  opacity: 0; }

.testTwoLevelNamedSingleArg {
  width: 0;
  height: 0;
  opacity: 0.1; }

.testTwoLevelNamedArgs {
  width: 1px;
  height: 2px;
  opacity: 0.3; }
