$x: true;
$file-1x: "budge.png";

@function fudge($str) {
  @return "assets/fudge/" + $str;
}

div {
  blah: url(foo + bar);
  blah: url(fn("s"));
  blah: url(if(true, "red.png", "blue.png"));
  blah: url(hello-#{world}.png);
  blah: url(if($x, fudge("#{$file-1x}"), "#{$file-1x}"));
}