.parent-sel-value { font-family: .parent-sel-value; }
.parent-sel-value .parent-sel-interpolation { font-family: .parent-sel-value .parent-sel-interpolation; }
.parent-sel-value .parent-sel-interpolation .parent-sel-value-concat { font-family: "Current parent: .parent-sel-value .parent-sel-interpolation .parent-sel-value-concat"; }
