.result{dquoted:"[ foo    ] bar";dquoted:"[[ foo    ] bar]";dquoted:"[ foo    ] bar";dquoted:"[ foo    ] bar";dquoted:"['[ foo    ] bar']";squoted:"[ foo    ] bar";squoted:"[[ foo    ] bar]";squoted:"[ foo    ] bar";squoted:"[ foo    ] bar";squoted:"['[ foo    ] bar']"}
