foo {
  color: blue;

  baz {
    color: purple;

    @at-root {
      bar {
        color: red;
      }
    }
  }
}

foo {
  color: blue;

  baz {
    color: purple;

    @at-root bar {
      color: red;
    }
  }
}
