@font-face {
  font-family: 'My Font';
  font-style: normal;
  font-weight: 300;
  src: local('My Font'), local('My-Font'),
    /* from http://.... original source of .eot */
    url('my-font.eot?#iefix') format('embedded-opentype'),
    /* from http://.... original source of .woff */
    url('my-font.woff') format('woff'),
    /* from http://.... original source of .ttf */
    url('my-font.ttf') format('truetype'),
    /* from http://.... original source of .svg */
    url('my-font.svg#MyFont') format('svg');
}
