$quoted-strings-csv: "alpha", "beta", 'gamma', 'delta';
$quoted-strings-ssv: "alpha" "beta" 'gamma' 'delta';

.csv {
  output: $quoted-strings-csv;
  output: #{$quoted-strings-csv};
  output: "[#{$quoted-strings-csv}]";
  output: "#{$quoted-strings-csv}";
  output: "["#{$quoted-strings-csv}"]";
  output: '#{$quoted-strings-csv}';
  output: "['#{$quoted-strings-csv}']";
}

.ssv {
  output: $quoted-strings-ssv;
  output: #{$quoted-strings-ssv};
  output: "[#{$quoted-strings-ssv}]";
  output: "#{$quoted-strings-ssv}";
  output: "["#{$quoted-strings-ssv}"]";
  output: '#{$quoted-strings-ssv}';
  output: "['#{$quoted-strings-ssv}']";
}
