/* This is a CSS comment. */
.one { color: green; }

/* Another comment */
/* The following should not be used:
.two {color: red;} */
.three { color: green; /* color: red; */ }

/**
.four {color: red;} */
.five { color: green; }

/**/
.six { color: green; }

/*********/
.seven { color: green; }

/* a comment **/
.eight { color: green; }
