div { bar: "BLAH"; bar: "BLAH"; bar: "BLAH"; bar: "1232178942"; bar: BLAH; bar: BLAH; bar: BLAH; bar: ""; bar: "blah"; bar: "blah"; bar: "blah"; bar: "1232178942"; bar: blah; bar: blah; bar: blah; bar: ""; }
