.result { output: "
ghijklmnopqrstuvwxyz"; output: 
ghijklmnopqrstuvwxyz; output: "[
ghijklmnopqrstuvwxyz]"; output: "
ghijklmnopqrstuvwxyz"; output: "
ghijklmnopqrstuvwxyz"; output: "['
ghijklmnopqrstuvwxyz']"; }
