foo { test-37: interpolant<=interpolant; test-38: interpolant <=interpolant; test-39: interpolant<= interpolant; test-40: interpolant <= interpolant; test-41: interpolant<=lschema_ritlp; test-42: interpolant <=lschema_ritlp; test-43: interpolant<= lschema_ritlp; test-44: interpolant <= lschema_ritlp; test-45: interpolant<=litlp_rschema; test-46: interpolant <=litlp_rschema; test-47: interpolant<= litlp_rschema; test-48: interpolant <= litlp_rschema; test-49: lschema_ritlp<=lschema_ritlp; test-50: lschema_ritlp <=lschema_ritlp; test-51: lschema_ritlp<= lschema_ritlp; test-52: lschema_ritlp <= lschema_ritlp; test-53: lschema_ritlp<=litlp_rschema; test-54: lschema_ritlp <=litlp_rschema; test-55: lschema_ritlp<= litlp_rschema; test-56: lschema_ritlp <= litlp_rschema; test-57: litlp_rschema<=litlp_rschema; test-58: litlp_rschema <=litlp_rschema; test-59: litlp_rschema<= litlp_rschema; test-60: litlp_rschema <= litlp_rschema; }
