@function foo() {
  @return 1+2 3/4 5+6;
}

@mixin bar($x: 3/4) {
  bar-content: $x;
}

div {
  content: foobar(1+2 3/4 5+6, orange);
  content: append(1+2 2/3 5+6, orange);
  content: 1+2 2/3 5+6;
  content: type-of(2/3);
  content: type-of(orange);
  content: foo();
  @include bar();
}