.okay1{width:132px}.okay2{width:100px;background-position:-100px -25px}.okay3{width:200px;background-position:-500px -100px}.error1{width:132px}.error2{width:100px;background-position:-100px -25px}.error3{width:200px;background-position:-500px -100px}
