foo {
  c0: lighten(black, 0%);
  c1: lighten(black, 1%);
  c2: lighten(black, 2%);
  c3: lighten(black, 3%);
  c4: lighten(black, 4%);
  c5: lighten(black, 5%);
  c6: lighten(black, 6%);
  c7: lighten(black, 7%);
  c8: lighten(black, 8%);
  c9: lighten(black, 9%);
  c10: lighten(black, 10%);
  c11: lighten(black, 11%);
  c12: lighten(black, 12%);
  c13: lighten(black, 13%);
  c14: lighten(black, 14%);
  c15: lighten(black, 15%);
  c16: lighten(black, 16%);
  c17: lighten(black, 17%);
  c18: lighten(black, 18%);
  c19: lighten(black, 19%);
  c20: lighten(black, 20%);
  c21: lighten(black, 21%);
  c22: lighten(black, 22%);
  c23: lighten(black, 23%);
  c24: lighten(black, 24%);
  c25: lighten(black, 25%);
  c26: lighten(black, 26%);
  c27: lighten(black, 27%);
  c28: lighten(black, 28%);
  c29: lighten(black, 29%);
  c30: lighten(black, 30%);
  c31: lighten(black, 31%);
  c32: lighten(black, 32%);
  c33: lighten(black, 33%);
  c34: lighten(black, 34%);
  c35: lighten(black, 35%);
  c36: lighten(black, 36%);
  c37: lighten(black, 37%);
  c38: lighten(black, 38%);
  c39: lighten(black, 39%);
  c40: lighten(black, 40%);
  c41: lighten(black, 41%);
  c42: lighten(black, 42%);
  c43: lighten(black, 43%);
  c44: lighten(black, 44%);
  c45: lighten(black, 45%);
  c46: lighten(black, 46%);
  c47: lighten(black, 47%);
  c48: lighten(black, 48%);
  c49: lighten(black, 49%);
  c50: lighten(black, 50%);
  c51: lighten(black, 51%);
  c52: lighten(black, 52%);
  c53: lighten(black, 53%);
  c54: lighten(black, 54%);
  c55: lighten(black, 55%);
  c56: lighten(black, 56%);
  c57: lighten(black, 57%);
  c58: lighten(black, 58%);
  c59: lighten(black, 59%);
  c60: lighten(black, 60%);
  c61: lighten(black, 61%);
  c62: lighten(black, 62%);
  c63: lighten(black, 63%);
  c64: lighten(black, 64%);
  c65: lighten(black, 65%);
  c66: lighten(black, 66%);
  c67: lighten(black, 67%);
  c68: lighten(black, 68%);
  c69: lighten(black, 69%);
  c70: lighten(black, 70%);
  c71: lighten(black, 71%);
  c72: lighten(black, 72%);
  c73: lighten(black, 73%);
  c74: lighten(black, 74%);
  c75: lighten(black, 75%);
  c76: lighten(black, 76%);
  c77: lighten(black, 77%);
  c78: lighten(black, 78%);
  c79: lighten(black, 79%);
  c80: lighten(black, 80%);
  c81: lighten(black, 81%);
  c82: lighten(black, 82%);
  c83: lighten(black, 83%);
  c84: lighten(black, 84%);
  c85: lighten(black, 85%);
  c86: lighten(black, 86%);
  c87: lighten(black, 87%);
  c88: lighten(black, 88%);
  c89: lighten(black, 89%);
  c90: lighten(black, 90%);
  c91: lighten(black, 91%);
  c92: lighten(black, 92%);
  c93: lighten(black, 93%);
  c94: lighten(black, 94%);
  c95: lighten(black, 95%);
  c96: lighten(black, 96%);
  c97: lighten(black, 97%);
  c98: lighten(black, 98%);
  c99: lighten(black, 99%);
  c100: lighten(black, 100%);
}
