@charset "UTF-8";
div {
  bar: "Xabcd";
  bar: "Xabcd";
  bar: "X'fjd'skabcd";
  bar: "abecd";
  bar: "abcde";
  bar: "abced";
  bar: "eabcd";
  bar: "eabcd";
  bar: "eabcd";
  bar: eabcd;
  bar: eabcd;
  bar: "abcdDéjà vu";
  bar: "Dabcdéjà vu";
  bar: "Déjà abcdvu";
  bar: "Déjà vuabcd";
  bar: " ABCD øáéíóúüñ¿éàŤǅǂɊɱʭʬѪ҈ݓ";
  bar: "ø ABCD áéíóúüñ¿éàŤǅǂɊɱʭʬѪ҈ݓ";
  bar: "øáéí ABCD óúüñ¿éàŤǅǂɊɱʭʬѪ҈ݓ";
  bar: "øáéíóúüñ ABCD ¿éàŤǅǂɊɱʭʬѪ҈ݓ";
  bar: "øáéíóúüñ¿éàŤǅǂɊɱʭʬѪ҈ݓ ABCD ";
  bar: "øáéíóúüñ¿éàŤǅǂɊɱʭʬѪ ABCD ҈ݓ";
  bar: " ABCD øáéíóúüñ¿éàŤǅǂɊɱʭʬѪ҈ݓ"; }
