#if {
  height: 100px;
}

#elseif {
  width: 100px;
}

#else {
  width: 100px;
}

#for {
  foo: bar1;
}

#while {
  foo: bar1;
}

#each {
  foo: bar1;
}

#inc {
  mix: in;
  inc: lude;
}

@supports (display: flex) {
  a {
    display: flex;
  }
}
@foo {
  bar: bat;
}
