@mixin foo($x: 1, $y: $x + 1) {
  value: $x, $y;
}

div {
  @include foo();
  @include foo(2);
  @include foo($y: 3);
}

$v: hey;

@mixin bar($x: $v) {
  value: $x;
}

div {
  $v: ho !global;
  @include bar();
}
