p {
  color: adjust-color(#102030, $blue: 5);
  color: adjust-color(#102030, $alpha: .325);
  color: adjust-color(#102030, $red: -5, $blue: 5);
  color: adjust-color(hsl(25, 100%, 80%), $lightness: -30%, $alpha: -0.4);
}