foo {
  c-361: adjust-color(red,$hue:-361);
  c-360: adjust-color(red,$hue:-360);
  c-359: adjust-color(red,$hue:-359);
  c-358: adjust-color(red,$hue:-358);
  c-357: adjust-color(red,$hue:-357);
  c-356: adjust-color(red,$hue:-356);
  c-355: adjust-color(red,$hue:-355);
  c-354: adjust-color(red,$hue:-354);
  c-353: adjust-color(red,$hue:-353);
  c-352: adjust-color(red,$hue:-352);
  c-351: adjust-color(red,$hue:-351);
  c-350: adjust-color(red,$hue:-350);
  c-349: adjust-color(red,$hue:-349);
  c-348: adjust-color(red,$hue:-348);
  c-347: adjust-color(red,$hue:-347);
  c-346: adjust-color(red,$hue:-346);
  c-345: adjust-color(red,$hue:-345);
  c-344: adjust-color(red,$hue:-344);
  c-343: adjust-color(red,$hue:-343);
  c-342: adjust-color(red,$hue:-342);
  c-341: adjust-color(red,$hue:-341);
  c-340: adjust-color(red,$hue:-340);
  c-339: adjust-color(red,$hue:-339);
  c-338: adjust-color(red,$hue:-338);
  c-337: adjust-color(red,$hue:-337);
  c-336: adjust-color(red,$hue:-336);
  c-335: adjust-color(red,$hue:-335);
  c-334: adjust-color(red,$hue:-334);
  c-333: adjust-color(red,$hue:-333);
  c-332: adjust-color(red,$hue:-332);
  c-331: adjust-color(red,$hue:-331);
  c-330: adjust-color(red,$hue:-330);
  c-329: adjust-color(red,$hue:-329);
  c-328: adjust-color(red,$hue:-328);
  c-327: adjust-color(red,$hue:-327);
  c-326: adjust-color(red,$hue:-326);
  c-325: adjust-color(red,$hue:-325);
  c-324: adjust-color(red,$hue:-324);
  c-323: adjust-color(red,$hue:-323);
  c-322: adjust-color(red,$hue:-322);
  c-321: adjust-color(red,$hue:-321);
  c-320: adjust-color(red,$hue:-320);
  c-319: adjust-color(red,$hue:-319);
  c-318: adjust-color(red,$hue:-318);
  c-317: adjust-color(red,$hue:-317);
  c-316: adjust-color(red,$hue:-316);
  c-315: adjust-color(red,$hue:-315);
  c-314: adjust-color(red,$hue:-314);
  c-313: adjust-color(red,$hue:-313);
  c-312: adjust-color(red,$hue:-312);
  c-311: adjust-color(red,$hue:-311);
  c-310: adjust-color(red,$hue:-310);
  c-309: adjust-color(red,$hue:-309);
  c-308: adjust-color(red,$hue:-308);
  c-307: adjust-color(red,$hue:-307);
  c-306: adjust-color(red,$hue:-306);
  c-305: adjust-color(red,$hue:-305);
  c-304: adjust-color(red,$hue:-304);
  c-303: adjust-color(red,$hue:-303);
  c-302: adjust-color(red,$hue:-302);
  c-301: adjust-color(red,$hue:-301);
  c-300: adjust-color(red,$hue:-300);
  c-299: adjust-color(red,$hue:-299);
  c-298: adjust-color(red,$hue:-298);
  c-297: adjust-color(red,$hue:-297);
  c-296: adjust-color(red,$hue:-296);
  c-295: adjust-color(red,$hue:-295);
  c-294: adjust-color(red,$hue:-294);
  c-293: adjust-color(red,$hue:-293);
  c-292: adjust-color(red,$hue:-292);
  c-291: adjust-color(red,$hue:-291);
  c-290: adjust-color(red,$hue:-290);
  c-289: adjust-color(red,$hue:-289);
  c-288: adjust-color(red,$hue:-288);
  c-287: adjust-color(red,$hue:-287);
  c-286: adjust-color(red,$hue:-286);
  c-285: adjust-color(red,$hue:-285);
  c-284: adjust-color(red,$hue:-284);
  c-283: adjust-color(red,$hue:-283);
  c-282: adjust-color(red,$hue:-282);
  c-281: adjust-color(red,$hue:-281);
  c-280: adjust-color(red,$hue:-280);
  c-279: adjust-color(red,$hue:-279);
  c-278: adjust-color(red,$hue:-278);
  c-277: adjust-color(red,$hue:-277);
  c-276: adjust-color(red,$hue:-276);
  c-275: adjust-color(red,$hue:-275);
  c-274: adjust-color(red,$hue:-274);
  c-273: adjust-color(red,$hue:-273);
  c-272: adjust-color(red,$hue:-272);
  c-271: adjust-color(red,$hue:-271);
  c-270: adjust-color(red,$hue:-270);
  c-269: adjust-color(red,$hue:-269);
  c-268: adjust-color(red,$hue:-268);
  c-267: adjust-color(red,$hue:-267);
  c-266: adjust-color(red,$hue:-266);
  c-265: adjust-color(red,$hue:-265);
  c-264: adjust-color(red,$hue:-264);
  c-263: adjust-color(red,$hue:-263);
  c-262: adjust-color(red,$hue:-262);
  c-261: adjust-color(red,$hue:-261);
  c-260: adjust-color(red,$hue:-260);
  c-259: adjust-color(red,$hue:-259);
  c-258: adjust-color(red,$hue:-258);
  c-257: adjust-color(red,$hue:-257);
  c-256: adjust-color(red,$hue:-256);
  c-255: adjust-color(red,$hue:-255);
  c-254: adjust-color(red,$hue:-254);
  c-253: adjust-color(red,$hue:-253);
  c-252: adjust-color(red,$hue:-252);
  c-251: adjust-color(red,$hue:-251);
  c-250: adjust-color(red,$hue:-250);
  c-249: adjust-color(red,$hue:-249);
  c-248: adjust-color(red,$hue:-248);
  c-247: adjust-color(red,$hue:-247);
  c-246: adjust-color(red,$hue:-246);
  c-245: adjust-color(red,$hue:-245);
  c-244: adjust-color(red,$hue:-244);
  c-243: adjust-color(red,$hue:-243);
  c-242: adjust-color(red,$hue:-242);
  c-241: adjust-color(red,$hue:-241);
  c-240: adjust-color(red,$hue:-240);
  c-239: adjust-color(red,$hue:-239);
  c-238: adjust-color(red,$hue:-238);
  c-237: adjust-color(red,$hue:-237);
  c-236: adjust-color(red,$hue:-236);
  c-235: adjust-color(red,$hue:-235);
  c-234: adjust-color(red,$hue:-234);
  c-233: adjust-color(red,$hue:-233);
  c-232: adjust-color(red,$hue:-232);
  c-231: adjust-color(red,$hue:-231);
  c-230: adjust-color(red,$hue:-230);
  c-229: adjust-color(red,$hue:-229);
  c-228: adjust-color(red,$hue:-228);
  c-227: adjust-color(red,$hue:-227);
  c-226: adjust-color(red,$hue:-226);
  c-225: adjust-color(red,$hue:-225);
  c-224: adjust-color(red,$hue:-224);
  c-223: adjust-color(red,$hue:-223);
  c-222: adjust-color(red,$hue:-222);
  c-221: adjust-color(red,$hue:-221);
  c-220: adjust-color(red,$hue:-220);
  c-219: adjust-color(red,$hue:-219);
  c-218: adjust-color(red,$hue:-218);
  c-217: adjust-color(red,$hue:-217);
  c-216: adjust-color(red,$hue:-216);
  c-215: adjust-color(red,$hue:-215);
  c-214: adjust-color(red,$hue:-214);
  c-213: adjust-color(red,$hue:-213);
  c-212: adjust-color(red,$hue:-212);
  c-211: adjust-color(red,$hue:-211);
  c-210: adjust-color(red,$hue:-210);
  c-209: adjust-color(red,$hue:-209);
  c-208: adjust-color(red,$hue:-208);
  c-207: adjust-color(red,$hue:-207);
  c-206: adjust-color(red,$hue:-206);
  c-205: adjust-color(red,$hue:-205);
  c-204: adjust-color(red,$hue:-204);
  c-203: adjust-color(red,$hue:-203);
  c-202: adjust-color(red,$hue:-202);
  c-201: adjust-color(red,$hue:-201);
  c-200: adjust-color(red,$hue:-200);
  c-199: adjust-color(red,$hue:-199);
  c-198: adjust-color(red,$hue:-198);
  c-197: adjust-color(red,$hue:-197);
  c-196: adjust-color(red,$hue:-196);
  c-195: adjust-color(red,$hue:-195);
  c-194: adjust-color(red,$hue:-194);
  c-193: adjust-color(red,$hue:-193);
  c-192: adjust-color(red,$hue:-192);
  c-191: adjust-color(red,$hue:-191);
  c-190: adjust-color(red,$hue:-190);
  c-189: adjust-color(red,$hue:-189);
  c-188: adjust-color(red,$hue:-188);
  c-187: adjust-color(red,$hue:-187);
  c-186: adjust-color(red,$hue:-186);
  c-185: adjust-color(red,$hue:-185);
  c-184: adjust-color(red,$hue:-184);
  c-183: adjust-color(red,$hue:-183);
  c-182: adjust-color(red,$hue:-182);
  c-181: adjust-color(red,$hue:-181);
  c-180: adjust-color(red,$hue:-180);
  c-179: adjust-color(red,$hue:-179);
  c-178: adjust-color(red,$hue:-178);
  c-177: adjust-color(red,$hue:-177);
  c-176: adjust-color(red,$hue:-176);
  c-175: adjust-color(red,$hue:-175);
  c-174: adjust-color(red,$hue:-174);
  c-173: adjust-color(red,$hue:-173);
  c-172: adjust-color(red,$hue:-172);
  c-171: adjust-color(red,$hue:-171);
  c-170: adjust-color(red,$hue:-170);
  c-169: adjust-color(red,$hue:-169);
  c-168: adjust-color(red,$hue:-168);
  c-167: adjust-color(red,$hue:-167);
  c-166: adjust-color(red,$hue:-166);
  c-165: adjust-color(red,$hue:-165);
  c-164: adjust-color(red,$hue:-164);
  c-163: adjust-color(red,$hue:-163);
  c-162: adjust-color(red,$hue:-162);
  c-161: adjust-color(red,$hue:-161);
  c-160: adjust-color(red,$hue:-160);
  c-159: adjust-color(red,$hue:-159);
  c-158: adjust-color(red,$hue:-158);
  c-157: adjust-color(red,$hue:-157);
  c-156: adjust-color(red,$hue:-156);
  c-155: adjust-color(red,$hue:-155);
  c-154: adjust-color(red,$hue:-154);
  c-153: adjust-color(red,$hue:-153);
  c-152: adjust-color(red,$hue:-152);
  c-151: adjust-color(red,$hue:-151);
  c-150: adjust-color(red,$hue:-150);
  c-149: adjust-color(red,$hue:-149);
  c-148: adjust-color(red,$hue:-148);
  c-147: adjust-color(red,$hue:-147);
  c-146: adjust-color(red,$hue:-146);
  c-145: adjust-color(red,$hue:-145);
  c-144: adjust-color(red,$hue:-144);
  c-143: adjust-color(red,$hue:-143);
  c-142: adjust-color(red,$hue:-142);
  c-141: adjust-color(red,$hue:-141);
  c-140: adjust-color(red,$hue:-140);
  c-139: adjust-color(red,$hue:-139);
  c-138: adjust-color(red,$hue:-138);
  c-137: adjust-color(red,$hue:-137);
  c-136: adjust-color(red,$hue:-136);
  c-135: adjust-color(red,$hue:-135);
  c-134: adjust-color(red,$hue:-134);
  c-133: adjust-color(red,$hue:-133);
  c-132: adjust-color(red,$hue:-132);
  c-131: adjust-color(red,$hue:-131);
  c-130: adjust-color(red,$hue:-130);
  c-129: adjust-color(red,$hue:-129);
  c-128: adjust-color(red,$hue:-128);
  c-127: adjust-color(red,$hue:-127);
  c-126: adjust-color(red,$hue:-126);
  c-125: adjust-color(red,$hue:-125);
  c-124: adjust-color(red,$hue:-124);
  c-123: adjust-color(red,$hue:-123);
  c-122: adjust-color(red,$hue:-122);
  c-121: adjust-color(red,$hue:-121);
  c-120: adjust-color(red,$hue:-120);
  c-119: adjust-color(red,$hue:-119);
  c-118: adjust-color(red,$hue:-118);
  c-117: adjust-color(red,$hue:-117);
  c-116: adjust-color(red,$hue:-116);
  c-115: adjust-color(red,$hue:-115);
  c-114: adjust-color(red,$hue:-114);
  c-113: adjust-color(red,$hue:-113);
  c-112: adjust-color(red,$hue:-112);
  c-111: adjust-color(red,$hue:-111);
  c-110: adjust-color(red,$hue:-110);
  c-109: adjust-color(red,$hue:-109);
  c-108: adjust-color(red,$hue:-108);
  c-107: adjust-color(red,$hue:-107);
  c-106: adjust-color(red,$hue:-106);
  c-105: adjust-color(red,$hue:-105);
  c-104: adjust-color(red,$hue:-104);
  c-103: adjust-color(red,$hue:-103);
  c-102: adjust-color(red,$hue:-102);
  c-101: adjust-color(red,$hue:-101);
  c-100: adjust-color(red,$hue:-100);
  c-99: adjust-color(red,$hue:-99);
  c-98: adjust-color(red,$hue:-98);
  c-97: adjust-color(red,$hue:-97);
  c-96: adjust-color(red,$hue:-96);
  c-95: adjust-color(red,$hue:-95);
  c-94: adjust-color(red,$hue:-94);
  c-93: adjust-color(red,$hue:-93);
  c-92: adjust-color(red,$hue:-92);
  c-91: adjust-color(red,$hue:-91);
  c-90: adjust-color(red,$hue:-90);
  c-89: adjust-color(red,$hue:-89);
  c-88: adjust-color(red,$hue:-88);
  c-87: adjust-color(red,$hue:-87);
  c-86: adjust-color(red,$hue:-86);
  c-85: adjust-color(red,$hue:-85);
  c-84: adjust-color(red,$hue:-84);
  c-83: adjust-color(red,$hue:-83);
  c-82: adjust-color(red,$hue:-82);
  c-81: adjust-color(red,$hue:-81);
  c-80: adjust-color(red,$hue:-80);
  c-79: adjust-color(red,$hue:-79);
  c-78: adjust-color(red,$hue:-78);
  c-77: adjust-color(red,$hue:-77);
  c-76: adjust-color(red,$hue:-76);
  c-75: adjust-color(red,$hue:-75);
  c-74: adjust-color(red,$hue:-74);
  c-73: adjust-color(red,$hue:-73);
  c-72: adjust-color(red,$hue:-72);
  c-71: adjust-color(red,$hue:-71);
  c-70: adjust-color(red,$hue:-70);
  c-69: adjust-color(red,$hue:-69);
  c-68: adjust-color(red,$hue:-68);
  c-67: adjust-color(red,$hue:-67);
  c-66: adjust-color(red,$hue:-66);
  c-65: adjust-color(red,$hue:-65);
  c-64: adjust-color(red,$hue:-64);
  c-63: adjust-color(red,$hue:-63);
  c-62: adjust-color(red,$hue:-62);
  c-61: adjust-color(red,$hue:-61);
  c-60: adjust-color(red,$hue:-60);
  c-59: adjust-color(red,$hue:-59);
  c-58: adjust-color(red,$hue:-58);
  c-57: adjust-color(red,$hue:-57);
  c-56: adjust-color(red,$hue:-56);
  c-55: adjust-color(red,$hue:-55);
  c-54: adjust-color(red,$hue:-54);
  c-53: adjust-color(red,$hue:-53);
  c-52: adjust-color(red,$hue:-52);
  c-51: adjust-color(red,$hue:-51);
  c-50: adjust-color(red,$hue:-50);
  c-49: adjust-color(red,$hue:-49);
  c-48: adjust-color(red,$hue:-48);
  c-47: adjust-color(red,$hue:-47);
  c-46: adjust-color(red,$hue:-46);
  c-45: adjust-color(red,$hue:-45);
  c-44: adjust-color(red,$hue:-44);
  c-43: adjust-color(red,$hue:-43);
  c-42: adjust-color(red,$hue:-42);
  c-41: adjust-color(red,$hue:-41);
  c-40: adjust-color(red,$hue:-40);
  c-39: adjust-color(red,$hue:-39);
  c-38: adjust-color(red,$hue:-38);
  c-37: adjust-color(red,$hue:-37);
  c-36: adjust-color(red,$hue:-36);
  c-35: adjust-color(red,$hue:-35);
  c-34: adjust-color(red,$hue:-34);
  c-33: adjust-color(red,$hue:-33);
  c-32: adjust-color(red,$hue:-32);
  c-31: adjust-color(red,$hue:-31);
  c-30: adjust-color(red,$hue:-30);
  c-29: adjust-color(red,$hue:-29);
  c-28: adjust-color(red,$hue:-28);
  c-27: adjust-color(red,$hue:-27);
  c-26: adjust-color(red,$hue:-26);
  c-25: adjust-color(red,$hue:-25);
  c-24: adjust-color(red,$hue:-24);
  c-23: adjust-color(red,$hue:-23);
  c-22: adjust-color(red,$hue:-22);
  c-21: adjust-color(red,$hue:-21);
  c-20: adjust-color(red,$hue:-20);
  c-19: adjust-color(red,$hue:-19);
  c-18: adjust-color(red,$hue:-18);
  c-17: adjust-color(red,$hue:-17);
  c-16: adjust-color(red,$hue:-16);
  c-15: adjust-color(red,$hue:-15);
  c-14: adjust-color(red,$hue:-14);
  c-13: adjust-color(red,$hue:-13);
  c-12: adjust-color(red,$hue:-12);
  c-11: adjust-color(red,$hue:-11);
  c-10: adjust-color(red,$hue:-10);
  c-9: adjust-color(red,$hue:-9);
  c-8: adjust-color(red,$hue:-8);
  c-7: adjust-color(red,$hue:-7);
  c-6: adjust-color(red,$hue:-6);
  c-5: adjust-color(red,$hue:-5);
  c-4: adjust-color(red,$hue:-4);
  c-3: adjust-color(red,$hue:-3);
  c-2: adjust-color(red,$hue:-2);
  c-1: adjust-color(red,$hue:-1);
  c0: adjust-color(red,$hue:0);
  c1: adjust-color(red,$hue:1);
  c2: adjust-color(red,$hue:2);
  c3: adjust-color(red,$hue:3);
  c4: adjust-color(red,$hue:4);
  c5: adjust-color(red,$hue:5);
  c6: adjust-color(red,$hue:6);
  c7: adjust-color(red,$hue:7);
  c8: adjust-color(red,$hue:8);
  c9: adjust-color(red,$hue:9);
  c10: adjust-color(red,$hue:10);
  c11: adjust-color(red,$hue:11);
  c12: adjust-color(red,$hue:12);
  c13: adjust-color(red,$hue:13);
  c14: adjust-color(red,$hue:14);
  c15: adjust-color(red,$hue:15);
  c16: adjust-color(red,$hue:16);
  c17: adjust-color(red,$hue:17);
  c18: adjust-color(red,$hue:18);
  c19: adjust-color(red,$hue:19);
  c20: adjust-color(red,$hue:20);
  c21: adjust-color(red,$hue:21);
  c22: adjust-color(red,$hue:22);
  c23: adjust-color(red,$hue:23);
  c24: adjust-color(red,$hue:24);
  c25: adjust-color(red,$hue:25);
  c26: adjust-color(red,$hue:26);
  c27: adjust-color(red,$hue:27);
  c28: adjust-color(red,$hue:28);
  c29: adjust-color(red,$hue:29);
  c30: adjust-color(red,$hue:30);
  c31: adjust-color(red,$hue:31);
  c32: adjust-color(red,$hue:32);
  c33: adjust-color(red,$hue:33);
  c34: adjust-color(red,$hue:34);
  c35: adjust-color(red,$hue:35);
  c36: adjust-color(red,$hue:36);
  c37: adjust-color(red,$hue:37);
  c38: adjust-color(red,$hue:38);
  c39: adjust-color(red,$hue:39);
  c40: adjust-color(red,$hue:40);
  c41: adjust-color(red,$hue:41);
  c42: adjust-color(red,$hue:42);
  c43: adjust-color(red,$hue:43);
  c44: adjust-color(red,$hue:44);
  c45: adjust-color(red,$hue:45);
  c46: adjust-color(red,$hue:46);
  c47: adjust-color(red,$hue:47);
  c48: adjust-color(red,$hue:48);
  c49: adjust-color(red,$hue:49);
  c50: adjust-color(red,$hue:50);
  c51: adjust-color(red,$hue:51);
  c52: adjust-color(red,$hue:52);
  c53: adjust-color(red,$hue:53);
  c54: adjust-color(red,$hue:54);
  c55: adjust-color(red,$hue:55);
  c56: adjust-color(red,$hue:56);
  c57: adjust-color(red,$hue:57);
  c58: adjust-color(red,$hue:58);
  c59: adjust-color(red,$hue:59);
  c60: adjust-color(red,$hue:60);
  c61: adjust-color(red,$hue:61);
  c62: adjust-color(red,$hue:62);
  c63: adjust-color(red,$hue:63);
  c64: adjust-color(red,$hue:64);
  c65: adjust-color(red,$hue:65);
  c66: adjust-color(red,$hue:66);
  c67: adjust-color(red,$hue:67);
  c68: adjust-color(red,$hue:68);
  c69: adjust-color(red,$hue:69);
  c70: adjust-color(red,$hue:70);
  c71: adjust-color(red,$hue:71);
  c72: adjust-color(red,$hue:72);
  c73: adjust-color(red,$hue:73);
  c74: adjust-color(red,$hue:74);
  c75: adjust-color(red,$hue:75);
  c76: adjust-color(red,$hue:76);
  c77: adjust-color(red,$hue:77);
  c78: adjust-color(red,$hue:78);
  c79: adjust-color(red,$hue:79);
  c80: adjust-color(red,$hue:80);
  c81: adjust-color(red,$hue:81);
  c82: adjust-color(red,$hue:82);
  c83: adjust-color(red,$hue:83);
  c84: adjust-color(red,$hue:84);
  c85: adjust-color(red,$hue:85);
  c86: adjust-color(red,$hue:86);
  c87: adjust-color(red,$hue:87);
  c88: adjust-color(red,$hue:88);
  c89: adjust-color(red,$hue:89);
  c90: adjust-color(red,$hue:90);
  c91: adjust-color(red,$hue:91);
  c92: adjust-color(red,$hue:92);
  c93: adjust-color(red,$hue:93);
  c94: adjust-color(red,$hue:94);
  c95: adjust-color(red,$hue:95);
  c96: adjust-color(red,$hue:96);
  c97: adjust-color(red,$hue:97);
  c98: adjust-color(red,$hue:98);
  c99: adjust-color(red,$hue:99);
  c100: adjust-color(red,$hue:100);
  c101: adjust-color(red,$hue:101);
  c102: adjust-color(red,$hue:102);
  c103: adjust-color(red,$hue:103);
  c104: adjust-color(red,$hue:104);
  c105: adjust-color(red,$hue:105);
  c106: adjust-color(red,$hue:106);
  c107: adjust-color(red,$hue:107);
  c108: adjust-color(red,$hue:108);
  c109: adjust-color(red,$hue:109);
  c110: adjust-color(red,$hue:110);
  c111: adjust-color(red,$hue:111);
  c112: adjust-color(red,$hue:112);
  c113: adjust-color(red,$hue:113);
  c114: adjust-color(red,$hue:114);
  c115: adjust-color(red,$hue:115);
  c116: adjust-color(red,$hue:116);
  c117: adjust-color(red,$hue:117);
  c118: adjust-color(red,$hue:118);
  c119: adjust-color(red,$hue:119);
  c120: adjust-color(red,$hue:120);
  c121: adjust-color(red,$hue:121);
  c122: adjust-color(red,$hue:122);
  c123: adjust-color(red,$hue:123);
  c124: adjust-color(red,$hue:124);
  c125: adjust-color(red,$hue:125);
  c126: adjust-color(red,$hue:126);
  c127: adjust-color(red,$hue:127);
  c128: adjust-color(red,$hue:128);
  c129: adjust-color(red,$hue:129);
  c130: adjust-color(red,$hue:130);
  c131: adjust-color(red,$hue:131);
  c132: adjust-color(red,$hue:132);
  c133: adjust-color(red,$hue:133);
  c134: adjust-color(red,$hue:134);
  c135: adjust-color(red,$hue:135);
  c136: adjust-color(red,$hue:136);
  c137: adjust-color(red,$hue:137);
  c138: adjust-color(red,$hue:138);
  c139: adjust-color(red,$hue:139);
  c140: adjust-color(red,$hue:140);
  c141: adjust-color(red,$hue:141);
  c142: adjust-color(red,$hue:142);
  c143: adjust-color(red,$hue:143);
  c144: adjust-color(red,$hue:144);
  c145: adjust-color(red,$hue:145);
  c146: adjust-color(red,$hue:146);
  c147: adjust-color(red,$hue:147);
  c148: adjust-color(red,$hue:148);
  c149: adjust-color(red,$hue:149);
  c150: adjust-color(red,$hue:150);
  c151: adjust-color(red,$hue:151);
  c152: adjust-color(red,$hue:152);
  c153: adjust-color(red,$hue:153);
  c154: adjust-color(red,$hue:154);
  c155: adjust-color(red,$hue:155);
  c156: adjust-color(red,$hue:156);
  c157: adjust-color(red,$hue:157);
  c158: adjust-color(red,$hue:158);
  c159: adjust-color(red,$hue:159);
  c160: adjust-color(red,$hue:160);
  c161: adjust-color(red,$hue:161);
  c162: adjust-color(red,$hue:162);
  c163: adjust-color(red,$hue:163);
  c164: adjust-color(red,$hue:164);
  c165: adjust-color(red,$hue:165);
  c166: adjust-color(red,$hue:166);
  c167: adjust-color(red,$hue:167);
  c168: adjust-color(red,$hue:168);
  c169: adjust-color(red,$hue:169);
  c170: adjust-color(red,$hue:170);
  c171: adjust-color(red,$hue:171);
  c172: adjust-color(red,$hue:172);
  c173: adjust-color(red,$hue:173);
  c174: adjust-color(red,$hue:174);
  c175: adjust-color(red,$hue:175);
  c176: adjust-color(red,$hue:176);
  c177: adjust-color(red,$hue:177);
  c178: adjust-color(red,$hue:178);
  c179: adjust-color(red,$hue:179);
  c180: adjust-color(red,$hue:180);
  c181: adjust-color(red,$hue:181);
  c182: adjust-color(red,$hue:182);
  c183: adjust-color(red,$hue:183);
  c184: adjust-color(red,$hue:184);
  c185: adjust-color(red,$hue:185);
  c186: adjust-color(red,$hue:186);
  c187: adjust-color(red,$hue:187);
  c188: adjust-color(red,$hue:188);
  c189: adjust-color(red,$hue:189);
  c190: adjust-color(red,$hue:190);
  c191: adjust-color(red,$hue:191);
  c192: adjust-color(red,$hue:192);
  c193: adjust-color(red,$hue:193);
  c194: adjust-color(red,$hue:194);
  c195: adjust-color(red,$hue:195);
  c196: adjust-color(red,$hue:196);
  c197: adjust-color(red,$hue:197);
  c198: adjust-color(red,$hue:198);
  c199: adjust-color(red,$hue:199);
  c200: adjust-color(red,$hue:200);
  c201: adjust-color(red,$hue:201);
  c202: adjust-color(red,$hue:202);
  c203: adjust-color(red,$hue:203);
  c204: adjust-color(red,$hue:204);
  c205: adjust-color(red,$hue:205);
  c206: adjust-color(red,$hue:206);
  c207: adjust-color(red,$hue:207);
  c208: adjust-color(red,$hue:208);
  c209: adjust-color(red,$hue:209);
  c210: adjust-color(red,$hue:210);
  c211: adjust-color(red,$hue:211);
  c212: adjust-color(red,$hue:212);
  c213: adjust-color(red,$hue:213);
  c214: adjust-color(red,$hue:214);
  c215: adjust-color(red,$hue:215);
  c216: adjust-color(red,$hue:216);
  c217: adjust-color(red,$hue:217);
  c218: adjust-color(red,$hue:218);
  c219: adjust-color(red,$hue:219);
  c220: adjust-color(red,$hue:220);
  c221: adjust-color(red,$hue:221);
  c222: adjust-color(red,$hue:222);
  c223: adjust-color(red,$hue:223);
  c224: adjust-color(red,$hue:224);
  c225: adjust-color(red,$hue:225);
  c226: adjust-color(red,$hue:226);
  c227: adjust-color(red,$hue:227);
  c228: adjust-color(red,$hue:228);
  c229: adjust-color(red,$hue:229);
  c230: adjust-color(red,$hue:230);
  c231: adjust-color(red,$hue:231);
  c232: adjust-color(red,$hue:232);
  c233: adjust-color(red,$hue:233);
  c234: adjust-color(red,$hue:234);
  c235: adjust-color(red,$hue:235);
  c236: adjust-color(red,$hue:236);
  c237: adjust-color(red,$hue:237);
  c238: adjust-color(red,$hue:238);
  c239: adjust-color(red,$hue:239);
  c240: adjust-color(red,$hue:240);
  c241: adjust-color(red,$hue:241);
  c242: adjust-color(red,$hue:242);
  c243: adjust-color(red,$hue:243);
  c244: adjust-color(red,$hue:244);
  c245: adjust-color(red,$hue:245);
  c246: adjust-color(red,$hue:246);
  c247: adjust-color(red,$hue:247);
  c248: adjust-color(red,$hue:248);
  c249: adjust-color(red,$hue:249);
  c250: adjust-color(red,$hue:250);
  c251: adjust-color(red,$hue:251);
  c252: adjust-color(red,$hue:252);
  c253: adjust-color(red,$hue:253);
  c254: adjust-color(red,$hue:254);
  c255: adjust-color(red,$hue:255);
  c256: adjust-color(red,$hue:256);
  c257: adjust-color(red,$hue:257);
  c258: adjust-color(red,$hue:258);
  c259: adjust-color(red,$hue:259);
  c260: adjust-color(red,$hue:260);
  c261: adjust-color(red,$hue:261);
  c262: adjust-color(red,$hue:262);
  c263: adjust-color(red,$hue:263);
  c264: adjust-color(red,$hue:264);
  c265: adjust-color(red,$hue:265);
  c266: adjust-color(red,$hue:266);
  c267: adjust-color(red,$hue:267);
  c268: adjust-color(red,$hue:268);
  c269: adjust-color(red,$hue:269);
  c270: adjust-color(red,$hue:270);
  c271: adjust-color(red,$hue:271);
  c272: adjust-color(red,$hue:272);
  c273: adjust-color(red,$hue:273);
  c274: adjust-color(red,$hue:274);
  c275: adjust-color(red,$hue:275);
  c276: adjust-color(red,$hue:276);
  c277: adjust-color(red,$hue:277);
  c278: adjust-color(red,$hue:278);
  c279: adjust-color(red,$hue:279);
  c280: adjust-color(red,$hue:280);
  c281: adjust-color(red,$hue:281);
  c282: adjust-color(red,$hue:282);
  c283: adjust-color(red,$hue:283);
  c284: adjust-color(red,$hue:284);
  c285: adjust-color(red,$hue:285);
  c286: adjust-color(red,$hue:286);
  c287: adjust-color(red,$hue:287);
  c288: adjust-color(red,$hue:288);
  c289: adjust-color(red,$hue:289);
  c290: adjust-color(red,$hue:290);
  c291: adjust-color(red,$hue:291);
  c292: adjust-color(red,$hue:292);
  c293: adjust-color(red,$hue:293);
  c294: adjust-color(red,$hue:294);
  c295: adjust-color(red,$hue:295);
  c296: adjust-color(red,$hue:296);
  c297: adjust-color(red,$hue:297);
  c298: adjust-color(red,$hue:298);
  c299: adjust-color(red,$hue:299);
  c300: adjust-color(red,$hue:300);
  c301: adjust-color(red,$hue:301);
  c302: adjust-color(red,$hue:302);
  c303: adjust-color(red,$hue:303);
  c304: adjust-color(red,$hue:304);
  c305: adjust-color(red,$hue:305);
  c306: adjust-color(red,$hue:306);
  c307: adjust-color(red,$hue:307);
  c308: adjust-color(red,$hue:308);
  c309: adjust-color(red,$hue:309);
  c310: adjust-color(red,$hue:310);
  c311: adjust-color(red,$hue:311);
  c312: adjust-color(red,$hue:312);
  c313: adjust-color(red,$hue:313);
  c314: adjust-color(red,$hue:314);
  c315: adjust-color(red,$hue:315);
  c316: adjust-color(red,$hue:316);
  c317: adjust-color(red,$hue:317);
  c318: adjust-color(red,$hue:318);
  c319: adjust-color(red,$hue:319);
  c320: adjust-color(red,$hue:320);
  c321: adjust-color(red,$hue:321);
  c322: adjust-color(red,$hue:322);
  c323: adjust-color(red,$hue:323);
  c324: adjust-color(red,$hue:324);
  c325: adjust-color(red,$hue:325);
  c326: adjust-color(red,$hue:326);
  c327: adjust-color(red,$hue:327);
  c328: adjust-color(red,$hue:328);
  c329: adjust-color(red,$hue:329);
  c330: adjust-color(red,$hue:330);
  c331: adjust-color(red,$hue:331);
  c332: adjust-color(red,$hue:332);
  c333: adjust-color(red,$hue:333);
  c334: adjust-color(red,$hue:334);
  c335: adjust-color(red,$hue:335);
  c336: adjust-color(red,$hue:336);
  c337: adjust-color(red,$hue:337);
  c338: adjust-color(red,$hue:338);
  c339: adjust-color(red,$hue:339);
  c340: adjust-color(red,$hue:340);
  c341: adjust-color(red,$hue:341);
  c342: adjust-color(red,$hue:342);
  c343: adjust-color(red,$hue:343);
  c344: adjust-color(red,$hue:344);
  c345: adjust-color(red,$hue:345);
  c346: adjust-color(red,$hue:346);
  c347: adjust-color(red,$hue:347);
  c348: adjust-color(red,$hue:348);
  c349: adjust-color(red,$hue:349);
  c350: adjust-color(red,$hue:350);
  c351: adjust-color(red,$hue:351);
  c352: adjust-color(red,$hue:352);
  c353: adjust-color(red,$hue:353);
  c354: adjust-color(red,$hue:354);
  c355: adjust-color(red,$hue:355);
  c356: adjust-color(red,$hue:356);
  c357: adjust-color(red,$hue:357);
  c358: adjust-color(red,$hue:358);
  c359: adjust-color(red,$hue:359);
  c360: adjust-color(red,$hue:360);
  c361: adjust-color(red,$hue:361);
}
