test {
  test-01: #{if(&, 'true', 'false')};
  test-01: #{if(0, 'true', 'false')};
  test-01: #{if('', 'true', 'false')};
  test-01: #{if('0', 'true', 'false')};
  test-01: #{if(null, 'true', 'false')};
  test-01: #{if(false, 'true', 'false')};
}

#{if(&, 'has-parent', 'parentless')} {
  test: parent;
}

@mixin with-js() {
  .js:root #{if(&, '&', '')} {
    @content;
  }
}

@include with-js() {
  .bou {
    content: 'bar';
  }
}

.bou {
  @include with-js() {
    .bar {
      content: 'baz';
    }
  }
}

