div span { moo: goo; }

foo { blah: blah; }
foo goo { blee: blee; hello: world; }
foo goo hoo { mux: scooba-dee-doo; flux: gooboo boo; }
foo goo hoo d { inside: d now; }
foo blux { hey: another thing; ho: will this work; }
