$blah: a b c;
$bloo: "hello";

div {
  color: red;
  width: 100%;
  $blah: a b c;
  $bloo: "hello";

  div {
    color: red;
    width: 100%;
    p {
      margin: $blah;
      $blee: goodbye;
      padding: 10px 5px;
      a {
        display: inline-block;
        padding: 5px;
        color: $blee;
      }
      foo: $bloo;
      empty {
        not-empty {
          background: lightgray;
          border: 1px solid blue;
          span {
            display: block;
            -webkit-box-sizing: border-box;
          }
          $blah: a b c;
          $bloo: "hello";

          div {
            color: red;
            width: 100%;
            p {
              margin: $blah;
              $blee: goodbye;
              padding: 10px 5px;
              a {
                display: inline-block;
                padding: 5px;
                color: $blee;
              }
              foo: $bloo;
              empty {
                not-empty {
                  background: lightgray;
                  border: 1px solid blue;
                  span {
                    display: block;
                    -webkit-box-sizing: border-box;
                  }
                }
              }
            }
            div {
              color: red;
              width: 100%;
              p {
                margin: $blah;
                $blee: goodbye;
                padding: 10px 5px;
                a {
                  display: inline-block;
                  padding: 5px;
                  color: $blee;
                }
                foo: $bloo;
                empty {
                  not-empty {
                    background: lightgray;
                    border: 1px solid blue;
                    span {
                      display: block;
                      -webkit-box-sizing: border-box;
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
    div {
      color: red;
      width: 100%;
      p {
        margin: $blah;
        $blee: goodbye;
        padding: 10px 5px;
        a {
          display: inline-block;
          padding: 5px;
          color: $blee;
        }
        foo: $bloo;
        empty {
          not-empty {
            background: lightgray;
            border: 1px solid blue;
            span {
              display: block;
              -webkit-box-sizing: border-box;
            }
          }
        }
      }
    }
  }
  p {
    margin: $blah;
    $blee: goodbye;
    padding: 10px 5px;
    a {
      display: inline-block;
      padding: 5px;
      color: $blee;
      $blah: a b c;
      $bloo: "hello";

      div {
        color: red;
        width: 100%;
        $blah: a b c;
        $bloo: "hello";

        div {
          color: red;
          width: 100%;
          p {
            margin: $blah;
            $blee: goodbye;
            padding: 10px 5px;
            a {
              display: inline-block;
              padding: 5px;
              color: $blee;
            }
            foo: $bloo;
            empty {
              not-empty {
                background: lightgray;
                border: 1px solid blue;
                span {
                  display: block;
                  -webkit-box-sizing: border-box;
                }
                $blah: a b c;
                $bloo: "hello";

                div {
                  color: red;
                  width: 100%;
                  p {
                    margin: $blah;
                    $blee: goodbye;
                    padding: 10px 5px;
                    a {
                      display: inline-block;
                      padding: 5px;
                      color: $blee;
                    }
                    foo: $bloo;
                    empty {
                      not-empty {
                        background: lightgray;
                        border: 1px solid blue;
                        span {
                          display: block;
                          -webkit-box-sizing: border-box;
                        }
                      }
                    }
                  }
                  div {
                    color: red;
                    width: 100%;
                    p {
                      margin: $blah;
                      $blee: goodbye;
                      padding: 10px 5px;
                      a {
                        display: inline-block;
                        padding: 5px;
                        color: $blee;
                      }
                      foo: $bloo;
                      empty {
                        not-empty {
                          background: lightgray;
                          border: 1px solid blue;
                          span {
                            display: block;
                            -webkit-box-sizing: border-box;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
          div {
            color: red;
            width: 100%;
            p {
              margin: $blah;
              $blee: goodbye;
              padding: 10px 5px;
              a {
                display: inline-block;
                padding: 5px;
                color: $blee;
              }
              foo: $bloo;
              empty {
                not-empty {
                  background: lightgray;
                  border: 1px solid blue;
                  span {
                    display: block;
                    -webkit-box-sizing: border-box;
                  }
                }
              }
            }
          }
        }
        p {
          margin: $blah;
          $blee: goodbye;
          padding: 10px 5px;
          a {
            display: inline-block;
            padding: 5px;
            color: $blee;
          }
          foo: $bloo;
          empty {
            not-empty {
              background: lightgray;
              border: 1px solid blue;
              span {
                display: block;
                -webkit-box-sizing: border-box;
              }
              $blah: a b c;
              $bloo: "hello";

              div {
                color: red;
                width: 100%;
                p {
                  margin: $blah;
                  $blee: goodbye;
                  padding: 10px 5px;
                  a {
                    display: inline-block;
                    padding: 5px;
                    color: $blee;
                  }
                  foo: $bloo;
                  empty {
                    not-empty {
                      background: lightgray;
                      border: 1px solid blue;
                      span {
                        display: block;
                        -webkit-box-sizing: border-box;
                      }
                    }
                  }
                }
                div {
                  color: red;
                  width: 100%;
                  p {
                    margin: $blah;
                    $blee: goodbye;
                    padding: 10px 5px;
                    a {
                      display: inline-block;
                      padding: 5px;
                      color: $blee;
                    }
                    foo: $bloo;
                    empty {
                      not-empty {
                        background: lightgray;
                        border: 1px solid blue;
                        span {
                          display: block;
                          -webkit-box-sizing: border-box;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
        div {
          color: red;
          width: 100%;
          p {
            margin: $blah;
            $blee: goodbye;
            padding: 10px 5px;
            a {
              display: inline-block;
              padding: 5px;
              color: $blee;
            }
            foo: $bloo;
            empty {
              not-empty {
                background: lightgray;
                border: 1px solid blue;
                span {
                  display: block;
                  -webkit-box-sizing: border-box;
                }
              }
            }
          }
        }
      }
    }
    foo: $bloo;
    empty {
      not-empty {
        background: lightgray;
        border: 1px solid blue;
        span {
          display: block;
          -webkit-box-sizing: border-box;
        }
        $blah: a b c;
        $bloo: "hello";

        div {
          color: red;
          width: 100%;
          p {
            margin: $blah;
            $blee: goodbye;
            padding: 10px 5px;
            a {
              display: inline-block;
              padding: 5px;
              color: $blee;
            }
            foo: $bloo;
            empty {
              not-empty {
                background: lightgray;
                border: 1px solid blue;
                span {
                  display: block;
                  -webkit-box-sizing: border-box;
                }
              }
            }
          }
          div {
            color: red;
            width: 100%;
            p {
              margin: $blah;
              $blee: goodbye;
              padding: 10px 5px;
              a {
                display: inline-block;
                padding: 5px;
                color: $blee;
              }
              foo: $bloo;
              empty {
                not-empty {
                  background: lightgray;
                  border: 1px solid blue;
                  span {
                    display: block;
                    -webkit-box-sizing: border-box;
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  div {
    color: red;
    width: 100%;
    p {
      margin: $blah;
      $blee: goodbye;
      padding: 10px 5px;
      a {
        display: inline-block;
        padding: 5px;
        color: $blee;
      }
      foo: $bloo;
      empty {
        not-empty {
          background: lightgray;
          border: 1px solid blue;
          span {
            display: block;
            -webkit-box-sizing: border-box;
          }
        }
      }
      $blah: a b c;
      $bloo: "hello";

      div {
        color: red;
        width: 100%;
        $blah: a b c;
        $bloo: "hello";

        div {
          color: red;
          width: 100%;
          p {
            margin: $blah;
            $blee: goodbye;
            padding: 10px 5px;
            a {
              display: inline-block;
              padding: 5px;
              color: $blee;
            }
            foo: $bloo;
            empty {
              not-empty {
                background: lightgray;
                border: 1px solid blue;
                span {
                  display: block;
                  -webkit-box-sizing: border-box;
                }
                $blah: a b c;
                $bloo: "hello";

                div {
                  color: red;
                  width: 100%;
                  p {
                    margin: $blah;
                    $blee: goodbye;
                    padding: 10px 5px;
                    a {
                      display: inline-block;
                      padding: 5px;
                      color: $blee;
                    }
                    foo: $bloo;
                    empty {
                      not-empty {
                        background: lightgray;
                        border: 1px solid blue;
                        span {
                          display: block;
                          -webkit-box-sizing: border-box;
                        }
                      }
                    }
                  }
                  div {
                    color: red;
                    width: 100%;
                    p {
                      margin: $blah;
                      $blee: goodbye;
                      padding: 10px 5px;
                      a {
                        display: inline-block;
                        padding: 5px;
                        color: $blee;
                      }
                      foo: $bloo;
                      empty {
                        not-empty {
                          background: lightgray;
                          border: 1px solid blue;
                          span {
                            display: block;
                            -webkit-box-sizing: border-box;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
          div {
            color: red;
            width: 100%;
            p {
              margin: $blah;
              $blee: goodbye;
              padding: 10px 5px;
              a {
                display: inline-block;
                padding: 5px;
                color: $blee;
              }
              foo: $bloo;
              empty {
                not-empty {
                  background: lightgray;
                  border: 1px solid blue;
                  span {
                    display: block;
                    -webkit-box-sizing: border-box;
                  }
                }
              }
            }
          }
        }
        p {
          margin: $blah;
          $blee: goodbye;
          padding: 10px 5px;
          a {
            display: inline-block;
            padding: 5px;
            color: $blee;
            $blah: a b c;
            $bloo: "hello";

            div {
              color: red;
              width: 100%;
              $blah: a b c;
              $bloo: "hello";

              div {
                color: red;
                width: 100%;
                p {
                  margin: $blah;
                  $blee: goodbye;
                  padding: 10px 5px;
                  a {
                    display: inline-block;
                    padding: 5px;
                    color: $blee;
                  }
                  foo: $bloo;
                  empty {
                    not-empty {
                      background: lightgray;
                      border: 1px solid blue;
                      span {
                        display: block;
                        -webkit-box-sizing: border-box;
                      }
                      $blah: a b c;
                      $bloo: "hello";

                      div {
                        color: red;
                        width: 100%;
                        p {
                          margin: $blah;
                          $blee: goodbye;
                          padding: 10px 5px;
                          a {
                            display: inline-block;
                            padding: 5px;
                            color: $blee;
                          }
                          foo: $bloo;
                          empty {
                            not-empty {
                              background: lightgray;
                              border: 1px solid blue;
                              span {
                                display: block;
                                -webkit-box-sizing: border-box;
                              }
                            }
                          }
                        }
                        div {
                          color: red;
                          width: 100%;
                          p {
                            margin: $blah;
                            $blee: goodbye;
                            padding: 10px 5px;
                            a {
                              display: inline-block;
                              padding: 5px;
                              color: $blee;
                            }
                            foo: $bloo;
                            empty {
                              not-empty {
                                background: lightgray;
                                border: 1px solid blue;
                                span {
                                  display: block;
                                  -webkit-box-sizing: border-box;
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
                div {
                  color: red;
                  width: 100%;
                  p {
                    margin: $blah;
                    $blee: goodbye;
                    padding: 10px 5px;
                    a {
                      display: inline-block;
                      padding: 5px;
                      color: $blee;
                    }
                    foo: $bloo;
                    empty {
                      not-empty {
                        background: lightgray;
                        border: 1px solid blue;
                        span {
                          display: block;
                          -webkit-box-sizing: border-box;
                        }
                      }
                    }
                  }
                }
              }
              p {
                margin: $blah;
                $blee: goodbye;
                padding: 10px 5px;
                a {
                  display: inline-block;
                  padding: 5px;
                  color: $blee;
                }
                foo: $bloo;
                empty {
                  not-empty {
                    background: lightgray;
                    border: 1px solid blue;
                    span {
                      display: block;
                      -webkit-box-sizing: border-box;
                    }
                    $blah: a b c;
                    $bloo: "hello";

                    div {
                      color: red;
                      width: 100%;
                      p {
                        margin: $blah;
                        $blee: goodbye;
                        padding: 10px 5px;
                        a {
                          display: inline-block;
                          padding: 5px;
                          color: $blee;
                        }
                        foo: $bloo;
                        empty {
                          not-empty {
                            background: lightgray;
                            border: 1px solid blue;
                            span {
                              display: block;
                              -webkit-box-sizing: border-box;
                            }
                          }
                        }
                      }
                      div {
                        color: red;
                        width: 100%;
                        p {
                          margin: $blah;
                          $blee: goodbye;
                          padding: 10px 5px;
                          a {
                            display: inline-block;
                            padding: 5px;
                            color: $blee;
                          }
                          foo: $bloo;
                          empty {
                            not-empty {
                              background: lightgray;
                              border: 1px solid blue;
                              span {
                                display: block;
                                -webkit-box-sizing: border-box;
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
              div {
                color: red;
                width: 100%;
                p {
                  margin: $blah;
                  $blee: goodbye;
                  padding: 10px 5px;
                  a {
                    display: inline-block;
                    padding: 5px;
                    color: $blee;
                  }
                  foo: $bloo;
                  empty {
                    not-empty {
                      background: lightgray;
                      border: 1px solid blue;
                      span {
                        display: block;
                        -webkit-box-sizing: border-box;
                      }
                    }
                  }
                }
              }
            }
          }
          foo: $bloo;
          empty {
            not-empty {
              background: lightgray;
              border: 1px solid blue;
              span {
                display: block;
                -webkit-box-sizing: border-box;
              }
              $blah: a b c;
              $bloo: "hello";

              div {
                color: red;
                width: 100%;
                p {
                  margin: $blah;
                  $blee: goodbye;
                  padding: 10px 5px;
                  a {
                    display: inline-block;
                    padding: 5px;
                    color: $blee;
                  }
                  foo: $bloo;
                  empty {
                    not-empty {
                      background: lightgray;
                      border: 1px solid blue;
                      span {
                        display: block;
                        -webkit-box-sizing: border-box;
                      }
                    }
                  }
                }
                div {
                  color: red;
                  width: 100%;
                  p {
                    margin: $blah;
                    $blee: goodbye;
                    padding: 10px 5px;
                    a {
                      display: inline-block;
                      padding: 5px;
                      color: $blee;
                    }
                    foo: $bloo;
                    empty {
                      not-empty {
                        background: lightgray;
                        border: 1px solid blue;
                        span {
                          display: block;
                          -webkit-box-sizing: border-box;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
        $blah: a b c;
        $bloo: "hello";

        div {
          color: red;
          width: 100%;
          $blah: a b c;
          $bloo: "hello";

          div {
            color: red;
            width: 100%;
            p {
              margin: $blah;
              $blee: goodbye;
              padding: 10px 5px;
              a {
                display: inline-block;
                padding: 5px;
                color: $blee;
              }
              foo: $bloo;
              empty {
                not-empty {
                  background: lightgray;
                  border: 1px solid blue;
                  span {
                    display: block;
                    -webkit-box-sizing: border-box;
                  }
                  $blah: a b c;
                  $bloo: "hello";

                  div {
                    color: red;
                    width: 100%;
                    p {
                      margin: $blah;
                      $blee: goodbye;
                      padding: 10px 5px;
                      a {
                        display: inline-block;
                        padding: 5px;
                        color: $blee;
                      }
                      foo: $bloo;
                      empty {
                        not-empty {
                          background: lightgray;
                          border: 1px solid blue;
                          span {
                            display: block;
                            -webkit-box-sizing: border-box;
                          }
                        }
                      }
                    }
                    div {
                      color: red;
                      width: 100%;
                      p {
                        margin: $blah;
                        $blee: goodbye;
                        padding: 10px 5px;
                        a {
                          display: inline-block;
                          padding: 5px;
                          color: $blee;
                        }
                        foo: $bloo;
                        empty {
                          not-empty {
                            background: lightgray;
                            border: 1px solid blue;
                            span {
                              display: block;
                              -webkit-box-sizing: border-box;
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
            div {
              color: red;
              width: 100%;
              p {
                margin: $blah;
                $blee: goodbye;
                padding: 10px 5px;
                a {
                  display: inline-block;
                  padding: 5px;
                  color: $blee;
                }
                foo: $bloo;
                empty {
                  not-empty {
                    background: lightgray;
                    border: 1px solid blue;
                    span {
                      display: block;
                      -webkit-box-sizing: border-box;
                    }
                  }
                }
              }
            }
          }
          p {
            margin: $blah;
            $blee: goodbye;
            padding: 10px 5px;
            a {
              display: inline-block;
              padding: 5px;
              color: $blee;
              $blah: a b c;
              $bloo: "hello";

              div {
                color: red;
                width: 100%;
                $blah: a b c;
                $bloo: "hello";

                div {
                  color: red;
                  width: 100%;
                  p {
                    margin: $blah;
                    $blee: goodbye;
                    padding: 10px 5px;
                    a {
                      display: inline-block;
                      padding: 5px;
                      color: $blee;
                    }
                    foo: $bloo;
                    empty {
                      not-empty {
                        background: lightgray;
                        border: 1px solid blue;
                        span {
                          display: block;
                          -webkit-box-sizing: border-box;
                        }
                        $blah: a b c;
                        $bloo: "hello";

                        div {
                          color: red;
                          width: 100%;
                          p {
                            margin: $blah;
                            $blee: goodbye;
                            padding: 10px 5px;
                            a {
                              display: inline-block;
                              padding: 5px;
                              color: $blee;
                            }
                            foo: $bloo;
                            empty {
                              not-empty {
                                background: lightgray;
                                border: 1px solid blue;
                                span {
                                  display: block;
                                  -webkit-box-sizing: border-box;
                                }
                              }
                            }
                          }
                          div {
                            color: red;
                            width: 100%;
                            p {
                              margin: $blah;
                              $blee: goodbye;
                              padding: 10px 5px;
                              a {
                                display: inline-block;
                                padding: 5px;
                                color: $blee;
                              }
                              foo: $bloo;
                              empty {
                                not-empty {
                                  background: lightgray;
                                  border: 1px solid blue;
                                  span {
                                    display: block;
                                    -webkit-box-sizing: border-box;
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                  div {
                    color: red;
                    width: 100%;
                    p {
                      margin: $blah;
                      $blee: goodbye;
                      padding: 10px 5px;
                      a {
                        display: inline-block;
                        padding: 5px;
                        color: $blee;
                      }
                      foo: $bloo;
                      empty {
                        not-empty {
                          background: lightgray;
                          border: 1px solid blue;
                          span {
                            display: block;
                            -webkit-box-sizing: border-box;
                          }
                        }
                      }
                    }
                  }
                }
                p {
                  margin: $blah;
                  $blee: goodbye;
                  padding: 10px 5px;
                  a {
                    display: inline-block;
                    padding: 5px;
                    color: $blee;
                  }
                  foo: $bloo;
                  empty {
                    not-empty {
                      background: lightgray;
                      border: 1px solid blue;
                      span {
                        display: block;
                        -webkit-box-sizing: border-box;
                      }
                      $blah: a b c;
                      $bloo: "hello";

                      div {
                        color: red;
                        width: 100%;
                        p {
                          margin: $blah;
                          $blee: goodbye;
                          padding: 10px 5px;
                          a {
                            display: inline-block;
                            padding: 5px;
                            color: $blee;
                          }
                          foo: $bloo;
                          empty {
                            not-empty {
                              background: lightgray;
                              border: 1px solid blue;
                              span {
                                display: block;
                                -webkit-box-sizing: border-box;
                              }
                            }
                          }
                        }
                        div {
                          color: red;
                          width: 100%;
                          p {
                            margin: $blah;
                            $blee: goodbye;
                            padding: 10px 5px;
                            a {
                              display: inline-block;
                              padding: 5px;
                              color: $blee;
                            }
                            foo: $bloo;
                            empty {
                              not-empty {
                                background: lightgray;
                                border: 1px solid blue;
                                span {
                                  display: block;
                                  -webkit-box-sizing: border-box;
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
                div {
                  color: red;
                  width: 100%;
                  p {
                    margin: $blah;
                    $blee: goodbye;
                    padding: 10px 5px;
                    a {
                      display: inline-block;
                      padding: 5px;
                      color: $blee;
                    }
                    foo: $bloo;
                    empty {
                      not-empty {
                        background: lightgray;
                        border: 1px solid blue;
                        span {
                          display: block;
                          -webkit-box-sizing: border-box;
                        }
                      }
                    }
                  }
                }
              }
            }
            foo: $bloo;
            empty {
              not-empty {
                background: lightgray;
                border: 1px solid blue;
                span {
                  display: block;
                  -webkit-box-sizing: border-box;
                }
                $blah: a b c;
                $bloo: "hello";

                div {
                  color: red;
                  width: 100%;
                  p {
                    margin: $blah;
                    $blee: goodbye;
                    padding: 10px 5px;
                    a {
                      display: inline-block;
                      padding: 5px;
                      color: $blee;
                    }
                    foo: $bloo;
                    empty {
                      not-empty {
                        background: lightgray;
                        border: 1px solid blue;
                        span {
                          display: block;
                          -webkit-box-sizing: border-box;
                        }
                      }
                    }
                  }
                  div {
                    color: red;
                    width: 100%;
                    p {
                      margin: $blah;
                      $blee: goodbye;
                      padding: 10px 5px;
                      a {
                        display: inline-block;
                        padding: 5px;
                        color: $blee;
                      }
                      foo: $bloo;
                      empty {
                        not-empty {
                          background: lightgray;
                          border: 1px solid blue;
                          span {
                            display: block;
                            -webkit-box-sizing: border-box;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
          div {
            color: red;
            width: 100%;
            p {
              margin: $blah;
              $blee: goodbye;
              padding: 10px 5px;
              a {
                display: inline-block;
                padding: 5px;
                color: $blee;
              }
              foo: $bloo;
              empty {
                not-empty {
                  background: lightgray;
                  border: 1px solid blue;
                  span {
                    display: block;
                    -webkit-box-sizing: border-box;
                  }
                }
              }
              $blah: a b c;
              $bloo: "hello";

              div {
                color: red;
                width: 100%;
                $blah: a b c;
                $bloo: "hello";

                div {
                  color: red;
                  width: 100%;
                  p {
                    margin: $blah;
                    $blee: goodbye;
                    padding: 10px 5px;
                    a {
                      display: inline-block;
                      padding: 5px;
                      color: $blee;
                    }
                    foo: $bloo;
                    empty {
                      not-empty {
                        background: lightgray;
                        border: 1px solid blue;
                        span {
                          display: block;
                          -webkit-box-sizing: border-box;
                        }
                        $blah: a b c;
                        $bloo: "hello";

                        div {
                          color: red;
                          width: 100%;
                          p {
                            margin: $blah;
                            $blee: goodbye;
                            padding: 10px 5px;
                            a {
                              display: inline-block;
                              padding: 5px;
                              color: $blee;
                            }
                            foo: $bloo;
                            empty {
                              not-empty {
                                background: lightgray;
                                border: 1px solid blue;
                                span {
                                  display: block;
                                  -webkit-box-sizing: border-box;
                                }
                              }
                            }
                          }
                          div {
                            color: red;
                            width: 100%;
                            p {
                              margin: $blah;
                              $blee: goodbye;
                              padding: 10px 5px;
                              a {
                                display: inline-block;
                                padding: 5px;
                                color: $blee;
                              }
                              foo: $bloo;
                              empty {
                                not-empty {
                                  background: lightgray;
                                  border: 1px solid blue;
                                  span {
                                    display: block;
                                    -webkit-box-sizing: border-box;
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                  div {
                    color: red;
                    width: 100%;
                    p {
                      margin: $blah;
                      $blee: goodbye;
                      padding: 10px 5px;
                      a {
                        display: inline-block;
                        padding: 5px;
                        color: $blee;
                      }
                      foo: $bloo;
                      empty {
                        not-empty {
                          background: lightgray;
                          border: 1px solid blue;
                          span {
                            display: block;
                            -webkit-box-sizing: border-box;
                          }
                        }
                      }
                    }
                  }
                }
                p {
                  margin: $blah;
                  $blee: goodbye;
                  padding: 10px 5px;
                  a {
                    display: inline-block;
                    padding: 5px;
                    color: $blee;
                    $blah: a b c;
                    $bloo: "hello";

                    div {
                      color: red;
                      width: 100%;
                      $blah: a b c;
                      $bloo: "hello";

                      div {
                        color: red;
                        width: 100%;
                        p {
                          margin: $blah;
                          $blee: goodbye;
                          padding: 10px 5px;
                          a {
                            display: inline-block;
                            padding: 5px;
                            color: $blee;
                          }
                          foo: $bloo;
                          empty {
                            not-empty {
                              background: lightgray;
                              border: 1px solid blue;
                              span {
                                display: block;
                                -webkit-box-sizing: border-box;
                              }
                              $blah: a b c;
                              $bloo: "hello";

                              div {
                                color: red;
                                width: 100%;
                                p {
                                  margin: $blah;
                                  $blee: goodbye;
                                  padding: 10px 5px;
                                  a {
                                    display: inline-block;
                                    padding: 5px;
                                    color: $blee;
                                  }
                                  foo: $bloo;
                                  empty {
                                    not-empty {
                                      background: lightgray;
                                      border: 1px solid blue;
                                      span {
                                        display: block;
                                        -webkit-box-sizing: border-box;
                                      }
                                    }
                                  }
                                }
                                div {
                                  color: red;
                                  width: 100%;
                                  p {
                                    margin: $blah;
                                    $blee: goodbye;
                                    padding: 10px 5px;
                                    a {
                                      display: inline-block;
                                      padding: 5px;
                                      color: $blee;
                                    }
                                    foo: $bloo;
                                    empty {
                                      not-empty {
                                        background: lightgray;
                                        border: 1px solid blue;
                                        span {
                                          display: block;
                                          -webkit-box-sizing: border-box;
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                        div {
                          color: red;
                          width: 100%;
                          p {
                            margin: $blah;
                            $blee: goodbye;
                            padding: 10px 5px;
                            a {
                              display: inline-block;
                              padding: 5px;
                              color: $blee;
                            }
                            foo: $bloo;
                            empty {
                              not-empty {
                                background: lightgray;
                                border: 1px solid blue;
                                span {
                                  display: block;
                                  -webkit-box-sizing: border-box;
                                }
                              }
                            }
                          }
                        }
                      }
                      p {
                        margin: $blah;
                        $blee: goodbye;
                        padding: 10px 5px;
                        a {
                          display: inline-block;
                          padding: 5px;
                          color: $blee;
                        }
                        foo: $bloo;
                        empty {
                          not-empty {
                            background: lightgray;
                            border: 1px solid blue;
                            span {
                              display: block;
                              -webkit-box-sizing: border-box;
                            }
                            $blah: a b c;
                            $bloo: "hello";

                            div {
                              color: red;
                              width: 100%;
                              p {
                                margin: $blah;
                                $blee: goodbye;
                                padding: 10px 5px;
                                a {
                                  display: inline-block;
                                  padding: 5px;
                                  color: $blee;
                                }
                                foo: $bloo;
                                empty {
                                  not-empty {
                                    background: lightgray;
                                    border: 1px solid blue;
                                    span {
                                      display: block;
                                      -webkit-box-sizing: border-box;
                                    }
                                  }
                                }
                              }
                              div {
                                color: red;
                                width: 100%;
                                p {
                                  margin: $blah;
                                  $blee: goodbye;
                                  padding: 10px 5px;
                                  a {
                                    display: inline-block;
                                    padding: 5px;
                                    color: $blee;
                                  }
                                  foo: $bloo;
                                  empty {
                                    not-empty {
                                      background: lightgray;
                                      border: 1px solid blue;
                                      span {
                                        display: block;
                                        -webkit-box-sizing: border-box;
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                      div {
                        color: red;
                        width: 100%;
                        p {
                          margin: $blah;
                          $blee: goodbye;
                          padding: 10px 5px;
                          a {
                            display: inline-block;
                            padding: 5px;
                            color: $blee;
                          }
                          foo: $bloo;
                          empty {
                            not-empty {
                              background: lightgray;
                              border: 1px solid blue;
                              span {
                                display: block;
                                -webkit-box-sizing: border-box;
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                  foo: $bloo;
                  empty {
                    not-empty {
                      background: lightgray;
                      border: 1px solid blue;
                      span {
                        display: block;
                        -webkit-box-sizing: border-box;
                      }
                      $blah: a b c;
                      $bloo: "hello";

                      div {
                        color: red;
                        width: 100%;
                        p {
                          margin: $blah;
                          $blee: goodbye;
                          padding: 10px 5px;
                          a {
                            display: inline-block;
                            padding: 5px;
                            color: $blee;
                          }
                          foo: $bloo;
                          empty {
                            not-empty {
                              background: lightgray;
                              border: 1px solid blue;
                              span {
                                display: block;
                                -webkit-box-sizing: border-box;
                              }
                            }
                          }
                        }
                        div {
                          color: red;
                          width: 100%;
                          p {
                            margin: $blah;
                            $blee: goodbye;
                            padding: 10px 5px;
                            a {
                              display: inline-block;
                              padding: 5px;
                              color: $blee;
                            }
                            foo: $bloo;
                            empty {
                              not-empty {
                                background: lightgray;
                                border: 1px solid blue;
                                span {
                                  display: block;
                                  -webkit-box-sizing: border-box;
                                }
                              }
                            }
                          }
                        }
                      }
                      $blah: a b c;
                      $bloo: "hello";

                      div {
                        color: red;
                        width: 100%;
                        $blah: a b c;
                        $bloo: "hello";

                        div {
                          color: red;
                          width: 100%;
                          p {
                            margin: $blah;
                            $blee: goodbye;
                            padding: 10px 5px;
                            a {
                              display: inline-block;
                              padding: 5px;
                              color: $blee;
                            }
                            foo: $bloo;
                            empty {
                              not-empty {
                                background: lightgray;
                                border: 1px solid blue;
                                span {
                                  display: block;
                                  -webkit-box-sizing: border-box;
                                }
                                $blah: a b c;
                                $bloo: "hello";

                                div {
                                  color: red;
                                  width: 100%;
                                  p {
                                    margin: $blah;
                                    $blee: goodbye;
                                    padding: 10px 5px;
                                    a {
                                      display: inline-block;
                                      padding: 5px;
                                      color: $blee;
                                    }
                                    foo: $bloo;
                                    empty {
                                      not-empty {
                                        background: lightgray;
                                        border: 1px solid blue;
                                        span {
                                          display: block;
                                          -webkit-box-sizing: border-box;
                                        }
                                      }
                                    }
                                  }
                                  div {
                                    color: red;
                                    width: 100%;
                                    p {
                                      margin: $blah;
                                      $blee: goodbye;
                                      padding: 10px 5px;
                                      a {
                                        display: inline-block;
                                        padding: 5px;
                                        color: $blee;
                                      }
                                      foo: $bloo;
                                      empty {
                                        not-empty {
                                          background: lightgray;
                                          border: 1px solid blue;
                                          span {
                                            display: block;
                                            -webkit-box-sizing: border-box;
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                          div {
                            color: red;
                            width: 100%;
                            p {
                              margin: $blah;
                              $blee: goodbye;
                              padding: 10px 5px;
                              a {
                                display: inline-block;
                                padding: 5px;
                                color: $blee;
                              }
                              foo: $bloo;
                              empty {
                                not-empty {
                                  background: lightgray;
                                  border: 1px solid blue;
                                  span {
                                    display: block;
                                    -webkit-box-sizing: border-box;
                                  }
                                }
                              }
                            }
                          }
                        }
                        p {
                          margin: $blah;
                          $blee: goodbye;
                          padding: 10px 5px;
                          a {
                            display: inline-block;
                            padding: 5px;
                            color: $blee;
                            $blah: a b c;
                            $bloo: "hello";

                            div {
                              color: red;
                              width: 100%;
                              $blah: a b c;
                              $bloo: "hello";

                              div {
                                color: red;
                                width: 100%;
                                p {
                                  margin: $blah;
                                  $blee: goodbye;
                                  padding: 10px 5px;
                                  a {
                                    display: inline-block;
                                    padding: 5px;
                                    color: $blee;
                                  }
                                  foo: $bloo;
                                  empty {
                                    not-empty {
                                      background: lightgray;
                                      border: 1px solid blue;
                                      span {
                                        display: block;
                                        -webkit-box-sizing: border-box;
                                      }
                                      $blah: a b c;
                                      $bloo: "hello";

                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                            }
                                          }
                                        }
                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                                div {
                                  color: red;
                                  width: 100%;
                                  p {
                                    margin: $blah;
                                    $blee: goodbye;
                                    padding: 10px 5px;
                                    a {
                                      display: inline-block;
                                      padding: 5px;
                                      color: $blee;
                                    }
                                    foo: $bloo;
                                    empty {
                                      not-empty {
                                        background: lightgray;
                                        border: 1px solid blue;
                                        span {
                                          display: block;
                                          -webkit-box-sizing: border-box;
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                              p {
                                margin: $blah;
                                $blee: goodbye;
                                padding: 10px 5px;
                                a {
                                  display: inline-block;
                                  padding: 5px;
                                  color: $blee;
                                }
                                foo: $bloo;
                                empty {
                                  not-empty {
                                    background: lightgray;
                                    border: 1px solid blue;
                                    span {
                                      display: block;
                                      -webkit-box-sizing: border-box;
                                    }
                                    $blah: a b c;
                                    $bloo: "hello";

                                    div {
                                      color: red;
                                      width: 100%;
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                          }
                                        }
                                      }
                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                              div {
                                color: red;
                                width: 100%;
                                p {
                                  margin: $blah;
                                  $blee: goodbye;
                                  padding: 10px 5px;
                                  a {
                                    display: inline-block;
                                    padding: 5px;
                                    color: $blee;
                                  }
                                  foo: $bloo;
                                  empty {
                                    not-empty {
                                      background: lightgray;
                                      border: 1px solid blue;
                                      span {
                                        display: block;
                                        -webkit-box-sizing: border-box;
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                          foo: $bloo;
                          empty {
                            not-empty {
                              background: lightgray;
                              border: 1px solid blue;
                              span {
                                display: block;
                                -webkit-box-sizing: border-box;
                              }
                              $blah: a b c;
                              $bloo: "hello";

                              div {
                                color: red;
                                width: 100%;
                                p {
                                  margin: $blah;
                                  $blee: goodbye;
                                  padding: 10px 5px;
                                  a {
                                    display: inline-block;
                                    padding: 5px;
                                    color: $blee;
                                  }
                                  foo: $bloo;
                                  empty {
                                    not-empty {
                                      background: lightgray;
                                      border: 1px solid blue;
                                      span {
                                        display: block;
                                        -webkit-box-sizing: border-box;
                                      }
                                    }
                                  }
                                }
                                div {
                                  color: red;
                                  width: 100%;
                                  p {
                                    margin: $blah;
                                    $blee: goodbye;
                                    padding: 10px 5px;
                                    a {
                                      display: inline-block;
                                      padding: 5px;
                                      color: $blee;
                                    }
                                    foo: $bloo;
                                    empty {
                                      not-empty {
                                        background: lightgray;
                                        border: 1px solid blue;
                                        span {
                                          display: block;
                                          -webkit-box-sizing: border-box;
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                        div {
                          color: red;
                          width: 100%;
                          p {
                            margin: $blah;
                            $blee: goodbye;
                            padding: 10px 5px;
                            a {
                              display: inline-block;
                              padding: 5px;
                              color: $blee;
                            }
                            foo: $bloo;
                            empty {
                              not-empty {
                                background: lightgray;
                                border: 1px solid blue;
                                span {
                                  display: block;
                                  -webkit-box-sizing: border-box;
                                }
                              }
                            }
                            $blah: a b c;
                            $bloo: "hello";

                            div {
                              color: red;
                              width: 100%;
                              $blah: a b c;
                              $bloo: "hello";

                              div {
                                color: red;
                                width: 100%;
                                p {
                                  margin: $blah;
                                  $blee: goodbye;
                                  padding: 10px 5px;
                                  a {
                                    display: inline-block;
                                    padding: 5px;
                                    color: $blee;
                                  }
                                  foo: $bloo;
                                  empty {
                                    not-empty {
                                      background: lightgray;
                                      border: 1px solid blue;
                                      span {
                                        display: block;
                                        -webkit-box-sizing: border-box;
                                      }
                                      $blah: a b c;
                                      $bloo: "hello";

                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                            }
                                          }
                                        }
                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                                div {
                                  color: red;
                                  width: 100%;
                                  p {
                                    margin: $blah;
                                    $blee: goodbye;
                                    padding: 10px 5px;
                                    a {
                                      display: inline-block;
                                      padding: 5px;
                                      color: $blee;
                                    }
                                    foo: $bloo;
                                    empty {
                                      not-empty {
                                        background: lightgray;
                                        border: 1px solid blue;
                                        span {
                                          display: block;
                                          -webkit-box-sizing: border-box;
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                              p {
                                margin: $blah;
                                $blee: goodbye;
                                padding: 10px 5px;
                                a {
                                  display: inline-block;
                                  padding: 5px;
                                  color: $blee;
                                  $blah: a b c;
                                  $bloo: "hello";

                                  div {
                                    color: red;
                                    width: 100%;
                                    $blah: a b c;
                                    $bloo: "hello";

                                    div {
                                      color: red;
                                      width: 100%;
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                            $blah: a b c;
                                            $bloo: "hello";

                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                              }
                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                    p {
                                      margin: $blah;
                                      $blee: goodbye;
                                      padding: 10px 5px;
                                      a {
                                        display: inline-block;
                                        padding: 5px;
                                        color: $blee;
                                      }
                                      foo: $bloo;
                                      empty {
                                        not-empty {
                                          background: lightgray;
                                          border: 1px solid blue;
                                          span {
                                            display: block;
                                            -webkit-box-sizing: border-box;
                                          }
                                          $blah: a b c;
                                          $bloo: "hello";

                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                }
                                              }
                                            }
                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                    div {
                                      color: red;
                                      width: 100%;
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                                foo: $bloo;
                                empty {
                                  not-empty {
                                    background: lightgray;
                                    border: 1px solid blue;
                                    span {
                                      display: block;
                                      -webkit-box-sizing: border-box;
                                    }
                                    $blah: a b c;
                                    $bloo: "hello";

                                    div {
                                      color: red;
                                      width: 100%;
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                          }
                                        }
                                      }
                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                              $blah: a b c;
                              $bloo: "hello";

                              div {
                                color: red;
                                width: 100%;
                                $blah: a b c;
                                $bloo: "hello";

                                div {
                                  color: red;
                                  width: 100%;
                                  p {
                                    margin: $blah;
                                    $blee: goodbye;
                                    padding: 10px 5px;
                                    a {
                                      display: inline-block;
                                      padding: 5px;
                                      color: $blee;
                                    }
                                    foo: $bloo;
                                    empty {
                                      not-empty {
                                        background: lightgray;
                                        border: 1px solid blue;
                                        span {
                                          display: block;
                                          -webkit-box-sizing: border-box;
                                        }
                                        $blah: a b c;
                                        $bloo: "hello";

                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                              }
                                            }
                                          }
                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                  div {
                                    color: red;
                                    width: 100%;
                                    p {
                                      margin: $blah;
                                      $blee: goodbye;
                                      padding: 10px 5px;
                                      a {
                                        display: inline-block;
                                        padding: 5px;
                                        color: $blee;
                                      }
                                      foo: $bloo;
                                      empty {
                                        not-empty {
                                          background: lightgray;
                                          border: 1px solid blue;
                                          span {
                                            display: block;
                                            -webkit-box-sizing: border-box;
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                                p {
                                  margin: $blah;
                                  $blee: goodbye;
                                  padding: 10px 5px;
                                  a {
                                    display: inline-block;
                                    padding: 5px;
                                    color: $blee;
                                    $blah: a b c;
                                    $bloo: "hello";

                                    div {
                                      color: red;
                                      width: 100%;
                                      $blah: a b c;
                                      $bloo: "hello";

                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                              $blah: a b c;
                                              $bloo: "hello";

                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                    }
                                                  }
                                                }
                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                            $blah: a b c;
                                            $bloo: "hello";

                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                              }
                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                  foo: $bloo;
                                  empty {
                                    not-empty {
                                      background: lightgray;
                                      border: 1px solid blue;
                                      span {
                                        display: block;
                                        -webkit-box-sizing: border-box;
                                      }
                                      $blah: a b c;
                                      $bloo: "hello";

                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                            }
                                          }
                                        }
                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                                div {
                                  color: red;
                                  width: 100%;
                                  p {
                                    margin: $blah;
                                    $blee: goodbye;
                                    padding: 10px 5px;
                                    a {
                                      display: inline-block;
                                      padding: 5px;
                                      color: $blee;
                                    }
                                    foo: $bloo;
                                    empty {
                                      not-empty {
                                        background: lightgray;
                                        border: 1px solid blue;
                                        span {
                                          display: block;
                                          -webkit-box-sizing: border-box;
                                        }
                                      }
                                    }
                                    $blah: a b c;
                                    $bloo: "hello";

                                    div {
                                      color: red;
                                      width: 100%;
                                      $blah: a b c;
                                      $bloo: "hello";

                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                              $blah: a b c;
                                              $bloo: "hello";

                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                    }
                                                  }
                                                }
                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                          $blah: a b c;
                                          $bloo: "hello";

                                          div {
                                            color: red;
                                            width: 100%;
                                            $blah: a b c;
                                            $bloo: "hello";

                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                    $blah: a b c;
                                                    $bloo: "hello";

                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                          }
                                                        }
                                                      }
                                                      div {
                                                        color: red;
                                                        width: 100%;
                                                        p {
                                                          margin: $blah;
                                                          $blee: goodbye;
                                                          padding: 10px 5px;
                                                          a {
                                                            display: inline-block;
                                                            padding: 5px;
                                                            color: $blee;
                                                          }
                                                          foo: $bloo;
                                                          empty {
                                                            not-empty {
                                                              background: lightgray;
                                                              border: 1px solid blue;
                                                              span {
                                                                display: block;
                                                                -webkit-box-sizing: border-box;
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                  $blah: a b c;
                                                  $bloo: "hello";

                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                        }
                                                      }
                                                    }
                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                            $blah: a b c;
                                            $bloo: "hello";

                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                              }
                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                              div {
                                color: red;
                                width: 100%;
                                p {
                                  margin: $blah;
                                  $blee: goodbye;
                                  padding: 10px 5px;
                                  a {
                                    display: inline-block;
                                    padding: 5px;
                                    color: $blee;
                                  }
                                  foo: $bloo;
                                  empty {
                                    not-empty {
                                      background: lightgray;
                                      border: 1px solid blue;
                                      span {
                                        display: block;
                                        -webkit-box-sizing: border-box;
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
                div {
                  color: red;
                  width: 100%;
                  p {
                    margin: $blah;
                    $blee: goodbye;
                    padding: 10px 5px;
                    a {
                      display: inline-block;
                      padding: 5px;
                      color: $blee;
                    }
                    foo: $bloo;
                    empty {
                      not-empty {
                        background: lightgray;
                        border: 1px solid blue;
                        span {
                          display: block;
                          -webkit-box-sizing: border-box;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
        div {
          color: red;
          width: 100%;
          p {
            margin: $blah;
            $blee: goodbye;
            padding: 10px 5px;
            a {
              display: inline-block;
              padding: 5px;
              color: $blee;
            }
            foo: $bloo;
            empty {
              not-empty {
                background: lightgray;
                border: 1px solid blue;
                span {
                  display: block;
                  -webkit-box-sizing: border-box;
                }
              }
            }
          }
        }
      }
    }
    $blah: a b c;
    $bloo: "hello";

    div {
      color: red;
      width: 100%;
      $blah: a b c;
      $bloo: "hello";

      div {
        color: red;
        width: 100%;
        p {
          margin: $blah;
          $blee: goodbye;
          padding: 10px 5px;
          a {
            display: inline-block;
            padding: 5px;
            color: $blee;
          }
          foo: $bloo;
          empty {
            not-empty {
              background: lightgray;
              border: 1px solid blue;
              span {
                display: block;
                -webkit-box-sizing: border-box;
              }
              $blah: a b c;
              $bloo: "hello";

              div {
                color: red;
                width: 100%;
                p {
                  margin: $blah;
                  $blee: goodbye;
                  padding: 10px 5px;
                  a {
                    display: inline-block;
                    padding: 5px;
                    color: $blee;
                  }
                  foo: $bloo;
                  empty {
                    not-empty {
                      background: lightgray;
                      border: 1px solid blue;
                      span {
                        display: block;
                        -webkit-box-sizing: border-box;
                      }
                    }
                  }
                }
                div {
                  color: red;
                  width: 100%;
                  p {
                    margin: $blah;
                    $blee: goodbye;
                    padding: 10px 5px;
                    a {
                      display: inline-block;
                      padding: 5px;
                      color: $blee;
                    }
                    foo: $bloo;
                    empty {
                      not-empty {
                        background: lightgray;
                        border: 1px solid blue;
                        span {
                          display: block;
                          -webkit-box-sizing: border-box;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
        div {
          color: red;
          width: 100%;
          p {
            margin: $blah;
            $blee: goodbye;
            padding: 10px 5px;
            a {
              display: inline-block;
              padding: 5px;
              color: $blee;
            }
            foo: $bloo;
            empty {
              not-empty {
                background: lightgray;
                border: 1px solid blue;
                span {
                  display: block;
                  -webkit-box-sizing: border-box;
                }
              }
            }
          }
        }
      }
      p {
        margin: $blah;
        $blee: goodbye;
        padding: 10px 5px;
        a {
          display: inline-block;
          padding: 5px;
          color: $blee;
          $blah: a b c;
          $bloo: "hello";

          div {
            color: red;
            width: 100%;
            $blah: a b c;
            $bloo: "hello";

            div {
              color: red;
              width: 100%;
              p {
                margin: $blah;
                $blee: goodbye;
                padding: 10px 5px;
                a {
                  display: inline-block;
                  padding: 5px;
                  color: $blee;
                }
                foo: $bloo;
                empty {
                  not-empty {
                    background: lightgray;
                    border: 1px solid blue;
                    span {
                      display: block;
                      -webkit-box-sizing: border-box;
                    }
                    $blah: a b c;
                    $bloo: "hello";

                    div {
                      color: red;
                      width: 100%;
                      p {
                        margin: $blah;
                        $blee: goodbye;
                        padding: 10px 5px;
                        a {
                          display: inline-block;
                          padding: 5px;
                          color: $blee;
                        }
                        foo: $bloo;
                        empty {
                          not-empty {
                            background: lightgray;
                            border: 1px solid blue;
                            span {
                              display: block;
                              -webkit-box-sizing: border-box;
                            }
                          }
                        }
                      }
                      div {
                        color: red;
                        width: 100%;
                        p {
                          margin: $blah;
                          $blee: goodbye;
                          padding: 10px 5px;
                          a {
                            display: inline-block;
                            padding: 5px;
                            color: $blee;
                          }
                          foo: $bloo;
                          empty {
                            not-empty {
                              background: lightgray;
                              border: 1px solid blue;
                              span {
                                display: block;
                                -webkit-box-sizing: border-box;
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
              div {
                color: red;
                width: 100%;
                p {
                  margin: $blah;
                  $blee: goodbye;
                  padding: 10px 5px;
                  a {
                    display: inline-block;
                    padding: 5px;
                    color: $blee;
                  }
                  foo: $bloo;
                  empty {
                    not-empty {
                      background: lightgray;
                      border: 1px solid blue;
                      span {
                        display: block;
                        -webkit-box-sizing: border-box;
                      }
                    }
                  }
                }
              }
            }
            p {
              margin: $blah;
              $blee: goodbye;
              padding: 10px 5px;
              a {
                display: inline-block;
                padding: 5px;
                color: $blee;
              }
              foo: $bloo;
              empty {
                not-empty {
                  background: lightgray;
                  border: 1px solid blue;
                  span {
                    display: block;
                    -webkit-box-sizing: border-box;
                  }
                  $blah: a b c;
                  $bloo: "hello";

                  div {
                    color: red;
                    width: 100%;
                    p {
                      margin: $blah;
                      $blee: goodbye;
                      padding: 10px 5px;
                      a {
                        display: inline-block;
                        padding: 5px;
                        color: $blee;
                      }
                      foo: $bloo;
                      empty {
                        not-empty {
                          background: lightgray;
                          border: 1px solid blue;
                          span {
                            display: block;
                            -webkit-box-sizing: border-box;
                          }
                        }
                      }
                    }
                    div {
                      color: red;
                      width: 100%;
                      p {
                        margin: $blah;
                        $blee: goodbye;
                        padding: 10px 5px;
                        a {
                          display: inline-block;
                          padding: 5px;
                          color: $blee;
                        }
                        foo: $bloo;
                        empty {
                          not-empty {
                            background: lightgray;
                            border: 1px solid blue;
                            span {
                              display: block;
                              -webkit-box-sizing: border-box;
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
            div {
              color: red;
              width: 100%;
              p {
                margin: $blah;
                $blee: goodbye;
                padding: 10px 5px;
                a {
                  display: inline-block;
                  padding: 5px;
                  color: $blee;
                }
                foo: $bloo;
                empty {
                  not-empty {
                    background: lightgray;
                    border: 1px solid blue;
                    span {
                      display: block;
                      -webkit-box-sizing: border-box;
                    }
                  }
                }
              }
            }
          }
        }
        foo: $bloo;
        empty {
          not-empty {
            background: lightgray;
            border: 1px solid blue;
            span {
              display: block;
              -webkit-box-sizing: border-box;
            }
            $blah: a b c;
            $bloo: "hello";

            div {
              color: red;
              width: 100%;
              p {
                margin: $blah;
                $blee: goodbye;
                padding: 10px 5px;
                a {
                  display: inline-block;
                  padding: 5px;
                  color: $blee;
                }
                foo: $bloo;
                empty {
                  not-empty {
                    background: lightgray;
                    border: 1px solid blue;
                    span {
                      display: block;
                      -webkit-box-sizing: border-box;
                    }
                  }
                }
              }
              div {
                color: red;
                width: 100%;
                p {
                  margin: $blah;
                  $blee: goodbye;
                  padding: 10px 5px;
                  a {
                    display: inline-block;
                    padding: 5px;
                    color: $blee;
                  }
                  foo: $bloo;
                  empty {
                    not-empty {
                      background: lightgray;
                      border: 1px solid blue;
                      span {
                        display: block;
                        -webkit-box-sizing: border-box;
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
      div {
        color: red;
        width: 100%;
        p {
          margin: $blah;
          $blee: goodbye;
          padding: 10px 5px;
          a {
            display: inline-block;
            padding: 5px;
            color: $blee;
          }
          foo: $bloo;
          empty {
            not-empty {
              background: lightgray;
              border: 1px solid blue;
              span {
                display: block;
                -webkit-box-sizing: border-box;
              }
            }
          }
          $blah: a b c;
          $bloo: "hello";

          div {
            color: red;
            width: 100%;
            $blah: a b c;
            $bloo: "hello";

            div {
              color: red;
              width: 100%;
              p {
                margin: $blah;
                $blee: goodbye;
                padding: 10px 5px;
                a {
                  display: inline-block;
                  padding: 5px;
                  color: $blee;
                }
                foo: $bloo;
                empty {
                  not-empty {
                    background: lightgray;
                    border: 1px solid blue;
                    span {
                      display: block;
                      -webkit-box-sizing: border-box;
                    }
                    $blah: a b c;
                    $bloo: "hello";

                    div {
                      color: red;
                      width: 100%;
                      p {
                        margin: $blah;
                        $blee: goodbye;
                        padding: 10px 5px;
                        a {
                          display: inline-block;
                          padding: 5px;
                          color: $blee;
                        }
                        foo: $bloo;
                        empty {
                          not-empty {
                            background: lightgray;
                            border: 1px solid blue;
                            span {
                              display: block;
                              -webkit-box-sizing: border-box;
                            }
                          }
                        }
                      }
                      div {
                        color: red;
                        width: 100%;
                        p {
                          margin: $blah;
                          $blee: goodbye;
                          padding: 10px 5px;
                          a {
                            display: inline-block;
                            padding: 5px;
                            color: $blee;
                          }
                          foo: $bloo;
                          empty {
                            not-empty {
                              background: lightgray;
                              border: 1px solid blue;
                              span {
                                display: block;
                                -webkit-box-sizing: border-box;
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
              div {
                color: red;
                width: 100%;
                p {
                  margin: $blah;
                  $blee: goodbye;
                  padding: 10px 5px;
                  a {
                    display: inline-block;
                    padding: 5px;
                    color: $blee;
                  }
                  foo: $bloo;
                  empty {
                    not-empty {
                      background: lightgray;
                      border: 1px solid blue;
                      span {
                        display: block;
                        -webkit-box-sizing: border-box;
                      }
                    }
                  }
                }
              }
            }
            p {
              margin: $blah;
              $blee: goodbye;
              padding: 10px 5px;
              a {
                display: inline-block;
                padding: 5px;
                color: $blee;
                $blah: a b c;
                $bloo: "hello";

                div {
                  color: red;
                  width: 100%;
                  $blah: a b c;
                  $bloo: "hello";

                  div {
                    color: red;
                    width: 100%;
                    p {
                      margin: $blah;
                      $blee: goodbye;
                      padding: 10px 5px;
                      a {
                        display: inline-block;
                        padding: 5px;
                        color: $blee;
                      }
                      foo: $bloo;
                      empty {
                        not-empty {
                          background: lightgray;
                          border: 1px solid blue;
                          span {
                            display: block;
                            -webkit-box-sizing: border-box;
                          }
                          $blah: a b c;
                          $bloo: "hello";

                          div {
                            color: red;
                            width: 100%;
                            p {
                              margin: $blah;
                              $blee: goodbye;
                              padding: 10px 5px;
                              a {
                                display: inline-block;
                                padding: 5px;
                                color: $blee;
                              }
                              foo: $bloo;
                              empty {
                                not-empty {
                                  background: lightgray;
                                  border: 1px solid blue;
                                  span {
                                    display: block;
                                    -webkit-box-sizing: border-box;
                                  }
                                }
                              }
                            }
                            div {
                              color: red;
                              width: 100%;
                              p {
                                margin: $blah;
                                $blee: goodbye;
                                padding: 10px 5px;
                                a {
                                  display: inline-block;
                                  padding: 5px;
                                  color: $blee;
                                }
                                foo: $bloo;
                                empty {
                                  not-empty {
                                    background: lightgray;
                                    border: 1px solid blue;
                                    span {
                                      display: block;
                                      -webkit-box-sizing: border-box;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                    div {
                      color: red;
                      width: 100%;
                      p {
                        margin: $blah;
                        $blee: goodbye;
                        padding: 10px 5px;
                        a {
                          display: inline-block;
                          padding: 5px;
                          color: $blee;
                        }
                        foo: $bloo;
                        empty {
                          not-empty {
                            background: lightgray;
                            border: 1px solid blue;
                            span {
                              display: block;
                              -webkit-box-sizing: border-box;
                            }
                          }
                        }
                      }
                    }
                  }
                  p {
                    margin: $blah;
                    $blee: goodbye;
                    padding: 10px 5px;
                    a {
                      display: inline-block;
                      padding: 5px;
                      color: $blee;
                    }
                    foo: $bloo;
                    empty {
                      not-empty {
                        background: lightgray;
                        border: 1px solid blue;
                        span {
                          display: block;
                          -webkit-box-sizing: border-box;
                        }
                        $blah: a b c;
                        $bloo: "hello";

                        div {
                          color: red;
                          width: 100%;
                          p {
                            margin: $blah;
                            $blee: goodbye;
                            padding: 10px 5px;
                            a {
                              display: inline-block;
                              padding: 5px;
                              color: $blee;
                            }
                            foo: $bloo;
                            empty {
                              not-empty {
                                background: lightgray;
                                border: 1px solid blue;
                                span {
                                  display: block;
                                  -webkit-box-sizing: border-box;
                                }
                              }
                            }
                          }
                          div {
                            color: red;
                            width: 100%;
                            p {
                              margin: $blah;
                              $blee: goodbye;
                              padding: 10px 5px;
                              a {
                                display: inline-block;
                                padding: 5px;
                                color: $blee;
                              }
                              foo: $bloo;
                              empty {
                                not-empty {
                                  background: lightgray;
                                  border: 1px solid blue;
                                  span {
                                    display: block;
                                    -webkit-box-sizing: border-box;
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                  div {
                    color: red;
                    width: 100%;
                    p {
                      margin: $blah;
                      $blee: goodbye;
                      padding: 10px 5px;
                      a {
                        display: inline-block;
                        padding: 5px;
                        color: $blee;
                      }
                      foo: $bloo;
                      empty {
                        not-empty {
                          background: lightgray;
                          border: 1px solid blue;
                          span {
                            display: block;
                            -webkit-box-sizing: border-box;
                          }
                        }
                      }
                    }
                  }
                }
              }
              foo: $bloo;
              empty {
                not-empty {
                  background: lightgray;
                  border: 1px solid blue;
                  span {
                    display: block;
                    -webkit-box-sizing: border-box;
                  }
                  $blah: a b c;
                  $bloo: "hello";

                  div {
                    color: red;
                    width: 100%;
                    p {
                      margin: $blah;
                      $blee: goodbye;
                      padding: 10px 5px;
                      a {
                        display: inline-block;
                        padding: 5px;
                        color: $blee;
                      }
                      foo: $bloo;
                      empty {
                        not-empty {
                          background: lightgray;
                          border: 1px solid blue;
                          span {
                            display: block;
                            -webkit-box-sizing: border-box;
                          }
                        }
                      }
                    }
                    div {
                      color: red;
                      width: 100%;
                      p {
                        margin: $blah;
                        $blee: goodbye;
                        padding: 10px 5px;
                        a {
                          display: inline-block;
                          padding: 5px;
                          color: $blee;
                        }
                        foo: $bloo;
                        empty {
                          not-empty {
                            background: lightgray;
                            border: 1px solid blue;
                            span {
                              display: block;
                              -webkit-box-sizing: border-box;
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
            $blah: a b c;
            $bloo: "hello";

            div {
              color: red;
              width: 100%;
              $blah: a b c;
              $bloo: "hello";

              div {
                color: red;
                width: 100%;
                p {
                  margin: $blah;
                  $blee: goodbye;
                  padding: 10px 5px;
                  a {
                    display: inline-block;
                    padding: 5px;
                    color: $blee;
                  }
                  foo: $bloo;
                  empty {
                    not-empty {
                      background: lightgray;
                      border: 1px solid blue;
                      span {
                        display: block;
                        -webkit-box-sizing: border-box;
                      }
                      $blah: a b c;
                      $bloo: "hello";

                      div {
                        color: red;
                        width: 100%;
                        p {
                          margin: $blah;
                          $blee: goodbye;
                          padding: 10px 5px;
                          a {
                            display: inline-block;
                            padding: 5px;
                            color: $blee;
                          }
                          foo: $bloo;
                          empty {
                            not-empty {
                              background: lightgray;
                              border: 1px solid blue;
                              span {
                                display: block;
                                -webkit-box-sizing: border-box;
                              }
                            }
                          }
                        }
                        div {
                          color: red;
                          width: 100%;
                          p {
                            margin: $blah;
                            $blee: goodbye;
                            padding: 10px 5px;
                            a {
                              display: inline-block;
                              padding: 5px;
                              color: $blee;
                            }
                            foo: $bloo;
                            empty {
                              not-empty {
                                background: lightgray;
                                border: 1px solid blue;
                                span {
                                  display: block;
                                  -webkit-box-sizing: border-box;
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
                div {
                  color: red;
                  width: 100%;
                  p {
                    margin: $blah;
                    $blee: goodbye;
                    padding: 10px 5px;
                    a {
                      display: inline-block;
                      padding: 5px;
                      color: $blee;
                    }
                    foo: $bloo;
                    empty {
                      not-empty {
                        background: lightgray;
                        border: 1px solid blue;
                        span {
                          display: block;
                          -webkit-box-sizing: border-box;
                        }
                      }
                    }
                  }
                }
              }
              p {
                margin: $blah;
                $blee: goodbye;
                padding: 10px 5px;
                a {
                  display: inline-block;
                  padding: 5px;
                  color: $blee;
                  $blah: a b c;
                  $bloo: "hello";

                  div {
                    color: red;
                    width: 100%;
                    $blah: a b c;
                    $bloo: "hello";

                    div {
                      color: red;
                      width: 100%;
                      p {
                        margin: $blah;
                        $blee: goodbye;
                        padding: 10px 5px;
                        a {
                          display: inline-block;
                          padding: 5px;
                          color: $blee;
                        }
                        foo: $bloo;
                        empty {
                          not-empty {
                            background: lightgray;
                            border: 1px solid blue;
                            span {
                              display: block;
                              -webkit-box-sizing: border-box;
                            }
                            $blah: a b c;
                            $bloo: "hello";

                            div {
                              color: red;
                              width: 100%;
                              p {
                                margin: $blah;
                                $blee: goodbye;
                                padding: 10px 5px;
                                a {
                                  display: inline-block;
                                  padding: 5px;
                                  color: $blee;
                                }
                                foo: $bloo;
                                empty {
                                  not-empty {
                                    background: lightgray;
                                    border: 1px solid blue;
                                    span {
                                      display: block;
                                      -webkit-box-sizing: border-box;
                                    }
                                  }
                                }
                              }
                              div {
                                color: red;
                                width: 100%;
                                p {
                                  margin: $blah;
                                  $blee: goodbye;
                                  padding: 10px 5px;
                                  a {
                                    display: inline-block;
                                    padding: 5px;
                                    color: $blee;
                                  }
                                  foo: $bloo;
                                  empty {
                                    not-empty {
                                      background: lightgray;
                                      border: 1px solid blue;
                                      span {
                                        display: block;
                                        -webkit-box-sizing: border-box;
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                      div {
                        color: red;
                        width: 100%;
                        p {
                          margin: $blah;
                          $blee: goodbye;
                          padding: 10px 5px;
                          a {
                            display: inline-block;
                            padding: 5px;
                            color: $blee;
                          }
                          foo: $bloo;
                          empty {
                            not-empty {
                              background: lightgray;
                              border: 1px solid blue;
                              span {
                                display: block;
                                -webkit-box-sizing: border-box;
                              }
                            }
                          }
                        }
                      }
                    }
                    p {
                      margin: $blah;
                      $blee: goodbye;
                      padding: 10px 5px;
                      a {
                        display: inline-block;
                        padding: 5px;
                        color: $blee;
                      }
                      foo: $bloo;
                      empty {
                        not-empty {
                          background: lightgray;
                          border: 1px solid blue;
                          span {
                            display: block;
                            -webkit-box-sizing: border-box;
                          }
                          $blah: a b c;
                          $bloo: "hello";

                          div {
                            color: red;
                            width: 100%;
                            p {
                              margin: $blah;
                              $blee: goodbye;
                              padding: 10px 5px;
                              a {
                                display: inline-block;
                                padding: 5px;
                                color: $blee;
                              }
                              foo: $bloo;
                              empty {
                                not-empty {
                                  background: lightgray;
                                  border: 1px solid blue;
                                  span {
                                    display: block;
                                    -webkit-box-sizing: border-box;
                                  }
                                }
                              }
                            }
                            div {
                              color: red;
                              width: 100%;
                              p {
                                margin: $blah;
                                $blee: goodbye;
                                padding: 10px 5px;
                                a {
                                  display: inline-block;
                                  padding: 5px;
                                  color: $blee;
                                }
                                foo: $bloo;
                                empty {
                                  not-empty {
                                    background: lightgray;
                                    border: 1px solid blue;
                                    span {
                                      display: block;
                                      -webkit-box-sizing: border-box;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                    div {
                      color: red;
                      width: 100%;
                      p {
                        margin: $blah;
                        $blee: goodbye;
                        padding: 10px 5px;
                        a {
                          display: inline-block;
                          padding: 5px;
                          color: $blee;
                        }
                        foo: $bloo;
                        empty {
                          not-empty {
                            background: lightgray;
                            border: 1px solid blue;
                            span {
                              display: block;
                              -webkit-box-sizing: border-box;
                            }
                          }
                        }
                      }
                    }
                  }
                }
                foo: $bloo;
                empty {
                  not-empty {
                    background: lightgray;
                    border: 1px solid blue;
                    span {
                      display: block;
                      -webkit-box-sizing: border-box;
                    }
                    $blah: a b c;
                    $bloo: "hello";

                    div {
                      color: red;
                      width: 100%;
                      p {
                        margin: $blah;
                        $blee: goodbye;
                        padding: 10px 5px;
                        a {
                          display: inline-block;
                          padding: 5px;
                          color: $blee;
                        }
                        foo: $bloo;
                        empty {
                          not-empty {
                            background: lightgray;
                            border: 1px solid blue;
                            span {
                              display: block;
                              -webkit-box-sizing: border-box;
                            }
                          }
                        }
                      }
                      div {
                        color: red;
                        width: 100%;
                        p {
                          margin: $blah;
                          $blee: goodbye;
                          padding: 10px 5px;
                          a {
                            display: inline-block;
                            padding: 5px;
                            color: $blee;
                          }
                          foo: $bloo;
                          empty {
                            not-empty {
                              background: lightgray;
                              border: 1px solid blue;
                              span {
                                display: block;
                                -webkit-box-sizing: border-box;
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
              div {
                color: red;
                width: 100%;
                p {
                  margin: $blah;
                  $blee: goodbye;
                  padding: 10px 5px;
                  a {
                    display: inline-block;
                    padding: 5px;
                    color: $blee;
                  }
                  foo: $bloo;
                  empty {
                    not-empty {
                      background: lightgray;
                      border: 1px solid blue;
                      span {
                        display: block;
                        -webkit-box-sizing: border-box;
                      }
                    }
                  }
                  $blah: a b c;
                  $bloo: "hello";

                  div {
                    color: red;
                    width: 100%;
                    $blah: a b c;
                    $bloo: "hello";

                    div {
                      color: red;
                      width: 100%;
                      p {
                        margin: $blah;
                        $blee: goodbye;
                        padding: 10px 5px;
                        a {
                          display: inline-block;
                          padding: 5px;
                          color: $blee;
                        }
                        foo: $bloo;
                        empty {
                          not-empty {
                            background: lightgray;
                            border: 1px solid blue;
                            span {
                              display: block;
                              -webkit-box-sizing: border-box;
                            }
                            $blah: a b c;
                            $bloo: "hello";

                            div {
                              color: red;
                              width: 100%;
                              p {
                                margin: $blah;
                                $blee: goodbye;
                                padding: 10px 5px;
                                a {
                                  display: inline-block;
                                  padding: 5px;
                                  color: $blee;
                                }
                                foo: $bloo;
                                empty {
                                  not-empty {
                                    background: lightgray;
                                    border: 1px solid blue;
                                    span {
                                      display: block;
                                      -webkit-box-sizing: border-box;
                                    }
                                  }
                                }
                              }
                              div {
                                color: red;
                                width: 100%;
                                p {
                                  margin: $blah;
                                  $blee: goodbye;
                                  padding: 10px 5px;
                                  a {
                                    display: inline-block;
                                    padding: 5px;
                                    color: $blee;
                                  }
                                  foo: $bloo;
                                  empty {
                                    not-empty {
                                      background: lightgray;
                                      border: 1px solid blue;
                                      span {
                                        display: block;
                                        -webkit-box-sizing: border-box;
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                      div {
                        color: red;
                        width: 100%;
                        p {
                          margin: $blah;
                          $blee: goodbye;
                          padding: 10px 5px;
                          a {
                            display: inline-block;
                            padding: 5px;
                            color: $blee;
                          }
                          foo: $bloo;
                          empty {
                            not-empty {
                              background: lightgray;
                              border: 1px solid blue;
                              span {
                                display: block;
                                -webkit-box-sizing: border-box;
                              }
                            }
                          }
                        }
                      }
                    }
                    p {
                      margin: $blah;
                      $blee: goodbye;
                      padding: 10px 5px;
                      a {
                        display: inline-block;
                        padding: 5px;
                        color: $blee;
                        $blah: a b c;
                        $bloo: "hello";

                        div {
                          color: red;
                          width: 100%;
                          $blah: a b c;
                          $bloo: "hello";

                          div {
                            color: red;
                            width: 100%;
                            p {
                              margin: $blah;
                              $blee: goodbye;
                              padding: 10px 5px;
                              a {
                                display: inline-block;
                                padding: 5px;
                                color: $blee;
                              }
                              foo: $bloo;
                              empty {
                                not-empty {
                                  background: lightgray;
                                  border: 1px solid blue;
                                  span {
                                    display: block;
                                    -webkit-box-sizing: border-box;
                                  }
                                  $blah: a b c;
                                  $bloo: "hello";

                                  div {
                                    color: red;
                                    width: 100%;
                                    p {
                                      margin: $blah;
                                      $blee: goodbye;
                                      padding: 10px 5px;
                                      a {
                                        display: inline-block;
                                        padding: 5px;
                                        color: $blee;
                                      }
                                      foo: $bloo;
                                      empty {
                                        not-empty {
                                          background: lightgray;
                                          border: 1px solid blue;
                                          span {
                                            display: block;
                                            -webkit-box-sizing: border-box;
                                          }
                                        }
                                      }
                                    }
                                    div {
                                      color: red;
                                      width: 100%;
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                            div {
                              color: red;
                              width: 100%;
                              p {
                                margin: $blah;
                                $blee: goodbye;
                                padding: 10px 5px;
                                a {
                                  display: inline-block;
                                  padding: 5px;
                                  color: $blee;
                                }
                                foo: $bloo;
                                empty {
                                  not-empty {
                                    background: lightgray;
                                    border: 1px solid blue;
                                    span {
                                      display: block;
                                      -webkit-box-sizing: border-box;
                                    }
                                  }
                                }
                              }
                            }
                          }
                          p {
                            margin: $blah;
                            $blee: goodbye;
                            padding: 10px 5px;
                            a {
                              display: inline-block;
                              padding: 5px;
                              color: $blee;
                            }
                            foo: $bloo;
                            empty {
                              not-empty {
                                background: lightgray;
                                border: 1px solid blue;
                                span {
                                  display: block;
                                  -webkit-box-sizing: border-box;
                                }
                                $blah: a b c;
                                $bloo: "hello";

                                div {
                                  color: red;
                                  width: 100%;
                                  p {
                                    margin: $blah;
                                    $blee: goodbye;
                                    padding: 10px 5px;
                                    a {
                                      display: inline-block;
                                      padding: 5px;
                                      color: $blee;
                                    }
                                    foo: $bloo;
                                    empty {
                                      not-empty {
                                        background: lightgray;
                                        border: 1px solid blue;
                                        span {
                                          display: block;
                                          -webkit-box-sizing: border-box;
                                        }
                                      }
                                    }
                                  }
                                  div {
                                    color: red;
                                    width: 100%;
                                    p {
                                      margin: $blah;
                                      $blee: goodbye;
                                      padding: 10px 5px;
                                      a {
                                        display: inline-block;
                                        padding: 5px;
                                        color: $blee;
                                      }
                                      foo: $bloo;
                                      empty {
                                        not-empty {
                                          background: lightgray;
                                          border: 1px solid blue;
                                          span {
                                            display: block;
                                            -webkit-box-sizing: border-box;
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                          div {
                            color: red;
                            width: 100%;
                            p {
                              margin: $blah;
                              $blee: goodbye;
                              padding: 10px 5px;
                              a {
                                display: inline-block;
                                padding: 5px;
                                color: $blee;
                              }
                              foo: $bloo;
                              empty {
                                not-empty {
                                  background: lightgray;
                                  border: 1px solid blue;
                                  span {
                                    display: block;
                                    -webkit-box-sizing: border-box;
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                      foo: $bloo;
                      empty {
                        not-empty {
                          background: lightgray;
                          border: 1px solid blue;
                          span {
                            display: block;
                            -webkit-box-sizing: border-box;
                          }
                          $blah: a b c;
                          $bloo: "hello";

                          div {
                            color: red;
                            width: 100%;
                            p {
                              margin: $blah;
                              $blee: goodbye;
                              padding: 10px 5px;
                              a {
                                display: inline-block;
                                padding: 5px;
                                color: $blee;
                              }
                              foo: $bloo;
                              empty {
                                not-empty {
                                  background: lightgray;
                                  border: 1px solid blue;
                                  span {
                                    display: block;
                                    -webkit-box-sizing: border-box;
                                  }
                                }
                              }
                            }
                            div {
                              color: red;
                              width: 100%;
                              p {
                                margin: $blah;
                                $blee: goodbye;
                                padding: 10px 5px;
                                a {
                                  display: inline-block;
                                  padding: 5px;
                                  color: $blee;
                                }
                                foo: $bloo;
                                empty {
                                  not-empty {
                                    background: lightgray;
                                    border: 1px solid blue;
                                    span {
                                      display: block;
                                      -webkit-box-sizing: border-box;
                                    }
                                  }
                                }
                              }
                            }
                          }
                          $blah: a b c;
                          $bloo: "hello";

                          div {
                            color: red;
                            width: 100%;
                            $blah: a b c;
                            $bloo: "hello";

                            div {
                              color: red;
                              width: 100%;
                              p {
                                margin: $blah;
                                $blee: goodbye;
                                padding: 10px 5px;
                                a {
                                  display: inline-block;
                                  padding: 5px;
                                  color: $blee;
                                }
                                foo: $bloo;
                                empty {
                                  not-empty {
                                    background: lightgray;
                                    border: 1px solid blue;
                                    span {
                                      display: block;
                                      -webkit-box-sizing: border-box;
                                    }
                                    $blah: a b c;
                                    $bloo: "hello";

                                    div {
                                      color: red;
                                      width: 100%;
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                          }
                                        }
                                      }
                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                              div {
                                color: red;
                                width: 100%;
                                p {
                                  margin: $blah;
                                  $blee: goodbye;
                                  padding: 10px 5px;
                                  a {
                                    display: inline-block;
                                    padding: 5px;
                                    color: $blee;
                                  }
                                  foo: $bloo;
                                  empty {
                                    not-empty {
                                      background: lightgray;
                                      border: 1px solid blue;
                                      span {
                                        display: block;
                                        -webkit-box-sizing: border-box;
                                      }
                                    }
                                  }
                                }
                              }
                            }
                            p {
                              margin: $blah;
                              $blee: goodbye;
                              padding: 10px 5px;
                              a {
                                display: inline-block;
                                padding: 5px;
                                color: $blee;
                                $blah: a b c;
                                $bloo: "hello";

                                div {
                                  color: red;
                                  width: 100%;
                                  $blah: a b c;
                                  $bloo: "hello";

                                  div {
                                    color: red;
                                    width: 100%;
                                    p {
                                      margin: $blah;
                                      $blee: goodbye;
                                      padding: 10px 5px;
                                      a {
                                        display: inline-block;
                                        padding: 5px;
                                        color: $blee;
                                      }
                                      foo: $bloo;
                                      empty {
                                        not-empty {
                                          background: lightgray;
                                          border: 1px solid blue;
                                          span {
                                            display: block;
                                            -webkit-box-sizing: border-box;
                                          }
                                          $blah: a b c;
                                          $bloo: "hello";

                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                }
                                              }
                                            }
                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                    div {
                                      color: red;
                                      width: 100%;
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                  p {
                                    margin: $blah;
                                    $blee: goodbye;
                                    padding: 10px 5px;
                                    a {
                                      display: inline-block;
                                      padding: 5px;
                                      color: $blee;
                                    }
                                    foo: $bloo;
                                    empty {
                                      not-empty {
                                        background: lightgray;
                                        border: 1px solid blue;
                                        span {
                                          display: block;
                                          -webkit-box-sizing: border-box;
                                        }
                                        $blah: a b c;
                                        $bloo: "hello";

                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                              }
                                            }
                                          }
                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                  div {
                                    color: red;
                                    width: 100%;
                                    p {
                                      margin: $blah;
                                      $blee: goodbye;
                                      padding: 10px 5px;
                                      a {
                                        display: inline-block;
                                        padding: 5px;
                                        color: $blee;
                                      }
                                      foo: $bloo;
                                      empty {
                                        not-empty {
                                          background: lightgray;
                                          border: 1px solid blue;
                                          span {
                                            display: block;
                                            -webkit-box-sizing: border-box;
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                              foo: $bloo;
                              empty {
                                not-empty {
                                  background: lightgray;
                                  border: 1px solid blue;
                                  span {
                                    display: block;
                                    -webkit-box-sizing: border-box;
                                  }
                                  $blah: a b c;
                                  $bloo: "hello";

                                  div {
                                    color: red;
                                    width: 100%;
                                    p {
                                      margin: $blah;
                                      $blee: goodbye;
                                      padding: 10px 5px;
                                      a {
                                        display: inline-block;
                                        padding: 5px;
                                        color: $blee;
                                      }
                                      foo: $bloo;
                                      empty {
                                        not-empty {
                                          background: lightgray;
                                          border: 1px solid blue;
                                          span {
                                            display: block;
                                            -webkit-box-sizing: border-box;
                                          }
                                        }
                                      }
                                    }
                                    div {
                                      color: red;
                                      width: 100%;
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                            div {
                              color: red;
                              width: 100%;
                              p {
                                margin: $blah;
                                $blee: goodbye;
                                padding: 10px 5px;
                                a {
                                  display: inline-block;
                                  padding: 5px;
                                  color: $blee;
                                }
                                foo: $bloo;
                                empty {
                                  not-empty {
                                    background: lightgray;
                                    border: 1px solid blue;
                                    span {
                                      display: block;
                                      -webkit-box-sizing: border-box;
                                    }
                                  }
                                }
                                $blah: a b c;
                                $bloo: "hello";

                                div {
                                  color: red;
                                  width: 100%;
                                  $blah: a b c;
                                  $bloo: "hello";

                                  div {
                                    color: red;
                                    width: 100%;
                                    p {
                                      margin: $blah;
                                      $blee: goodbye;
                                      padding: 10px 5px;
                                      a {
                                        display: inline-block;
                                        padding: 5px;
                                        color: $blee;
                                      }
                                      foo: $bloo;
                                      empty {
                                        not-empty {
                                          background: lightgray;
                                          border: 1px solid blue;
                                          span {
                                            display: block;
                                            -webkit-box-sizing: border-box;
                                          }
                                          $blah: a b c;
                                          $bloo: "hello";

                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                }
                                              }
                                            }
                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                    div {
                                      color: red;
                                      width: 100%;
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                  p {
                                    margin: $blah;
                                    $blee: goodbye;
                                    padding: 10px 5px;
                                    a {
                                      display: inline-block;
                                      padding: 5px;
                                      color: $blee;
                                      $blah: a b c;
                                      $bloo: "hello";

                                      div {
                                        color: red;
                                        width: 100%;
                                        $blah: a b c;
                                        $bloo: "hello";

                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                                $blah: a b c;
                                                $bloo: "hello";

                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                      }
                                                    }
                                                  }
                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                              $blah: a b c;
                                              $bloo: "hello";

                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                    }
                                                  }
                                                }
                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                    foo: $bloo;
                                    empty {
                                      not-empty {
                                        background: lightgray;
                                        border: 1px solid blue;
                                        span {
                                          display: block;
                                          -webkit-box-sizing: border-box;
                                        }
                                        $blah: a b c;
                                        $bloo: "hello";

                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                              }
                                            }
                                          }
                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                  $blah: a b c;
                                  $bloo: "hello";

                                  div {
                                    color: red;
                                    width: 100%;
                                    $blah: a b c;
                                    $bloo: "hello";

                                    div {
                                      color: red;
                                      width: 100%;
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                            $blah: a b c;
                                            $bloo: "hello";

                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                              }
                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                    p {
                                      margin: $blah;
                                      $blee: goodbye;
                                      padding: 10px 5px;
                                      a {
                                        display: inline-block;
                                        padding: 5px;
                                        color: $blee;
                                        $blah: a b c;
                                        $bloo: "hello";

                                        div {
                                          color: red;
                                          width: 100%;
                                          $blah: a b c;
                                          $bloo: "hello";

                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                  $blah: a b c;
                                                  $bloo: "hello";

                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                        }
                                                      }
                                                    }
                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                                $blah: a b c;
                                                $bloo: "hello";

                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                      }
                                                    }
                                                  }
                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                      foo: $bloo;
                                      empty {
                                        not-empty {
                                          background: lightgray;
                                          border: 1px solid blue;
                                          span {
                                            display: block;
                                            -webkit-box-sizing: border-box;
                                          }
                                          $blah: a b c;
                                          $bloo: "hello";

                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                }
                                              }
                                            }
                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                    div {
                                      color: red;
                                      width: 100%;
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                          }
                                        }
                                        $blah: a b c;
                                        $bloo: "hello";

                                        div {
                                          color: red;
                                          width: 100%;
                                          $blah: a b c;
                                          $bloo: "hello";

                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                  $blah: a b c;
                                                  $bloo: "hello";

                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                        }
                                                      }
                                                    }
                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                              $blah: a b c;
                                              $bloo: "hello";

                                              div {
                                                color: red;
                                                width: 100%;
                                                $blah: a b c;
                                                $bloo: "hello";

                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                        $blah: a b c;
                                                        $bloo: "hello";

                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                              }
                                                            }
                                                          }
                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                      $blah: a b c;
                                                      $bloo: "hello";

                                                      div {
                                                        color: red;
                                                        width: 100%;
                                                        p {
                                                          margin: $blah;
                                                          $blee: goodbye;
                                                          padding: 10px 5px;
                                                          a {
                                                            display: inline-block;
                                                            padding: 5px;
                                                            color: $blee;
                                                          }
                                                          foo: $bloo;
                                                          empty {
                                                            not-empty {
                                                              background: lightgray;
                                                              border: 1px solid blue;
                                                              span {
                                                                display: block;
                                                                -webkit-box-sizing: border-box;
                                                              }
                                                            }
                                                          }
                                                        }
                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                                $blah: a b c;
                                                $bloo: "hello";

                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                      }
                                                    }
                                                  }
                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                  div {
                                    color: red;
                                    width: 100%;
                                    p {
                                      margin: $blah;
                                      $blee: goodbye;
                                      padding: 10px 5px;
                                      a {
                                        display: inline-block;
                                        padding: 5px;
                                        color: $blee;
                                      }
                                      foo: $bloo;
                                      empty {
                                        not-empty {
                                          background: lightgray;
                                          border: 1px solid blue;
                                          span {
                                            display: block;
                                            -webkit-box-sizing: border-box;
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                    div {
                      color: red;
                      width: 100%;
                      p {
                        margin: $blah;
                        $blee: goodbye;
                        padding: 10px 5px;
                        a {
                          display: inline-block;
                          padding: 5px;
                          color: $blee;
                        }
                        foo: $bloo;
                        empty {
                          not-empty {
                            background: lightgray;
                            border: 1px solid blue;
                            span {
                              display: block;
                              -webkit-box-sizing: border-box;
                            }
                          }
                        }
                      }
                    }
                    $blah: a b c;
                    $bloo: "hello";

                    div {
                      color: red;
                      width: 100%;
                      $blah: a b c;
                      $bloo: "hello";

                      div {
                        color: red;
                        width: 100%;
                        p {
                          margin: $blah;
                          $blee: goodbye;
                          padding: 10px 5px;
                          a {
                            display: inline-block;
                            padding: 5px;
                            color: $blee;
                          }
                          foo: $bloo;
                          empty {
                            not-empty {
                              background: lightgray;
                              border: 1px solid blue;
                              span {
                                display: block;
                                -webkit-box-sizing: border-box;
                              }
                              $blah: a b c;
                              $bloo: "hello";

                              div {
                                color: red;
                                width: 100%;
                                p {
                                  margin: $blah;
                                  $blee: goodbye;
                                  padding: 10px 5px;
                                  a {
                                    display: inline-block;
                                    padding: 5px;
                                    color: $blee;
                                  }
                                  foo: $bloo;
                                  empty {
                                    not-empty {
                                      background: lightgray;
                                      border: 1px solid blue;
                                      span {
                                        display: block;
                                        -webkit-box-sizing: border-box;
                                      }
                                    }
                                  }
                                }
                                div {
                                  color: red;
                                  width: 100%;
                                  p {
                                    margin: $blah;
                                    $blee: goodbye;
                                    padding: 10px 5px;
                                    a {
                                      display: inline-block;
                                      padding: 5px;
                                      color: $blee;
                                    }
                                    foo: $bloo;
                                    empty {
                                      not-empty {
                                        background: lightgray;
                                        border: 1px solid blue;
                                        span {
                                          display: block;
                                          -webkit-box-sizing: border-box;
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                        div {
                          color: red;
                          width: 100%;
                          p {
                            margin: $blah;
                            $blee: goodbye;
                            padding: 10px 5px;
                            a {
                              display: inline-block;
                              padding: 5px;
                              color: $blee;
                            }
                            foo: $bloo;
                            empty {
                              not-empty {
                                background: lightgray;
                                border: 1px solid blue;
                                span {
                                  display: block;
                                  -webkit-box-sizing: border-box;
                                }
                              }
                            }
                          }
                        }
                      }
                      p {
                        margin: $blah;
                        $blee: goodbye;
                        padding: 10px 5px;
                        a {
                          display: inline-block;
                          padding: 5px;
                          color: $blee;
                          $blah: a b c;
                          $bloo: "hello";

                          div {
                            color: red;
                            width: 100%;
                            $blah: a b c;
                            $bloo: "hello";

                            div {
                              color: red;
                              width: 100%;
                              p {
                                margin: $blah;
                                $blee: goodbye;
                                padding: 10px 5px;
                                a {
                                  display: inline-block;
                                  padding: 5px;
                                  color: $blee;
                                }
                                foo: $bloo;
                                empty {
                                  not-empty {
                                    background: lightgray;
                                    border: 1px solid blue;
                                    span {
                                      display: block;
                                      -webkit-box-sizing: border-box;
                                    }
                                    $blah: a b c;
                                    $bloo: "hello";

                                    div {
                                      color: red;
                                      width: 100%;
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                          }
                                        }
                                      }
                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                              div {
                                color: red;
                                width: 100%;
                                p {
                                  margin: $blah;
                                  $blee: goodbye;
                                  padding: 10px 5px;
                                  a {
                                    display: inline-block;
                                    padding: 5px;
                                    color: $blee;
                                  }
                                  foo: $bloo;
                                  empty {
                                    not-empty {
                                      background: lightgray;
                                      border: 1px solid blue;
                                      span {
                                        display: block;
                                        -webkit-box-sizing: border-box;
                                      }
                                    }
                                  }
                                }
                              }
                            }
                            p {
                              margin: $blah;
                              $blee: goodbye;
                              padding: 10px 5px;
                              a {
                                display: inline-block;
                                padding: 5px;
                                color: $blee;
                              }
                              foo: $bloo;
                              empty {
                                not-empty {
                                  background: lightgray;
                                  border: 1px solid blue;
                                  span {
                                    display: block;
                                    -webkit-box-sizing: border-box;
                                  }
                                  $blah: a b c;
                                  $bloo: "hello";

                                  div {
                                    color: red;
                                    width: 100%;
                                    p {
                                      margin: $blah;
                                      $blee: goodbye;
                                      padding: 10px 5px;
                                      a {
                                        display: inline-block;
                                        padding: 5px;
                                        color: $blee;
                                      }
                                      foo: $bloo;
                                      empty {
                                        not-empty {
                                          background: lightgray;
                                          border: 1px solid blue;
                                          span {
                                            display: block;
                                            -webkit-box-sizing: border-box;
                                          }
                                        }
                                      }
                                    }
                                    div {
                                      color: red;
                                      width: 100%;
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                            div {
                              color: red;
                              width: 100%;
                              p {
                                margin: $blah;
                                $blee: goodbye;
                                padding: 10px 5px;
                                a {
                                  display: inline-block;
                                  padding: 5px;
                                  color: $blee;
                                }
                                foo: $bloo;
                                empty {
                                  not-empty {
                                    background: lightgray;
                                    border: 1px solid blue;
                                    span {
                                      display: block;
                                      -webkit-box-sizing: border-box;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                        foo: $bloo;
                        empty {
                          not-empty {
                            background: lightgray;
                            border: 1px solid blue;
                            span {
                              display: block;
                              -webkit-box-sizing: border-box;
                            }
                            $blah: a b c;
                            $bloo: "hello";

                            div {
                              color: red;
                              width: 100%;
                              p {
                                margin: $blah;
                                $blee: goodbye;
                                padding: 10px 5px;
                                a {
                                  display: inline-block;
                                  padding: 5px;
                                  color: $blee;
                                }
                                foo: $bloo;
                                empty {
                                  not-empty {
                                    background: lightgray;
                                    border: 1px solid blue;
                                    span {
                                      display: block;
                                      -webkit-box-sizing: border-box;
                                    }
                                  }
                                }
                              }
                              div {
                                color: red;
                                width: 100%;
                                p {
                                  margin: $blah;
                                  $blee: goodbye;
                                  padding: 10px 5px;
                                  a {
                                    display: inline-block;
                                    padding: 5px;
                                    color: $blee;
                                  }
                                  foo: $bloo;
                                  empty {
                                    not-empty {
                                      background: lightgray;
                                      border: 1px solid blue;
                                      span {
                                        display: block;
                                        -webkit-box-sizing: border-box;
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                      div {
                        color: red;
                        width: 100%;
                        p {
                          margin: $blah;
                          $blee: goodbye;
                          padding: 10px 5px;
                          a {
                            display: inline-block;
                            padding: 5px;
                            color: $blee;
                          }
                          foo: $bloo;
                          empty {
                            not-empty {
                              background: lightgray;
                              border: 1px solid blue;
                              span {
                                display: block;
                                -webkit-box-sizing: border-box;
                              }
                            }
                          }
                          $blah: a b c;
                          $bloo: "hello";

                          div {
                            color: red;
                            width: 100%;
                            $blah: a b c;
                            $bloo: "hello";

                            div {
                              color: red;
                              width: 100%;
                              p {
                                margin: $blah;
                                $blee: goodbye;
                                padding: 10px 5px;
                                a {
                                  display: inline-block;
                                  padding: 5px;
                                  color: $blee;
                                }
                                foo: $bloo;
                                empty {
                                  not-empty {
                                    background: lightgray;
                                    border: 1px solid blue;
                                    span {
                                      display: block;
                                      -webkit-box-sizing: border-box;
                                    }
                                    $blah: a b c;
                                    $bloo: "hello";

                                    div {
                                      color: red;
                                      width: 100%;
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                          }
                                        }
                                      }
                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                              div {
                                color: red;
                                width: 100%;
                                p {
                                  margin: $blah;
                                  $blee: goodbye;
                                  padding: 10px 5px;
                                  a {
                                    display: inline-block;
                                    padding: 5px;
                                    color: $blee;
                                  }
                                  foo: $bloo;
                                  empty {
                                    not-empty {
                                      background: lightgray;
                                      border: 1px solid blue;
                                      span {
                                        display: block;
                                        -webkit-box-sizing: border-box;
                                      }
                                    }
                                  }
                                }
                              }
                            }
                            p {
                              margin: $blah;
                              $blee: goodbye;
                              padding: 10px 5px;
                              a {
                                display: inline-block;
                                padding: 5px;
                                color: $blee;
                                $blah: a b c;
                                $bloo: "hello";

                                div {
                                  color: red;
                                  width: 100%;
                                  $blah: a b c;
                                  $bloo: "hello";

                                  div {
                                    color: red;
                                    width: 100%;
                                    p {
                                      margin: $blah;
                                      $blee: goodbye;
                                      padding: 10px 5px;
                                      a {
                                        display: inline-block;
                                        padding: 5px;
                                        color: $blee;
                                      }
                                      foo: $bloo;
                                      empty {
                                        not-empty {
                                          background: lightgray;
                                          border: 1px solid blue;
                                          span {
                                            display: block;
                                            -webkit-box-sizing: border-box;
                                          }
                                          $blah: a b c;
                                          $bloo: "hello";

                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                }
                                              }
                                            }
                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                    div {
                                      color: red;
                                      width: 100%;
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                  p {
                                    margin: $blah;
                                    $blee: goodbye;
                                    padding: 10px 5px;
                                    a {
                                      display: inline-block;
                                      padding: 5px;
                                      color: $blee;
                                    }
                                    foo: $bloo;
                                    empty {
                                      not-empty {
                                        background: lightgray;
                                        border: 1px solid blue;
                                        span {
                                          display: block;
                                          -webkit-box-sizing: border-box;
                                        }
                                        $blah: a b c;
                                        $bloo: "hello";

                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                              }
                                            }
                                          }
                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                  div {
                                    color: red;
                                    width: 100%;
                                    p {
                                      margin: $blah;
                                      $blee: goodbye;
                                      padding: 10px 5px;
                                      a {
                                        display: inline-block;
                                        padding: 5px;
                                        color: $blee;
                                      }
                                      foo: $bloo;
                                      empty {
                                        not-empty {
                                          background: lightgray;
                                          border: 1px solid blue;
                                          span {
                                            display: block;
                                            -webkit-box-sizing: border-box;
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                              foo: $bloo;
                              empty {
                                not-empty {
                                  background: lightgray;
                                  border: 1px solid blue;
                                  span {
                                    display: block;
                                    -webkit-box-sizing: border-box;
                                  }
                                  $blah: a b c;
                                  $bloo: "hello";

                                  div {
                                    color: red;
                                    width: 100%;
                                    p {
                                      margin: $blah;
                                      $blee: goodbye;
                                      padding: 10px 5px;
                                      a {
                                        display: inline-block;
                                        padding: 5px;
                                        color: $blee;
                                      }
                                      foo: $bloo;
                                      empty {
                                        not-empty {
                                          background: lightgray;
                                          border: 1px solid blue;
                                          span {
                                            display: block;
                                            -webkit-box-sizing: border-box;
                                          }
                                        }
                                      }
                                    }
                                    div {
                                      color: red;
                                      width: 100%;
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                            $blah: a b c;
                            $bloo: "hello";

                            div {
                              color: red;
                              width: 100%;
                              $blah: a b c;
                              $bloo: "hello";

                              div {
                                color: red;
                                width: 100%;
                                p {
                                  margin: $blah;
                                  $blee: goodbye;
                                  padding: 10px 5px;
                                  a {
                                    display: inline-block;
                                    padding: 5px;
                                    color: $blee;
                                  }
                                  foo: $bloo;
                                  empty {
                                    not-empty {
                                      background: lightgray;
                                      border: 1px solid blue;
                                      span {
                                        display: block;
                                        -webkit-box-sizing: border-box;
                                      }
                                      $blah: a b c;
                                      $bloo: "hello";

                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                            }
                                          }
                                        }
                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                                div {
                                  color: red;
                                  width: 100%;
                                  p {
                                    margin: $blah;
                                    $blee: goodbye;
                                    padding: 10px 5px;
                                    a {
                                      display: inline-block;
                                      padding: 5px;
                                      color: $blee;
                                    }
                                    foo: $bloo;
                                    empty {
                                      not-empty {
                                        background: lightgray;
                                        border: 1px solid blue;
                                        span {
                                          display: block;
                                          -webkit-box-sizing: border-box;
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                              p {
                                margin: $blah;
                                $blee: goodbye;
                                padding: 10px 5px;
                                a {
                                  display: inline-block;
                                  padding: 5px;
                                  color: $blee;
                                  $blah: a b c;
                                  $bloo: "hello";

                                  div {
                                    color: red;
                                    width: 100%;
                                    $blah: a b c;
                                    $bloo: "hello";

                                    div {
                                      color: red;
                                      width: 100%;
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                            $blah: a b c;
                                            $bloo: "hello";

                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                              }
                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                    p {
                                      margin: $blah;
                                      $blee: goodbye;
                                      padding: 10px 5px;
                                      a {
                                        display: inline-block;
                                        padding: 5px;
                                        color: $blee;
                                      }
                                      foo: $bloo;
                                      empty {
                                        not-empty {
                                          background: lightgray;
                                          border: 1px solid blue;
                                          span {
                                            display: block;
                                            -webkit-box-sizing: border-box;
                                          }
                                          $blah: a b c;
                                          $bloo: "hello";

                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                }
                                              }
                                            }
                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                    div {
                                      color: red;
                                      width: 100%;
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                                foo: $bloo;
                                empty {
                                  not-empty {
                                    background: lightgray;
                                    border: 1px solid blue;
                                    span {
                                      display: block;
                                      -webkit-box-sizing: border-box;
                                    }
                                    $blah: a b c;
                                    $bloo: "hello";

                                    div {
                                      color: red;
                                      width: 100%;
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                          }
                                        }
                                      }
                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                              div {
                                color: red;
                                width: 100%;
                                p {
                                  margin: $blah;
                                  $blee: goodbye;
                                  padding: 10px 5px;
                                  a {
                                    display: inline-block;
                                    padding: 5px;
                                    color: $blee;
                                  }
                                  foo: $bloo;
                                  empty {
                                    not-empty {
                                      background: lightgray;
                                      border: 1px solid blue;
                                      span {
                                        display: block;
                                        -webkit-box-sizing: border-box;
                                      }
                                    }
                                  }
                                  $blah: a b c;
                                  $bloo: "hello";

                                  div {
                                    color: red;
                                    width: 100%;
                                    $blah: a b c;
                                    $bloo: "hello";

                                    div {
                                      color: red;
                                      width: 100%;
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                            $blah: a b c;
                                            $bloo: "hello";

                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                              }
                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                    p {
                                      margin: $blah;
                                      $blee: goodbye;
                                      padding: 10px 5px;
                                      a {
                                        display: inline-block;
                                        padding: 5px;
                                        color: $blee;
                                        $blah: a b c;
                                        $bloo: "hello";

                                        div {
                                          color: red;
                                          width: 100%;
                                          $blah: a b c;
                                          $bloo: "hello";

                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                  $blah: a b c;
                                                  $bloo: "hello";

                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                        }
                                                      }
                                                    }
                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                                $blah: a b c;
                                                $bloo: "hello";

                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                      }
                                                    }
                                                  }
                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                      foo: $bloo;
                                      empty {
                                        not-empty {
                                          background: lightgray;
                                          border: 1px solid blue;
                                          span {
                                            display: block;
                                            -webkit-box-sizing: border-box;
                                          }
                                          $blah: a b c;
                                          $bloo: "hello";

                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                }
                                              }
                                            }
                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                          $blah: a b c;
                                          $bloo: "hello";

                                          div {
                                            color: red;
                                            width: 100%;
                                            $blah: a b c;
                                            $bloo: "hello";

                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                    $blah: a b c;
                                                    $bloo: "hello";

                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                          }
                                                        }
                                                      }
                                                      div {
                                                        color: red;
                                                        width: 100%;
                                                        p {
                                                          margin: $blah;
                                                          $blee: goodbye;
                                                          padding: 10px 5px;
                                                          a {
                                                            display: inline-block;
                                                            padding: 5px;
                                                            color: $blee;
                                                          }
                                                          foo: $bloo;
                                                          empty {
                                                            not-empty {
                                                              background: lightgray;
                                                              border: 1px solid blue;
                                                              span {
                                                                display: block;
                                                                -webkit-box-sizing: border-box;
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                                $blah: a b c;
                                                $bloo: "hello";

                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  $blah: a b c;
                                                  $bloo: "hello";

                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                          $blah: a b c;
                                                          $bloo: "hello";

                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                }
                                                              }
                                                            }
                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                        $blah: a b c;
                                                        $bloo: "hello";

                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                              }
                                                            }
                                                          }
                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                  $blah: a b c;
                                                  $bloo: "hello";

                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                        }
                                                      }
                                                    }
                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                                $blah: a b c;
                                                $bloo: "hello";

                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  $blah: a b c;
                                                  $bloo: "hello";

                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                          $blah: a b c;
                                                          $bloo: "hello";

                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                }
                                                              }
                                                            }
                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                      $blah: a b c;
                                                      $bloo: "hello";

                                                      div {
                                                        color: red;
                                                        width: 100%;
                                                        $blah: a b c;
                                                        $bloo: "hello";

                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                                $blah: a b c;
                                                                $bloo: "hello";

                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                        p {
                                                          margin: $blah;
                                                          $blee: goodbye;
                                                          padding: 10px 5px;
                                                          a {
                                                            display: inline-block;
                                                            padding: 5px;
                                                            color: $blee;
                                                          }
                                                          foo: $bloo;
                                                          empty {
                                                            not-empty {
                                                              background: lightgray;
                                                              border: 1px solid blue;
                                                              span {
                                                                display: block;
                                                                -webkit-box-sizing: border-box;
                                                              }
                                                              $blah: a b c;
                                                              $bloo: "hello";

                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                        $blah: a b c;
                                                        $bloo: "hello";

                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                              }
                                                            }
                                                          }
                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                  $blah: a b c;
                                                  $bloo: "hello";

                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    $blah: a b c;
                                                    $bloo: "hello";

                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                            $blah: a b c;
                                                            $bloo: "hello";

                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                      div {
                                                        color: red;
                                                        width: 100%;
                                                        p {
                                                          margin: $blah;
                                                          $blee: goodbye;
                                                          padding: 10px 5px;
                                                          a {
                                                            display: inline-block;
                                                            padding: 5px;
                                                            color: $blee;
                                                          }
                                                          foo: $bloo;
                                                          empty {
                                                            not-empty {
                                                              background: lightgray;
                                                              border: 1px solid blue;
                                                              span {
                                                                display: block;
                                                                -webkit-box-sizing: border-box;
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                        $blah: a b c;
                                                        $bloo: "hello";

                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          $blah: a b c;
                                                          $bloo: "hello";

                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                  $blah: a b c;
                                                                  $bloo: "hello";

                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                                $blah: a b c;
                                                                $bloo: "hello";

                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                          $blah: a b c;
                                                          $bloo: "hello";

                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                }
                                                              }
                                                            }
                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                          }
                                                        }
                                                        $blah: a b c;
                                                        $bloo: "hello";

                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          $blah: a b c;
                                                          $bloo: "hello";

                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                  $blah: a b c;
                                                                  $bloo: "hello";

                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                              $blah: a b c;
                                                              $bloo: "hello";

                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                $blah: a b c;
                                                                $bloo: "hello";

                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                        $blah: a b c;
                                                                        $bloo: "hello";

                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                          div {
                                                                            color: red;
                                                                            width: 100%;
                                                                            p {
                                                                              margin: $blah;
                                                                              $blee: goodbye;
                                                                              padding: 10px 5px;
                                                                              a {
                                                                                display: inline-block;
                                                                                padding: 5px;
                                                                                color: $blee;
                                                                              }
                                                                              foo: $bloo;
                                                                              empty {
                                                                                not-empty {
                                                                                  background: lightgray;
                                                                                  border: 1px solid blue;
                                                                                  span {
                                                                                    display: block;
                                                                                    -webkit-box-sizing: border-box;
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                      $blah: a b c;
                                                                      $bloo: "hello";

                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                                $blah: a b c;
                                                                $bloo: "hello";

                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                    div {
                                      color: red;
                                      width: 100%;
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                            div {
                              color: red;
                              width: 100%;
                              p {
                                margin: $blah;
                                $blee: goodbye;
                                padding: 10px 5px;
                                a {
                                  display: inline-block;
                                  padding: 5px;
                                  color: $blee;
                                }
                                foo: $bloo;
                                empty {
                                  not-empty {
                                    background: lightgray;
                                    border: 1px solid blue;
                                    span {
                                      display: block;
                                      -webkit-box-sizing: border-box;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                        $blah: a b c;
                        $bloo: "hello";

                        div {
                          color: red;
                          width: 100%;
                          $blah: a b c;
                          $bloo: "hello";

                          div {
                            color: red;
                            width: 100%;
                            p {
                              margin: $blah;
                              $blee: goodbye;
                              padding: 10px 5px;
                              a {
                                display: inline-block;
                                padding: 5px;
                                color: $blee;
                              }
                              foo: $bloo;
                              empty {
                                not-empty {
                                  background: lightgray;
                                  border: 1px solid blue;
                                  span {
                                    display: block;
                                    -webkit-box-sizing: border-box;
                                  }
                                  $blah: a b c;
                                  $bloo: "hello";

                                  div {
                                    color: red;
                                    width: 100%;
                                    p {
                                      margin: $blah;
                                      $blee: goodbye;
                                      padding: 10px 5px;
                                      a {
                                        display: inline-block;
                                        padding: 5px;
                                        color: $blee;
                                      }
                                      foo: $bloo;
                                      empty {
                                        not-empty {
                                          background: lightgray;
                                          border: 1px solid blue;
                                          span {
                                            display: block;
                                            -webkit-box-sizing: border-box;
                                          }
                                        }
                                      }
                                    }
                                    div {
                                      color: red;
                                      width: 100%;
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                            div {
                              color: red;
                              width: 100%;
                              p {
                                margin: $blah;
                                $blee: goodbye;
                                padding: 10px 5px;
                                a {
                                  display: inline-block;
                                  padding: 5px;
                                  color: $blee;
                                }
                                foo: $bloo;
                                empty {
                                  not-empty {
                                    background: lightgray;
                                    border: 1px solid blue;
                                    span {
                                      display: block;
                                      -webkit-box-sizing: border-box;
                                    }
                                  }
                                }
                              }
                            }
                          }
                          p {
                            margin: $blah;
                            $blee: goodbye;
                            padding: 10px 5px;
                            a {
                              display: inline-block;
                              padding: 5px;
                              color: $blee;
                              $blah: a b c;
                              $bloo: "hello";

                              div {
                                color: red;
                                width: 100%;
                                $blah: a b c;
                                $bloo: "hello";

                                div {
                                  color: red;
                                  width: 100%;
                                  p {
                                    margin: $blah;
                                    $blee: goodbye;
                                    padding: 10px 5px;
                                    a {
                                      display: inline-block;
                                      padding: 5px;
                                      color: $blee;
                                    }
                                    foo: $bloo;
                                    empty {
                                      not-empty {
                                        background: lightgray;
                                        border: 1px solid blue;
                                        span {
                                          display: block;
                                          -webkit-box-sizing: border-box;
                                        }
                                        $blah: a b c;
                                        $bloo: "hello";

                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                              }
                                            }
                                          }
                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                  div {
                                    color: red;
                                    width: 100%;
                                    p {
                                      margin: $blah;
                                      $blee: goodbye;
                                      padding: 10px 5px;
                                      a {
                                        display: inline-block;
                                        padding: 5px;
                                        color: $blee;
                                      }
                                      foo: $bloo;
                                      empty {
                                        not-empty {
                                          background: lightgray;
                                          border: 1px solid blue;
                                          span {
                                            display: block;
                                            -webkit-box-sizing: border-box;
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                                p {
                                  margin: $blah;
                                  $blee: goodbye;
                                  padding: 10px 5px;
                                  a {
                                    display: inline-block;
                                    padding: 5px;
                                    color: $blee;
                                  }
                                  foo: $bloo;
                                  empty {
                                    not-empty {
                                      background: lightgray;
                                      border: 1px solid blue;
                                      span {
                                        display: block;
                                        -webkit-box-sizing: border-box;
                                      }
                                      $blah: a b c;
                                      $bloo: "hello";

                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                            }
                                          }
                                        }
                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                                div {
                                  color: red;
                                  width: 100%;
                                  p {
                                    margin: $blah;
                                    $blee: goodbye;
                                    padding: 10px 5px;
                                    a {
                                      display: inline-block;
                                      padding: 5px;
                                      color: $blee;
                                    }
                                    foo: $bloo;
                                    empty {
                                      not-empty {
                                        background: lightgray;
                                        border: 1px solid blue;
                                        span {
                                          display: block;
                                          -webkit-box-sizing: border-box;
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                            foo: $bloo;
                            empty {
                              not-empty {
                                background: lightgray;
                                border: 1px solid blue;
                                span {
                                  display: block;
                                  -webkit-box-sizing: border-box;
                                }
                                $blah: a b c;
                                $bloo: "hello";

                                div {
                                  color: red;
                                  width: 100%;
                                  p {
                                    margin: $blah;
                                    $blee: goodbye;
                                    padding: 10px 5px;
                                    a {
                                      display: inline-block;
                                      padding: 5px;
                                      color: $blee;
                                    }
                                    foo: $bloo;
                                    empty {
                                      not-empty {
                                        background: lightgray;
                                        border: 1px solid blue;
                                        span {
                                          display: block;
                                          -webkit-box-sizing: border-box;
                                        }
                                      }
                                    }
                                  }
                                  div {
                                    color: red;
                                    width: 100%;
                                    p {
                                      margin: $blah;
                                      $blee: goodbye;
                                      padding: 10px 5px;
                                      a {
                                        display: inline-block;
                                        padding: 5px;
                                        color: $blee;
                                      }
                                      foo: $bloo;
                                      empty {
                                        not-empty {
                                          background: lightgray;
                                          border: 1px solid blue;
                                          span {
                                            display: block;
                                            -webkit-box-sizing: border-box;
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                          div {
                            color: red;
                            width: 100%;
                            p {
                              margin: $blah;
                              $blee: goodbye;
                              padding: 10px 5px;
                              a {
                                display: inline-block;
                                padding: 5px;
                                color: $blee;
                              }
                              foo: $bloo;
                              empty {
                                not-empty {
                                  background: lightgray;
                                  border: 1px solid blue;
                                  span {
                                    display: block;
                                    -webkit-box-sizing: border-box;
                                  }
                                }
                              }
                              $blah: a b c;
                              $bloo: "hello";

                              div {
                                color: red;
                                width: 100%;
                                $blah: a b c;
                                $bloo: "hello";

                                div {
                                  color: red;
                                  width: 100%;
                                  p {
                                    margin: $blah;
                                    $blee: goodbye;
                                    padding: 10px 5px;
                                    a {
                                      display: inline-block;
                                      padding: 5px;
                                      color: $blee;
                                    }
                                    foo: $bloo;
                                    empty {
                                      not-empty {
                                        background: lightgray;
                                        border: 1px solid blue;
                                        span {
                                          display: block;
                                          -webkit-box-sizing: border-box;
                                        }
                                        $blah: a b c;
                                        $bloo: "hello";

                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                              }
                                            }
                                          }
                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                  div {
                                    color: red;
                                    width: 100%;
                                    p {
                                      margin: $blah;
                                      $blee: goodbye;
                                      padding: 10px 5px;
                                      a {
                                        display: inline-block;
                                        padding: 5px;
                                        color: $blee;
                                      }
                                      foo: $bloo;
                                      empty {
                                        not-empty {
                                          background: lightgray;
                                          border: 1px solid blue;
                                          span {
                                            display: block;
                                            -webkit-box-sizing: border-box;
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                                p {
                                  margin: $blah;
                                  $blee: goodbye;
                                  padding: 10px 5px;
                                  a {
                                    display: inline-block;
                                    padding: 5px;
                                    color: $blee;
                                    $blah: a b c;
                                    $bloo: "hello";

                                    div {
                                      color: red;
                                      width: 100%;
                                      $blah: a b c;
                                      $bloo: "hello";

                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                              $blah: a b c;
                                              $bloo: "hello";

                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                    }
                                                  }
                                                }
                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                            $blah: a b c;
                                            $bloo: "hello";

                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                              }
                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                  foo: $bloo;
                                  empty {
                                    not-empty {
                                      background: lightgray;
                                      border: 1px solid blue;
                                      span {
                                        display: block;
                                        -webkit-box-sizing: border-box;
                                      }
                                      $blah: a b c;
                                      $bloo: "hello";

                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                            }
                                          }
                                        }
                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                                $blah: a b c;
                                $bloo: "hello";

                                div {
                                  color: red;
                                  width: 100%;
                                  $blah: a b c;
                                  $bloo: "hello";

                                  div {
                                    color: red;
                                    width: 100%;
                                    p {
                                      margin: $blah;
                                      $blee: goodbye;
                                      padding: 10px 5px;
                                      a {
                                        display: inline-block;
                                        padding: 5px;
                                        color: $blee;
                                      }
                                      foo: $bloo;
                                      empty {
                                        not-empty {
                                          background: lightgray;
                                          border: 1px solid blue;
                                          span {
                                            display: block;
                                            -webkit-box-sizing: border-box;
                                          }
                                          $blah: a b c;
                                          $bloo: "hello";

                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                }
                                              }
                                            }
                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                    div {
                                      color: red;
                                      width: 100%;
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                  p {
                                    margin: $blah;
                                    $blee: goodbye;
                                    padding: 10px 5px;
                                    a {
                                      display: inline-block;
                                      padding: 5px;
                                      color: $blee;
                                      $blah: a b c;
                                      $bloo: "hello";

                                      div {
                                        color: red;
                                        width: 100%;
                                        $blah: a b c;
                                        $bloo: "hello";

                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                                $blah: a b c;
                                                $bloo: "hello";

                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                      }
                                                    }
                                                  }
                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                              $blah: a b c;
                                              $bloo: "hello";

                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                    }
                                                  }
                                                }
                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                    foo: $bloo;
                                    empty {
                                      not-empty {
                                        background: lightgray;
                                        border: 1px solid blue;
                                        span {
                                          display: block;
                                          -webkit-box-sizing: border-box;
                                        }
                                        $blah: a b c;
                                        $bloo: "hello";

                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                              }
                                            }
                                          }
                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                  div {
                                    color: red;
                                    width: 100%;
                                    p {
                                      margin: $blah;
                                      $blee: goodbye;
                                      padding: 10px 5px;
                                      a {
                                        display: inline-block;
                                        padding: 5px;
                                        color: $blee;
                                      }
                                      foo: $bloo;
                                      empty {
                                        not-empty {
                                          background: lightgray;
                                          border: 1px solid blue;
                                          span {
                                            display: block;
                                            -webkit-box-sizing: border-box;
                                          }
                                        }
                                      }
                                      $blah: a b c;
                                      $bloo: "hello";

                                      div {
                                        color: red;
                                        width: 100%;
                                        $blah: a b c;
                                        $bloo: "hello";

                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                                $blah: a b c;
                                                $bloo: "hello";

                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                      }
                                                    }
                                                  }
                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                            $blah: a b c;
                                            $bloo: "hello";

                                            div {
                                              color: red;
                                              width: 100%;
                                              $blah: a b c;
                                              $bloo: "hello";

                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                      $blah: a b c;
                                                      $bloo: "hello";

                                                      div {
                                                        color: red;
                                                        width: 100%;
                                                        p {
                                                          margin: $blah;
                                                          $blee: goodbye;
                                                          padding: 10px 5px;
                                                          a {
                                                            display: inline-block;
                                                            padding: 5px;
                                                            color: $blee;
                                                          }
                                                          foo: $bloo;
                                                          empty {
                                                            not-empty {
                                                              background: lightgray;
                                                              border: 1px solid blue;
                                                              span {
                                                                display: block;
                                                                -webkit-box-sizing: border-box;
                                                              }
                                                            }
                                                          }
                                                        }
                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                    $blah: a b c;
                                                    $bloo: "hello";

                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                          }
                                                        }
                                                      }
                                                      div {
                                                        color: red;
                                                        width: 100%;
                                                        p {
                                                          margin: $blah;
                                                          $blee: goodbye;
                                                          padding: 10px 5px;
                                                          a {
                                                            display: inline-block;
                                                            padding: 5px;
                                                            color: $blee;
                                                          }
                                                          foo: $bloo;
                                                          empty {
                                                            not-empty {
                                                              background: lightgray;
                                                              border: 1px solid blue;
                                                              span {
                                                                display: block;
                                                                -webkit-box-sizing: border-box;
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                              $blah: a b c;
                                              $bloo: "hello";

                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                    }
                                                  }
                                                }
                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                              $blah: a b c;
                                              $bloo: "hello";

                                              div {
                                                color: red;
                                                width: 100%;
                                                $blah: a b c;
                                                $bloo: "hello";

                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                        $blah: a b c;
                                                        $bloo: "hello";

                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                              }
                                                            }
                                                          }
                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                    $blah: a b c;
                                                    $bloo: "hello";

                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      $blah: a b c;
                                                      $bloo: "hello";

                                                      div {
                                                        color: red;
                                                        width: 100%;
                                                        p {
                                                          margin: $blah;
                                                          $blee: goodbye;
                                                          padding: 10px 5px;
                                                          a {
                                                            display: inline-block;
                                                            padding: 5px;
                                                            color: $blee;
                                                          }
                                                          foo: $bloo;
                                                          empty {
                                                            not-empty {
                                                              background: lightgray;
                                                              border: 1px solid blue;
                                                              span {
                                                                display: block;
                                                                -webkit-box-sizing: border-box;
                                                              }
                                                              $blah: a b c;
                                                              $bloo: "hello";

                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                            $blah: a b c;
                                                            $bloo: "hello";

                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                      div {
                                                        color: red;
                                                        width: 100%;
                                                        p {
                                                          margin: $blah;
                                                          $blee: goodbye;
                                                          padding: 10px 5px;
                                                          a {
                                                            display: inline-block;
                                                            padding: 5px;
                                                            color: $blee;
                                                          }
                                                          foo: $bloo;
                                                          empty {
                                                            not-empty {
                                                              background: lightgray;
                                                              border: 1px solid blue;
                                                              span {
                                                                display: block;
                                                                -webkit-box-sizing: border-box;
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                      $blah: a b c;
                                                      $bloo: "hello";

                                                      div {
                                                        color: red;
                                                        width: 100%;
                                                        p {
                                                          margin: $blah;
                                                          $blee: goodbye;
                                                          padding: 10px 5px;
                                                          a {
                                                            display: inline-block;
                                                            padding: 5px;
                                                            color: $blee;
                                                          }
                                                          foo: $bloo;
                                                          empty {
                                                            not-empty {
                                                              background: lightgray;
                                                              border: 1px solid blue;
                                                              span {
                                                                display: block;
                                                                -webkit-box-sizing: border-box;
                                                              }
                                                            }
                                                          }
                                                        }
                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                      }
                                                    }
                                                    $blah: a b c;
                                                    $bloo: "hello";

                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      $blah: a b c;
                                                      $bloo: "hello";

                                                      div {
                                                        color: red;
                                                        width: 100%;
                                                        p {
                                                          margin: $blah;
                                                          $blee: goodbye;
                                                          padding: 10px 5px;
                                                          a {
                                                            display: inline-block;
                                                            padding: 5px;
                                                            color: $blee;
                                                          }
                                                          foo: $bloo;
                                                          empty {
                                                            not-empty {
                                                              background: lightgray;
                                                              border: 1px solid blue;
                                                              span {
                                                                display: block;
                                                                -webkit-box-sizing: border-box;
                                                              }
                                                              $blah: a b c;
                                                              $bloo: "hello";

                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                          $blah: a b c;
                                                          $bloo: "hello";

                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            $blah: a b c;
                                                            $bloo: "hello";

                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                    $blah: a b c;
                                                                    $bloo: "hello";

                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                  $blah: a b c;
                                                                  $bloo: "hello";

                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                            $blah: a b c;
                                                            $bloo: "hello";

                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                      $blah: a b c;
                                                      $bloo: "hello";

                                                      div {
                                                        color: red;
                                                        width: 100%;
                                                        $blah: a b c;
                                                        $bloo: "hello";

                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                                $blah: a b c;
                                                                $bloo: "hello";

                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                        p {
                                                          margin: $blah;
                                                          $blee: goodbye;
                                                          padding: 10px 5px;
                                                          a {
                                                            display: inline-block;
                                                            padding: 5px;
                                                            color: $blee;
                                                            $blah: a b c;
                                                            $bloo: "hello";

                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              $blah: a b c;
                                                              $bloo: "hello";

                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                      $blah: a b c;
                                                                      $bloo: "hello";

                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                    $blah: a b c;
                                                                    $bloo: "hello";

                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                          foo: $bloo;
                                                          empty {
                                                            not-empty {
                                                              background: lightgray;
                                                              border: 1px solid blue;
                                                              span {
                                                                display: block;
                                                                -webkit-box-sizing: border-box;
                                                              }
                                                              $blah: a b c;
                                                              $bloo: "hello";

                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                              }
                                                            }
                                                            $blah: a b c;
                                                            $bloo: "hello";

                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              $blah: a b c;
                                                              $bloo: "hello";

                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                      $blah: a b c;
                                                                      $bloo: "hello";

                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                  $blah: a b c;
                                                                  $bloo: "hello";

                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    $blah: a b c;
                                                                    $bloo: "hello";

                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                            $blah: a b c;
                                                                            $bloo: "hello";

                                                                            div {
                                                                              color: red;
                                                                              width: 100%;
                                                                              p {
                                                                                margin: $blah;
                                                                                $blee: goodbye;
                                                                                padding: 10px 5px;
                                                                                a {
                                                                                  display: inline-block;
                                                                                  padding: 5px;
                                                                                  color: $blee;
                                                                                }
                                                                                foo: $bloo;
                                                                                empty {
                                                                                  not-empty {
                                                                                    background: lightgray;
                                                                                    border: 1px solid blue;
                                                                                    span {
                                                                                      display: block;
                                                                                      -webkit-box-sizing: border-box;
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                              div {
                                                                                color: red;
                                                                                width: 100%;
                                                                                p {
                                                                                  margin: $blah;
                                                                                  $blee: goodbye;
                                                                                  padding: 10px 5px;
                                                                                  a {
                                                                                    display: inline-block;
                                                                                    padding: 5px;
                                                                                    color: $blee;
                                                                                  }
                                                                                  foo: $bloo;
                                                                                  empty {
                                                                                    not-empty {
                                                                                      background: lightgray;
                                                                                      border: 1px solid blue;
                                                                                      span {
                                                                                        display: block;
                                                                                        -webkit-box-sizing: border-box;
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                          $blah: a b c;
                                                                          $bloo: "hello";

                                                                          div {
                                                                            color: red;
                                                                            width: 100%;
                                                                            p {
                                                                              margin: $blah;
                                                                              $blee: goodbye;
                                                                              padding: 10px 5px;
                                                                              a {
                                                                                display: inline-block;
                                                                                padding: 5px;
                                                                                color: $blee;
                                                                              }
                                                                              foo: $bloo;
                                                                              empty {
                                                                                not-empty {
                                                                                  background: lightgray;
                                                                                  border: 1px solid blue;
                                                                                  span {
                                                                                    display: block;
                                                                                    -webkit-box-sizing: border-box;
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                            div {
                                                                              color: red;
                                                                              width: 100%;
                                                                              p {
                                                                                margin: $blah;
                                                                                $blee: goodbye;
                                                                                padding: 10px 5px;
                                                                                a {
                                                                                  display: inline-block;
                                                                                  padding: 5px;
                                                                                  color: $blee;
                                                                                }
                                                                                foo: $bloo;
                                                                                empty {
                                                                                  not-empty {
                                                                                    background: lightgray;
                                                                                    border: 1px solid blue;
                                                                                    span {
                                                                                      display: block;
                                                                                      -webkit-box-sizing: border-box;
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                    $blah: a b c;
                                                                    $bloo: "hello";

                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                      div {
                                                        color: red;
                                                        width: 100%;
                                                        p {
                                                          margin: $blah;
                                                          $blee: goodbye;
                                                          padding: 10px 5px;
                                                          a {
                                                            display: inline-block;
                                                            padding: 5px;
                                                            color: $blee;
                                                          }
                                                          foo: $bloo;
                                                          empty {
                                                            not-empty {
                                                              background: lightgray;
                                                              border: 1px solid blue;
                                                              span {
                                                                display: block;
                                                                -webkit-box-sizing: border-box;
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                                div {
                                  color: red;
                                  width: 100%;
                                  p {
                                    margin: $blah;
                                    $blee: goodbye;
                                    padding: 10px 5px;
                                    a {
                                      display: inline-block;
                                      padding: 5px;
                                      color: $blee;
                                    }
                                    foo: $bloo;
                                    empty {
                                      not-empty {
                                        background: lightgray;
                                        border: 1px solid blue;
                                        span {
                                          display: block;
                                          -webkit-box-sizing: border-box;
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                              $blah: a b c;
                              $bloo: "hello";

                              div {
                                color: red;
                                width: 100%;
                                $blah: a b c;
                                $bloo: "hello";

                                div {
                                  color: red;
                                  width: 100%;
                                  p {
                                    margin: $blah;
                                    $blee: goodbye;
                                    padding: 10px 5px;
                                    a {
                                      display: inline-block;
                                      padding: 5px;
                                      color: $blee;
                                    }
                                    foo: $bloo;
                                    empty {
                                      not-empty {
                                        background: lightgray;
                                        border: 1px solid blue;
                                        span {
                                          display: block;
                                          -webkit-box-sizing: border-box;
                                        }
                                        $blah: a b c;
                                        $bloo: "hello";

                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                              }
                                            }
                                          }
                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                  div {
                                    color: red;
                                    width: 100%;
                                    p {
                                      margin: $blah;
                                      $blee: goodbye;
                                      padding: 10px 5px;
                                      a {
                                        display: inline-block;
                                        padding: 5px;
                                        color: $blee;
                                      }
                                      foo: $bloo;
                                      empty {
                                        not-empty {
                                          background: lightgray;
                                          border: 1px solid blue;
                                          span {
                                            display: block;
                                            -webkit-box-sizing: border-box;
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                                p {
                                  margin: $blah;
                                  $blee: goodbye;
                                  padding: 10px 5px;
                                  a {
                                    display: inline-block;
                                    padding: 5px;
                                    color: $blee;
                                    $blah: a b c;
                                    $bloo: "hello";

                                    div {
                                      color: red;
                                      width: 100%;
                                      $blah: a b c;
                                      $bloo: "hello";

                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                              $blah: a b c;
                                              $bloo: "hello";

                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                    }
                                                  }
                                                }
                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                            $blah: a b c;
                                            $bloo: "hello";

                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                              }
                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                  foo: $bloo;
                                  empty {
                                    not-empty {
                                      background: lightgray;
                                      border: 1px solid blue;
                                      span {
                                        display: block;
                                        -webkit-box-sizing: border-box;
                                      }
                                      $blah: a b c;
                                      $bloo: "hello";

                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                            }
                                          }
                                        }
                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                                div {
                                  color: red;
                                  width: 100%;
                                  p {
                                    margin: $blah;
                                    $blee: goodbye;
                                    padding: 10px 5px;
                                    a {
                                      display: inline-block;
                                      padding: 5px;
                                      color: $blee;
                                    }
                                    foo: $bloo;
                                    empty {
                                      not-empty {
                                        background: lightgray;
                                        border: 1px solid blue;
                                        span {
                                          display: block;
                                          -webkit-box-sizing: border-box;
                                        }
                                      }
                                    }
                                    $blah: a b c;
                                    $bloo: "hello";

                                    div {
                                      color: red;
                                      width: 100%;
                                      $blah: a b c;
                                      $bloo: "hello";

                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                              $blah: a b c;
                                              $bloo: "hello";

                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                    }
                                                  }
                                                }
                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                          $blah: a b c;
                                          $bloo: "hello";

                                          div {
                                            color: red;
                                            width: 100%;
                                            $blah: a b c;
                                            $bloo: "hello";

                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                    $blah: a b c;
                                                    $bloo: "hello";

                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                          }
                                                        }
                                                      }
                                                      div {
                                                        color: red;
                                                        width: 100%;
                                                        p {
                                                          margin: $blah;
                                                          $blee: goodbye;
                                                          padding: 10px 5px;
                                                          a {
                                                            display: inline-block;
                                                            padding: 5px;
                                                            color: $blee;
                                                          }
                                                          foo: $bloo;
                                                          empty {
                                                            not-empty {
                                                              background: lightgray;
                                                              border: 1px solid blue;
                                                              span {
                                                                display: block;
                                                                -webkit-box-sizing: border-box;
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                  $blah: a b c;
                                                  $bloo: "hello";

                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                        }
                                                      }
                                                    }
                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                            $blah: a b c;
                                            $bloo: "hello";

                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                              }
                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                      $blah: a b c;
                                      $bloo: "hello";

                                      div {
                                        color: red;
                                        width: 100%;
                                        $blah: a b c;
                                        $bloo: "hello";

                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                                $blah: a b c;
                                                $bloo: "hello";

                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                      }
                                                    }
                                                  }
                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                            $blah: a b c;
                                            $bloo: "hello";

                                            div {
                                              color: red;
                                              width: 100%;
                                              $blah: a b c;
                                              $bloo: "hello";

                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                      $blah: a b c;
                                                      $bloo: "hello";

                                                      div {
                                                        color: red;
                                                        width: 100%;
                                                        p {
                                                          margin: $blah;
                                                          $blee: goodbye;
                                                          padding: 10px 5px;
                                                          a {
                                                            display: inline-block;
                                                            padding: 5px;
                                                            color: $blee;
                                                          }
                                                          foo: $bloo;
                                                          empty {
                                                            not-empty {
                                                              background: lightgray;
                                                              border: 1px solid blue;
                                                              span {
                                                                display: block;
                                                                -webkit-box-sizing: border-box;
                                                              }
                                                            }
                                                          }
                                                        }
                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                    $blah: a b c;
                                                    $bloo: "hello";

                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                          }
                                                        }
                                                      }
                                                      div {
                                                        color: red;
                                                        width: 100%;
                                                        p {
                                                          margin: $blah;
                                                          $blee: goodbye;
                                                          padding: 10px 5px;
                                                          a {
                                                            display: inline-block;
                                                            padding: 5px;
                                                            color: $blee;
                                                          }
                                                          foo: $bloo;
                                                          empty {
                                                            not-empty {
                                                              background: lightgray;
                                                              border: 1px solid blue;
                                                              span {
                                                                display: block;
                                                                -webkit-box-sizing: border-box;
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                              $blah: a b c;
                                              $bloo: "hello";

                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                    }
                                                  }
                                                }
                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                        div {
                                          color: red;
                                          width: 100%;
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                              }
                                            }
                                            $blah: a b c;
                                            $bloo: "hello";

                                            div {
                                              color: red;
                                              width: 100%;
                                              $blah: a b c;
                                              $bloo: "hello";

                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                      $blah: a b c;
                                                      $bloo: "hello";

                                                      div {
                                                        color: red;
                                                        width: 100%;
                                                        p {
                                                          margin: $blah;
                                                          $blee: goodbye;
                                                          padding: 10px 5px;
                                                          a {
                                                            display: inline-block;
                                                            padding: 5px;
                                                            color: $blee;
                                                          }
                                                          foo: $bloo;
                                                          empty {
                                                            not-empty {
                                                              background: lightgray;
                                                              border: 1px solid blue;
                                                              span {
                                                                display: block;
                                                                -webkit-box-sizing: border-box;
                                                              }
                                                            }
                                                          }
                                                        }
                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                  $blah: a b c;
                                                  $bloo: "hello";

                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    $blah: a b c;
                                                    $bloo: "hello";

                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                            $blah: a b c;
                                                            $bloo: "hello";

                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                      div {
                                                        color: red;
                                                        width: 100%;
                                                        p {
                                                          margin: $blah;
                                                          $blee: goodbye;
                                                          padding: 10px 5px;
                                                          a {
                                                            display: inline-block;
                                                            padding: 5px;
                                                            color: $blee;
                                                          }
                                                          foo: $bloo;
                                                          empty {
                                                            not-empty {
                                                              background: lightgray;
                                                              border: 1px solid blue;
                                                              span {
                                                                display: block;
                                                                -webkit-box-sizing: border-box;
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                          $blah: a b c;
                                                          $bloo: "hello";

                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                }
                                                              }
                                                            }
                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                    $blah: a b c;
                                                    $bloo: "hello";

                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                          }
                                                        }
                                                      }
                                                      div {
                                                        color: red;
                                                        width: 100%;
                                                        p {
                                                          margin: $blah;
                                                          $blee: goodbye;
                                                          padding: 10px 5px;
                                                          a {
                                                            display: inline-block;
                                                            padding: 5px;
                                                            color: $blee;
                                                          }
                                                          foo: $bloo;
                                                          empty {
                                                            not-empty {
                                                              background: lightgray;
                                                              border: 1px solid blue;
                                                              span {
                                                                display: block;
                                                                -webkit-box-sizing: border-box;
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                    $blah: a b c;
                                                    $bloo: "hello";

                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      $blah: a b c;
                                                      $bloo: "hello";

                                                      div {
                                                        color: red;
                                                        width: 100%;
                                                        p {
                                                          margin: $blah;
                                                          $blee: goodbye;
                                                          padding: 10px 5px;
                                                          a {
                                                            display: inline-block;
                                                            padding: 5px;
                                                            color: $blee;
                                                          }
                                                          foo: $bloo;
                                                          empty {
                                                            not-empty {
                                                              background: lightgray;
                                                              border: 1px solid blue;
                                                              span {
                                                                display: block;
                                                                -webkit-box-sizing: border-box;
                                                              }
                                                              $blah: a b c;
                                                              $bloo: "hello";

                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                          $blah: a b c;
                                                          $bloo: "hello";

                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            $blah: a b c;
                                                            $bloo: "hello";

                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                    $blah: a b c;
                                                                    $bloo: "hello";

                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                  $blah: a b c;
                                                                  $bloo: "hello";

                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                            $blah: a b c;
                                                            $bloo: "hello";

                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                      div {
                                                        color: red;
                                                        width: 100%;
                                                        p {
                                                          margin: $blah;
                                                          $blee: goodbye;
                                                          padding: 10px 5px;
                                                          a {
                                                            display: inline-block;
                                                            padding: 5px;
                                                            color: $blee;
                                                          }
                                                          foo: $bloo;
                                                          empty {
                                                            not-empty {
                                                              background: lightgray;
                                                              border: 1px solid blue;
                                                              span {
                                                                display: block;
                                                                -webkit-box-sizing: border-box;
                                                              }
                                                            }
                                                          }
                                                          $blah: a b c;
                                                          $bloo: "hello";

                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            $blah: a b c;
                                                            $bloo: "hello";

                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                    $blah: a b c;
                                                                    $bloo: "hello";

                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                                $blah: a b c;
                                                                $bloo: "hello";

                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  $blah: a b c;
                                                                  $bloo: "hello";

                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                          $blah: a b c;
                                                                          $bloo: "hello";

                                                                          div {
                                                                            color: red;
                                                                            width: 100%;
                                                                            p {
                                                                              margin: $blah;
                                                                              $blee: goodbye;
                                                                              padding: 10px 5px;
                                                                              a {
                                                                                display: inline-block;
                                                                                padding: 5px;
                                                                                color: $blee;
                                                                              }
                                                                              foo: $bloo;
                                                                              empty {
                                                                                not-empty {
                                                                                  background: lightgray;
                                                                                  border: 1px solid blue;
                                                                                  span {
                                                                                    display: block;
                                                                                    -webkit-box-sizing: border-box;
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                            div {
                                                                              color: red;
                                                                              width: 100%;
                                                                              p {
                                                                                margin: $blah;
                                                                                $blee: goodbye;
                                                                                padding: 10px 5px;
                                                                                a {
                                                                                  display: inline-block;
                                                                                  padding: 5px;
                                                                                  color: $blee;
                                                                                }
                                                                                foo: $bloo;
                                                                                empty {
                                                                                  not-empty {
                                                                                    background: lightgray;
                                                                                    border: 1px solid blue;
                                                                                    span {
                                                                                      display: block;
                                                                                      -webkit-box-sizing: border-box;
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                        $blah: a b c;
                                                                        $bloo: "hello";

                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                          div {
                                                                            color: red;
                                                                            width: 100%;
                                                                            p {
                                                                              margin: $blah;
                                                                              $blee: goodbye;
                                                                              padding: 10px 5px;
                                                                              a {
                                                                                display: inline-block;
                                                                                padding: 5px;
                                                                                color: $blee;
                                                                              }
                                                                              foo: $bloo;
                                                                              empty {
                                                                                not-empty {
                                                                                  background: lightgray;
                                                                                  border: 1px solid blue;
                                                                                  span {
                                                                                    display: block;
                                                                                    -webkit-box-sizing: border-box;
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                  $blah: a b c;
                                                                  $bloo: "hello";

                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                            $blah: a b c;
                                                            $bloo: "hello";

                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              $blah: a b c;
                                                              $bloo: "hello";

                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                      $blah: a b c;
                                                                      $bloo: "hello";

                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                  $blah: a b c;
                                                                  $bloo: "hello";

                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    $blah: a b c;
                                                                    $bloo: "hello";

                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                            $blah: a b c;
                                                                            $bloo: "hello";

                                                                            div {
                                                                              color: red;
                                                                              width: 100%;
                                                                              p {
                                                                                margin: $blah;
                                                                                $blee: goodbye;
                                                                                padding: 10px 5px;
                                                                                a {
                                                                                  display: inline-block;
                                                                                  padding: 5px;
                                                                                  color: $blee;
                                                                                }
                                                                                foo: $bloo;
                                                                                empty {
                                                                                  not-empty {
                                                                                    background: lightgray;
                                                                                    border: 1px solid blue;
                                                                                    span {
                                                                                      display: block;
                                                                                      -webkit-box-sizing: border-box;
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                              div {
                                                                                color: red;
                                                                                width: 100%;
                                                                                p {
                                                                                  margin: $blah;
                                                                                  $blee: goodbye;
                                                                                  padding: 10px 5px;
                                                                                  a {
                                                                                    display: inline-block;
                                                                                    padding: 5px;
                                                                                    color: $blee;
                                                                                  }
                                                                                  foo: $bloo;
                                                                                  empty {
                                                                                    not-empty {
                                                                                      background: lightgray;
                                                                                      border: 1px solid blue;
                                                                                      span {
                                                                                        display: block;
                                                                                        -webkit-box-sizing: border-box;
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                          $blah: a b c;
                                                                          $bloo: "hello";

                                                                          div {
                                                                            color: red;
                                                                            width: 100%;
                                                                            p {
                                                                              margin: $blah;
                                                                              $blee: goodbye;
                                                                              padding: 10px 5px;
                                                                              a {
                                                                                display: inline-block;
                                                                                padding: 5px;
                                                                                color: $blee;
                                                                              }
                                                                              foo: $bloo;
                                                                              empty {
                                                                                not-empty {
                                                                                  background: lightgray;
                                                                                  border: 1px solid blue;
                                                                                  span {
                                                                                    display: block;
                                                                                    -webkit-box-sizing: border-box;
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                            div {
                                                                              color: red;
                                                                              width: 100%;
                                                                              p {
                                                                                margin: $blah;
                                                                                $blee: goodbye;
                                                                                padding: 10px 5px;
                                                                                a {
                                                                                  display: inline-block;
                                                                                  padding: 5px;
                                                                                  color: $blee;
                                                                                }
                                                                                foo: $bloo;
                                                                                empty {
                                                                                  not-empty {
                                                                                    background: lightgray;
                                                                                    border: 1px solid blue;
                                                                                    span {
                                                                                      display: block;
                                                                                      -webkit-box-sizing: border-box;
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                    $blah: a b c;
                                                                    $bloo: "hello";

                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                    }
                                                                  }
                                                                  $blah: a b c;
                                                                  $bloo: "hello";

                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    $blah: a b c;
                                                                    $bloo: "hello";

                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                            $blah: a b c;
                                                                            $bloo: "hello";

                                                                            div {
                                                                              color: red;
                                                                              width: 100%;
                                                                              p {
                                                                                margin: $blah;
                                                                                $blee: goodbye;
                                                                                padding: 10px 5px;
                                                                                a {
                                                                                  display: inline-block;
                                                                                  padding: 5px;
                                                                                  color: $blee;
                                                                                }
                                                                                foo: $bloo;
                                                                                empty {
                                                                                  not-empty {
                                                                                    background: lightgray;
                                                                                    border: 1px solid blue;
                                                                                    span {
                                                                                      display: block;
                                                                                      -webkit-box-sizing: border-box;
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                              div {
                                                                                color: red;
                                                                                width: 100%;
                                                                                p {
                                                                                  margin: $blah;
                                                                                  $blee: goodbye;
                                                                                  padding: 10px 5px;
                                                                                  a {
                                                                                    display: inline-block;
                                                                                    padding: 5px;
                                                                                    color: $blee;
                                                                                  }
                                                                                  foo: $bloo;
                                                                                  empty {
                                                                                    not-empty {
                                                                                      background: lightgray;
                                                                                      border: 1px solid blue;
                                                                                      span {
                                                                                        display: block;
                                                                                        -webkit-box-sizing: border-box;
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                        $blah: a b c;
                                                                        $bloo: "hello";

                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          $blah: a b c;
                                                                          $bloo: "hello";

                                                                          div {
                                                                            color: red;
                                                                            width: 100%;
                                                                            p {
                                                                              margin: $blah;
                                                                              $blee: goodbye;
                                                                              padding: 10px 5px;
                                                                              a {
                                                                                display: inline-block;
                                                                                padding: 5px;
                                                                                color: $blee;
                                                                              }
                                                                              foo: $bloo;
                                                                              empty {
                                                                                not-empty {
                                                                                  background: lightgray;
                                                                                  border: 1px solid blue;
                                                                                  span {
                                                                                    display: block;
                                                                                    -webkit-box-sizing: border-box;
                                                                                  }
                                                                                  $blah: a b c;
                                                                                  $bloo: "hello";

                                                                                  div {
                                                                                    color: red;
                                                                                    width: 100%;
                                                                                    p {
                                                                                      margin: $blah;
                                                                                      $blee: goodbye;
                                                                                      padding: 10px 5px;
                                                                                      a {
                                                                                        display: inline-block;
                                                                                        padding: 5px;
                                                                                        color: $blee;
                                                                                      }
                                                                                      foo: $bloo;
                                                                                      empty {
                                                                                        not-empty {
                                                                                          background: lightgray;
                                                                                          border: 1px solid blue;
                                                                                          span {
                                                                                            display: block;
                                                                                            -webkit-box-sizing: border-box;
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                    div {
                                                                                      color: red;
                                                                                      width: 100%;
                                                                                      p {
                                                                                        margin: $blah;
                                                                                        $blee: goodbye;
                                                                                        padding: 10px 5px;
                                                                                        a {
                                                                                          display: inline-block;
                                                                                          padding: 5px;
                                                                                          color: $blee;
                                                                                        }
                                                                                        foo: $bloo;
                                                                                        empty {
                                                                                          not-empty {
                                                                                            background: lightgray;
                                                                                            border: 1px solid blue;
                                                                                            span {
                                                                                              display: block;
                                                                                              -webkit-box-sizing: border-box;
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                            div {
                                                                              color: red;
                                                                              width: 100%;
                                                                              p {
                                                                                margin: $blah;
                                                                                $blee: goodbye;
                                                                                padding: 10px 5px;
                                                                                a {
                                                                                  display: inline-block;
                                                                                  padding: 5px;
                                                                                  color: $blee;
                                                                                }
                                                                                foo: $bloo;
                                                                                empty {
                                                                                  not-empty {
                                                                                    background: lightgray;
                                                                                    border: 1px solid blue;
                                                                                    span {
                                                                                      display: block;
                                                                                      -webkit-box-sizing: border-box;
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                                $blah: a b c;
                                                                                $bloo: "hello";

                                                                                div {
                                                                                  color: red;
                                                                                  width: 100%;
                                                                                  p {
                                                                                    margin: $blah;
                                                                                    $blee: goodbye;
                                                                                    padding: 10px 5px;
                                                                                    a {
                                                                                      display: inline-block;
                                                                                      padding: 5px;
                                                                                      color: $blee;
                                                                                    }
                                                                                    foo: $bloo;
                                                                                    empty {
                                                                                      not-empty {
                                                                                        background: lightgray;
                                                                                        border: 1px solid blue;
                                                                                        span {
                                                                                          display: block;
                                                                                          -webkit-box-sizing: border-box;
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                  div {
                                                                                    color: red;
                                                                                    width: 100%;
                                                                                    p {
                                                                                      margin: $blah;
                                                                                      $blee: goodbye;
                                                                                      padding: 10px 5px;
                                                                                      a {
                                                                                        display: inline-block;
                                                                                        padding: 5px;
                                                                                        color: $blee;
                                                                                      }
                                                                                      foo: $bloo;
                                                                                      empty {
                                                                                        not-empty {
                                                                                          background: lightgray;
                                                                                          border: 1px solid blue;
                                                                                          span {
                                                                                            display: block;
                                                                                            -webkit-box-sizing: border-box;
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                          div {
                                                                            color: red;
                                                                            width: 100%;
                                                                            p {
                                                                              margin: $blah;
                                                                              $blee: goodbye;
                                                                              padding: 10px 5px;
                                                                              a {
                                                                                display: inline-block;
                                                                                padding: 5px;
                                                                                color: $blee;
                                                                              }
                                                                              foo: $bloo;
                                                                              empty {
                                                                                not-empty {
                                                                                  background: lightgray;
                                                                                  border: 1px solid blue;
                                                                                  span {
                                                                                    display: block;
                                                                                    -webkit-box-sizing: border-box;
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                          $blah: a b c;
                                                                          $bloo: "hello";

                                                                          div {
                                                                            color: red;
                                                                            width: 100%;
                                                                            p {
                                                                              margin: $blah;
                                                                              $blee: goodbye;
                                                                              padding: 10px 5px;
                                                                              a {
                                                                                display: inline-block;
                                                                                padding: 5px;
                                                                                color: $blee;
                                                                              }
                                                                              foo: $bloo;
                                                                              empty {
                                                                                not-empty {
                                                                                  background: lightgray;
                                                                                  border: 1px solid blue;
                                                                                  span {
                                                                                    display: block;
                                                                                    -webkit-box-sizing: border-box;
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                            div {
                                                                              color: red;
                                                                              width: 100%;
                                                                              p {
                                                                                margin: $blah;
                                                                                $blee: goodbye;
                                                                                padding: 10px 5px;
                                                                                a {
                                                                                  display: inline-block;
                                                                                  padding: 5px;
                                                                                  color: $blee;
                                                                                }
                                                                                foo: $bloo;
                                                                                empty {
                                                                                  not-empty {
                                                                                    background: lightgray;
                                                                                    border: 1px solid blue;
                                                                                    span {
                                                                                      display: block;
                                                                                      -webkit-box-sizing: border-box;
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                  $blah: a b c;
                                  $bloo: "hello";

                                  div {
                                    color: red;
                                    width: 100%;
                                    $blah: a b c;
                                    $bloo: "hello";

                                    div {
                                      color: red;
                                      width: 100%;
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                            $blah: a b c;
                                            $bloo: "hello";

                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                              }
                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                      div {
                                        color: red;
                                        width: 100%;
                                        p {
                                          margin: $blah;
                                          $blee: goodbye;
                                          padding: 10px 5px;
                                          a {
                                            display: inline-block;
                                            padding: 5px;
                                            color: $blee;
                                          }
                                          foo: $bloo;
                                          empty {
                                            not-empty {
                                              background: lightgray;
                                              border: 1px solid blue;
                                              span {
                                                display: block;
                                                -webkit-box-sizing: border-box;
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                    p {
                                      margin: $blah;
                                      $blee: goodbye;
                                      padding: 10px 5px;
                                      a {
                                        display: inline-block;
                                        padding: 5px;
                                        color: $blee;
                                        $blah: a b c;
                                        $bloo: "hello";

                                        div {
                                          color: red;
                                          width: 100%;
                                          $blah: a b c;
                                          $bloo: "hello";

                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                  $blah: a b c;
                                                  $bloo: "hello";

                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                        }
                                                      }
                                                    }
                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                                $blah: a b c;
                                                $bloo: "hello";

                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                      }
                                                    }
                                                  }
                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                      foo: $bloo;
                                      empty {
                                        not-empty {
                                          background: lightgray;
                                          border: 1px solid blue;
                                          span {
                                            display: block;
                                            -webkit-box-sizing: border-box;
                                          }
                                          $blah: a b c;
                                          $bloo: "hello";

                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                }
                                              }
                                            }
                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                    div {
                                      color: red;
                                      width: 100%;
                                      p {
                                        margin: $blah;
                                        $blee: goodbye;
                                        padding: 10px 5px;
                                        a {
                                          display: inline-block;
                                          padding: 5px;
                                          color: $blee;
                                        }
                                        foo: $bloo;
                                        empty {
                                          not-empty {
                                            background: lightgray;
                                            border: 1px solid blue;
                                            span {
                                              display: block;
                                              -webkit-box-sizing: border-box;
                                            }
                                          }
                                        }
                                        $blah: a b c;
                                        $bloo: "hello";

                                        div {
                                          color: red;
                                          width: 100%;
                                          $blah: a b c;
                                          $bloo: "hello";

                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                  $blah: a b c;
                                                  $bloo: "hello";

                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                        }
                                                      }
                                                    }
                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                          p {
                                            margin: $blah;
                                            $blee: goodbye;
                                            padding: 10px 5px;
                                            a {
                                              display: inline-block;
                                              padding: 5px;
                                              color: $blee;
                                              $blah: a b c;
                                              $bloo: "hello";

                                              div {
                                                color: red;
                                                width: 100%;
                                                $blah: a b c;
                                                $bloo: "hello";

                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                        $blah: a b c;
                                                        $bloo: "hello";

                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                              }
                                                            }
                                                          }
                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                      $blah: a b c;
                                                      $bloo: "hello";

                                                      div {
                                                        color: red;
                                                        width: 100%;
                                                        p {
                                                          margin: $blah;
                                                          $blee: goodbye;
                                                          padding: 10px 5px;
                                                          a {
                                                            display: inline-block;
                                                            padding: 5px;
                                                            color: $blee;
                                                          }
                                                          foo: $bloo;
                                                          empty {
                                                            not-empty {
                                                              background: lightgray;
                                                              border: 1px solid blue;
                                                              span {
                                                                display: block;
                                                                -webkit-box-sizing: border-box;
                                                              }
                                                            }
                                                          }
                                                        }
                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                            foo: $bloo;
                                            empty {
                                              not-empty {
                                                background: lightgray;
                                                border: 1px solid blue;
                                                span {
                                                  display: block;
                                                  -webkit-box-sizing: border-box;
                                                }
                                                $blah: a b c;
                                                $bloo: "hello";

                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                      }
                                                    }
                                                  }
                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                          $blah: a b c;
                                          $bloo: "hello";

                                          div {
                                            color: red;
                                            width: 100%;
                                            $blah: a b c;
                                            $bloo: "hello";

                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                    $blah: a b c;
                                                    $bloo: "hello";

                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                          }
                                                        }
                                                      }
                                                      div {
                                                        color: red;
                                                        width: 100%;
                                                        p {
                                                          margin: $blah;
                                                          $blee: goodbye;
                                                          padding: 10px 5px;
                                                          a {
                                                            display: inline-block;
                                                            padding: 5px;
                                                            color: $blee;
                                                          }
                                                          foo: $bloo;
                                                          empty {
                                                            not-empty {
                                                              background: lightgray;
                                                              border: 1px solid blue;
                                                              span {
                                                                display: block;
                                                                -webkit-box-sizing: border-box;
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                              div {
                                                color: red;
                                                width: 100%;
                                                p {
                                                  margin: $blah;
                                                  $blee: goodbye;
                                                  padding: 10px 5px;
                                                  a {
                                                    display: inline-block;
                                                    padding: 5px;
                                                    color: $blee;
                                                  }
                                                  foo: $bloo;
                                                  empty {
                                                    not-empty {
                                                      background: lightgray;
                                                      border: 1px solid blue;
                                                      span {
                                                        display: block;
                                                        -webkit-box-sizing: border-box;
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                                $blah: a b c;
                                                $bloo: "hello";

                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  $blah: a b c;
                                                  $bloo: "hello";

                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                          $blah: a b c;
                                                          $bloo: "hello";

                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                }
                                                              }
                                                            }
                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                        $blah: a b c;
                                                        $bloo: "hello";

                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                              }
                                                            }
                                                          }
                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                  $blah: a b c;
                                                  $bloo: "hello";

                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                        }
                                                      }
                                                    }
                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                            div {
                                              color: red;
                                              width: 100%;
                                              p {
                                                margin: $blah;
                                                $blee: goodbye;
                                                padding: 10px 5px;
                                                a {
                                                  display: inline-block;
                                                  padding: 5px;
                                                  color: $blee;
                                                }
                                                foo: $bloo;
                                                empty {
                                                  not-empty {
                                                    background: lightgray;
                                                    border: 1px solid blue;
                                                    span {
                                                      display: block;
                                                      -webkit-box-sizing: border-box;
                                                    }
                                                  }
                                                }
                                                $blah: a b c;
                                                $bloo: "hello";

                                                div {
                                                  color: red;
                                                  width: 100%;
                                                  $blah: a b c;
                                                  $bloo: "hello";

                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                          $blah: a b c;
                                                          $bloo: "hello";

                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                }
                                                              }
                                                            }
                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                  p {
                                                    margin: $blah;
                                                    $blee: goodbye;
                                                    padding: 10px 5px;
                                                    a {
                                                      display: inline-block;
                                                      padding: 5px;
                                                      color: $blee;
                                                      $blah: a b c;
                                                      $bloo: "hello";

                                                      div {
                                                        color: red;
                                                        width: 100%;
                                                        $blah: a b c;
                                                        $bloo: "hello";

                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                                $blah: a b c;
                                                                $bloo: "hello";

                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                        p {
                                                          margin: $blah;
                                                          $blee: goodbye;
                                                          padding: 10px 5px;
                                                          a {
                                                            display: inline-block;
                                                            padding: 5px;
                                                            color: $blee;
                                                          }
                                                          foo: $bloo;
                                                          empty {
                                                            not-empty {
                                                              background: lightgray;
                                                              border: 1px solid blue;
                                                              span {
                                                                display: block;
                                                                -webkit-box-sizing: border-box;
                                                              }
                                                              $blah: a b c;
                                                              $bloo: "hello";

                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                    foo: $bloo;
                                                    empty {
                                                      not-empty {
                                                        background: lightgray;
                                                        border: 1px solid blue;
                                                        span {
                                                          display: block;
                                                          -webkit-box-sizing: border-box;
                                                        }
                                                        $blah: a b c;
                                                        $bloo: "hello";

                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                              }
                                                            }
                                                          }
                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                        $blah: a b c;
                                                        $bloo: "hello";

                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          $blah: a b c;
                                                          $bloo: "hello";

                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                  $blah: a b c;
                                                                  $bloo: "hello";

                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                              $blah: a b c;
                                                              $bloo: "hello";

                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                $blah: a b c;
                                                                $bloo: "hello";

                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                        $blah: a b c;
                                                                        $bloo: "hello";

                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                          div {
                                                                            color: red;
                                                                            width: 100%;
                                                                            p {
                                                                              margin: $blah;
                                                                              $blee: goodbye;
                                                                              padding: 10px 5px;
                                                                              a {
                                                                                display: inline-block;
                                                                                padding: 5px;
                                                                                color: $blee;
                                                                              }
                                                                              foo: $bloo;
                                                                              empty {
                                                                                not-empty {
                                                                                  background: lightgray;
                                                                                  border: 1px solid blue;
                                                                                  span {
                                                                                    display: block;
                                                                                    -webkit-box-sizing: border-box;
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                      $blah: a b c;
                                                                      $bloo: "hello";

                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                                $blah: a b c;
                                                                $bloo: "hello";

                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                }
                                                              }
                                                              $blah: a b c;
                                                              $bloo: "hello";

                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                $blah: a b c;
                                                                $bloo: "hello";

                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                        $blah: a b c;
                                                                        $bloo: "hello";

                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                          div {
                                                                            color: red;
                                                                            width: 100%;
                                                                            p {
                                                                              margin: $blah;
                                                                              $blee: goodbye;
                                                                              padding: 10px 5px;
                                                                              a {
                                                                                display: inline-block;
                                                                                padding: 5px;
                                                                                color: $blee;
                                                                              }
                                                                              foo: $bloo;
                                                                              empty {
                                                                                not-empty {
                                                                                  background: lightgray;
                                                                                  border: 1px solid blue;
                                                                                  span {
                                                                                    display: block;
                                                                                    -webkit-box-sizing: border-box;
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                    $blah: a b c;
                                                                    $bloo: "hello";

                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      $blah: a b c;
                                                                      $bloo: "hello";

                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                              $blah: a b c;
                                                                              $bloo: "hello";

                                                                              div {
                                                                                color: red;
                                                                                width: 100%;
                                                                                p {
                                                                                  margin: $blah;
                                                                                  $blee: goodbye;
                                                                                  padding: 10px 5px;
                                                                                  a {
                                                                                    display: inline-block;
                                                                                    padding: 5px;
                                                                                    color: $blee;
                                                                                  }
                                                                                  foo: $bloo;
                                                                                  empty {
                                                                                    not-empty {
                                                                                      background: lightgray;
                                                                                      border: 1px solid blue;
                                                                                      span {
                                                                                        display: block;
                                                                                        -webkit-box-sizing: border-box;
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                                div {
                                                                                  color: red;
                                                                                  width: 100%;
                                                                                  p {
                                                                                    margin: $blah;
                                                                                    $blee: goodbye;
                                                                                    padding: 10px 5px;
                                                                                    a {
                                                                                      display: inline-block;
                                                                                      padding: 5px;
                                                                                      color: $blee;
                                                                                    }
                                                                                    foo: $bloo;
                                                                                    empty {
                                                                                      not-empty {
                                                                                        background: lightgray;
                                                                                        border: 1px solid blue;
                                                                                        span {
                                                                                          display: block;
                                                                                          -webkit-box-sizing: border-box;
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                            $blah: a b c;
                                                                            $bloo: "hello";

                                                                            div {
                                                                              color: red;
                                                                              width: 100%;
                                                                              p {
                                                                                margin: $blah;
                                                                                $blee: goodbye;
                                                                                padding: 10px 5px;
                                                                                a {
                                                                                  display: inline-block;
                                                                                  padding: 5px;
                                                                                  color: $blee;
                                                                                }
                                                                                foo: $bloo;
                                                                                empty {
                                                                                  not-empty {
                                                                                    background: lightgray;
                                                                                    border: 1px solid blue;
                                                                                    span {
                                                                                      display: block;
                                                                                      -webkit-box-sizing: border-box;
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                              div {
                                                                                color: red;
                                                                                width: 100%;
                                                                                p {
                                                                                  margin: $blah;
                                                                                  $blee: goodbye;
                                                                                  padding: 10px 5px;
                                                                                  a {
                                                                                    display: inline-block;
                                                                                    padding: 5px;
                                                                                    color: $blee;
                                                                                  }
                                                                                  foo: $bloo;
                                                                                  empty {
                                                                                    not-empty {
                                                                                      background: lightgray;
                                                                                      border: 1px solid blue;
                                                                                      span {
                                                                                        display: block;
                                                                                        -webkit-box-sizing: border-box;
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                      $blah: a b c;
                                                                      $bloo: "hello";

                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                                $blah: a b c;
                                                                $bloo: "hello";

                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  $blah: a b c;
                                                                  $bloo: "hello";

                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                          $blah: a b c;
                                                                          $bloo: "hello";

                                                                          div {
                                                                            color: red;
                                                                            width: 100%;
                                                                            p {
                                                                              margin: $blah;
                                                                              $blee: goodbye;
                                                                              padding: 10px 5px;
                                                                              a {
                                                                                display: inline-block;
                                                                                padding: 5px;
                                                                                color: $blee;
                                                                              }
                                                                              foo: $bloo;
                                                                              empty {
                                                                                not-empty {
                                                                                  background: lightgray;
                                                                                  border: 1px solid blue;
                                                                                  span {
                                                                                    display: block;
                                                                                    -webkit-box-sizing: border-box;
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                            div {
                                                                              color: red;
                                                                              width: 100%;
                                                                              p {
                                                                                margin: $blah;
                                                                                $blee: goodbye;
                                                                                padding: 10px 5px;
                                                                                a {
                                                                                  display: inline-block;
                                                                                  padding: 5px;
                                                                                  color: $blee;
                                                                                }
                                                                                foo: $bloo;
                                                                                empty {
                                                                                  not-empty {
                                                                                    background: lightgray;
                                                                                    border: 1px solid blue;
                                                                                    span {
                                                                                      display: block;
                                                                                      -webkit-box-sizing: border-box;
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                      $blah: a b c;
                                                                      $bloo: "hello";

                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        $blah: a b c;
                                                                        $bloo: "hello";

                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                                $blah: a b c;
                                                                                $bloo: "hello";

                                                                                div {
                                                                                  color: red;
                                                                                  width: 100%;
                                                                                  p {
                                                                                    margin: $blah;
                                                                                    $blee: goodbye;
                                                                                    padding: 10px 5px;
                                                                                    a {
                                                                                      display: inline-block;
                                                                                      padding: 5px;
                                                                                      color: $blee;
                                                                                    }
                                                                                    foo: $bloo;
                                                                                    empty {
                                                                                      not-empty {
                                                                                        background: lightgray;
                                                                                        border: 1px solid blue;
                                                                                        span {
                                                                                          display: block;
                                                                                          -webkit-box-sizing: border-box;
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                  div {
                                                                                    color: red;
                                                                                    width: 100%;
                                                                                    p {
                                                                                      margin: $blah;
                                                                                      $blee: goodbye;
                                                                                      padding: 10px 5px;
                                                                                      a {
                                                                                        display: inline-block;
                                                                                        padding: 5px;
                                                                                        color: $blee;
                                                                                      }
                                                                                      foo: $bloo;
                                                                                      empty {
                                                                                        not-empty {
                                                                                          background: lightgray;
                                                                                          border: 1px solid blue;
                                                                                          span {
                                                                                            display: block;
                                                                                            -webkit-box-sizing: border-box;
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                          div {
                                                                            color: red;
                                                                            width: 100%;
                                                                            p {
                                                                              margin: $blah;
                                                                              $blee: goodbye;
                                                                              padding: 10px 5px;
                                                                              a {
                                                                                display: inline-block;
                                                                                padding: 5px;
                                                                                color: $blee;
                                                                              }
                                                                              foo: $bloo;
                                                                              empty {
                                                                                not-empty {
                                                                                  background: lightgray;
                                                                                  border: 1px solid blue;
                                                                                  span {
                                                                                    display: block;
                                                                                    -webkit-box-sizing: border-box;
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                              $blah: a b c;
                                                                              $bloo: "hello";

                                                                              div {
                                                                                color: red;
                                                                                width: 100%;
                                                                                p {
                                                                                  margin: $blah;
                                                                                  $blee: goodbye;
                                                                                  padding: 10px 5px;
                                                                                  a {
                                                                                    display: inline-block;
                                                                                    padding: 5px;
                                                                                    color: $blee;
                                                                                  }
                                                                                  foo: $bloo;
                                                                                  empty {
                                                                                    not-empty {
                                                                                      background: lightgray;
                                                                                      border: 1px solid blue;
                                                                                      span {
                                                                                        display: block;
                                                                                        -webkit-box-sizing: border-box;
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                                div {
                                                                                  color: red;
                                                                                  width: 100%;
                                                                                  p {
                                                                                    margin: $blah;
                                                                                    $blee: goodbye;
                                                                                    padding: 10px 5px;
                                                                                    a {
                                                                                      display: inline-block;
                                                                                      padding: 5px;
                                                                                      color: $blee;
                                                                                    }
                                                                                    foo: $bloo;
                                                                                    empty {
                                                                                      not-empty {
                                                                                        background: lightgray;
                                                                                        border: 1px solid blue;
                                                                                        span {
                                                                                          display: block;
                                                                                          -webkit-box-sizing: border-box;
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                        $blah: a b c;
                                                                        $bloo: "hello";

                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                          div {
                                                                            color: red;
                                                                            width: 100%;
                                                                            p {
                                                                              margin: $blah;
                                                                              $blee: goodbye;
                                                                              padding: 10px 5px;
                                                                              a {
                                                                                display: inline-block;
                                                                                padding: 5px;
                                                                                color: $blee;
                                                                              }
                                                                              foo: $bloo;
                                                                              empty {
                                                                                not-empty {
                                                                                  background: lightgray;
                                                                                  border: 1px solid blue;
                                                                                  span {
                                                                                    display: block;
                                                                                    -webkit-box-sizing: border-box;
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                      $blah: a b c;
                                                                      $bloo: "hello";

                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        $blah: a b c;
                                                                        $bloo: "hello";

                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                                $blah: a b c;
                                                                                $bloo: "hello";

                                                                                div {
                                                                                  color: red;
                                                                                  width: 100%;
                                                                                  p {
                                                                                    margin: $blah;
                                                                                    $blee: goodbye;
                                                                                    padding: 10px 5px;
                                                                                    a {
                                                                                      display: inline-block;
                                                                                      padding: 5px;
                                                                                      color: $blee;
                                                                                    }
                                                                                    foo: $bloo;
                                                                                    empty {
                                                                                      not-empty {
                                                                                        background: lightgray;
                                                                                        border: 1px solid blue;
                                                                                        span {
                                                                                          display: block;
                                                                                          -webkit-box-sizing: border-box;
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                  div {
                                                                                    color: red;
                                                                                    width: 100%;
                                                                                    p {
                                                                                      margin: $blah;
                                                                                      $blee: goodbye;
                                                                                      padding: 10px 5px;
                                                                                      a {
                                                                                        display: inline-block;
                                                                                        padding: 5px;
                                                                                        color: $blee;
                                                                                      }
                                                                                      foo: $bloo;
                                                                                      empty {
                                                                                        not-empty {
                                                                                          background: lightgray;
                                                                                          border: 1px solid blue;
                                                                                          span {
                                                                                            display: block;
                                                                                            -webkit-box-sizing: border-box;
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                          div {
                                                                            color: red;
                                                                            width: 100%;
                                                                            p {
                                                                              margin: $blah;
                                                                              $blee: goodbye;
                                                                              padding: 10px 5px;
                                                                              a {
                                                                                display: inline-block;
                                                                                padding: 5px;
                                                                                color: $blee;
                                                                              }
                                                                              foo: $bloo;
                                                                              empty {
                                                                                not-empty {
                                                                                  background: lightgray;
                                                                                  border: 1px solid blue;
                                                                                  span {
                                                                                    display: block;
                                                                                    -webkit-box-sizing: border-box;
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                            $blah: a b c;
                                                                            $bloo: "hello";

                                                                            div {
                                                                              color: red;
                                                                              width: 100%;
                                                                              $blah: a b c;
                                                                              $bloo: "hello";

                                                                              div {
                                                                                color: red;
                                                                                width: 100%;
                                                                                p {
                                                                                  margin: $blah;
                                                                                  $blee: goodbye;
                                                                                  padding: 10px 5px;
                                                                                  a {
                                                                                    display: inline-block;
                                                                                    padding: 5px;
                                                                                    color: $blee;
                                                                                  }
                                                                                  foo: $bloo;
                                                                                  empty {
                                                                                    not-empty {
                                                                                      background: lightgray;
                                                                                      border: 1px solid blue;
                                                                                      span {
                                                                                        display: block;
                                                                                        -webkit-box-sizing: border-box;
                                                                                      }
                                                                                      $blah: a b c;
                                                                                      $bloo: "hello";

                                                                                      div {
                                                                                        color: red;
                                                                                        width: 100%;
                                                                                        p {
                                                                                          margin: $blah;
                                                                                          $blee: goodbye;
                                                                                          padding: 10px 5px;
                                                                                          a {
                                                                                            display: inline-block;
                                                                                            padding: 5px;
                                                                                            color: $blee;
                                                                                          }
                                                                                          foo: $bloo;
                                                                                          empty {
                                                                                            not-empty {
                                                                                              background: lightgray;
                                                                                              border: 1px solid blue;
                                                                                              span {
                                                                                                display: block;
                                                                                                -webkit-box-sizing: border-box;
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                        div {
                                                                                          color: red;
                                                                                          width: 100%;
                                                                                          p {
                                                                                            margin: $blah;
                                                                                            $blee: goodbye;
                                                                                            padding: 10px 5px;
                                                                                            a {
                                                                                              display: inline-block;
                                                                                              padding: 5px;
                                                                                              color: $blee;
                                                                                            }
                                                                                            foo: $bloo;
                                                                                            empty {
                                                                                              not-empty {
                                                                                                background: lightgray;
                                                                                                border: 1px solid blue;
                                                                                                span {
                                                                                                  display: block;
                                                                                                  -webkit-box-sizing: border-box;
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                                div {
                                                                                  color: red;
                                                                                  width: 100%;
                                                                                  p {
                                                                                    margin: $blah;
                                                                                    $blee: goodbye;
                                                                                    padding: 10px 5px;
                                                                                    a {
                                                                                      display: inline-block;
                                                                                      padding: 5px;
                                                                                      color: $blee;
                                                                                    }
                                                                                    foo: $bloo;
                                                                                    empty {
                                                                                      not-empty {
                                                                                        background: lightgray;
                                                                                        border: 1px solid blue;
                                                                                        span {
                                                                                          display: block;
                                                                                          -webkit-box-sizing: border-box;
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                              p {
                                                                                margin: $blah;
                                                                                $blee: goodbye;
                                                                                padding: 10px 5px;
                                                                                a {
                                                                                  display: inline-block;
                                                                                  padding: 5px;
                                                                                  color: $blee;
                                                                                }
                                                                                foo: $bloo;
                                                                                empty {
                                                                                  not-empty {
                                                                                    background: lightgray;
                                                                                    border: 1px solid blue;
                                                                                    span {
                                                                                      display: block;
                                                                                      -webkit-box-sizing: border-box;
                                                                                    }
                                                                                    $blah: a b c;
                                                                                    $bloo: "hello";

                                                                                    div {
                                                                                      color: red;
                                                                                      width: 100%;
                                                                                      p {
                                                                                        margin: $blah;
                                                                                        $blee: goodbye;
                                                                                        padding: 10px 5px;
                                                                                        a {
                                                                                          display: inline-block;
                                                                                          padding: 5px;
                                                                                          color: $blee;
                                                                                        }
                                                                                        foo: $bloo;
                                                                                        empty {
                                                                                          not-empty {
                                                                                            background: lightgray;
                                                                                            border: 1px solid blue;
                                                                                            span {
                                                                                              display: block;
                                                                                              -webkit-box-sizing: border-box;
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                      div {
                                                                                        color: red;
                                                                                        width: 100%;
                                                                                        p {
                                                                                          margin: $blah;
                                                                                          $blee: goodbye;
                                                                                          padding: 10px 5px;
                                                                                          a {
                                                                                            display: inline-block;
                                                                                            padding: 5px;
                                                                                            color: $blee;
                                                                                          }
                                                                                          foo: $bloo;
                                                                                          empty {
                                                                                            not-empty {
                                                                                              background: lightgray;
                                                                                              border: 1px solid blue;
                                                                                              span {
                                                                                                display: block;
                                                                                                -webkit-box-sizing: border-box;
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                              div {
                                                                                color: red;
                                                                                width: 100%;
                                                                                p {
                                                                                  margin: $blah;
                                                                                  $blee: goodbye;
                                                                                  padding: 10px 5px;
                                                                                  a {
                                                                                    display: inline-block;
                                                                                    padding: 5px;
                                                                                    color: $blee;
                                                                                  }
                                                                                  foo: $bloo;
                                                                                  empty {
                                                                                    not-empty {
                                                                                      background: lightgray;
                                                                                      border: 1px solid blue;
                                                                                      span {
                                                                                        display: block;
                                                                                        -webkit-box-sizing: border-box;
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                              $blah: a b c;
                                                                              $bloo: "hello";

                                                                              div {
                                                                                color: red;
                                                                                width: 100%;
                                                                                p {
                                                                                  margin: $blah;
                                                                                  $blee: goodbye;
                                                                                  padding: 10px 5px;
                                                                                  a {
                                                                                    display: inline-block;
                                                                                    padding: 5px;
                                                                                    color: $blee;
                                                                                  }
                                                                                  foo: $bloo;
                                                                                  empty {
                                                                                    not-empty {
                                                                                      background: lightgray;
                                                                                      border: 1px solid blue;
                                                                                      span {
                                                                                        display: block;
                                                                                        -webkit-box-sizing: border-box;
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                                div {
                                                                                  color: red;
                                                                                  width: 100%;
                                                                                  p {
                                                                                    margin: $blah;
                                                                                    $blee: goodbye;
                                                                                    padding: 10px 5px;
                                                                                    a {
                                                                                      display: inline-block;
                                                                                      padding: 5px;
                                                                                      color: $blee;
                                                                                    }
                                                                                    foo: $bloo;
                                                                                    empty {
                                                                                      not-empty {
                                                                                        background: lightgray;
                                                                                        border: 1px solid blue;
                                                                                        span {
                                                                                          display: block;
                                                                                          -webkit-box-sizing: border-box;
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                  $blah: a b c;
                                                  $bloo: "hello";

                                                  div {
                                                    color: red;
                                                    width: 100%;
                                                    $blah: a b c;
                                                    $bloo: "hello";

                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                            $blah: a b c;
                                                            $bloo: "hello";

                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                      div {
                                                        color: red;
                                                        width: 100%;
                                                        p {
                                                          margin: $blah;
                                                          $blee: goodbye;
                                                          padding: 10px 5px;
                                                          a {
                                                            display: inline-block;
                                                            padding: 5px;
                                                            color: $blee;
                                                          }
                                                          foo: $bloo;
                                                          empty {
                                                            not-empty {
                                                              background: lightgray;
                                                              border: 1px solid blue;
                                                              span {
                                                                display: block;
                                                                -webkit-box-sizing: border-box;
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                    p {
                                                      margin: $blah;
                                                      $blee: goodbye;
                                                      padding: 10px 5px;
                                                      a {
                                                        display: inline-block;
                                                        padding: 5px;
                                                        color: $blee;
                                                        $blah: a b c;
                                                        $bloo: "hello";

                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          $blah: a b c;
                                                          $bloo: "hello";

                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                  $blah: a b c;
                                                                  $bloo: "hello";

                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                                $blah: a b c;
                                                                $bloo: "hello";

                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                      foo: $bloo;
                                                      empty {
                                                        not-empty {
                                                          background: lightgray;
                                                          border: 1px solid blue;
                                                          span {
                                                            display: block;
                                                            -webkit-box-sizing: border-box;
                                                          }
                                                          $blah: a b c;
                                                          $bloo: "hello";

                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                }
                                                              }
                                                            }
                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                    div {
                                                      color: red;
                                                      width: 100%;
                                                      p {
                                                        margin: $blah;
                                                        $blee: goodbye;
                                                        padding: 10px 5px;
                                                        a {
                                                          display: inline-block;
                                                          padding: 5px;
                                                          color: $blee;
                                                        }
                                                        foo: $bloo;
                                                        empty {
                                                          not-empty {
                                                            background: lightgray;
                                                            border: 1px solid blue;
                                                            span {
                                                              display: block;
                                                              -webkit-box-sizing: border-box;
                                                            }
                                                          }
                                                        }
                                                        $blah: a b c;
                                                        $bloo: "hello";

                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          $blah: a b c;
                                                          $bloo: "hello";

                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                  $blah: a b c;
                                                                  $bloo: "hello";

                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                              $blah: a b c;
                                                              $bloo: "hello";

                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                $blah: a b c;
                                                                $bloo: "hello";

                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                        $blah: a b c;
                                                                        $bloo: "hello";

                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                          div {
                                                                            color: red;
                                                                            width: 100%;
                                                                            p {
                                                                              margin: $blah;
                                                                              $blee: goodbye;
                                                                              padding: 10px 5px;
                                                                              a {
                                                                                display: inline-block;
                                                                                padding: 5px;
                                                                                color: $blee;
                                                                              }
                                                                              foo: $bloo;
                                                                              empty {
                                                                                not-empty {
                                                                                  background: lightgray;
                                                                                  border: 1px solid blue;
                                                                                  span {
                                                                                    display: block;
                                                                                    -webkit-box-sizing: border-box;
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                      $blah: a b c;
                                                                      $bloo: "hello";

                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                                $blah: a b c;
                                                                $bloo: "hello";

                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                          $blah: a b c;
                                                          $bloo: "hello";

                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            $blah: a b c;
                                                            $bloo: "hello";

                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                    $blah: a b c;
                                                                    $bloo: "hello";

                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                                $blah: a b c;
                                                                $bloo: "hello";

                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  $blah: a b c;
                                                                  $bloo: "hello";

                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                          $blah: a b c;
                                                                          $bloo: "hello";

                                                                          div {
                                                                            color: red;
                                                                            width: 100%;
                                                                            p {
                                                                              margin: $blah;
                                                                              $blee: goodbye;
                                                                              padding: 10px 5px;
                                                                              a {
                                                                                display: inline-block;
                                                                                padding: 5px;
                                                                                color: $blee;
                                                                              }
                                                                              foo: $bloo;
                                                                              empty {
                                                                                not-empty {
                                                                                  background: lightgray;
                                                                                  border: 1px solid blue;
                                                                                  span {
                                                                                    display: block;
                                                                                    -webkit-box-sizing: border-box;
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                            div {
                                                                              color: red;
                                                                              width: 100%;
                                                                              p {
                                                                                margin: $blah;
                                                                                $blee: goodbye;
                                                                                padding: 10px 5px;
                                                                                a {
                                                                                  display: inline-block;
                                                                                  padding: 5px;
                                                                                  color: $blee;
                                                                                }
                                                                                foo: $bloo;
                                                                                empty {
                                                                                  not-empty {
                                                                                    background: lightgray;
                                                                                    border: 1px solid blue;
                                                                                    span {
                                                                                      display: block;
                                                                                      -webkit-box-sizing: border-box;
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                        $blah: a b c;
                                                                        $bloo: "hello";

                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                          div {
                                                                            color: red;
                                                                            width: 100%;
                                                                            p {
                                                                              margin: $blah;
                                                                              $blee: goodbye;
                                                                              padding: 10px 5px;
                                                                              a {
                                                                                display: inline-block;
                                                                                padding: 5px;
                                                                                color: $blee;
                                                                              }
                                                                              foo: $bloo;
                                                                              empty {
                                                                                not-empty {
                                                                                  background: lightgray;
                                                                                  border: 1px solid blue;
                                                                                  span {
                                                                                    display: block;
                                                                                    -webkit-box-sizing: border-box;
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                  $blah: a b c;
                                                                  $bloo: "hello";

                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                  }
                                                                }
                                                                $blah: a b c;
                                                                $bloo: "hello";

                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  $blah: a b c;
                                                                  $bloo: "hello";

                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                          $blah: a b c;
                                                                          $bloo: "hello";

                                                                          div {
                                                                            color: red;
                                                                            width: 100%;
                                                                            p {
                                                                              margin: $blah;
                                                                              $blee: goodbye;
                                                                              padding: 10px 5px;
                                                                              a {
                                                                                display: inline-block;
                                                                                padding: 5px;
                                                                                color: $blee;
                                                                              }
                                                                              foo: $bloo;
                                                                              empty {
                                                                                not-empty {
                                                                                  background: lightgray;
                                                                                  border: 1px solid blue;
                                                                                  span {
                                                                                    display: block;
                                                                                    -webkit-box-sizing: border-box;
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                            div {
                                                                              color: red;
                                                                              width: 100%;
                                                                              p {
                                                                                margin: $blah;
                                                                                $blee: goodbye;
                                                                                padding: 10px 5px;
                                                                                a {
                                                                                  display: inline-block;
                                                                                  padding: 5px;
                                                                                  color: $blee;
                                                                                }
                                                                                foo: $bloo;
                                                                                empty {
                                                                                  not-empty {
                                                                                    background: lightgray;
                                                                                    border: 1px solid blue;
                                                                                    span {
                                                                                      display: block;
                                                                                      -webkit-box-sizing: border-box;
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                      $blah: a b c;
                                                                      $bloo: "hello";

                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        $blah: a b c;
                                                                        $bloo: "hello";

                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                                $blah: a b c;
                                                                                $bloo: "hello";

                                                                                div {
                                                                                  color: red;
                                                                                  width: 100%;
                                                                                  p {
                                                                                    margin: $blah;
                                                                                    $blee: goodbye;
                                                                                    padding: 10px 5px;
                                                                                    a {
                                                                                      display: inline-block;
                                                                                      padding: 5px;
                                                                                      color: $blee;
                                                                                    }
                                                                                    foo: $bloo;
                                                                                    empty {
                                                                                      not-empty {
                                                                                        background: lightgray;
                                                                                        border: 1px solid blue;
                                                                                        span {
                                                                                          display: block;
                                                                                          -webkit-box-sizing: border-box;
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                  div {
                                                                                    color: red;
                                                                                    width: 100%;
                                                                                    p {
                                                                                      margin: $blah;
                                                                                      $blee: goodbye;
                                                                                      padding: 10px 5px;
                                                                                      a {
                                                                                        display: inline-block;
                                                                                        padding: 5px;
                                                                                        color: $blee;
                                                                                      }
                                                                                      foo: $bloo;
                                                                                      empty {
                                                                                        not-empty {
                                                                                          background: lightgray;
                                                                                          border: 1px solid blue;
                                                                                          span {
                                                                                            display: block;
                                                                                            -webkit-box-sizing: border-box;
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                          div {
                                                                            color: red;
                                                                            width: 100%;
                                                                            p {
                                                                              margin: $blah;
                                                                              $blee: goodbye;
                                                                              padding: 10px 5px;
                                                                              a {
                                                                                display: inline-block;
                                                                                padding: 5px;
                                                                                color: $blee;
                                                                              }
                                                                              foo: $bloo;
                                                                              empty {
                                                                                not-empty {
                                                                                  background: lightgray;
                                                                                  border: 1px solid blue;
                                                                                  span {
                                                                                    display: block;
                                                                                    -webkit-box-sizing: border-box;
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                              $blah: a b c;
                                                                              $bloo: "hello";

                                                                              div {
                                                                                color: red;
                                                                                width: 100%;
                                                                                p {
                                                                                  margin: $blah;
                                                                                  $blee: goodbye;
                                                                                  padding: 10px 5px;
                                                                                  a {
                                                                                    display: inline-block;
                                                                                    padding: 5px;
                                                                                    color: $blee;
                                                                                  }
                                                                                  foo: $bloo;
                                                                                  empty {
                                                                                    not-empty {
                                                                                      background: lightgray;
                                                                                      border: 1px solid blue;
                                                                                      span {
                                                                                        display: block;
                                                                                        -webkit-box-sizing: border-box;
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                                div {
                                                                                  color: red;
                                                                                  width: 100%;
                                                                                  p {
                                                                                    margin: $blah;
                                                                                    $blee: goodbye;
                                                                                    padding: 10px 5px;
                                                                                    a {
                                                                                      display: inline-block;
                                                                                      padding: 5px;
                                                                                      color: $blee;
                                                                                    }
                                                                                    foo: $bloo;
                                                                                    empty {
                                                                                      not-empty {
                                                                                        background: lightgray;
                                                                                        border: 1px solid blue;
                                                                                        span {
                                                                                          display: block;
                                                                                          -webkit-box-sizing: border-box;
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                        $blah: a b c;
                                                                        $bloo: "hello";

                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                          div {
                                                                            color: red;
                                                                            width: 100%;
                                                                            p {
                                                                              margin: $blah;
                                                                              $blee: goodbye;
                                                                              padding: 10px 5px;
                                                                              a {
                                                                                display: inline-block;
                                                                                padding: 5px;
                                                                                color: $blee;
                                                                              }
                                                                              foo: $bloo;
                                                                              empty {
                                                                                not-empty {
                                                                                  background: lightgray;
                                                                                  border: 1px solid blue;
                                                                                  span {
                                                                                    display: block;
                                                                                    -webkit-box-sizing: border-box;
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                        $blah: a b c;
                                                                        $bloo: "hello";

                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          $blah: a b c;
                                                                          $bloo: "hello";

                                                                          div {
                                                                            color: red;
                                                                            width: 100%;
                                                                            p {
                                                                              margin: $blah;
                                                                              $blee: goodbye;
                                                                              padding: 10px 5px;
                                                                              a {
                                                                                display: inline-block;
                                                                                padding: 5px;
                                                                                color: $blee;
                                                                              }
                                                                              foo: $bloo;
                                                                              empty {
                                                                                not-empty {
                                                                                  background: lightgray;
                                                                                  border: 1px solid blue;
                                                                                  span {
                                                                                    display: block;
                                                                                    -webkit-box-sizing: border-box;
                                                                                  }
                                                                                  $blah: a b c;
                                                                                  $bloo: "hello";

                                                                                  div {
                                                                                    color: red;
                                                                                    width: 100%;
                                                                                    p {
                                                                                      margin: $blah;
                                                                                      $blee: goodbye;
                                                                                      padding: 10px 5px;
                                                                                      a {
                                                                                        display: inline-block;
                                                                                        padding: 5px;
                                                                                        color: $blee;
                                                                                      }
                                                                                      foo: $bloo;
                                                                                      empty {
                                                                                        not-empty {
                                                                                          background: lightgray;
                                                                                          border: 1px solid blue;
                                                                                          span {
                                                                                            display: block;
                                                                                            -webkit-box-sizing: border-box;
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                    div {
                                                                                      color: red;
                                                                                      width: 100%;
                                                                                      p {
                                                                                        margin: $blah;
                                                                                        $blee: goodbye;
                                                                                        padding: 10px 5px;
                                                                                        a {
                                                                                          display: inline-block;
                                                                                          padding: 5px;
                                                                                          color: $blee;
                                                                                        }
                                                                                        foo: $bloo;
                                                                                        empty {
                                                                                          not-empty {
                                                                                            background: lightgray;
                                                                                            border: 1px solid blue;
                                                                                            span {
                                                                                              display: block;
                                                                                              -webkit-box-sizing: border-box;
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                            div {
                                                                              color: red;
                                                                              width: 100%;
                                                                              p {
                                                                                margin: $blah;
                                                                                $blee: goodbye;
                                                                                padding: 10px 5px;
                                                                                a {
                                                                                  display: inline-block;
                                                                                  padding: 5px;
                                                                                  color: $blee;
                                                                                }
                                                                                foo: $bloo;
                                                                                empty {
                                                                                  not-empty {
                                                                                    background: lightgray;
                                                                                    border: 1px solid blue;
                                                                                    span {
                                                                                      display: block;
                                                                                      -webkit-box-sizing: border-box;
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                              $blah: a b c;
                                                                              $bloo: "hello";

                                                                              div {
                                                                                color: red;
                                                                                width: 100%;
                                                                                $blah: a b c;
                                                                                $bloo: "hello";

                                                                                div {
                                                                                  color: red;
                                                                                  width: 100%;
                                                                                  p {
                                                                                    margin: $blah;
                                                                                    $blee: goodbye;
                                                                                    padding: 10px 5px;
                                                                                    a {
                                                                                      display: inline-block;
                                                                                      padding: 5px;
                                                                                      color: $blee;
                                                                                    }
                                                                                    foo: $bloo;
                                                                                    empty {
                                                                                      not-empty {
                                                                                        background: lightgray;
                                                                                        border: 1px solid blue;
                                                                                        span {
                                                                                          display: block;
                                                                                          -webkit-box-sizing: border-box;
                                                                                        }
                                                                                        $blah: a b c;
                                                                                        $bloo: "hello";

                                                                                        div {
                                                                                          color: red;
                                                                                          width: 100%;
                                                                                          p {
                                                                                            margin: $blah;
                                                                                            $blee: goodbye;
                                                                                            padding: 10px 5px;
                                                                                            a {
                                                                                              display: inline-block;
                                                                                              padding: 5px;
                                                                                              color: $blee;
                                                                                            }
                                                                                            foo: $bloo;
                                                                                            empty {
                                                                                              not-empty {
                                                                                                background: lightgray;
                                                                                                border: 1px solid blue;
                                                                                                span {
                                                                                                  display: block;
                                                                                                  -webkit-box-sizing: border-box;
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                          div {
                                                                                            color: red;
                                                                                            width: 100%;
                                                                                            p {
                                                                                              margin: $blah;
                                                                                              $blee: goodbye;
                                                                                              padding: 10px 5px;
                                                                                              a {
                                                                                                display: inline-block;
                                                                                                padding: 5px;
                                                                                                color: $blee;
                                                                                              }
                                                                                              foo: $bloo;
                                                                                              empty {
                                                                                                not-empty {
                                                                                                  background: lightgray;
                                                                                                  border: 1px solid blue;
                                                                                                  span {
                                                                                                    display: block;
                                                                                                    -webkit-box-sizing: border-box;
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                  div {
                                                                                    color: red;
                                                                                    width: 100%;
                                                                                    p {
                                                                                      margin: $blah;
                                                                                      $blee: goodbye;
                                                                                      padding: 10px 5px;
                                                                                      a {
                                                                                        display: inline-block;
                                                                                        padding: 5px;
                                                                                        color: $blee;
                                                                                      }
                                                                                      foo: $bloo;
                                                                                      empty {
                                                                                        not-empty {
                                                                                          background: lightgray;
                                                                                          border: 1px solid blue;
                                                                                          span {
                                                                                            display: block;
                                                                                            -webkit-box-sizing: border-box;
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                                p {
                                                                                  margin: $blah;
                                                                                  $blee: goodbye;
                                                                                  padding: 10px 5px;
                                                                                  a {
                                                                                    display: inline-block;
                                                                                    padding: 5px;
                                                                                    color: $blee;
                                                                                  }
                                                                                  foo: $bloo;
                                                                                  empty {
                                                                                    not-empty {
                                                                                      background: lightgray;
                                                                                      border: 1px solid blue;
                                                                                      span {
                                                                                        display: block;
                                                                                        -webkit-box-sizing: border-box;
                                                                                      }
                                                                                      $blah: a b c;
                                                                                      $bloo: "hello";

                                                                                      div {
                                                                                        color: red;
                                                                                        width: 100%;
                                                                                        p {
                                                                                          margin: $blah;
                                                                                          $blee: goodbye;
                                                                                          padding: 10px 5px;
                                                                                          a {
                                                                                            display: inline-block;
                                                                                            padding: 5px;
                                                                                            color: $blee;
                                                                                          }
                                                                                          foo: $bloo;
                                                                                          empty {
                                                                                            not-empty {
                                                                                              background: lightgray;
                                                                                              border: 1px solid blue;
                                                                                              span {
                                                                                                display: block;
                                                                                                -webkit-box-sizing: border-box;
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                        div {
                                                                                          color: red;
                                                                                          width: 100%;
                                                                                          p {
                                                                                            margin: $blah;
                                                                                            $blee: goodbye;
                                                                                            padding: 10px 5px;
                                                                                            a {
                                                                                              display: inline-block;
                                                                                              padding: 5px;
                                                                                              color: $blee;
                                                                                            }
                                                                                            foo: $bloo;
                                                                                            empty {
                                                                                              not-empty {
                                                                                                background: lightgray;
                                                                                                border: 1px solid blue;
                                                                                                span {
                                                                                                  display: block;
                                                                                                  -webkit-box-sizing: border-box;
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                                div {
                                                                                  color: red;
                                                                                  width: 100%;
                                                                                  p {
                                                                                    margin: $blah;
                                                                                    $blee: goodbye;
                                                                                    padding: 10px 5px;
                                                                                    a {
                                                                                      display: inline-block;
                                                                                      padding: 5px;
                                                                                      color: $blee;
                                                                                    }
                                                                                    foo: $bloo;
                                                                                    empty {
                                                                                      not-empty {
                                                                                        background: lightgray;
                                                                                        border: 1px solid blue;
                                                                                        span {
                                                                                          display: block;
                                                                                          -webkit-box-sizing: border-box;
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                                $blah: a b c;
                                                                                $bloo: "hello";

                                                                                div {
                                                                                  color: red;
                                                                                  width: 100%;
                                                                                  p {
                                                                                    margin: $blah;
                                                                                    $blee: goodbye;
                                                                                    padding: 10px 5px;
                                                                                    a {
                                                                                      display: inline-block;
                                                                                      padding: 5px;
                                                                                      color: $blee;
                                                                                    }
                                                                                    foo: $bloo;
                                                                                    empty {
                                                                                      not-empty {
                                                                                        background: lightgray;
                                                                                        border: 1px solid blue;
                                                                                        span {
                                                                                          display: block;
                                                                                          -webkit-box-sizing: border-box;
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                  div {
                                                                                    color: red;
                                                                                    width: 100%;
                                                                                    p {
                                                                                      margin: $blah;
                                                                                      $blee: goodbye;
                                                                                      padding: 10px 5px;
                                                                                      a {
                                                                                        display: inline-block;
                                                                                        padding: 5px;
                                                                                        color: $blee;
                                                                                      }
                                                                                      foo: $bloo;
                                                                                      empty {
                                                                                        not-empty {
                                                                                          background: lightgray;
                                                                                          border: 1px solid blue;
                                                                                          span {
                                                                                            display: block;
                                                                                            -webkit-box-sizing: border-box;
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                          div {
                                                                            color: red;
                                                                            width: 100%;
                                                                            p {
                                                                              margin: $blah;
                                                                              $blee: goodbye;
                                                                              padding: 10px 5px;
                                                                              a {
                                                                                display: inline-block;
                                                                                padding: 5px;
                                                                                color: $blee;
                                                                              }
                                                                              foo: $bloo;
                                                                              empty {
                                                                                not-empty {
                                                                                  background: lightgray;
                                                                                  border: 1px solid blue;
                                                                                  span {
                                                                                    display: block;
                                                                                    -webkit-box-sizing: border-box;
                                                                                  }
                                                                                }
                                                                              }
                                                                              $blah: a b c;
                                                                              $bloo: "hello";

                                                                              div {
                                                                                color: red;
                                                                                width: 100%;
                                                                                $blah: a b c;
                                                                                $bloo: "hello";

                                                                                div {
                                                                                  color: red;
                                                                                  width: 100%;
                                                                                  p {
                                                                                    margin: $blah;
                                                                                    $blee: goodbye;
                                                                                    padding: 10px 5px;
                                                                                    a {
                                                                                      display: inline-block;
                                                                                      padding: 5px;
                                                                                      color: $blee;
                                                                                    }
                                                                                    foo: $bloo;
                                                                                    empty {
                                                                                      not-empty {
                                                                                        background: lightgray;
                                                                                        border: 1px solid blue;
                                                                                        span {
                                                                                          display: block;
                                                                                          -webkit-box-sizing: border-box;
                                                                                        }
                                                                                        $blah: a b c;
                                                                                        $bloo: "hello";

                                                                                        div {
                                                                                          color: red;
                                                                                          width: 100%;
                                                                                          p {
                                                                                            margin: $blah;
                                                                                            $blee: goodbye;
                                                                                            padding: 10px 5px;
                                                                                            a {
                                                                                              display: inline-block;
                                                                                              padding: 5px;
                                                                                              color: $blee;
                                                                                            }
                                                                                            foo: $bloo;
                                                                                            empty {
                                                                                              not-empty {
                                                                                                background: lightgray;
                                                                                                border: 1px solid blue;
                                                                                                span {
                                                                                                  display: block;
                                                                                                  -webkit-box-sizing: border-box;
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                          div {
                                                                                            color: red;
                                                                                            width: 100%;
                                                                                            p {
                                                                                              margin: $blah;
                                                                                              $blee: goodbye;
                                                                                              padding: 10px 5px;
                                                                                              a {
                                                                                                display: inline-block;
                                                                                                padding: 5px;
                                                                                                color: $blee;
                                                                                              }
                                                                                              foo: $bloo;
                                                                                              empty {
                                                                                                not-empty {
                                                                                                  background: lightgray;
                                                                                                  border: 1px solid blue;
                                                                                                  span {
                                                                                                    display: block;
                                                                                                    -webkit-box-sizing: border-box;
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                  div {
                                                                                    color: red;
                                                                                    width: 100%;
                                                                                    p {
                                                                                      margin: $blah;
                                                                                      $blee: goodbye;
                                                                                      padding: 10px 5px;
                                                                                      a {
                                                                                        display: inline-block;
                                                                                        padding: 5px;
                                                                                        color: $blee;
                                                                                      }
                                                                                      foo: $bloo;
                                                                                      empty {
                                                                                        not-empty {
                                                                                          background: lightgray;
                                                                                          border: 1px solid blue;
                                                                                          span {
                                                                                            display: block;
                                                                                            -webkit-box-sizing: border-box;
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                                p {
                                                                                  margin: $blah;
                                                                                  $blee: goodbye;
                                                                                  padding: 10px 5px;
                                                                                  a {
                                                                                    display: inline-block;
                                                                                    padding: 5px;
                                                                                    color: $blee;
                                                                                    $blah: a b c;
                                                                                    $bloo: "hello";

                                                                                    div {
                                                                                      color: red;
                                                                                      width: 100%;
                                                                                      $blah: a b c;
                                                                                      $bloo: "hello";

                                                                                      div {
                                                                                        color: red;
                                                                                        width: 100%;
                                                                                        p {
                                                                                          margin: $blah;
                                                                                          $blee: goodbye;
                                                                                          padding: 10px 5px;
                                                                                          a {
                                                                                            display: inline-block;
                                                                                            padding: 5px;
                                                                                            color: $blee;
                                                                                          }
                                                                                          foo: $bloo;
                                                                                          empty {
                                                                                            not-empty {
                                                                                              background: lightgray;
                                                                                              border: 1px solid blue;
                                                                                              span {
                                                                                                display: block;
                                                                                                -webkit-box-sizing: border-box;
                                                                                              }
                                                                                              $blah: a b c;
                                                                                              $bloo: "hello";

                                                                                              div {
                                                                                                color: red;
                                                                                                width: 100%;
                                                                                                p {
                                                                                                  margin: $blah;
                                                                                                  $blee: goodbye;
                                                                                                  padding: 10px 5px;
                                                                                                  a {
                                                                                                    display: inline-block;
                                                                                                    padding: 5px;
                                                                                                    color: $blee;
                                                                                                  }
                                                                                                  foo: $bloo;
                                                                                                  empty {
                                                                                                    not-empty {
                                                                                                      background: lightgray;
                                                                                                      border: 1px solid blue;
                                                                                                      span {
                                                                                                        display: block;
                                                                                                        -webkit-box-sizing: border-box;
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                                div {
                                                                                                  color: red;
                                                                                                  width: 100%;
                                                                                                  p {
                                                                                                    margin: $blah;
                                                                                                    $blee: goodbye;
                                                                                                    padding: 10px 5px;
                                                                                                    a {
                                                                                                      display: inline-block;
                                                                                                      padding: 5px;
                                                                                                      color: $blee;
                                                                                                    }
                                                                                                    foo: $bloo;
                                                                                                    empty {
                                                                                                      not-empty {
                                                                                                        background: lightgray;
                                                                                                        border: 1px solid blue;
                                                                                                        span {
                                                                                                          display: block;
                                                                                                          -webkit-box-sizing: border-box;
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                        div {
                                                                                          color: red;
                                                                                          width: 100%;
                                                                                          p {
                                                                                            margin: $blah;
                                                                                            $blee: goodbye;
                                                                                            padding: 10px 5px;
                                                                                            a {
                                                                                              display: inline-block;
                                                                                              padding: 5px;
                                                                                              color: $blee;
                                                                                            }
                                                                                            foo: $bloo;
                                                                                            empty {
                                                                                              not-empty {
                                                                                                background: lightgray;
                                                                                                border: 1px solid blue;
                                                                                                span {
                                                                                                  display: block;
                                                                                                  -webkit-box-sizing: border-box;
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                      p {
                                                                                        margin: $blah;
                                                                                        $blee: goodbye;
                                                                                        padding: 10px 5px;
                                                                                        a {
                                                                                          display: inline-block;
                                                                                          padding: 5px;
                                                                                          color: $blee;
                                                                                        }
                                                                                        foo: $bloo;
                                                                                        empty {
                                                                                          not-empty {
                                                                                            background: lightgray;
                                                                                            border: 1px solid blue;
                                                                                            span {
                                                                                              display: block;
                                                                                              -webkit-box-sizing: border-box;
                                                                                            }
                                                                                            $blah: a b c;
                                                                                            $bloo: "hello";

                                                                                            div {
                                                                                              color: red;
                                                                                              width: 100%;
                                                                                              p {
                                                                                                margin: $blah;
                                                                                                $blee: goodbye;
                                                                                                padding: 10px 5px;
                                                                                                a {
                                                                                                  display: inline-block;
                                                                                                  padding: 5px;
                                                                                                  color: $blee;
                                                                                                }
                                                                                                foo: $bloo;
                                                                                                empty {
                                                                                                  not-empty {
                                                                                                    background: lightgray;
                                                                                                    border: 1px solid blue;
                                                                                                    span {
                                                                                                      display: block;
                                                                                                      -webkit-box-sizing: border-box;
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                              div {
                                                                                                color: red;
                                                                                                width: 100%;
                                                                                                p {
                                                                                                  margin: $blah;
                                                                                                  $blee: goodbye;
                                                                                                  padding: 10px 5px;
                                                                                                  a {
                                                                                                    display: inline-block;
                                                                                                    padding: 5px;
                                                                                                    color: $blee;
                                                                                                  }
                                                                                                  foo: $bloo;
                                                                                                  empty {
                                                                                                    not-empty {
                                                                                                      background: lightgray;
                                                                                                      border: 1px solid blue;
                                                                                                      span {
                                                                                                        display: block;
                                                                                                        -webkit-box-sizing: border-box;
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                      div {
                                                                                        color: red;
                                                                                        width: 100%;
                                                                                        p {
                                                                                          margin: $blah;
                                                                                          $blee: goodbye;
                                                                                          padding: 10px 5px;
                                                                                          a {
                                                                                            display: inline-block;
                                                                                            padding: 5px;
                                                                                            color: $blee;
                                                                                          }
                                                                                          foo: $bloo;
                                                                                          empty {
                                                                                            not-empty {
                                                                                              background: lightgray;
                                                                                              border: 1px solid blue;
                                                                                              span {
                                                                                                display: block;
                                                                                                -webkit-box-sizing: border-box;
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                  foo: $bloo;
                                                                                  empty {
                                                                                    not-empty {
                                                                                      background: lightgray;
                                                                                      border: 1px solid blue;
                                                                                      span {
                                                                                        display: block;
                                                                                        -webkit-box-sizing: border-box;
                                                                                      }
                                                                                      $blah: a b c;
                                                                                      $bloo: "hello";

                                                                                      div {
                                                                                        color: red;
                                                                                        width: 100%;
                                                                                        p {
                                                                                          margin: $blah;
                                                                                          $blee: goodbye;
                                                                                          padding: 10px 5px;
                                                                                          a {
                                                                                            display: inline-block;
                                                                                            padding: 5px;
                                                                                            color: $blee;
                                                                                          }
                                                                                          foo: $bloo;
                                                                                          empty {
                                                                                            not-empty {
                                                                                              background: lightgray;
                                                                                              border: 1px solid blue;
                                                                                              span {
                                                                                                display: block;
                                                                                                -webkit-box-sizing: border-box;
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                        div {
                                                                                          color: red;
                                                                                          width: 100%;
                                                                                          p {
                                                                                            margin: $blah;
                                                                                            $blee: goodbye;
                                                                                            padding: 10px 5px;
                                                                                            a {
                                                                                              display: inline-block;
                                                                                              padding: 5px;
                                                                                              color: $blee;
                                                                                            }
                                                                                            foo: $bloo;
                                                                                            empty {
                                                                                              not-empty {
                                                                                                background: lightgray;
                                                                                                border: 1px solid blue;
                                                                                                span {
                                                                                                  display: block;
                                                                                                  -webkit-box-sizing: border-box;
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                                $blah: a b c;
                                                                                $bloo: "hello";

                                                                                div {
                                                                                  color: red;
                                                                                  width: 100%;
                                                                                  $blah: a b c;
                                                                                  $bloo: "hello";

                                                                                  div {
                                                                                    color: red;
                                                                                    width: 100%;
                                                                                    p {
                                                                                      margin: $blah;
                                                                                      $blee: goodbye;
                                                                                      padding: 10px 5px;
                                                                                      a {
                                                                                        display: inline-block;
                                                                                        padding: 5px;
                                                                                        color: $blee;
                                                                                      }
                                                                                      foo: $bloo;
                                                                                      empty {
                                                                                        not-empty {
                                                                                          background: lightgray;
                                                                                          border: 1px solid blue;
                                                                                          span {
                                                                                            display: block;
                                                                                            -webkit-box-sizing: border-box;
                                                                                          }
                                                                                          $blah: a b c;
                                                                                          $bloo: "hello";

                                                                                          div {
                                                                                            color: red;
                                                                                            width: 100%;
                                                                                            p {
                                                                                              margin: $blah;
                                                                                              $blee: goodbye;
                                                                                              padding: 10px 5px;
                                                                                              a {
                                                                                                display: inline-block;
                                                                                                padding: 5px;
                                                                                                color: $blee;
                                                                                              }
                                                                                              foo: $bloo;
                                                                                              empty {
                                                                                                not-empty {
                                                                                                  background: lightgray;
                                                                                                  border: 1px solid blue;
                                                                                                  span {
                                                                                                    display: block;
                                                                                                    -webkit-box-sizing: border-box;
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                            div {
                                                                                              color: red;
                                                                                              width: 100%;
                                                                                              p {
                                                                                                margin: $blah;
                                                                                                $blee: goodbye;
                                                                                                padding: 10px 5px;
                                                                                                a {
                                                                                                  display: inline-block;
                                                                                                  padding: 5px;
                                                                                                  color: $blee;
                                                                                                }
                                                                                                foo: $bloo;
                                                                                                empty {
                                                                                                  not-empty {
                                                                                                    background: lightgray;
                                                                                                    border: 1px solid blue;
                                                                                                    span {
                                                                                                      display: block;
                                                                                                      -webkit-box-sizing: border-box;
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                    div {
                                                                                      color: red;
                                                                                      width: 100%;
                                                                                      p {
                                                                                        margin: $blah;
                                                                                        $blee: goodbye;
                                                                                        padding: 10px 5px;
                                                                                        a {
                                                                                          display: inline-block;
                                                                                          padding: 5px;
                                                                                          color: $blee;
                                                                                        }
                                                                                        foo: $bloo;
                                                                                        empty {
                                                                                          not-empty {
                                                                                            background: lightgray;
                                                                                            border: 1px solid blue;
                                                                                            span {
                                                                                              display: block;
                                                                                              -webkit-box-sizing: border-box;
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                  p {
                                                                                    margin: $blah;
                                                                                    $blee: goodbye;
                                                                                    padding: 10px 5px;
                                                                                    a {
                                                                                      display: inline-block;
                                                                                      padding: 5px;
                                                                                      color: $blee;
                                                                                      $blah: a b c;
                                                                                      $bloo: "hello";

                                                                                      div {
                                                                                        color: red;
                                                                                        width: 100%;
                                                                                        $blah: a b c;
                                                                                        $bloo: "hello";

                                                                                        div {
                                                                                          color: red;
                                                                                          width: 100%;
                                                                                          p {
                                                                                            margin: $blah;
                                                                                            $blee: goodbye;
                                                                                            padding: 10px 5px;
                                                                                            a {
                                                                                              display: inline-block;
                                                                                              padding: 5px;
                                                                                              color: $blee;
                                                                                            }
                                                                                            foo: $bloo;
                                                                                            empty {
                                                                                              not-empty {
                                                                                                background: lightgray;
                                                                                                border: 1px solid blue;
                                                                                                span {
                                                                                                  display: block;
                                                                                                  -webkit-box-sizing: border-box;
                                                                                                }
                                                                                                $blah: a b c;
                                                                                                $bloo: "hello";

                                                                                                div {
                                                                                                  color: red;
                                                                                                  width: 100%;
                                                                                                  p {
                                                                                                    margin: $blah;
                                                                                                    $blee: goodbye;
                                                                                                    padding: 10px 5px;
                                                                                                    a {
                                                                                                      display: inline-block;
                                                                                                      padding: 5px;
                                                                                                      color: $blee;
                                                                                                    }
                                                                                                    foo: $bloo;
                                                                                                    empty {
                                                                                                      not-empty {
                                                                                                        background: lightgray;
                                                                                                        border: 1px solid blue;
                                                                                                        span {
                                                                                                          display: block;
                                                                                                          -webkit-box-sizing: border-box;
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                  div {
                                                                                                    color: red;
                                                                                                    width: 100%;
                                                                                                    p {
                                                                                                      margin: $blah;
                                                                                                      $blee: goodbye;
                                                                                                      padding: 10px 5px;
                                                                                                      a {
                                                                                                        display: inline-block;
                                                                                                        padding: 5px;
                                                                                                        color: $blee;
                                                                                                      }
                                                                                                      foo: $bloo;
                                                                                                      empty {
                                                                                                        not-empty {
                                                                                                          background: lightgray;
                                                                                                          border: 1px solid blue;
                                                                                                          span {
                                                                                                            display: block;
                                                                                                            -webkit-box-sizing: border-box;
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                          div {
                                                                                            color: red;
                                                                                            width: 100%;
                                                                                            p {
                                                                                              margin: $blah;
                                                                                              $blee: goodbye;
                                                                                              padding: 10px 5px;
                                                                                              a {
                                                                                                display: inline-block;
                                                                                                padding: 5px;
                                                                                                color: $blee;
                                                                                              }
                                                                                              foo: $bloo;
                                                                                              empty {
                                                                                                not-empty {
                                                                                                  background: lightgray;
                                                                                                  border: 1px solid blue;
                                                                                                  span {
                                                                                                    display: block;
                                                                                                    -webkit-box-sizing: border-box;
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                        p {
                                                                                          margin: $blah;
                                                                                          $blee: goodbye;
                                                                                          padding: 10px 5px;
                                                                                          a {
                                                                                            display: inline-block;
                                                                                            padding: 5px;
                                                                                            color: $blee;
                                                                                          }
                                                                                          foo: $bloo;
                                                                                          empty {
                                                                                            not-empty {
                                                                                              background: lightgray;
                                                                                              border: 1px solid blue;
                                                                                              span {
                                                                                                display: block;
                                                                                                -webkit-box-sizing: border-box;
                                                                                              }
                                                                                              $blah: a b c;
                                                                                              $bloo: "hello";

                                                                                              div {
                                                                                                color: red;
                                                                                                width: 100%;
                                                                                                p {
                                                                                                  margin: $blah;
                                                                                                  $blee: goodbye;
                                                                                                  padding: 10px 5px;
                                                                                                  a {
                                                                                                    display: inline-block;
                                                                                                    padding: 5px;
                                                                                                    color: $blee;
                                                                                                  }
                                                                                                  foo: $bloo;
                                                                                                  empty {
                                                                                                    not-empty {
                                                                                                      background: lightgray;
                                                                                                      border: 1px solid blue;
                                                                                                      span {
                                                                                                        display: block;
                                                                                                        -webkit-box-sizing: border-box;
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                                div {
                                                                                                  color: red;
                                                                                                  width: 100%;
                                                                                                  p {
                                                                                                    margin: $blah;
                                                                                                    $blee: goodbye;
                                                                                                    padding: 10px 5px;
                                                                                                    a {
                                                                                                      display: inline-block;
                                                                                                      padding: 5px;
                                                                                                      color: $blee;
                                                                                                    }
                                                                                                    foo: $bloo;
                                                                                                    empty {
                                                                                                      not-empty {
                                                                                                        background: lightgray;
                                                                                                        border: 1px solid blue;
                                                                                                        span {
                                                                                                          display: block;
                                                                                                          -webkit-box-sizing: border-box;
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                        div {
                                                                                          color: red;
                                                                                          width: 100%;
                                                                                          p {
                                                                                            margin: $blah;
                                                                                            $blee: goodbye;
                                                                                            padding: 10px 5px;
                                                                                            a {
                                                                                              display: inline-block;
                                                                                              padding: 5px;
                                                                                              color: $blee;
                                                                                            }
                                                                                            foo: $bloo;
                                                                                            empty {
                                                                                              not-empty {
                                                                                                background: lightgray;
                                                                                                border: 1px solid blue;
                                                                                                span {
                                                                                                  display: block;
                                                                                                  -webkit-box-sizing: border-box;
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                    foo: $bloo;
                                                                                    empty {
                                                                                      not-empty {
                                                                                        background: lightgray;
                                                                                        border: 1px solid blue;
                                                                                        span {
                                                                                          display: block;
                                                                                          -webkit-box-sizing: border-box;
                                                                                        }
                                                                                        $blah: a b c;
                                                                                        $bloo: "hello";

                                                                                        div {
                                                                                          color: red;
                                                                                          width: 100%;
                                                                                          p {
                                                                                            margin: $blah;
                                                                                            $blee: goodbye;
                                                                                            padding: 10px 5px;
                                                                                            a {
                                                                                              display: inline-block;
                                                                                              padding: 5px;
                                                                                              color: $blee;
                                                                                            }
                                                                                            foo: $bloo;
                                                                                            empty {
                                                                                              not-empty {
                                                                                                background: lightgray;
                                                                                                border: 1px solid blue;
                                                                                                span {
                                                                                                  display: block;
                                                                                                  -webkit-box-sizing: border-box;
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                          div {
                                                                                            color: red;
                                                                                            width: 100%;
                                                                                            p {
                                                                                              margin: $blah;
                                                                                              $blee: goodbye;
                                                                                              padding: 10px 5px;
                                                                                              a {
                                                                                                display: inline-block;
                                                                                                padding: 5px;
                                                                                                color: $blee;
                                                                                              }
                                                                                              foo: $bloo;
                                                                                              empty {
                                                                                                not-empty {
                                                                                                  background: lightgray;
                                                                                                  border: 1px solid blue;
                                                                                                  span {
                                                                                                    display: block;
                                                                                                    -webkit-box-sizing: border-box;
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                  div {
                                                                                    color: red;
                                                                                    width: 100%;
                                                                                    p {
                                                                                      margin: $blah;
                                                                                      $blee: goodbye;
                                                                                      padding: 10px 5px;
                                                                                      a {
                                                                                        display: inline-block;
                                                                                        padding: 5px;
                                                                                        color: $blee;
                                                                                      }
                                                                                      foo: $bloo;
                                                                                      empty {
                                                                                        not-empty {
                                                                                          background: lightgray;
                                                                                          border: 1px solid blue;
                                                                                          span {
                                                                                            display: block;
                                                                                            -webkit-box-sizing: border-box;
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                      $blah: a b c;
                                                                                      $bloo: "hello";

                                                                                      div {
                                                                                        color: red;
                                                                                        width: 100%;
                                                                                        $blah: a b c;
                                                                                        $bloo: "hello";

                                                                                        div {
                                                                                          color: red;
                                                                                          width: 100%;
                                                                                          p {
                                                                                            margin: $blah;
                                                                                            $blee: goodbye;
                                                                                            padding: 10px 5px;
                                                                                            a {
                                                                                              display: inline-block;
                                                                                              padding: 5px;
                                                                                              color: $blee;
                                                                                            }
                                                                                            foo: $bloo;
                                                                                            empty {
                                                                                              not-empty {
                                                                                                background: lightgray;
                                                                                                border: 1px solid blue;
                                                                                                span {
                                                                                                  display: block;
                                                                                                  -webkit-box-sizing: border-box;
                                                                                                }
                                                                                                $blah: a b c;
                                                                                                $bloo: "hello";

                                                                                                div {
                                                                                                  color: red;
                                                                                                  width: 100%;
                                                                                                  p {
                                                                                                    margin: $blah;
                                                                                                    $blee: goodbye;
                                                                                                    padding: 10px 5px;
                                                                                                    a {
                                                                                                      display: inline-block;
                                                                                                      padding: 5px;
                                                                                                      color: $blee;
                                                                                                    }
                                                                                                    foo: $bloo;
                                                                                                    empty {
                                                                                                      not-empty {
                                                                                                        background: lightgray;
                                                                                                        border: 1px solid blue;
                                                                                                        span {
                                                                                                          display: block;
                                                                                                          -webkit-box-sizing: border-box;
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                  div {
                                                                                                    color: red;
                                                                                                    width: 100%;
                                                                                                    p {
                                                                                                      margin: $blah;
                                                                                                      $blee: goodbye;
                                                                                                      padding: 10px 5px;
                                                                                                      a {
                                                                                                        display: inline-block;
                                                                                                        padding: 5px;
                                                                                                        color: $blee;
                                                                                                      }
                                                                                                      foo: $bloo;
                                                                                                      empty {
                                                                                                        not-empty {
                                                                                                          background: lightgray;
                                                                                                          border: 1px solid blue;
                                                                                                          span {
                                                                                                            display: block;
                                                                                                            -webkit-box-sizing: border-box;
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                          div {
                                                                                            color: red;
                                                                                            width: 100%;
                                                                                            p {
                                                                                              margin: $blah;
                                                                                              $blee: goodbye;
                                                                                              padding: 10px 5px;
                                                                                              a {
                                                                                                display: inline-block;
                                                                                                padding: 5px;
                                                                                                color: $blee;
                                                                                              }
                                                                                              foo: $bloo;
                                                                                              empty {
                                                                                                not-empty {
                                                                                                  background: lightgray;
                                                                                                  border: 1px solid blue;
                                                                                                  span {
                                                                                                    display: block;
                                                                                                    -webkit-box-sizing: border-box;
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                        p {
                                                                                          margin: $blah;
                                                                                          $blee: goodbye;
                                                                                          padding: 10px 5px;
                                                                                          a {
                                                                                            display: inline-block;
                                                                                            padding: 5px;
                                                                                            color: $blee;
                                                                                            $blah: a b c;
                                                                                            $bloo: "hello";

                                                                                            div {
                                                                                              color: red;
                                                                                              width: 100%;
                                                                                              $blah: a b c;
                                                                                              $bloo: "hello";

                                                                                              div {
                                                                                                color: red;
                                                                                                width: 100%;
                                                                                                p {
                                                                                                  margin: $blah;
                                                                                                  $blee: goodbye;
                                                                                                  padding: 10px 5px;
                                                                                                  a {
                                                                                                    display: inline-block;
                                                                                                    padding: 5px;
                                                                                                    color: $blee;
                                                                                                  }
                                                                                                  foo: $bloo;
                                                                                                  empty {
                                                                                                    not-empty {
                                                                                                      background: lightgray;
                                                                                                      border: 1px solid blue;
                                                                                                      span {
                                                                                                        display: block;
                                                                                                        -webkit-box-sizing: border-box;
                                                                                                      }
                                                                                                      $blah: a b c;
                                                                                                      $bloo: "hello";

                                                                                                      div {
                                                                                                        color: red;
                                                                                                        width: 100%;
                                                                                                        p {
                                                                                                          margin: $blah;
                                                                                                          $blee: goodbye;
                                                                                                          padding: 10px 5px;
                                                                                                          a {
                                                                                                            display: inline-block;
                                                                                                            padding: 5px;
                                                                                                            color: $blee;
                                                                                                          }
                                                                                                          foo: $bloo;
                                                                                                          empty {
                                                                                                            not-empty {
                                                                                                              background: lightgray;
                                                                                                              border: 1px solid blue;
                                                                                                              span {
                                                                                                                display: block;
                                                                                                                -webkit-box-sizing: border-box;
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                        div {
                                                                                                          color: red;
                                                                                                          width: 100%;
                                                                                                          p {
                                                                                                            margin: $blah;
                                                                                                            $blee: goodbye;
                                                                                                            padding: 10px 5px;
                                                                                                            a {
                                                                                                              display: inline-block;
                                                                                                              padding: 5px;
                                                                                                              color: $blee;
                                                                                                            }
                                                                                                            foo: $bloo;
                                                                                                            empty {
                                                                                                              not-empty {
                                                                                                                background: lightgray;
                                                                                                                border: 1px solid blue;
                                                                                                                span {
                                                                                                                  display: block;
                                                                                                                  -webkit-box-sizing: border-box;
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                                div {
                                                                                                  color: red;
                                                                                                  width: 100%;
                                                                                                  p {
                                                                                                    margin: $blah;
                                                                                                    $blee: goodbye;
                                                                                                    padding: 10px 5px;
                                                                                                    a {
                                                                                                      display: inline-block;
                                                                                                      padding: 5px;
                                                                                                      color: $blee;
                                                                                                    }
                                                                                                    foo: $bloo;
                                                                                                    empty {
                                                                                                      not-empty {
                                                                                                        background: lightgray;
                                                                                                        border: 1px solid blue;
                                                                                                        span {
                                                                                                          display: block;
                                                                                                          -webkit-box-sizing: border-box;
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                              p {
                                                                                                margin: $blah;
                                                                                                $blee: goodbye;
                                                                                                padding: 10px 5px;
                                                                                                a {
                                                                                                  display: inline-block;
                                                                                                  padding: 5px;
                                                                                                  color: $blee;
                                                                                                }
                                                                                                foo: $bloo;
                                                                                                empty {
                                                                                                  not-empty {
                                                                                                    background: lightgray;
                                                                                                    border: 1px solid blue;
                                                                                                    span {
                                                                                                      display: block;
                                                                                                      -webkit-box-sizing: border-box;
                                                                                                    }
                                                                                                    $blah: a b c;
                                                                                                    $bloo: "hello";

                                                                                                    div {
                                                                                                      color: red;
                                                                                                      width: 100%;
                                                                                                      p {
                                                                                                        margin: $blah;
                                                                                                        $blee: goodbye;
                                                                                                        padding: 10px 5px;
                                                                                                        a {
                                                                                                          display: inline-block;
                                                                                                          padding: 5px;
                                                                                                          color: $blee;
                                                                                                        }
                                                                                                        foo: $bloo;
                                                                                                        empty {
                                                                                                          not-empty {
                                                                                                            background: lightgray;
                                                                                                            border: 1px solid blue;
                                                                                                            span {
                                                                                                              display: block;
                                                                                                              -webkit-box-sizing: border-box;
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                      div {
                                                                                                        color: red;
                                                                                                        width: 100%;
                                                                                                        p {
                                                                                                          margin: $blah;
                                                                                                          $blee: goodbye;
                                                                                                          padding: 10px 5px;
                                                                                                          a {
                                                                                                            display: inline-block;
                                                                                                            padding: 5px;
                                                                                                            color: $blee;
                                                                                                          }
                                                                                                          foo: $bloo;
                                                                                                          empty {
                                                                                                            not-empty {
                                                                                                              background: lightgray;
                                                                                                              border: 1px solid blue;
                                                                                                              span {
                                                                                                                display: block;
                                                                                                                -webkit-box-sizing: border-box;
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                              div {
                                                                                                color: red;
                                                                                                width: 100%;
                                                                                                p {
                                                                                                  margin: $blah;
                                                                                                  $blee: goodbye;
                                                                                                  padding: 10px 5px;
                                                                                                  a {
                                                                                                    display: inline-block;
                                                                                                    padding: 5px;
                                                                                                    color: $blee;
                                                                                                  }
                                                                                                  foo: $bloo;
                                                                                                  empty {
                                                                                                    not-empty {
                                                                                                      background: lightgray;
                                                                                                      border: 1px solid blue;
                                                                                                      span {
                                                                                                        display: block;
                                                                                                        -webkit-box-sizing: border-box;
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                          foo: $bloo;
                                                                                          empty {
                                                                                            not-empty {
                                                                                              background: lightgray;
                                                                                              border: 1px solid blue;
                                                                                              span {
                                                                                                display: block;
                                                                                                -webkit-box-sizing: border-box;
                                                                                              }
                                                                                              $blah: a b c;
                                                                                              $bloo: "hello";

                                                                                              div {
                                                                                                color: red;
                                                                                                width: 100%;
                                                                                                p {
                                                                                                  margin: $blah;
                                                                                                  $blee: goodbye;
                                                                                                  padding: 10px 5px;
                                                                                                  a {
                                                                                                    display: inline-block;
                                                                                                    padding: 5px;
                                                                                                    color: $blee;
                                                                                                  }
                                                                                                  foo: $bloo;
                                                                                                  empty {
                                                                                                    not-empty {
                                                                                                      background: lightgray;
                                                                                                      border: 1px solid blue;
                                                                                                      span {
                                                                                                        display: block;
                                                                                                        -webkit-box-sizing: border-box;
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                                div {
                                                                                                  color: red;
                                                                                                  width: 100%;
                                                                                                  p {
                                                                                                    margin: $blah;
                                                                                                    $blee: goodbye;
                                                                                                    padding: 10px 5px;
                                                                                                    a {
                                                                                                      display: inline-block;
                                                                                                      padding: 5px;
                                                                                                      color: $blee;
                                                                                                    }
                                                                                                    foo: $bloo;
                                                                                                    empty {
                                                                                                      not-empty {
                                                                                                        background: lightgray;
                                                                                                        border: 1px solid blue;
                                                                                                        span {
                                                                                                          display: block;
                                                                                                          -webkit-box-sizing: border-box;
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                        div {
                                                                                          color: red;
                                                                                          width: 100%;
                                                                                          p {
                                                                                            margin: $blah;
                                                                                            $blee: goodbye;
                                                                                            padding: 10px 5px;
                                                                                            a {
                                                                                              display: inline-block;
                                                                                              padding: 5px;
                                                                                              color: $blee;
                                                                                            }
                                                                                            foo: $bloo;
                                                                                            empty {
                                                                                              not-empty {
                                                                                                background: lightgray;
                                                                                                border: 1px solid blue;
                                                                                                span {
                                                                                                  display: block;
                                                                                                  -webkit-box-sizing: border-box;
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                                div {
                                                                                  color: red;
                                                                                  width: 100%;
                                                                                  p {
                                                                                    margin: $blah;
                                                                                    $blee: goodbye;
                                                                                    padding: 10px 5px;
                                                                                    a {
                                                                                      display: inline-block;
                                                                                      padding: 5px;
                                                                                      color: $blee;
                                                                                    }
                                                                                    foo: $bloo;
                                                                                    empty {
                                                                                      not-empty {
                                                                                        background: lightgray;
                                                                                        border: 1px solid blue;
                                                                                        span {
                                                                                          display: block;
                                                                                          -webkit-box-sizing: border-box;
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                      $blah: a b c;
                                                      $bloo: "hello";

                                                      div {
                                                        color: red;
                                                        width: 100%;
                                                        $blah: a b c;
                                                        $bloo: "hello";

                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                                $blah: a b c;
                                                                $bloo: "hello";

                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                          div {
                                                            color: red;
                                                            width: 100%;
                                                            p {
                                                              margin: $blah;
                                                              $blee: goodbye;
                                                              padding: 10px 5px;
                                                              a {
                                                                display: inline-block;
                                                                padding: 5px;
                                                                color: $blee;
                                                              }
                                                              foo: $bloo;
                                                              empty {
                                                                not-empty {
                                                                  background: lightgray;
                                                                  border: 1px solid blue;
                                                                  span {
                                                                    display: block;
                                                                    -webkit-box-sizing: border-box;
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                        p {
                                                          margin: $blah;
                                                          $blee: goodbye;
                                                          padding: 10px 5px;
                                                          a {
                                                            display: inline-block;
                                                            padding: 5px;
                                                            color: $blee;
                                                            $blah: a b c;
                                                            $bloo: "hello";

                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              $blah: a b c;
                                                              $bloo: "hello";

                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                      $blah: a b c;
                                                                      $bloo: "hello";

                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                    $blah: a b c;
                                                                    $bloo: "hello";

                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                          foo: $bloo;
                                                          empty {
                                                            not-empty {
                                                              background: lightgray;
                                                              border: 1px solid blue;
                                                              span {
                                                                display: block;
                                                                -webkit-box-sizing: border-box;
                                                              }
                                                              $blah: a b c;
                                                              $bloo: "hello";

                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                        div {
                                                          color: red;
                                                          width: 100%;
                                                          p {
                                                            margin: $blah;
                                                            $blee: goodbye;
                                                            padding: 10px 5px;
                                                            a {
                                                              display: inline-block;
                                                              padding: 5px;
                                                              color: $blee;
                                                            }
                                                            foo: $bloo;
                                                            empty {
                                                              not-empty {
                                                                background: lightgray;
                                                                border: 1px solid blue;
                                                                span {
                                                                  display: block;
                                                                  -webkit-box-sizing: border-box;
                                                                }
                                                              }
                                                            }
                                                            $blah: a b c;
                                                            $bloo: "hello";

                                                            div {
                                                              color: red;
                                                              width: 100%;
                                                              $blah: a b c;
                                                              $bloo: "hello";

                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                      $blah: a b c;
                                                                      $bloo: "hello";

                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                              p {
                                                                margin: $blah;
                                                                $blee: goodbye;
                                                                padding: 10px 5px;
                                                                a {
                                                                  display: inline-block;
                                                                  padding: 5px;
                                                                  color: $blee;
                                                                  $blah: a b c;
                                                                  $bloo: "hello";

                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    $blah: a b c;
                                                                    $bloo: "hello";

                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                            $blah: a b c;
                                                                            $bloo: "hello";

                                                                            div {
                                                                              color: red;
                                                                              width: 100%;
                                                                              p {
                                                                                margin: $blah;
                                                                                $blee: goodbye;
                                                                                padding: 10px 5px;
                                                                                a {
                                                                                  display: inline-block;
                                                                                  padding: 5px;
                                                                                  color: $blee;
                                                                                }
                                                                                foo: $bloo;
                                                                                empty {
                                                                                  not-empty {
                                                                                    background: lightgray;
                                                                                    border: 1px solid blue;
                                                                                    span {
                                                                                      display: block;
                                                                                      -webkit-box-sizing: border-box;
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                              div {
                                                                                color: red;
                                                                                width: 100%;
                                                                                p {
                                                                                  margin: $blah;
                                                                                  $blee: goodbye;
                                                                                  padding: 10px 5px;
                                                                                  a {
                                                                                    display: inline-block;
                                                                                    padding: 5px;
                                                                                    color: $blee;
                                                                                  }
                                                                                  foo: $bloo;
                                                                                  empty {
                                                                                    not-empty {
                                                                                      background: lightgray;
                                                                                      border: 1px solid blue;
                                                                                      span {
                                                                                        display: block;
                                                                                        -webkit-box-sizing: border-box;
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                          $blah: a b c;
                                                                          $bloo: "hello";

                                                                          div {
                                                                            color: red;
                                                                            width: 100%;
                                                                            p {
                                                                              margin: $blah;
                                                                              $blee: goodbye;
                                                                              padding: 10px 5px;
                                                                              a {
                                                                                display: inline-block;
                                                                                padding: 5px;
                                                                                color: $blee;
                                                                              }
                                                                              foo: $bloo;
                                                                              empty {
                                                                                not-empty {
                                                                                  background: lightgray;
                                                                                  border: 1px solid blue;
                                                                                  span {
                                                                                    display: block;
                                                                                    -webkit-box-sizing: border-box;
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                            div {
                                                                              color: red;
                                                                              width: 100%;
                                                                              p {
                                                                                margin: $blah;
                                                                                $blee: goodbye;
                                                                                padding: 10px 5px;
                                                                                a {
                                                                                  display: inline-block;
                                                                                  padding: 5px;
                                                                                  color: $blee;
                                                                                }
                                                                                foo: $bloo;
                                                                                empty {
                                                                                  not-empty {
                                                                                    background: lightgray;
                                                                                    border: 1px solid blue;
                                                                                    span {
                                                                                      display: block;
                                                                                      -webkit-box-sizing: border-box;
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                                foo: $bloo;
                                                                empty {
                                                                  not-empty {
                                                                    background: lightgray;
                                                                    border: 1px solid blue;
                                                                    span {
                                                                      display: block;
                                                                      -webkit-box-sizing: border-box;
                                                                    }
                                                                    $blah: a b c;
                                                                    $bloo: "hello";

                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                              $blah: a b c;
                                                              $bloo: "hello";

                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                $blah: a b c;
                                                                $bloo: "hello";

                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                        $blah: a b c;
                                                                        $bloo: "hello";

                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                          div {
                                                                            color: red;
                                                                            width: 100%;
                                                                            p {
                                                                              margin: $blah;
                                                                              $blee: goodbye;
                                                                              padding: 10px 5px;
                                                                              a {
                                                                                display: inline-block;
                                                                                padding: 5px;
                                                                                color: $blee;
                                                                              }
                                                                              foo: $bloo;
                                                                              empty {
                                                                                not-empty {
                                                                                  background: lightgray;
                                                                                  border: 1px solid blue;
                                                                                  span {
                                                                                    display: block;
                                                                                    -webkit-box-sizing: border-box;
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                  div {
                                                                    color: red;
                                                                    width: 100%;
                                                                    p {
                                                                      margin: $blah;
                                                                      $blee: goodbye;
                                                                      padding: 10px 5px;
                                                                      a {
                                                                        display: inline-block;
                                                                        padding: 5px;
                                                                        color: $blee;
                                                                      }
                                                                      foo: $bloo;
                                                                      empty {
                                                                        not-empty {
                                                                          background: lightgray;
                                                                          border: 1px solid blue;
                                                                          span {
                                                                            display: block;
                                                                            -webkit-box-sizing: border-box;
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                    $blah: a b c;
                                                                    $bloo: "hello";

                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      $blah: a b c;
                                                                      $bloo: "hello";

                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                              $blah: a b c;
                                                                              $bloo: "hello";

                                                                              div {
                                                                                color: red;
                                                                                width: 100%;
                                                                                p {
                                                                                  margin: $blah;
                                                                                  $blee: goodbye;
                                                                                  padding: 10px 5px;
                                                                                  a {
                                                                                    display: inline-block;
                                                                                    padding: 5px;
                                                                                    color: $blee;
                                                                                  }
                                                                                  foo: $bloo;
                                                                                  empty {
                                                                                    not-empty {
                                                                                      background: lightgray;
                                                                                      border: 1px solid blue;
                                                                                      span {
                                                                                        display: block;
                                                                                        -webkit-box-sizing: border-box;
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                                div {
                                                                                  color: red;
                                                                                  width: 100%;
                                                                                  p {
                                                                                    margin: $blah;
                                                                                    $blee: goodbye;
                                                                                    padding: 10px 5px;
                                                                                    a {
                                                                                      display: inline-block;
                                                                                      padding: 5px;
                                                                                      color: $blee;
                                                                                    }
                                                                                    foo: $bloo;
                                                                                    empty {
                                                                                      not-empty {
                                                                                        background: lightgray;
                                                                                        border: 1px solid blue;
                                                                                        span {
                                                                                          display: block;
                                                                                          -webkit-box-sizing: border-box;
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                            $blah: a b c;
                                                                            $bloo: "hello";

                                                                            div {
                                                                              color: red;
                                                                              width: 100%;
                                                                              p {
                                                                                margin: $blah;
                                                                                $blee: goodbye;
                                                                                padding: 10px 5px;
                                                                                a {
                                                                                  display: inline-block;
                                                                                  padding: 5px;
                                                                                  color: $blee;
                                                                                }
                                                                                foo: $bloo;
                                                                                empty {
                                                                                  not-empty {
                                                                                    background: lightgray;
                                                                                    border: 1px solid blue;
                                                                                    span {
                                                                                      display: block;
                                                                                      -webkit-box-sizing: border-box;
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                              div {
                                                                                color: red;
                                                                                width: 100%;
                                                                                p {
                                                                                  margin: $blah;
                                                                                  $blee: goodbye;
                                                                                  padding: 10px 5px;
                                                                                  a {
                                                                                    display: inline-block;
                                                                                    padding: 5px;
                                                                                    color: $blee;
                                                                                  }
                                                                                  foo: $bloo;
                                                                                  empty {
                                                                                    not-empty {
                                                                                      background: lightgray;
                                                                                      border: 1px solid blue;
                                                                                      span {
                                                                                        display: block;
                                                                                        -webkit-box-sizing: border-box;
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                      $blah: a b c;
                                                                      $bloo: "hello";

                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                                div {
                                                                  color: red;
                                                                  width: 100%;
                                                                  p {
                                                                    margin: $blah;
                                                                    $blee: goodbye;
                                                                    padding: 10px 5px;
                                                                    a {
                                                                      display: inline-block;
                                                                      padding: 5px;
                                                                      color: $blee;
                                                                    }
                                                                    foo: $bloo;
                                                                    empty {
                                                                      not-empty {
                                                                        background: lightgray;
                                                                        border: 1px solid blue;
                                                                        span {
                                                                          display: block;
                                                                          -webkit-box-sizing: border-box;
                                                                        }
                                                                      }
                                                                    }
                                                                    $blah: a b c;
                                                                    $bloo: "hello";

                                                                    div {
                                                                      color: red;
                                                                      width: 100%;
                                                                      $blah: a b c;
                                                                      $bloo: "hello";

                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                              $blah: a b c;
                                                                              $bloo: "hello";

                                                                              div {
                                                                                color: red;
                                                                                width: 100%;
                                                                                p {
                                                                                  margin: $blah;
                                                                                  $blee: goodbye;
                                                                                  padding: 10px 5px;
                                                                                  a {
                                                                                    display: inline-block;
                                                                                    padding: 5px;
                                                                                    color: $blee;
                                                                                  }
                                                                                  foo: $bloo;
                                                                                  empty {
                                                                                    not-empty {
                                                                                      background: lightgray;
                                                                                      border: 1px solid blue;
                                                                                      span {
                                                                                        display: block;
                                                                                        -webkit-box-sizing: border-box;
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                                div {
                                                                                  color: red;
                                                                                  width: 100%;
                                                                                  p {
                                                                                    margin: $blah;
                                                                                    $blee: goodbye;
                                                                                    padding: 10px 5px;
                                                                                    a {
                                                                                      display: inline-block;
                                                                                      padding: 5px;
                                                                                      color: $blee;
                                                                                    }
                                                                                    foo: $bloo;
                                                                                    empty {
                                                                                      not-empty {
                                                                                        background: lightgray;
                                                                                        border: 1px solid blue;
                                                                                        span {
                                                                                          display: block;
                                                                                          -webkit-box-sizing: border-box;
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                        div {
                                                                          color: red;
                                                                          width: 100%;
                                                                          p {
                                                                            margin: $blah;
                                                                            $blee: goodbye;
                                                                            padding: 10px 5px;
                                                                            a {
                                                                              display: inline-block;
                                                                              padding: 5px;
                                                                              color: $blee;
                                                                            }
                                                                            foo: $bloo;
                                                                            empty {
                                                                              not-empty {
                                                                                background: lightgray;
                                                                                border: 1px solid blue;
                                                                                span {
                                                                                  display: block;
                                                                                  -webkit-box-sizing: border-box;
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                      p {
                                                                        margin: $blah;
                                                                        $blee: goodbye;
                                                                        padding: 10px 5px;
                                                                        a {
                                                                          display: inline-block;
                                                                          padding: 5px;
                                                                          color: $blee;
                                                                          $blah: a b c;
                                                                          $bloo: "hello";

                                                                          div {
                                                                            color: red;
                                                                            width: 100%;
                                                                            $blah: a b c;
                                                                            $bloo: "hello";

                                                                            div {
                                                                              color: red;
                                                                              width: 100%;
                                                                              p {
                                                                                margin: $blah;
                                                                                $blee: goodbye;
                                                                                padding: 10px 5px;
                                                                                a {
                                                                                  display: inline-block;
                                                                                  padding: 5px;
                                                                                  color: $blee;
                                                                                }
                                                                                foo: $bloo;
                                                                                empty {
                                                                                  not-empty {
                                                                                    background: lightgray;
                                                                                    border: 1px solid blue;
                                                                                    span {
                                                                                      display: block;
                                                                                      -webkit-box-sizing: border-box;
                                                                                    }
                                                                                    $blah: a b c;
                                                                                    $bloo: "hello";

                                                                                    div {
                                                                                      color: red;
                                                                                      width: 100%;
                                                                                      p {
                                                                                        margin: $blah;
                                                                                        $blee: goodbye;
                                                                                        padding: 10px 5px;
                                                                                        a {
                                                                                          display: inline-block;
                                                                                          padding: 5px;
                                                                                          color: $blee;
                                                                                        }
                                                                                        foo: $bloo;
                                                                                        empty {
                                                                                          not-empty {
                                                                                            background: lightgray;
                                                                                            border: 1px solid blue;
                                                                                            span {
                                                                                              display: block;
                                                                                              -webkit-box-sizing: border-box;
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                      div {
                                                                                        color: red;
                                                                                        width: 100%;
                                                                                        p {
                                                                                          margin: $blah;
                                                                                          $blee: goodbye;
                                                                                          padding: 10px 5px;
                                                                                          a {
                                                                                            display: inline-block;
                                                                                            padding: 5px;
                                                                                            color: $blee;
                                                                                          }
                                                                                          foo: $bloo;
                                                                                          empty {
                                                                                            not-empty {
                                                                                              background: lightgray;
                                                                                              border: 1px solid blue;
                                                                                              span {
                                                                                                display: block;
                                                                                                -webkit-box-sizing: border-box;
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                              div {
                                                                                color: red;
                                                                                width: 100%;
                                                                                p {
                                                                                  margin: $blah;
                                                                                  $blee: goodbye;
                                                                                  padding: 10px 5px;
                                                                                  a {
                                                                                    display: inline-block;
                                                                                    padding: 5px;
                                                                                    color: $blee;
                                                                                  }
                                                                                  foo: $bloo;
                                                                                  empty {
                                                                                    not-empty {
                                                                                      background: lightgray;
                                                                                      border: 1px solid blue;
                                                                                      span {
                                                                                        display: block;
                                                                                        -webkit-box-sizing: border-box;
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                            p {
                                                                              margin: $blah;
                                                                              $blee: goodbye;
                                                                              padding: 10px 5px;
                                                                              a {
                                                                                display: inline-block;
                                                                                padding: 5px;
                                                                                color: $blee;
                                                                              }
                                                                              foo: $bloo;
                                                                              empty {
                                                                                not-empty {
                                                                                  background: lightgray;
                                                                                  border: 1px solid blue;
                                                                                  span {
                                                                                    display: block;
                                                                                    -webkit-box-sizing: border-box;
                                                                                  }
                                                                                  $blah: a b c;
                                                                                  $bloo: "hello";

                                                                                  div {
                                                                                    color: red;
                                                                                    width: 100%;
                                                                                    p {
                                                                                      margin: $blah;
                                                                                      $blee: goodbye;
                                                                                      padding: 10px 5px;
                                                                                      a {
                                                                                        display: inline-block;
                                                                                        padding: 5px;
                                                                                        color: $blee;
                                                                                      }
                                                                                      foo: $bloo;
                                                                                      empty {
                                                                                        not-empty {
                                                                                          background: lightgray;
                                                                                          border: 1px solid blue;
                                                                                          span {
                                                                                            display: block;
                                                                                            -webkit-box-sizing: border-box;
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                    div {
                                                                                      color: red;
                                                                                      width: 100%;
                                                                                      p {
                                                                                        margin: $blah;
                                                                                        $blee: goodbye;
                                                                                        padding: 10px 5px;
                                                                                        a {
                                                                                          display: inline-block;
                                                                                          padding: 5px;
                                                                                          color: $blee;
                                                                                        }
                                                                                        foo: $bloo;
                                                                                        empty {
                                                                                          not-empty {
                                                                                            background: lightgray;
                                                                                            border: 1px solid blue;
                                                                                            span {
                                                                                              display: block;
                                                                                              -webkit-box-sizing: border-box;
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                            div {
                                                                              color: red;
                                                                              width: 100%;
                                                                              p {
                                                                                margin: $blah;
                                                                                $blee: goodbye;
                                                                                padding: 10px 5px;
                                                                                a {
                                                                                  display: inline-block;
                                                                                  padding: 5px;
                                                                                  color: $blee;
                                                                                }
                                                                                foo: $bloo;
                                                                                empty {
                                                                                  not-empty {
                                                                                    background: lightgray;
                                                                                    border: 1px solid blue;
                                                                                    span {
                                                                                      display: block;
                                                                                      -webkit-box-sizing: border-box;
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                        foo: $bloo;
                                                                        empty {
                                                                          not-empty {
                                                                            background: lightgray;
                                                                            border: 1px solid blue;
                                                                            span {
                                                                              display: block;
                                                                              -webkit-box-sizing: border-box;
                                                                            }
                                                                            $blah: a b c;
                                                                            $bloo: "hello";

                                                                            div {
                                                                              color: red;
                                                                              width: 100%;
                                                                              p {
                                                                                margin: $blah;
                                                                                $blee: goodbye;
                                                                                padding: 10px 5px;
                                                                                a {
                                                                                  display: inline-block;
                                                                                  padding: 5px;
                                                                                  color: $blee;
                                                                                }
                                                                                foo: $bloo;
                                                                                empty {
                                                                                  not-empty {
                                                                                    background: lightgray;
                                                                                    border: 1px solid blue;
                                                                                    span {
                                                                                      display: block;
                                                                                      -webkit-box-sizing: border-box;
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                              div {
                                                                                color: red;
                                                                                width: 100%;
                                                                                p {
                                                                                  margin: $blah;
                                                                                  $blee: goodbye;
                                                                                  padding: 10px 5px;
                                                                                  a {
                                                                                    display: inline-block;
                                                                                    padding: 5px;
                                                                                    color: $blee;
                                                                                  }
                                                                                  foo: $bloo;
                                                                                  empty {
                                                                                    not-empty {
                                                                                      background: lightgray;
                                                                                      border: 1px solid blue;
                                                                                      span {
                                                                                        display: block;
                                                                                        -webkit-box-sizing: border-box;
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                            $blah: a b c;
                                                                            $bloo: "hello";

                                                                            div {
                                                                              color: red;
                                                                              width: 100%;
                                                                              $blah: a b c;
                                                                              $bloo: "hello";

                                                                              div {
                                                                                color: red;
                                                                                width: 100%;
                                                                                p {
                                                                                  margin: $blah;
                                                                                  $blee: goodbye;
                                                                                  padding: 10px 5px;
                                                                                  a {
                                                                                    display: inline-block;
                                                                                    padding: 5px;
                                                                                    color: $blee;
                                                                                  }
                                                                                  foo: $bloo;
                                                                                  empty {
                                                                                    not-empty {
                                                                                      background: lightgray;
                                                                                      border: 1px solid blue;
                                                                                      span {
                                                                                        display: block;
                                                                                        -webkit-box-sizing: border-box;
                                                                                      }
                                                                                      $blah: a b c;
                                                                                      $bloo: "hello";

                                                                                      div {
                                                                                        color: red;
                                                                                        width: 100%;
                                                                                        p {
                                                                                          margin: $blah;
                                                                                          $blee: goodbye;
                                                                                          padding: 10px 5px;
                                                                                          a {
                                                                                            display: inline-block;
                                                                                            padding: 5px;
                                                                                            color: $blee;
                                                                                          }
                                                                                          foo: $bloo;
                                                                                          empty {
                                                                                            not-empty {
                                                                                              background: lightgray;
                                                                                              border: 1px solid blue;
                                                                                              span {
                                                                                                display: block;
                                                                                                -webkit-box-sizing: border-box;
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                        div {
                                                                                          color: red;
                                                                                          width: 100%;
                                                                                          p {
                                                                                            margin: $blah;
                                                                                            $blee: goodbye;
                                                                                            padding: 10px 5px;
                                                                                            a {
                                                                                              display: inline-block;
                                                                                              padding: 5px;
                                                                                              color: $blee;
                                                                                            }
                                                                                            foo: $bloo;
                                                                                            empty {
                                                                                              not-empty {
                                                                                                background: lightgray;
                                                                                                border: 1px solid blue;
                                                                                                span {
                                                                                                  display: block;
                                                                                                  -webkit-box-sizing: border-box;
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                                div {
                                                                                  color: red;
                                                                                  width: 100%;
                                                                                  p {
                                                                                    margin: $blah;
                                                                                    $blee: goodbye;
                                                                                    padding: 10px 5px;
                                                                                    a {
                                                                                      display: inline-block;
                                                                                      padding: 5px;
                                                                                      color: $blee;
                                                                                    }
                                                                                    foo: $bloo;
                                                                                    empty {
                                                                                      not-empty {
                                                                                        background: lightgray;
                                                                                        border: 1px solid blue;
                                                                                        span {
                                                                                          display: block;
                                                                                          -webkit-box-sizing: border-box;
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                              p {
                                                                                margin: $blah;
                                                                                $blee: goodbye;
                                                                                padding: 10px 5px;
                                                                                a {
                                                                                  display: inline-block;
                                                                                  padding: 5px;
                                                                                  color: $blee;
                                                                                  $blah: a b c;
                                                                                  $bloo: "hello";

                                                                                  div {
                                                                                    color: red;
                                                                                    width: 100%;
                                                                                    $blah: a b c;
                                                                                    $bloo: "hello";

                                                                                    div {
                                                                                      color: red;
                                                                                      width: 100%;
                                                                                      p {
                                                                                        margin: $blah;
                                                                                        $blee: goodbye;
                                                                                        padding: 10px 5px;
                                                                                        a {
                                                                                          display: inline-block;
                                                                                          padding: 5px;
                                                                                          color: $blee;
                                                                                        }
                                                                                        foo: $bloo;
                                                                                        empty {
                                                                                          not-empty {
                                                                                            background: lightgray;
                                                                                            border: 1px solid blue;
                                                                                            span {
                                                                                              display: block;
                                                                                              -webkit-box-sizing: border-box;
                                                                                            }
                                                                                            $blah: a b c;
                                                                                            $bloo: "hello";

                                                                                            div {
                                                                                              color: red;
                                                                                              width: 100%;
                                                                                              p {
                                                                                                margin: $blah;
                                                                                                $blee: goodbye;
                                                                                                padding: 10px 5px;
                                                                                                a {
                                                                                                  display: inline-block;
                                                                                                  padding: 5px;
                                                                                                  color: $blee;
                                                                                                }
                                                                                                foo: $bloo;
                                                                                                empty {
                                                                                                  not-empty {
                                                                                                    background: lightgray;
                                                                                                    border: 1px solid blue;
                                                                                                    span {
                                                                                                      display: block;
                                                                                                      -webkit-box-sizing: border-box;
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                              div {
                                                                                                color: red;
                                                                                                width: 100%;
                                                                                                p {
                                                                                                  margin: $blah;
                                                                                                  $blee: goodbye;
                                                                                                  padding: 10px 5px;
                                                                                                  a {
                                                                                                    display: inline-block;
                                                                                                    padding: 5px;
                                                                                                    color: $blee;
                                                                                                  }
                                                                                                  foo: $bloo;
                                                                                                  empty {
                                                                                                    not-empty {
                                                                                                      background: lightgray;
                                                                                                      border: 1px solid blue;
                                                                                                      span {
                                                                                                        display: block;
                                                                                                        -webkit-box-sizing: border-box;
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                      div {
                                                                                        color: red;
                                                                                        width: 100%;
                                                                                        p {
                                                                                          margin: $blah;
                                                                                          $blee: goodbye;
                                                                                          padding: 10px 5px;
                                                                                          a {
                                                                                            display: inline-block;
                                                                                            padding: 5px;
                                                                                            color: $blee;
                                                                                          }
                                                                                          foo: $bloo;
                                                                                          empty {
                                                                                            not-empty {
                                                                                              background: lightgray;
                                                                                              border: 1px solid blue;
                                                                                              span {
                                                                                                display: block;
                                                                                                -webkit-box-sizing: border-box;
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                    p {
                                                                                      margin: $blah;
                                                                                      $blee: goodbye;
                                                                                      padding: 10px 5px;
                                                                                      a {
                                                                                        display: inline-block;
                                                                                        padding: 5px;
                                                                                        color: $blee;
                                                                                      }
                                                                                      foo: $bloo;
                                                                                      empty {
                                                                                        not-empty {
                                                                                          background: lightgray;
                                                                                          border: 1px solid blue;
                                                                                          span {
                                                                                            display: block;
                                                                                            -webkit-box-sizing: border-box;
                                                                                          }
                                                                                          $blah: a b c;
                                                                                          $bloo: "hello";

                                                                                          div {
                                                                                            color: red;
                                                                                            width: 100%;
                                                                                            p {
                                                                                              margin: $blah;
                                                                                              $blee: goodbye;
                                                                                              padding: 10px 5px;
                                                                                              a {
                                                                                                display: inline-block;
                                                                                                padding: 5px;
                                                                                                color: $blee;
                                                                                              }
                                                                                              foo: $bloo;
                                                                                              empty {
                                                                                                not-empty {
                                                                                                  background: lightgray;
                                                                                                  border: 1px solid blue;
                                                                                                  span {
                                                                                                    display: block;
                                                                                                    -webkit-box-sizing: border-box;
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                            div {
                                                                                              color: red;
                                                                                              width: 100%;
                                                                                              p {
                                                                                                margin: $blah;
                                                                                                $blee: goodbye;
                                                                                                padding: 10px 5px;
                                                                                                a {
                                                                                                  display: inline-block;
                                                                                                  padding: 5px;
                                                                                                  color: $blee;
                                                                                                }
                                                                                                foo: $bloo;
                                                                                                empty {
                                                                                                  not-empty {
                                                                                                    background: lightgray;
                                                                                                    border: 1px solid blue;
                                                                                                    span {
                                                                                                      display: block;
                                                                                                      -webkit-box-sizing: border-box;
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                    div {
                                                                                      color: red;
                                                                                      width: 100%;
                                                                                      p {
                                                                                        margin: $blah;
                                                                                        $blee: goodbye;
                                                                                        padding: 10px 5px;
                                                                                        a {
                                                                                          display: inline-block;
                                                                                          padding: 5px;
                                                                                          color: $blee;
                                                                                        }
                                                                                        foo: $bloo;
                                                                                        empty {
                                                                                          not-empty {
                                                                                            background: lightgray;
                                                                                            border: 1px solid blue;
                                                                                            span {
                                                                                              display: block;
                                                                                              -webkit-box-sizing: border-box;
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                                foo: $bloo;
                                                                                empty {
                                                                                  not-empty {
                                                                                    background: lightgray;
                                                                                    border: 1px solid blue;
                                                                                    span {
                                                                                      display: block;
                                                                                      -webkit-box-sizing: border-box;
                                                                                    }
                                                                                    $blah: a b c;
                                                                                    $bloo: "hello";

                                                                                    div {
                                                                                      color: red;
                                                                                      width: 100%;
                                                                                      p {
                                                                                        margin: $blah;
                                                                                        $blee: goodbye;
                                                                                        padding: 10px 5px;
                                                                                        a {
                                                                                          display: inline-block;
                                                                                          padding: 5px;
                                                                                          color: $blee;
                                                                                        }
                                                                                        foo: $bloo;
                                                                                        empty {
                                                                                          not-empty {
                                                                                            background: lightgray;
                                                                                            border: 1px solid blue;
                                                                                            span {
                                                                                              display: block;
                                                                                              -webkit-box-sizing: border-box;
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                      div {
                                                                                        color: red;
                                                                                        width: 100%;
                                                                                        p {
                                                                                          margin: $blah;
                                                                                          $blee: goodbye;
                                                                                          padding: 10px 5px;
                                                                                          a {
                                                                                            display: inline-block;
                                                                                            padding: 5px;
                                                                                            color: $blee;
                                                                                          }
                                                                                          foo: $bloo;
                                                                                          empty {
                                                                                            not-empty {
                                                                                              background: lightgray;
                                                                                              border: 1px solid blue;
                                                                                              span {
                                                                                                display: block;
                                                                                                -webkit-box-sizing: border-box;
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                              div {
                                                                                color: red;
                                                                                width: 100%;
                                                                                p {
                                                                                  margin: $blah;
                                                                                  $blee: goodbye;
                                                                                  padding: 10px 5px;
                                                                                  a {
                                                                                    display: inline-block;
                                                                                    padding: 5px;
                                                                                    color: $blee;
                                                                                  }
                                                                                  foo: $bloo;
                                                                                  empty {
                                                                                    not-empty {
                                                                                      background: lightgray;
                                                                                      border: 1px solid blue;
                                                                                      span {
                                                                                        display: block;
                                                                                        -webkit-box-sizing: border-box;
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                  $blah: a b c;
                                                                                  $bloo: "hello";

                                                                                  div {
                                                                                    color: red;
                                                                                    width: 100%;
                                                                                    $blah: a b c;
                                                                                    $bloo: "hello";

                                                                                    div {
                                                                                      color: red;
                                                                                      width: 100%;
                                                                                      p {
                                                                                        margin: $blah;
                                                                                        $blee: goodbye;
                                                                                        padding: 10px 5px;
                                                                                        a {
                                                                                          display: inline-block;
                                                                                          padding: 5px;
                                                                                          color: $blee;
                                                                                        }
                                                                                        foo: $bloo;
                                                                                        empty {
                                                                                          not-empty {
                                                                                            background: lightgray;
                                                                                            border: 1px solid blue;
                                                                                            span {
                                                                                              display: block;
                                                                                              -webkit-box-sizing: border-box;
                                                                                            }
                                                                                            $blah: a b c;
                                                                                            $bloo: "hello";

                                                                                            div {
                                                                                              color: red;
                                                                                              width: 100%;
                                                                                              p {
                                                                                                margin: $blah;
                                                                                                $blee: goodbye;
                                                                                                padding: 10px 5px;
                                                                                                a {
                                                                                                  display: inline-block;
                                                                                                  padding: 5px;
                                                                                                  color: $blee;
                                                                                                }
                                                                                                foo: $bloo;
                                                                                                empty {
                                                                                                  not-empty {
                                                                                                    background: lightgray;
                                                                                                    border: 1px solid blue;
                                                                                                    span {
                                                                                                      display: block;
                                                                                                      -webkit-box-sizing: border-box;
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                              div {
                                                                                                color: red;
                                                                                                width: 100%;
                                                                                                p {
                                                                                                  margin: $blah;
                                                                                                  $blee: goodbye;
                                                                                                  padding: 10px 5px;
                                                                                                  a {
                                                                                                    display: inline-block;
                                                                                                    padding: 5px;
                                                                                                    color: $blee;
                                                                                                  }
                                                                                                  foo: $bloo;
                                                                                                  empty {
                                                                                                    not-empty {
                                                                                                      background: lightgray;
                                                                                                      border: 1px solid blue;
                                                                                                      span {
                                                                                                        display: block;
                                                                                                        -webkit-box-sizing: border-box;
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                      div {
                                                                                        color: red;
                                                                                        width: 100%;
                                                                                        p {
                                                                                          margin: $blah;
                                                                                          $blee: goodbye;
                                                                                          padding: 10px 5px;
                                                                                          a {
                                                                                            display: inline-block;
                                                                                            padding: 5px;
                                                                                            color: $blee;
                                                                                          }
                                                                                          foo: $bloo;
                                                                                          empty {
                                                                                            not-empty {
                                                                                              background: lightgray;
                                                                                              border: 1px solid blue;
                                                                                              span {
                                                                                                display: block;
                                                                                                -webkit-box-sizing: border-box;
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                    p {
                                                                                      margin: $blah;
                                                                                      $blee: goodbye;
                                                                                      padding: 10px 5px;
                                                                                      a {
                                                                                        display: inline-block;
                                                                                        padding: 5px;
                                                                                        color: $blee;
                                                                                        $blah: a b c;
                                                                                        $bloo: "hello";

                                                                                        div {
                                                                                          color: red;
                                                                                          width: 100%;
                                                                                          $blah: a b c;
                                                                                          $bloo: "hello";

                                                                                          div {
                                                                                            color: red;
                                                                                            width: 100%;
                                                                                            p {
                                                                                              margin: $blah;
                                                                                              $blee: goodbye;
                                                                                              padding: 10px 5px;
                                                                                              a {
                                                                                                display: inline-block;
                                                                                                padding: 5px;
                                                                                                color: $blee;
                                                                                              }
                                                                                              foo: $bloo;
                                                                                              empty {
                                                                                                not-empty {
                                                                                                  background: lightgray;
                                                                                                  border: 1px solid blue;
                                                                                                  span {
                                                                                                    display: block;
                                                                                                    -webkit-box-sizing: border-box;
                                                                                                  }
                                                                                                  $blah: a b c;
                                                                                                  $bloo: "hello";

                                                                                                  div {
                                                                                                    color: red;
                                                                                                    width: 100%;
                                                                                                    p {
                                                                                                      margin: $blah;
                                                                                                      $blee: goodbye;
                                                                                                      padding: 10px 5px;
                                                                                                      a {
                                                                                                        display: inline-block;
                                                                                                        padding: 5px;
                                                                                                        color: $blee;
                                                                                                      }
                                                                                                      foo: $bloo;
                                                                                                      empty {
                                                                                                        not-empty {
                                                                                                          background: lightgray;
                                                                                                          border: 1px solid blue;
                                                                                                          span {
                                                                                                            display: block;
                                                                                                            -webkit-box-sizing: border-box;
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                    div {
                                                                                                      color: red;
                                                                                                      width: 100%;
                                                                                                      p {
                                                                                                        margin: $blah;
                                                                                                        $blee: goodbye;
                                                                                                        padding: 10px 5px;
                                                                                                        a {
                                                                                                          display: inline-block;
                                                                                                          padding: 5px;
                                                                                                          color: $blee;
                                                                                                        }
                                                                                                        foo: $bloo;
                                                                                                        empty {
                                                                                                          not-empty {
                                                                                                            background: lightgray;
                                                                                                            border: 1px solid blue;
                                                                                                            span {
                                                                                                              display: block;
                                                                                                              -webkit-box-sizing: border-box;
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                            div {
                                                                                              color: red;
                                                                                              width: 100%;
                                                                                              p {
                                                                                                margin: $blah;
                                                                                                $blee: goodbye;
                                                                                                padding: 10px 5px;
                                                                                                a {
                                                                                                  display: inline-block;
                                                                                                  padding: 5px;
                                                                                                  color: $blee;
                                                                                                }
                                                                                                foo: $bloo;
                                                                                                empty {
                                                                                                  not-empty {
                                                                                                    background: lightgray;
                                                                                                    border: 1px solid blue;
                                                                                                    span {
                                                                                                      display: block;
                                                                                                      -webkit-box-sizing: border-box;
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                          p {
                                                                                            margin: $blah;
                                                                                            $blee: goodbye;
                                                                                            padding: 10px 5px;
                                                                                            a {
                                                                                              display: inline-block;
                                                                                              padding: 5px;
                                                                                              color: $blee;
                                                                                            }
                                                                                            foo: $bloo;
                                                                                            empty {
                                                                                              not-empty {
                                                                                                background: lightgray;
                                                                                                border: 1px solid blue;
                                                                                                span {
                                                                                                  display: block;
                                                                                                  -webkit-box-sizing: border-box;
                                                                                                }
                                                                                                $blah: a b c;
                                                                                                $bloo: "hello";

                                                                                                div {
                                                                                                  color: red;
                                                                                                  width: 100%;
                                                                                                  p {
                                                                                                    margin: $blah;
                                                                                                    $blee: goodbye;
                                                                                                    padding: 10px 5px;
                                                                                                    a {
                                                                                                      display: inline-block;
                                                                                                      padding: 5px;
                                                                                                      color: $blee;
                                                                                                    }
                                                                                                    foo: $bloo;
                                                                                                    empty {
                                                                                                      not-empty {
                                                                                                        background: lightgray;
                                                                                                        border: 1px solid blue;
                                                                                                        span {
                                                                                                          display: block;
                                                                                                          -webkit-box-sizing: border-box;
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                  div {
                                                                                                    color: red;
                                                                                                    width: 100%;
                                                                                                    p {
                                                                                                      margin: $blah;
                                                                                                      $blee: goodbye;
                                                                                                      padding: 10px 5px;
                                                                                                      a {
                                                                                                        display: inline-block;
                                                                                                        padding: 5px;
                                                                                                        color: $blee;
                                                                                                      }
                                                                                                      foo: $bloo;
                                                                                                      empty {
                                                                                                        not-empty {
                                                                                                          background: lightgray;
                                                                                                          border: 1px solid blue;
                                                                                                          span {
                                                                                                            display: block;
                                                                                                            -webkit-box-sizing: border-box;
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                          div {
                                                                                            color: red;
                                                                                            width: 100%;
                                                                                            p {
                                                                                              margin: $blah;
                                                                                              $blee: goodbye;
                                                                                              padding: 10px 5px;
                                                                                              a {
                                                                                                display: inline-block;
                                                                                                padding: 5px;
                                                                                                color: $blee;
                                                                                              }
                                                                                              foo: $bloo;
                                                                                              empty {
                                                                                                not-empty {
                                                                                                  background: lightgray;
                                                                                                  border: 1px solid blue;
                                                                                                  span {
                                                                                                    display: block;
                                                                                                    -webkit-box-sizing: border-box;
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                      foo: $bloo;
                                                                                      empty {
                                                                                        not-empty {
                                                                                          background: lightgray;
                                                                                          border: 1px solid blue;
                                                                                          span {
                                                                                            display: block;
                                                                                            -webkit-box-sizing: border-box;
                                                                                          }
                                                                                          $blah: a b c;
                                                                                          $bloo: "hello";

                                                                                          div {
                                                                                            color: red;
                                                                                            width: 100%;
                                                                                            p {
                                                                                              margin: $blah;
                                                                                              $blee: goodbye;
                                                                                              padding: 10px 5px;
                                                                                              a {
                                                                                                display: inline-block;
                                                                                                padding: 5px;
                                                                                                color: $blee;
                                                                                              }
                                                                                              foo: $bloo;
                                                                                              empty {
                                                                                                not-empty {
                                                                                                  background: lightgray;
                                                                                                  border: 1px solid blue;
                                                                                                  span {
                                                                                                    display: block;
                                                                                                    -webkit-box-sizing: border-box;
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                            div {
                                                                                              color: red;
                                                                                              width: 100%;
                                                                                              p {
                                                                                                margin: $blah;
                                                                                                $blee: goodbye;
                                                                                                padding: 10px 5px;
                                                                                                a {
                                                                                                  display: inline-block;
                                                                                                  padding: 5px;
                                                                                                  color: $blee;
                                                                                                }
                                                                                                foo: $bloo;
                                                                                                empty {
                                                                                                  not-empty {
                                                                                                    background: lightgray;
                                                                                                    border: 1px solid blue;
                                                                                                    span {
                                                                                                      display: block;
                                                                                                      -webkit-box-sizing: border-box;
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                    $blah: a b c;
                                                                                    $bloo: "hello";

                                                                                    div {
                                                                                      color: red;
                                                                                      width: 100%;
                                                                                      $blah: a b c;
                                                                                      $bloo: "hello";

                                                                                      div {
                                                                                        color: red;
                                                                                        width: 100%;
                                                                                        p {
                                                                                          margin: $blah;
                                                                                          $blee: goodbye;
                                                                                          padding: 10px 5px;
                                                                                          a {
                                                                                            display: inline-block;
                                                                                            padding: 5px;
                                                                                            color: $blee;
                                                                                          }
                                                                                          foo: $bloo;
                                                                                          empty {
                                                                                            not-empty {
                                                                                              background: lightgray;
                                                                                              border: 1px solid blue;
                                                                                              span {
                                                                                                display: block;
                                                                                                -webkit-box-sizing: border-box;
                                                                                              }
                                                                                              $blah: a b c;
                                                                                              $bloo: "hello";

                                                                                              div {
                                                                                                color: red;
                                                                                                width: 100%;
                                                                                                p {
                                                                                                  margin: $blah;
                                                                                                  $blee: goodbye;
                                                                                                  padding: 10px 5px;
                                                                                                  a {
                                                                                                    display: inline-block;
                                                                                                    padding: 5px;
                                                                                                    color: $blee;
                                                                                                  }
                                                                                                  foo: $bloo;
                                                                                                  empty {
                                                                                                    not-empty {
                                                                                                      background: lightgray;
                                                                                                      border: 1px solid blue;
                                                                                                      span {
                                                                                                        display: block;
                                                                                                        -webkit-box-sizing: border-box;
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                                div {
                                                                                                  color: red;
                                                                                                  width: 100%;
                                                                                                  p {
                                                                                                    margin: $blah;
                                                                                                    $blee: goodbye;
                                                                                                    padding: 10px 5px;
                                                                                                    a {
                                                                                                      display: inline-block;
                                                                                                      padding: 5px;
                                                                                                      color: $blee;
                                                                                                    }
                                                                                                    foo: $bloo;
                                                                                                    empty {
                                                                                                      not-empty {
                                                                                                        background: lightgray;
                                                                                                        border: 1px solid blue;
                                                                                                        span {
                                                                                                          display: block;
                                                                                                          -webkit-box-sizing: border-box;
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                        div {
                                                                                          color: red;
                                                                                          width: 100%;
                                                                                          p {
                                                                                            margin: $blah;
                                                                                            $blee: goodbye;
                                                                                            padding: 10px 5px;
                                                                                            a {
                                                                                              display: inline-block;
                                                                                              padding: 5px;
                                                                                              color: $blee;
                                                                                            }
                                                                                            foo: $bloo;
                                                                                            empty {
                                                                                              not-empty {
                                                                                                background: lightgray;
                                                                                                border: 1px solid blue;
                                                                                                span {
                                                                                                  display: block;
                                                                                                  -webkit-box-sizing: border-box;
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                      p {
                                                                                        margin: $blah;
                                                                                        $blee: goodbye;
                                                                                        padding: 10px 5px;
                                                                                        a {
                                                                                          display: inline-block;
                                                                                          padding: 5px;
                                                                                          color: $blee;
                                                                                          $blah: a b c;
                                                                                          $bloo: "hello";

                                                                                          div {
                                                                                            color: red;
                                                                                            width: 100%;
                                                                                            $blah: a b c;
                                                                                            $bloo: "hello";

                                                                                            div {
                                                                                              color: red;
                                                                                              width: 100%;
                                                                                              p {
                                                                                                margin: $blah;
                                                                                                $blee: goodbye;
                                                                                                padding: 10px 5px;
                                                                                                a {
                                                                                                  display: inline-block;
                                                                                                  padding: 5px;
                                                                                                  color: $blee;
                                                                                                }
                                                                                                foo: $bloo;
                                                                                                empty {
                                                                                                  not-empty {
                                                                                                    background: lightgray;
                                                                                                    border: 1px solid blue;
                                                                                                    span {
                                                                                                      display: block;
                                                                                                      -webkit-box-sizing: border-box;
                                                                                                    }
                                                                                                    $blah: a b c;
                                                                                                    $bloo: "hello";

                                                                                                    div {
                                                                                                      color: red;
                                                                                                      width: 100%;
                                                                                                      p {
                                                                                                        margin: $blah;
                                                                                                        $blee: goodbye;
                                                                                                        padding: 10px 5px;
                                                                                                        a {
                                                                                                          display: inline-block;
                                                                                                          padding: 5px;
                                                                                                          color: $blee;
                                                                                                        }
                                                                                                        foo: $bloo;
                                                                                                        empty {
                                                                                                          not-empty {
                                                                                                            background: lightgray;
                                                                                                            border: 1px solid blue;
                                                                                                            span {
                                                                                                              display: block;
                                                                                                              -webkit-box-sizing: border-box;
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                      div {
                                                                                                        color: red;
                                                                                                        width: 100%;
                                                                                                        p {
                                                                                                          margin: $blah;
                                                                                                          $blee: goodbye;
                                                                                                          padding: 10px 5px;
                                                                                                          a {
                                                                                                            display: inline-block;
                                                                                                            padding: 5px;
                                                                                                            color: $blee;
                                                                                                          }
                                                                                                          foo: $bloo;
                                                                                                          empty {
                                                                                                            not-empty {
                                                                                                              background: lightgray;
                                                                                                              border: 1px solid blue;
                                                                                                              span {
                                                                                                                display: block;
                                                                                                                -webkit-box-sizing: border-box;
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                              div {
                                                                                                color: red;
                                                                                                width: 100%;
                                                                                                p {
                                                                                                  margin: $blah;
                                                                                                  $blee: goodbye;
                                                                                                  padding: 10px 5px;
                                                                                                  a {
                                                                                                    display: inline-block;
                                                                                                    padding: 5px;
                                                                                                    color: $blee;
                                                                                                  }
                                                                                                  foo: $bloo;
                                                                                                  empty {
                                                                                                    not-empty {
                                                                                                      background: lightgray;
                                                                                                      border: 1px solid blue;
                                                                                                      span {
                                                                                                        display: block;
                                                                                                        -webkit-box-sizing: border-box;
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                            p {
                                                                                              margin: $blah;
                                                                                              $blee: goodbye;
                                                                                              padding: 10px 5px;
                                                                                              a {
                                                                                                display: inline-block;
                                                                                                padding: 5px;
                                                                                                color: $blee;
                                                                                              }
                                                                                              foo: $bloo;
                                                                                              empty {
                                                                                                not-empty {
                                                                                                  background: lightgray;
                                                                                                  border: 1px solid blue;
                                                                                                  span {
                                                                                                    display: block;
                                                                                                    -webkit-box-sizing: border-box;
                                                                                                  }
                                                                                                  $blah: a b c;
                                                                                                  $bloo: "hello";

                                                                                                  div {
                                                                                                    color: red;
                                                                                                    width: 100%;
                                                                                                    p {
                                                                                                      margin: $blah;
                                                                                                      $blee: goodbye;
                                                                                                      padding: 10px 5px;
                                                                                                      a {
                                                                                                        display: inline-block;
                                                                                                        padding: 5px;
                                                                                                        color: $blee;
                                                                                                      }
                                                                                                      foo: $bloo;
                                                                                                      empty {
                                                                                                        not-empty {
                                                                                                          background: lightgray;
                                                                                                          border: 1px solid blue;
                                                                                                          span {
                                                                                                            display: block;
                                                                                                            -webkit-box-sizing: border-box;
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                    div {
                                                                                                      color: red;
                                                                                                      width: 100%;
                                                                                                      p {
                                                                                                        margin: $blah;
                                                                                                        $blee: goodbye;
                                                                                                        padding: 10px 5px;
                                                                                                        a {
                                                                                                          display: inline-block;
                                                                                                          padding: 5px;
                                                                                                          color: $blee;
                                                                                                        }
                                                                                                        foo: $bloo;
                                                                                                        empty {
                                                                                                          not-empty {
                                                                                                            background: lightgray;
                                                                                                            border: 1px solid blue;
                                                                                                            span {
                                                                                                              display: block;
                                                                                                              -webkit-box-sizing: border-box;
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                            div {
                                                                                              color: red;
                                                                                              width: 100%;
                                                                                              p {
                                                                                                margin: $blah;
                                                                                                $blee: goodbye;
                                                                                                padding: 10px 5px;
                                                                                                a {
                                                                                                  display: inline-block;
                                                                                                  padding: 5px;
                                                                                                  color: $blee;
                                                                                                }
                                                                                                foo: $bloo;
                                                                                                empty {
                                                                                                  not-empty {
                                                                                                    background: lightgray;
                                                                                                    border: 1px solid blue;
                                                                                                    span {
                                                                                                      display: block;
                                                                                                      -webkit-box-sizing: border-box;
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                        foo: $bloo;
                                                                                        empty {
                                                                                          not-empty {
                                                                                            background: lightgray;
                                                                                            border: 1px solid blue;
                                                                                            span {
                                                                                              display: block;
                                                                                              -webkit-box-sizing: border-box;
                                                                                            }
                                                                                            $blah: a b c;
                                                                                            $bloo: "hello";

                                                                                            div {
                                                                                              color: red;
                                                                                              width: 100%;
                                                                                              p {
                                                                                                margin: $blah;
                                                                                                $blee: goodbye;
                                                                                                padding: 10px 5px;
                                                                                                a {
                                                                                                  display: inline-block;
                                                                                                  padding: 5px;
                                                                                                  color: $blee;
                                                                                                }
                                                                                                foo: $bloo;
                                                                                                empty {
                                                                                                  not-empty {
                                                                                                    background: lightgray;
                                                                                                    border: 1px solid blue;
                                                                                                    span {
                                                                                                      display: block;
                                                                                                      -webkit-box-sizing: border-box;
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                              div {
                                                                                                color: red;
                                                                                                width: 100%;
                                                                                                p {
                                                                                                  margin: $blah;
                                                                                                  $blee: goodbye;
                                                                                                  padding: 10px 5px;
                                                                                                  a {
                                                                                                    display: inline-block;
                                                                                                    padding: 5px;
                                                                                                    color: $blee;
                                                                                                  }
                                                                                                  foo: $bloo;
                                                                                                  empty {
                                                                                                    not-empty {
                                                                                                      background: lightgray;
                                                                                                      border: 1px solid blue;
                                                                                                      span {
                                                                                                        display: block;
                                                                                                        -webkit-box-sizing: border-box;
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                      div {
                                                                                        color: red;
                                                                                        width: 100%;
                                                                                        p {
                                                                                          margin: $blah;
                                                                                          $blee: goodbye;
                                                                                          padding: 10px 5px;
                                                                                          a {
                                                                                            display: inline-block;
                                                                                            padding: 5px;
                                                                                            color: $blee;
                                                                                          }
                                                                                          foo: $bloo;
                                                                                          empty {
                                                                                            not-empty {
                                                                                              background: lightgray;
                                                                                              border: 1px solid blue;
                                                                                              span {
                                                                                                display: block;
                                                                                                -webkit-box-sizing: border-box;
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                          $blah: a b c;
                                                                                          $bloo: "hello";

                                                                                          div {
                                                                                            color: red;
                                                                                            width: 100%;
                                                                                            $blah: a b c;
                                                                                            $bloo: "hello";

                                                                                            div {
                                                                                              color: red;
                                                                                              width: 100%;
                                                                                              p {
                                                                                                margin: $blah;
                                                                                                $blee: goodbye;
                                                                                                padding: 10px 5px;
                                                                                                a {
                                                                                                  display: inline-block;
                                                                                                  padding: 5px;
                                                                                                  color: $blee;
                                                                                                }
                                                                                                foo: $bloo;
                                                                                                empty {
                                                                                                  not-empty {
                                                                                                    background: lightgray;
                                                                                                    border: 1px solid blue;
                                                                                                    span {
                                                                                                      display: block;
                                                                                                      -webkit-box-sizing: border-box;
                                                                                                    }
                                                                                                    $blah: a b c;
                                                                                                    $bloo: "hello";

                                                                                                    div {
                                                                                                      color: red;
                                                                                                      width: 100%;
                                                                                                      p {
                                                                                                        margin: $blah;
                                                                                                        $blee: goodbye;
                                                                                                        padding: 10px 5px;
                                                                                                        a {
                                                                                                          display: inline-block;
                                                                                                          padding: 5px;
                                                                                                          color: $blee;
                                                                                                        }
                                                                                                        foo: $bloo;
                                                                                                        empty {
                                                                                                          not-empty {
                                                                                                            background: lightgray;
                                                                                                            border: 1px solid blue;
                                                                                                            span {
                                                                                                              display: block;
                                                                                                              -webkit-box-sizing: border-box;
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                      div {
                                                                                                        color: red;
                                                                                                        width: 100%;
                                                                                                        p {
                                                                                                          margin: $blah;
                                                                                                          $blee: goodbye;
                                                                                                          padding: 10px 5px;
                                                                                                          a {
                                                                                                            display: inline-block;
                                                                                                            padding: 5px;
                                                                                                            color: $blee;
                                                                                                          }
                                                                                                          foo: $bloo;
                                                                                                          empty {
                                                                                                            not-empty {
                                                                                                              background: lightgray;
                                                                                                              border: 1px solid blue;
                                                                                                              span {
                                                                                                                display: block;
                                                                                                                -webkit-box-sizing: border-box;
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                              div {
                                                                                                color: red;
                                                                                                width: 100%;
                                                                                                p {
                                                                                                  margin: $blah;
                                                                                                  $blee: goodbye;
                                                                                                  padding: 10px 5px;
                                                                                                  a {
                                                                                                    display: inline-block;
                                                                                                    padding: 5px;
                                                                                                    color: $blee;
                                                                                                  }
                                                                                                  foo: $bloo;
                                                                                                  empty {
                                                                                                    not-empty {
                                                                                                      background: lightgray;
                                                                                                      border: 1px solid blue;
                                                                                                      span {
                                                                                                        display: block;
                                                                                                        -webkit-box-sizing: border-box;
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                            p {
                                                                                              margin: $blah;
                                                                                              $blee: goodbye;
                                                                                              padding: 10px 5px;
                                                                                              a {
                                                                                                display: inline-block;
                                                                                                padding: 5px;
                                                                                                color: $blee;
                                                                                                $blah: a b c;
                                                                                                $bloo: "hello";

                                                                                                div {
                                                                                                  color: red;
                                                                                                  width: 100%;
                                                                                                  $blah: a b c;
                                                                                                  $bloo: "hello";

                                                                                                  div {
                                                                                                    color: red;
                                                                                                    width: 100%;
                                                                                                    p {
                                                                                                      margin: $blah;
                                                                                                      $blee: goodbye;
                                                                                                      padding: 10px 5px;
                                                                                                      a {
                                                                                                        display: inline-block;
                                                                                                        padding: 5px;
                                                                                                        color: $blee;
                                                                                                      }
                                                                                                      foo: $bloo;
                                                                                                      empty {
                                                                                                        not-empty {
                                                                                                          background: lightgray;
                                                                                                          border: 1px solid blue;
                                                                                                          span {
                                                                                                            display: block;
                                                                                                            -webkit-box-sizing: border-box;
                                                                                                          }
                                                                                                          $blah: a b c;
                                                                                                          $bloo: "hello";

                                                                                                          div {
                                                                                                            color: red;
                                                                                                            width: 100%;
                                                                                                            p {
                                                                                                              margin: $blah;
                                                                                                              $blee: goodbye;
                                                                                                              padding: 10px 5px;
                                                                                                              a {
                                                                                                                display: inline-block;
                                                                                                                padding: 5px;
                                                                                                                color: $blee;
                                                                                                              }
                                                                                                              foo: $bloo;
                                                                                                              empty {
                                                                                                                not-empty {
                                                                                                                  background: lightgray;
                                                                                                                  border: 1px solid blue;
                                                                                                                  span {
                                                                                                                    display: block;
                                                                                                                    -webkit-box-sizing: border-box;
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                            div {
                                                                                                              color: red;
                                                                                                              width: 100%;
                                                                                                              p {
                                                                                                                margin: $blah;
                                                                                                                $blee: goodbye;
                                                                                                                padding: 10px 5px;
                                                                                                                a {
                                                                                                                  display: inline-block;
                                                                                                                  padding: 5px;
                                                                                                                  color: $blee;
                                                                                                                }
                                                                                                                foo: $bloo;
                                                                                                                empty {
                                                                                                                  not-empty {
                                                                                                                    background: lightgray;
                                                                                                                    border: 1px solid blue;
                                                                                                                    span {
                                                                                                                      display: block;
                                                                                                                      -webkit-box-sizing: border-box;
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                    div {
                                                                                                      color: red;
                                                                                                      width: 100%;
                                                                                                      p {
                                                                                                        margin: $blah;
                                                                                                        $blee: goodbye;
                                                                                                        padding: 10px 5px;
                                                                                                        a {
                                                                                                          display: inline-block;
                                                                                                          padding: 5px;
                                                                                                          color: $blee;
                                                                                                        }
                                                                                                        foo: $bloo;
                                                                                                        empty {
                                                                                                          not-empty {
                                                                                                            background: lightgray;
                                                                                                            border: 1px solid blue;
                                                                                                            span {
                                                                                                              display: block;
                                                                                                              -webkit-box-sizing: border-box;
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                  p {
                                                                                                    margin: $blah;
                                                                                                    $blee: goodbye;
                                                                                                    padding: 10px 5px;
                                                                                                    a {
                                                                                                      display: inline-block;
                                                                                                      padding: 5px;
                                                                                                      color: $blee;
                                                                                                    }
                                                                                                    foo: $bloo;
                                                                                                    empty {
                                                                                                      not-empty {
                                                                                                        background: lightgray;
                                                                                                        border: 1px solid blue;
                                                                                                        span {
                                                                                                          display: block;
                                                                                                          -webkit-box-sizing: border-box;
                                                                                                        }
                                                                                                        $blah: a b c;
                                                                                                        $bloo: "hello";

                                                                                                        div {
                                                                                                          color: red;
                                                                                                          width: 100%;
                                                                                                          p {
                                                                                                            margin: $blah;
                                                                                                            $blee: goodbye;
                                                                                                            padding: 10px 5px;
                                                                                                            a {
                                                                                                              display: inline-block;
                                                                                                              padding: 5px;
                                                                                                              color: $blee;
                                                                                                            }
                                                                                                            foo: $bloo;
                                                                                                            empty {
                                                                                                              not-empty {
                                                                                                                background: lightgray;
                                                                                                                border: 1px solid blue;
                                                                                                                span {
                                                                                                                  display: block;
                                                                                                                  -webkit-box-sizing: border-box;
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                          div {
                                                                                                            color: red;
                                                                                                            width: 100%;
                                                                                                            p {
                                                                                                              margin: $blah;
                                                                                                              $blee: goodbye;
                                                                                                              padding: 10px 5px;
                                                                                                              a {
                                                                                                                display: inline-block;
                                                                                                                padding: 5px;
                                                                                                                color: $blee;
                                                                                                              }
                                                                                                              foo: $bloo;
                                                                                                              empty {
                                                                                                                not-empty {
                                                                                                                  background: lightgray;
                                                                                                                  border: 1px solid blue;
                                                                                                                  span {
                                                                                                                    display: block;
                                                                                                                    -webkit-box-sizing: border-box;
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                  div {
                                                                                                    color: red;
                                                                                                    width: 100%;
                                                                                                    p {
                                                                                                      margin: $blah;
                                                                                                      $blee: goodbye;
                                                                                                      padding: 10px 5px;
                                                                                                      a {
                                                                                                        display: inline-block;
                                                                                                        padding: 5px;
                                                                                                        color: $blee;
                                                                                                      }
                                                                                                      foo: $bloo;
                                                                                                      empty {
                                                                                                        not-empty {
                                                                                                          background: lightgray;
                                                                                                          border: 1px solid blue;
                                                                                                          span {
                                                                                                            display: block;
                                                                                                            -webkit-box-sizing: border-box;
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                              foo: $bloo;
                                                                                              empty {
                                                                                                not-empty {
                                                                                                  background: lightgray;
                                                                                                  border: 1px solid blue;
                                                                                                  span {
                                                                                                    display: block;
                                                                                                    -webkit-box-sizing: border-box;
                                                                                                  }
                                                                                                  $blah: a b c;
                                                                                                  $bloo: "hello";

                                                                                                  div {
                                                                                                    color: red;
                                                                                                    width: 100%;
                                                                                                    p {
                                                                                                      margin: $blah;
                                                                                                      $blee: goodbye;
                                                                                                      padding: 10px 5px;
                                                                                                      a {
                                                                                                        display: inline-block;
                                                                                                        padding: 5px;
                                                                                                        color: $blee;
                                                                                                      }
                                                                                                      foo: $bloo;
                                                                                                      empty {
                                                                                                        not-empty {
                                                                                                          background: lightgray;
                                                                                                          border: 1px solid blue;
                                                                                                          span {
                                                                                                            display: block;
                                                                                                            -webkit-box-sizing: border-box;
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                    div {
                                                                                                      color: red;
                                                                                                      width: 100%;
                                                                                                      p {
                                                                                                        margin: $blah;
                                                                                                        $blee: goodbye;
                                                                                                        padding: 10px 5px;
                                                                                                        a {
                                                                                                          display: inline-block;
                                                                                                          padding: 5px;
                                                                                                          color: $blee;
                                                                                                        }
                                                                                                        foo: $bloo;
                                                                                                        empty {
                                                                                                          not-empty {
                                                                                                            background: lightgray;
                                                                                                            border: 1px solid blue;
                                                                                                            span {
                                                                                                              display: block;
                                                                                                              -webkit-box-sizing: border-box;
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                            div {
                                                                                              color: red;
                                                                                              width: 100%;
                                                                                              p {
                                                                                                margin: $blah;
                                                                                                $blee: goodbye;
                                                                                                padding: 10px 5px;
                                                                                                a {
                                                                                                  display: inline-block;
                                                                                                  padding: 5px;
                                                                                                  color: $blee;
                                                                                                }
                                                                                                foo: $bloo;
                                                                                                empty {
                                                                                                  not-empty {
                                                                                                    background: lightgray;
                                                                                                    border: 1px solid blue;
                                                                                                    span {
                                                                                                      display: block;
                                                                                                      -webkit-box-sizing: border-box;
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                    div {
                                                                                      color: red;
                                                                                      width: 100%;
                                                                                      p {
                                                                                        margin: $blah;
                                                                                        $blee: goodbye;
                                                                                        padding: 10px 5px;
                                                                                        a {
                                                                                          display: inline-block;
                                                                                          padding: 5px;
                                                                                          color: $blee;
                                                                                        }
                                                                                        foo: $bloo;
                                                                                        empty {
                                                                                          not-empty {
                                                                                            background: lightgray;
                                                                                            border: 1px solid blue;
                                                                                            span {
                                                                                              display: block;
                                                                                              -webkit-box-sizing: border-box;
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                      div {
                                                                        color: red;
                                                                        width: 100%;
                                                                        p {
                                                                          margin: $blah;
                                                                          $blee: goodbye;
                                                                          padding: 10px 5px;
                                                                          a {
                                                                            display: inline-block;
                                                                            padding: 5px;
                                                                            color: $blee;
                                                                          }
                                                                          foo: $bloo;
                                                                          empty {
                                                                            not-empty {
                                                                              background: lightgray;
                                                                              border: 1px solid blue;
                                                                              span {
                                                                                display: block;
                                                                                -webkit-box-sizing: border-box;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                              div {
                                                                color: red;
                                                                width: 100%;
                                                                p {
                                                                  margin: $blah;
                                                                  $blee: goodbye;
                                                                  padding: 10px 5px;
                                                                  a {
                                                                    display: inline-block;
                                                                    padding: 5px;
                                                                    color: $blee;
                                                                  }
                                                                  foo: $bloo;
                                                                  empty {
                                                                    not-empty {
                                                                      background: lightgray;
                                                                      border: 1px solid blue;
                                                                      span {
                                                                        display: block;
                                                                        -webkit-box-sizing: border-box;
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                          div {
                                            color: red;
                                            width: 100%;
                                            p {
                                              margin: $blah;
                                              $blee: goodbye;
                                              padding: 10px 5px;
                                              a {
                                                display: inline-block;
                                                padding: 5px;
                                                color: $blee;
                                              }
                                              foo: $bloo;
                                              empty {
                                                not-empty {
                                                  background: lightgray;
                                                  border: 1px solid blue;
                                                  span {
                                                    display: block;
                                                    -webkit-box-sizing: border-box;
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
            div {
              color: red;
              width: 100%;
              p {
                margin: $blah;
                $blee: goodbye;
                padding: 10px 5px;
                a {
                  display: inline-block;
                  padding: 5px;
                  color: $blee;
                }
                foo: $bloo;
                empty {
                  not-empty {
                    background: lightgray;
                    border: 1px solid blue;
                    span {
                      display: block;
                      -webkit-box-sizing: border-box;
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
}